OC.L10N.register(
    "news",
    {
    "News" : "Správy",
    "an article" : "článok",
    "Someone" : "Niekto",
    "%1$s shared \"%2$s\" with you" : "%1$s vám sprístupnil \"%2$s\"",
    "{user} shared \"{article}\" with you" : "{user} zdieľal s Vami \"{article}\"",
    "News feeds" : "Spravodajský kanál",
    "Unread articles" : "Neprečítané články",
    "News folders" : "Adresáre s Novinovými článkami",
    "News articles" : "Novinové články",
    "Shared with me" : "Zdieľané so mnou",
    "Untitled article" : "Neoznačený článok",
    "An RSS/Atom feed reader" : "RSS/Atom čítačka",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "Reader Aplikácia na čítanie kanálov RSS/Atom pre Nextcloud\n\n- 📲 Synchronizujte svoje kanály s viacerými [klientmi] pre mobily alebo počítače (https://nextcloud.github.io/news/clients/)\n- 🔄 Automatické aktualizácie vašich spravodajských kanálov\n- 🆓 Voľný a otvorený zdroj pod AGPLv3, žiadne reklamy ani prémiové funkcie\n\n** Na to, aby táto aplikácia fungovala, je momentálne potrebný Systemový Cron **\n\nPožiadavky nájdete [tu] (https://nextcloud.github.io/news/install/#dependencies)\n\nZoznam zmien je k dispozícii [tu] (https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nVytvorte [hlásenie chyby] (https://github.com/nextcloud/news/issues/new/choose)\n\nVytvorte [žiadosť o funkciu] (https://github.com/nextcloud/news/discussions/new)\n\nNahlásiť [problém s kanálom] (https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Sťahovanie",
    "Close" : "Zavrieť",
    "Internal server error!" : "Interná chyba servera!",
    "Unknown error!" : "Neznáma chyba!",
    "Web address" : "Web adresa",
    "Please check your data/nextcloud.log file for additional information!" : "Ďalšie informácie nájdete v súbore data/nextcloud.log!",
    "No folder" : "Žiaden priečinok",
    "Folder name" : "Názov priečinka",
    "Username" : "Používateľské meno",
    "Password" : "Heslo",
    "Feed exists already!" : "Kanál už existuje!",
    "New folder" : "Nový priečinok",
    "Folder exists already!" : "Priečinok už existuje!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Prihlasovacie údaje pre HTTP Basic Auth musia byť uložené nezašifrované! Každý s prístupom k serveru alebo databáze si ich bude môcť prečítať!",
    "Credentials" : "Prihlasovacie údaje",
    "Auto discover Feed" : "Automaticky objavovať Informačný kanál",
    "Subscribe" : "Prihlásiť odber",
    "Successfully updated news configuration" : "Nastavenie pre Novinky úspešne aktualizované",
    "Unable to update news config" : "Nepodarilo sa aktualizovať nastavenie pre Novinky",
    "Logo purge has never been run." : "Vyčistenie loga ešte nebolo vykonané.",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "Posledné vyčistenie loga prebehlo {relativeLastLogoPurge}. Niečo nie je v poriadku.",
    "Last logo purge job ran {relativeLastLogoPurge}." : "Posledná úloha na vyčistenie loga bežala {relativeLastLogoPurge}.",
    "No job execution data available. The cron job may not be running properly." : "Žiadne údaje o vykonaní úlohy. Cron úloha nemusí bežať správne.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Posledné vykonanie úlohy bežalo {relativeTime}. Niečo je v neporiadku.",
    "Last job ran {relativeTime}." : "Posledná úloha bežala {relativeTime}.",
    "Maximum read count per feed" : "Maximálny počet noviniek pre kanál",
    "Maximum redirects" : "Maximum presmerovaní",
    "Feed fetcher timeout" : "Vypršal čas pre sťahovanie článkov",
    "Explore Service URL" : "Prehľadať URL služby",
    "Update interval" : "Interval aktualizácie",
    "Use system cron for updates" : "Použiť systémový plánovač cron pre aktualizácie",
    "Disable this if you use a custom updater." : "Toto vypnite ak používate vlastný updater.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Určuje najvyšší počet článkov, ktoré sú dostupné na prečítanie z jednotlivých kanálov a nebudú zmazané pri čistení; ak sa staré články po prečítaní znovu objavia, navýšte túto hodnotu; záporné hodnoty ako napr. -1 túto funkciu vypnú.",
    "Delete unread articles automatically" : "Zmazať neprečítané články automaticky",
    "Enable this if you also want to delete unread articles." : "Toto povoľte ak chcete zmazať aj neprečítané články.",
    "How many redirects the feed fetcher should follow." : "Koľko presmerovaní sa má sledovať pri sťahovaní článkov.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maximálna hodnota v sekundách pre aktualizáciu RSS alebo Atom zdroja; ak sa prekročí, aktualizácia sa ukončí.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Ak je poskytnuté, URL tejto služby bude dotazované na zobrazenie zdrojov v sekcii prieskumného kanála. Ak chcete prejsť na vstavanú službu prieskumu, nechajte toto pole prázdne.",
    "Interval in seconds in which the feeds will be updated." : "Interval v sekundách, počas ktorého sa kanály aktualizujú.",
    "Use next update time for feed updates" : "Pre aktualizácie informačného kanála použiť čas ďalšej aktualizácie",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Povoľte túto možnosť, ak chcete použiť vypočítaný čas ďalšej aktualizácie na aktualizácie informačného kanála. Zakázať aktualizáciu informačných kanálov výlučne na základe intervalu aktualizácie.",
    "Article list" : "Zoznam článkov",
    "Article details" : "Detail článku",
    "No article selected" : "Žiadny článok nebol vybraný.",
    "Please select an article from the list." : "Vyberte článok zo zoznamu.",
    "Show all articles" : "Zobraziť všetky články",
    "Move feed" : "Presunúť kanál",
    "Please select the new folder" : "Prosím, vyberte novú zložku",
    "Move" : "Presunúť",
    "User Name" : "Úžívateľské meno",
    "Share" : "Zdieľať",
    "Share with" : "Zdieľať s",
    "Share with {num} users" : "Zdieľať s {num} užívateľmi",
    "Rename Folder" : "Premenovať Priečinok",
    "Are you sure you want to delete?" : "Naozaj chcete vymazať?",
    "Unable to save starred open state" : "Nemôžem uložiť označený stav otvorenia",
    "Mark read" : "Označ ako prečítané",
    "All articles" : "Všetky články",
    "Recently viewed" : "Nedávno zobrazené",
    "Starred" : "S hviezdičkou",
    "Has feeds with errors!" : "Má kanály s chybami!",
    "Explore" : "Preskúmať",
    "Feed settings" : "Nastavenia kanála",
    "News settings" : "Nastavenia noviniek",
    "Rename" : "Premenovať",
    "Delete" : "Zmazať",
    "Rename Feed" : "Premenovať kanál",
    "Open Feed URL" : "Otvoriť adresu kanála",
    "Unpin from top" : "Odobnuť zhora",
    "Pin to top" : "Pripnúť nahor",
    "Newest first" : "Od najnovších",
    "Oldest first" : "Od najstarších",
    "Default order" : "Predvolené poradie",
    "Enable full text" : "Povoliť plný text",
    "Disable full text" : "Zakázať plný text",
    "Mark as unread on update" : "Označiť ako neprečítané pri aktualizácii",
    "Keep read status on update" : "Zachovať stav prečítania pri aktualizácii",
    "Sync disabled" : "Synchronizácia vypnutá",
    "Sync enabled" : "Synchronizácia povolená",
    "from" : "Od",
    "Previous Item" : "Predchodzia položka",
    "Next Item" : "Ďalšia položka",
    "Share within Instance" : "Zdieľať v rámci inštancie",
    "Toggle star article" : "Prepnúť hviezdičku",
    "Mark unread" : "Označiť ako neprečítané",
    "Close details" : "Zatvoriť podrobnosti",
    "shared by" : "zdieľané s",
    "by" : "od",
    "Play audio" : "Prehrávanie audia",
    "Download audio" : "Stiahnuť audio",
    "Download video" : "Stiahnuť video",
    "Refresh list" : "Obnoviť zoznam",
    "Open website" : "Otvoriť webstránku",
    "Keep article unread" : "Ponechať ako neprečítaný",
    "Toggle keep current article unread" : "Prepnúť ponechanie článku ako neprečítaný",
    "Remove keep article unread" : "Odstrániť označenie ako neprečítaný",
    "Default" : "Predvolené",
    "Compact" : "Kompaktný",
    "Screenreader" : "Čítačka obrazovky",
    "Vertical" : "Vertikálne",
    "Horizontal" : "Horizontálne",
    "Off" : "Vypnúť",
    "Always" : "Vždy",
    "Never" : "Nikdy",
    "Please select a valid OPML file" : "Prosím, vyberte platný súbor OPML",
    "File successfully uploaded" : "Súbor bol úspešne nahraný",
    "Error uploading the opml file" : "Chyba pri nahrávaní súboru opml",
    "Error connecting to the server" : "Chyba pri pripojení k serveru",
    "Error retrieving the opml file" : "Chyba pri získavaní súboru opml",
    "Please select a valid json file" : "Vyberte prosím platný súbor json",
    "Error uploading the json file" : "Chyba pri nahrávaní súboru json",
    "Error retrieving the json file" : "Chyba pri získavaní json súboru",
    "General" : "Všeobecné",
    "Disable mark read through scrolling" : "Vypnúť označovanie ako prečítané pri posune",
    "Reverse ordering (oldest on top)" : "Opačné zoradenie (od najstarších)",
    "Disable automatic refresh" : "Zakázať automatické obnovenie",
    "Media" : "Média",
    "Appearance" : "Vzhľad",
    "Display mode" : "Mód zobrazenia",
    "Split mode" : "Rozdelený režim",
    "Import" : "Import",
    "Export" : "Export",
    "Abonnements (OPML)" : "Abonenti (OPML)",
    "Importing feeds" : "Importovanie kanálov",
    "Please wait" : "Čakajte prosím",
    "Articles (JSON)" : "Články (JSON)",
    "Keyboard shortcuts" : "Klávesové skratky",
    "Refresh" : "Obnoviť",
    "Screenreader mode only" : "Režim iba pre čítače obrazovky",
    "Jump to previous article" : "Ísť na predošlý článok",
    "Jump to next article" : "Ísť na ďalší článok",
    "Item navigation and control" : "Navigácia a ovládanie položiek",
    "Open article in new tab" : "Otvoriť článok na novej karte",
    "Show article details in compact view" : "Zobraziť podrobnosti článku v kompaktnom zobrazení",
    "Close article details in compact view" : "Nezobrazovať podrobnosti článku v kompaktnom zobrazení",
    "Feed/Folder navigation and control" : "Navigácia a ovládanie kanálu/složky",
    "Jump to previous feed" : "Prejsť na predchádzajúci kanál",
    "Jump to next feed" : "Prejsť na ďalší kanál",
    "Jump to previous folder" : "Prejsť do predchádzajúcej složky",
    "Jump to next folder" : "Prejsť na ďalšiu zložku",
    "Mark current articles feed/folder as read" : "Označiť aktuálny kanál/priečinok s článkami ako prečítaný",
    "Resources" : "Zdroje",
    "Last update" : "Posledná aktualizácia",
    "Time when the feed was last downloaded" : "Čas, kedy bol informačný kanál naposledy stiahnutý",
    "Next update" : "Nasledujúca aktualizácia",
    "Time when the next feed update will be done" : "Čas, kedy bude informačný kanál najbližšie aktualizovaný",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Iba ak je aktivovaný v nastaveniach správcu, inak sa používa pravidelný interval aktualizácie",
    "Articles per update" : "Počet článkov pre aktualizáciu",
    "Maximum number of articles reached in a feed update" : "V aktualizácii informačného kanála bol dosiahnutý maximálny počet článkov",
    "Error Count" : "Počet chýb",
    "Number of errors that have occurred since the last successful feed update" : "Počet chýb, ktoré sa vyskytli od poslednej úspešnej aktualizácie informačného kanála",
    "Title" : "Názov",
    "Folder" : "Priečinok",
    "Not available" : "Nie je dostupné",
    "All Articles" : "Všetky články",
    "No feeds found to add" : "Žiadne kanály na pridanie neboli nájdené.",
    "Subscribe to" : "Odobrať z",
    "Unread Articles" : "Neprečítané články",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Bol zistený ajax alebo webcron mód. Vaše kanály sa nebudú aktualizovať!",
    "How to set up the operating system cron" : "Ako nastaviť cron v operačnom systéme",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Nainštalovať a nastaviť rýchlejší paralelný systém aktualizácie používajúci aktualizačné API modulu Noviniek"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
