OC.L10N.register(
    "news",
    {
    "%1$s shared \"%2$s\" with you" : "%1$s en deus rannet \"%2$s\" deoc'h",
    "Download" : "Pellgargañ",
    "Close" : "Serriñ",
    "Web address" : "Chom-lec'h web",
    "No folder" : "Teuliad ebet",
    "Folder name" : "Anv teuliad",
    "Username" : "anv implijer",
    "Password" : "Ger-tremen",
    "New folder" : "Teuliad nevez",
    "Credentials" : "Kretaatoù",
    "Move" : "Diplasañ",
    "Share" : "Rannan",
    "All articles" : "Pep pennad",
    "Rename" : "Adenvel",
    "Delete" : "Dilemel",
    "Newest first" : "An hini nevesañ da gentañ",
    "Oldest first" : "An hini kozhoñ da gentañ",
    "by" : "gant",
    "Play audio" : "Loc'hañ an audio",
    "Download video" : "Pellkargañ ar video",
    "Open website" : "Digor al lec'hienn-web",
    "Never" : "James",
    "General" : "Hollek",
    "Import" : "Emporzhiañ ",
    "Refresh" : "Freskaat",
    "Title" : "Titl",
    "Folder" : "Teuliad"
},
"nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
