OC.L10N.register(
    "news",
    {
    "News" : "Noutăți",
    "%1$s shared \"%2$s\" with you" : "%1$s a partajat fișierul \"%2$s\" cu tine",
    "News feeds" : "Fluxuri de știri",
    "Unread articles" : "Articole necitite",
    "News folders" : "Fluxuri de știri",
    "Shared with me" : "Partajat cu mine",
    "An RSS/Atom feed reader" : "Un cititor de fluxuri RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 O aplicație pentru citirea știrilor RSS/Atom Feed pentru Nextcloud\n\n- 📲 Sincronizați-vă fluxurile cu dispozitive mobile sau desktop multiple [clienți](https://nextcloud.github.io/news/clients/)\n- 🔄 Actualizarea automată a fluxurilor de știri\n- 🆓 Gratis și open source sub AGPLv3, fără ads sau funcționalități premium\n\n**System Cron este necesar în prezent pentru funcționarea aplicației**\n\nCerințele se pot găsi [here](https://nextcloud.github.io/news/install/#dependencies)\n\nLista Changelog este disponibilă la [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreați un [raport de bug](https://github.com/nextcloud/news/issues/new/choose)\n\nCreați o [solicitare de funcționalități](https://github.com/nextcloud/news/discussions/new)\n\nRaportați o [problemă de feed](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Descarcă",
    "Close" : "Închide",
    "Web address" : "Adresă web",
    "No folder" : "Niciun director",
    "Folder name" : "Denumire director",
    "Username" : "Utilizator",
    "Password" : "Parolă",
    "Feed exists already!" : "Fluxul există deja!",
    "New folder" : "Director nou",
    "Folder exists already!" : "Directorul există deja!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Informațiile de autentificare HTTP trebuie să fie stocate decriptate! Toate persoanele ce au access la acest server sau bază de date vor putea accesa aceste infromații!",
    "Credentials" : "Detalii de autentificare",
    "Auto discover Feed" : "Descoperă automat fluxurile de date",
    "Subscribe" : "Abonare",
    "Maximum read count per feed" : "Număr maxim de citiri pentru un flux",
    "Maximum redirects" : "Numărul maxim de redirectări",
    "Feed fetcher timeout" : "Intervalul de așteptat al programului ce adună fluxurile de date",
    "Explore Service URL" : "Explorează serviciul URL",
    "Update interval" : "Interval de actualizări",
    "Use system cron for updates" : "Folosește programul cron pentru updates",
    "Disable this if you use a custom updater." : "Dezactivează această funcție dacă folosești un program diferit de actualizări.",
    "How many redirects the feed fetcher should follow." : "Cât de multe redirecționări ar trebui aplicația să urmărească.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Numărul maxim de secunde de așteptare pentru fuxurile RSS sau Atom; dacă ține mai mult timp atunci actualizarea va fi oprită.",
    "Interval in seconds in which the feeds will be updated." : "Interval actualizare a fluxurilor de date specificat în secunde.",
    "Show all articles" : "Arată toate articolele",
    "Move" : "Mută",
    "Share" : "Partajează",
    "Mark read" : "Marchează ca citit",
    "All articles" : "Toate articolele",
    "Starred" : "Articole selectate",
    "Explore" : "Explorează",
    "Rename" : "Redenumește",
    "Delete" : "Șterge",
    "Rename Feed" : "Redenumește feed-ul",
    "Unpin from top" : "Indepărtatați din capul listei",
    "Pin to top" : "Adăugați în capul listei",
    "Newest first" : "Cel mai nou mai întâi",
    "Oldest first" : "Cel mai vechi mai întâi",
    "Default order" : "Ordinea impicită",
    "Enable full text" : "Activează afișarea textului complet",
    "Disable full text" : "Dezactivează afișarea textului complet",
    "from" : "de la",
    "Toggle star article" : "Scoate articolul din favorite",
    "shared by" : "partajat de",
    "by" : "de",
    "Play audio" : "Redare audio",
    "Download audio" : "Descarca audio",
    "Download video" : "Descarcă video",
    "Open website" : "Deschide website",
    "Keep article unread" : "Păstrează articolul necitit",
    "Toggle keep current article unread" : "Marchează acest articol ca necitit",
    "Remove keep article unread" : "Articol necitit",
    "Default" : "Implicită",
    "Horizontal" : "Orizontal",
    "Off" : "Oprit",
    "Always" : "Întotdeauna",
    "Never" : "Niciodată",
    "General" : "General",
    "Disable mark read through scrolling" : "Dezactivează funcția de \"citit\" prin derulare",
    "Reverse ordering (oldest on top)" : "Ordonare inversă (cele mai vechi primele)",
    "Media" : "Media",
    "Appearance" : "Aspect",
    "Import" : "Importă",
    "Export" : "Exportă",
    "Keyboard shortcuts" : "Scurtături din tastatură",
    "Refresh" : "Împrospătare",
    "Jump to previous article" : "Sari la următorul articol",
    "Jump to next article" : "Sari la următorul articol",
    "Open article in new tab" : "Deschide articolul într-un tab nou",
    "Resources" : "Resurse",
    "Title" : "Titlu",
    "Folder" : "Director",
    "Subscribe to" : "Abonamează-te la",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Modul Ajax sau webcron este activ! Fluxurile dumneavoastră nu vor fi actualizate!",
    "How to set up the operating system cron" : "Cum să setezi funcția cron a sistemului de operare",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instalează și setează un program de actualizări mai rapide ce folosește soluția de API a aplicației News"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
