OC.L10N.register(
    "news",
    {
    "News" : "–ú—ç–¥—ç—ç",
    "Someone" : "Хэн нэгэн",
    "Shared with me" : "Надтай хуваалцсан",
    "Download" : "–¢–∞—Ç–∞—Ö",
    "Close" : "–•–∞–∞—Ö",
    "Web address" : "–í—ç–± —Ö–∞—è–≥",
    "No folder" : "–•–∞–≤—Ç–∞—Å –∞–ª–≥–∞",
    "Folder name" : "–•–∞–≤—Ç–∞—Å–Ω—ã –Ω—ç—Ä",
    "Username" : "–•—ç—Ä—ç–≥–ª—ç–≥—á–∏–π–Ω –Ω—ç—Ä",
    "Password" : "–ù—É—É—Ü “Ø–≥",
    "New folder" : "–®–∏–Ω—ç —Ö–∞–≤—Ç–∞—Å",
    "Credentials" : "–ò—Ç–≥—ç–º–∂–ª—ç–ª",
    "Subscribe" : "–ó–∞—Ö–∏–∞–ª–≥–∞",
    "Last job ran {relativeTime}." : "Сүүлийн ажил {relativeTime}-д ажилласан.",
    "Move" : "–ó”©”©—Ö",
    "Share" : "–¢“Ø–≥—ç—ç—Ö",
    "Explore" : "–•–∞–π—Ö",
    "Rename" : "–ù—ç—Ä–ª—ç–Ω—ç “Ø“Ø",
    "Delete" : "–£—Å—Ç–≥–∞—Ö",
    "Newest first" : "–®–∏–Ω–∏–π–≥ —É—Ä–¥ –Ω—å",
    "Oldest first" : "–•—É—É—á–Ω—ã–≥ —É—Ä–¥ –Ω—å",
    "from" : "—Ç—ç–Ω–¥—ç—ç—Å",
    "Toggle star article" : "”®–≥“Ø“Ø–ª–ª–∏–π–≥ —Å–æ–ª—å",
    "Play audio" : "–ê—É–¥–∏–æ —Ç–æ–≥–ª—É—É–ª–∞—Ö",
    "Download audio" : "–ê—É–¥–∏–æ–≥ —Ç–∞—Ç–∞–∂ –∞–≤–∞—Ö",
    "Download video" : "–í–∏–¥–µ–æ–≥ —Ç–∞—Ç–∞–∂ –∞–≤–∞—Ö",
    "Default" : "Өгөгдмөл",
    "Compact" : "Шахмал",
    "Vertical" : "Босоо",
    "Horizontal" : "Хэвтээ",
    "Off" : "Унтраах",
    "Always" : "Үргэлж",
    "Never" : "—Ö—ç–∑—ç—ç—á",
    "General" : "–µ—Ä”©–Ω—Ö–∏–π",
    "Media" : "Медиа",
    "Appearance" : "Гадаад төрх",
    "Import" : "‚Äì√≤‚Äì¬∫‚Äì√∏‚Äì√¶‚Äî√Ñ‚Äî√á",
    "Export" : "–≠–∫—Å–ø–æ—Ä—Ç",
    "Keyboard shortcuts" : "Гарын товчлолууд",
    "Refresh" : "–°—ç—Ä–≥—ç—ç—Ö",
    "Jump to previous article" : "”®–º–Ω”©—Ö –Ω–∏–π—Ç–ª—ç–ª —Ä“Ø“Ø –æ—á–∏—Ö",
    "Jump to next article" : "–î–∞—Ä–∞–∞–≥–∏–π–Ω ”©–≥“Ø“Ø–ª–ª–∏–π–≥ “Ø–∑—ç—ç—Ä—ç–π",
    "Resources" : "Нөөцүүд",
    "Title" : "Гарчиг",
    "Folder" : "–•–∞–≤—Ç–∞—Å",
    "Not available" : "Боломжгүй",
    "How to set up the operating system cron" : "“Æ–π–ª–¥–ª–∏–π–Ω —Å–∏—Å—Ç–µ–º–∏–π–Ω cron-–≥ —Ö—ç—Ä—Ö—ç–Ω —Ç–æ—Ö–∏—Ä—É—É–ª–∞—Ö —Ç–∞–ª–∞–∞—Ä"
},
"nplurals=2; plural=(n != 1);");
