OC.L10N.register(
    "news",
    {
    "News" : "الأخبار",
    "Someone" : "شخصٌ ما",
    "%1$s shared \"%2$s\" with you" : "%1$s شارك معك \"%2$s\"",
    "News feeds" : "اللُقم الإجبارية",
    "Unread articles" : "مقالات غير مقروءة",
    "News folders" : "مجلدات الأخبار",
    "News articles" : "مقالات الأخبار",
    "Shared with me" : "تمّت مُشاركته معي",
    "An RSS/Atom feed reader" : "قارئ اللُقم الإخبارية RSS/Atom ",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 تطبيق قارئ اللُقم الإخبارية من نكست كلاود RSS / Atom لـ Nextcloud\n\n- 📲 قم بمزامنة لُقمك مع [عملاء] أجهزة محمولة أو سطح مكتب متعددة (https://nextcloud.github.io/news/clients/) \n- تحديثات تلقائية للُقم الأخبار الخاصة بك \n\n- 🆓 مصدر مجاني ومفتوح بموجب AGPLv3 ، بدون إعلانات \n** مطلوب تشغيل \"مدير  الوظائف الخلفية\" System Cron كي يعمل هذا التطبيق \n\nيمكن إيجاد المتطلبات [هنا](https://nextcloud.github.io/news/install/#dependencies)\n\nسجل التغييرات [هنا](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nأنشيء [بلاغ عن مشكل](https://github.com/nextcloud/news/issues/new/choose)\n\nأنشيء [طلب تحسين](https://github.com/nextcloud/news/discussions/new)\n\nأبلغ عن [مشاكل في الإلقام](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "تنزيل",
    "Close" : "إغلاق",
    "Internal server error!" : "خطأ داخلي في الخادوم!",
    "Unknown error!" : "خطأ غير محدد!",
    "Web address" : "عنوان ويب",
    "Please check your data/nextcloud.log file for additional information!" : "رجاءً، لمعلومات أكثر، قم بالاطلاع على ملف data/nextcloud.log !",
    "No folder" : "لا يوجد مجلد",
    "Folder name" : "اسم المجلد",
    "Username" : "اسم المستخدم",
    "Password" : "كلمة المرور",
    "Feed exists already!" : "اللُقمة الإخبارية موجود ةمسبقاً!",
    "New folder" : "مجلد جديد",
    "Folder exists already!" : "المجلد موجود بالفعل",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "يجب تخزين بيانات اعتماد المصادقة الأساسية لبروتوكول HTTP دون تشفير! بحيث يتمكن كل شخص لديه حق الوصول إلى الخادم أو قاعدة البيانات من الوصول إليها!",
    "Credentials" : "حيثيّات الدخول credentials",
    "Auto discover Feed" : "الاستكشاف التلقائي للُّقم الإخبارية",
    "Subscribe" : "إشترك subscribe",
    "Successfully updated news configuration" : "تمّ بنجاحٍ تحديث تهيئة الأخبار",
    "Unable to update news config" : "تعذّر تحديث تهيئة الأخبار",
    "Last job ran {relativeTime}." : "آخر مهمة JOB جرت في {relativeTime}.",
    "Maximum read count per feed" : "الحد الأقصى لعدّاد القراءة لكل لُقمة",
    "Maximum redirects" : "الحد الأقصى لعمليات إعادة التوجيه",
    "Feed fetcher timeout" : "مهلة تحميل اللُقمة الإخبارية",
    "Explore Service URL" : "استكشاف عنوان URL للخدمة",
    "Update interval" : "الفترة الفاصلة بين التحدياث",
    "Use system cron for updates" : "للتحديثات، استخدم مُجدول مهام الخلفية cron",
    "Disable this if you use a custom updater." : "أوقف هذا إذا كنت تستخدم برنامج تحديث مخصص.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "يحدد الحد الأقصى لمقدار المقالات التي يمكن قراءتها في كل لُقمة إخبارية والتي لن يتم حذفها بواسطة مهمة التنظيف. إذا ظهرت المقالات القديمة مرة أخرى بعد قراءتها، قم بزيادة هذه القيمة. القيم السالبة مثل -1 ستوقف تشغيل هذه الميزة.",
    "Delete unread articles automatically" : "حذف المقالات غير المقرؤة تلقائيّاً",
    "Enable this if you also want to delete unread articles." : "قم بتمكين هذا إذا رغبت في حذف المقالات غير المقرؤة أيضاً.",
    "How many redirects the feed fetcher should follow." : "كم عدد مرات إعادة التوجيه التي يتوجب اتباعها عند جلب اللُقم الإخبارية.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "الحد الأقصى بالثواني لمهلة انتظار تحميل لُقمة RSS أو Atom. إذا استغرق الأمر وقتًا أطول، فسيتم إنهاء عملية التحديث.",
    "Interval in seconds in which the feeds will be updated." : "الفترة الفاصلة بين تحديثات الإلقام بالثواني",
    "Use next update time for feed updates" : "استخدم فرصة التحديث التالية لتحديث الخلاصات feed",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "قم بتمكين هذا لاستخدام فرصة التحديث التالية المجدولة لتحديث الخلاصات feed. قم بتعطيل تحديث الخلاصات استناداً فقط إلى الفواصل الزمنية بين التحديثات.",
    "Article list" : "قائمة المقالات",
    "Article details" : "تفاصيل المقالات",
    "No article selected" : "لم يتم تحديد أي مقالٍ",
    "Show all articles" : "أظهر جميع المواضيع",
    "Move" : "نقل",
    "User Name" : "اسم المستخدِم",
    "Share" : "مشاركة",
    "Share with" : "شارِكه مع",
    "Share with {num} users" : "شاركه مع {num} مستخدِمين",
    "Rename Folder" : "تغير تسمية مجلد",
    "Are you sure you want to delete?" : "هل أنت متأكد من أنك تريد الحذف؟",
    "Mark read" : "عيّن أنه تمت القراءة",
    "All articles" : "جميع المقالات",
    "Starred" : "معلّم بنجمة",
    "Has feeds with errors!" : "توجد لُقم إخبارية بأخطاء",
    "Explore" : "إستكشف",
    "Rename" : "إعادة التسمية",
    "Delete" : "حذف ",
    "Rename Feed" : "تغيير تسمية اللُقمة",
    "Open Feed URL" : "إفتَح رابط اللُقمة الإخبارية",
    "Unpin from top" : "إلغ التثبيت في الأعلى",
    "Pin to top" : "ثبتّ في الأعلى",
    "Newest first" : "الأحدث أولا",
    "Oldest first" : "الأقدم أولا",
    "Default order" : "الترتيب التلقائي",
    "Enable full text" : "تمكين النص الكامل",
    "Disable full text" : "إلغاء تمكني النص الكامل",
    "from" : "مِن",
    "Previous Item" : "العنصر السابق",
    "Next Item" : "العنصر التالي",
    "Share within Instance" : "شارك داخل نفس الخادم",
    "Toggle star article" : "تبديل/إلغاء تمييز المقال بنجمة",
    "Mark unread" : "ميِّز كـ\"غير مقرؤ\"",
    "Close details" : "أغلِق التفاصيل",
    "shared by" : "مُشاركة من",
    "by" : "من قِبَل",
    "Play audio" : "تشغيل الصوت",
    "Download audio" : "تنزيل الصوت",
    "Download video" : "تنزيل الفيديو",
    "Open website" : "فتح الموقع",
    "Keep article unread" : "إبقاء المقالة غير مقروءة",
    "Toggle keep current article unread" : "تبديل لإبقاء المقالة الحالية غير مقروءة",
    "Remove keep article unread" : "إلغاء إبقاء المقالة الحالية غير مقروءة",
    "Default" : "التلقائي",
    "Compact" : "مُدمج",
    "Screenreader" : "قارئ الشاشة",
    "Vertical" : "رأسِي",
    "Horizontal" : "أفُقِي",
    "Off" : "معطل",
    "Always" : "دائماً",
    "Never" : "مُطلَقاً",
    "Please select a valid OPML file" : "رجاءً، إختر ملف OPML صحيح",
    "File successfully uploaded" : "تمّ رفع الملف بنجاحٍ",
    "Error uploading the opml file" : "خطأ أثناء رفع ملف OPML",
    "Error connecting to the server" : "خطأ في التوصيل مع الخادوم",
    "Error retrieving the opml file" : "خطأ في استرجاع ملف OPML",
    "General" : "عامٌّ",
    "Disable mark read through scrolling" : "تعطيل علامة القراءة من خلال التمرير",
    "Reverse ordering (oldest on top)" : "عكس الترتيب (الأقدم بالأعلي)",
    "Disable automatic refresh" : "تعطيل التحديث التلقائي",
    "Media" : "الوسائط",
    "Appearance" : "المظهر",
    "Display mode" : "وضعية العرض",
    "Split mode" : "الوضعية المُجزَّأة",
    "Import" : "إستيراد",
    "Export" : "تصدير",
    "Abonnements (OPML)" : "الاشتراكات (OPML)",
    "Please wait" : "يرجى الانتظار ...",
    "Keyboard shortcuts" : "اختصارات لوحة المفاتيح",
    "Refresh" : "تحديث",
    "Jump to previous article" : "الانتقال إلي المقالة السابقة",
    "Jump to next article" : "الانتقال إلي المقالة التالية",
    "Open article in new tab" : "افتح المقال في تبويب جديد",
    "Show article details in compact view" : "أعرُض تفاصيل المقال بشكل مضغوط",
    "Close article details in compact view" : "أغلِق تفاصيل المقال في العرض المضغوط",
    "Mark current articles feed/folder as read" : "وضع علامة مقروء على إلقام/مجلد المقالات الحالية",
    "Resources" : "الموارد",
    "Last update" : "آخر تحديث",
    "Time when the feed was last downloaded" : "الوقت الذي تمّ فيه تنزيل الخلاصة آخر مرة",
    "Next update" : "التحديث التالي",
    "Time when the next feed update will be done" : "الوقت الذي سيتم فيه التحديث القادم للخلاصة ",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "فقط إذا تم التنشيط في إعدادات المشرف، وإلاّ فسيتم استخدام فترة التحديث الاعتيادية",
    "Articles per update" : "المقالات بحسب التحديثات",
    "Maximum number of articles reached in a feed update" : "أقصى عدد من المقالات أمكن الوصول إليه عند تحديث الخلاصة",
    "Error Count" : "عدد الأخطاء",
    "Number of errors that have occurred since the last successful feed update" : "عدد الأخطاء التي حدثت منذ آخر تحديث ناجح للخلاصة",
    "Title" : "العنوان",
    "Folder" : "مجلد",
    "Not available" : "غير متاح",
    "All Articles" : "كل المقالات",
    "No feeds found to add" : "لم يمكن العثور على أي لقمة لإضافته",
    "Subscribe to" : "إشترك في",
    "Unread Articles" : "المقالات غير المقروءة",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "تمّ اكتشاف وضعية Ajax أو webcron! سوف لن يتم تحديث إلقامك!",
    "How to set up the operating system cron" : "كيفية تنصيب النظام cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "تثبيت وإعداد محدث مواز أسرع يستخدم التطبيقات الجديدة لتحديث واجهة برمجة التطبيقات \"API\""
},
"nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
