<?php

// autoload_static.php @generated by Composer

namespace Composer\Autoload;

class ComposerStaticInitdc884737dd20712f15b8093167310365
{
    public static $files = array (
        '7b11c4dc42b3b3023073cb14e519683c' => __DIR__ . '/..' . '/ralouphie/getallheaders/src/getallheaders.php',
    );

    public static $prefixLengthsPsr4 = array (
        'f' =>
        array (
            'fivefilters\\Readability\\' => 24,
        ),
        'S' =>
        array (
            'Symfony\\Component\\HtmlSanitizer\\' => 32,
        ),
        'P' =>
        array (
            'Psr\\Http\\Message\\' => 17,
            'Psr\\Http\\Client\\' => 16,
        ),
        'O' =>
        array (
            'OCA\\News\\' => 9,
        ),
        'N' =>
        array (
            'Nyholm\\Psr7\\' => 12,
        ),
        'M' =>
        array (
            'Masterminds\\' => 12,
        ),
        'L' =>
        array (
            'League\\Uri\\' => 11,
        ),
        'H' =>
        array (
            'Http\\Promise\\' => 13,
            'Http\\Discovery\\' => 15,
            'Http\\Client\\' => 12,
            'Http\\Adapter\\Guzzle7\\' => 21,
        ),
        'G' =>
        array (
            'GuzzleHttp\\Psr7\\' => 16,
        ),
        'F' =>
        array (
            'FeedIo\\' => 7,
            'Favicon\\' => 8,
        ),
        'B' =>
        array (
            'Bamarni\\Composer\\Bin\\' => 21,
        ),
    );

    public static $prefixDirsPsr4 = array (
        'fivefilters\\Readability\\' =>
        array (
            0 => __DIR__ . '/..' . '/fivefilters/readability.php/src',
        ),
        'Symfony\\Component\\HtmlSanitizer\\' =>
        array (
            0 => __DIR__ . '/..' . '/symfony/html-sanitizer',
        ),
        'Psr\\Http\\Message\\' =>
        array (
            0 => __DIR__ . '/..' . '/psr/http-factory/src',
            1 => __DIR__ . '/..' . '/psr/http-message/src',
        ),
        'Psr\\Http\\Client\\' =>
        array (
            0 => __DIR__ . '/..' . '/psr/http-client/src',
        ),
        'OCA\\News\\' =>
        array (
            0 => __DIR__ . '/../..' . '/lib',
        ),
        'Nyholm\\Psr7\\' =>
        array (
            0 => __DIR__ . '/..' . '/nyholm/psr7/src',
        ),
        'Masterminds\\' =>
        array (
            0 => __DIR__ . '/..' . '/masterminds/html5/src',
        ),
        'League\\Uri\\' =>
        array (
            0 => __DIR__ . '/..' . '/league/uri',
            1 => __DIR__ . '/..' . '/league/uri-interfaces',
        ),
        'Http\\Promise\\' =>
        array (
            0 => __DIR__ . '/..' . '/php-http/promise/src',
        ),
        'Http\\Discovery\\' =>
        array (
            0 => __DIR__ . '/..' . '/php-http/discovery/src',
        ),
        'Http\\Client\\' =>
        array (
            0 => __DIR__ . '/..' . '/php-http/httplug/src',
        ),
        'Http\\Adapter\\Guzzle7\\' =>
        array (
            0 => __DIR__ . '/..' . '/php-http/guzzle7-adapter/src',
        ),
        'GuzzleHttp\\Psr7\\' =>
        array (
            0 => __DIR__ . '/..' . '/guzzlehttp/psr7/src',
        ),
        'FeedIo\\' =>
        array (
            0 => __DIR__ . '/..' . '/php-feed-io/feed-io/src/FeedIo',
        ),
        'Favicon\\' =>
        array (
            0 => __DIR__ . '/..' . '/arthurhoaro/favicon/src/Favicon',
        ),
        'Bamarni\\Composer\\Bin\\' =>
        array (
            0 => __DIR__ . '/..' . '/bamarni/composer-bin-plugin/src',
        ),
    );

    public static $classMap = array (
        'Composer\\InstalledVersions' => __DIR__ . '/..' . '/composer/InstalledVersions.php',
    );

    public static function getInitializer(ClassLoader $loader)
    {
        return \Closure::bind(function () use ($loader) {
            $loader->prefixLengthsPsr4 = ComposerStaticInitdc884737dd20712f15b8093167310365::$prefixLengthsPsr4;
            $loader->prefixDirsPsr4 = ComposerStaticInitdc884737dd20712f15b8093167310365::$prefixDirsPsr4;
            $loader->classMap = ComposerStaticInitdc884737dd20712f15b8093167310365::$classMap;

        }, null, ClassLoader::class);
    }
}
