OC.L10N.register(
    "news",
    {
    "News" : "News",
    "Someone" : "Someone",
    "%1$s shared \"%2$s\" with you" : "%1$s shared \"%2$s\" with you",
    "News feeds" : "News feeds",
    "Unread articles" : "Unread articles",
    "News folders" : "News folders",
    "News articles" : "News articles",
    "Shared with me" : "Shared with me",
    "An RSS/Atom feed reader" : "An RSS/Atom feed reader",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Download",
    "Close" : "Close",
    "Web address" : "Web address",
    "No folder" : "No folder",
    "Folder name" : "Folder name",
    "Username" : "Username",
    "Password" : "პაროლი",
    "Feed exists already!" : "Feed exists already!",
    "New folder" : "New folder",
    "Folder exists already!" : "Folder exists already!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!",
    "Credentials" : "Credentials",
    "Auto discover Feed" : "Auto discover Feed",
    "Subscribe" : "Subscribe",
    "Successfully updated news configuration" : "Successfully updated news configuration",
    "Unable to update news config" : "Unable to update news config",
    "Last job ran {relativeTime}." : "Last job ran {relativeTime}.",
    "Maximum read count per feed" : "Maximum read count per feed",
    "Maximum redirects" : "Maximum redirects",
    "Feed fetcher timeout" : "Feed fetcher timeout",
    "Explore Service URL" : "Explore Service URL",
    "Update interval" : "Update interval",
    "Use system cron for updates" : "Use system cron for updates",
    "Disable this if you use a custom updater." : "Disable this if you use a custom updater.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off.",
    "Delete unread articles automatically" : "Delete unread articles automatically",
    "Enable this if you also want to delete unread articles." : "Enable this if you also want to delete unread articles.",
    "How many redirects the feed fetcher should follow." : "How many redirects the feed fetcher should follow.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted.",
    "Interval in seconds in which the feeds will be updated." : "Interval in seconds in which the feeds will be updated.",
    "No article selected" : "No article selected",
    "Show all articles" : "Show all articles",
    "Move" : "Move",
    "User Name" : "User Name",
    "Share" : "Share",
    "Share with" : "Share with",
    "Share with {num} users" : "Share with {num} users",
    "Rename Folder" : "Rename Folder",
    "Are you sure you want to delete?" : "Are you sure you want to delete?",
    "Mark read" : "Mark read",
    "All articles" : "All articles",
    "Starred" : "Starred",
    "Explore" : "Explore",
    "Rename" : "Rename",
    "Delete" : "Delete",
    "Rename Feed" : "Rename Feed",
    "Open Feed URL" : "Open Feed URL",
    "Unpin from top" : "Unpin from top",
    "Pin to top" : "Pin to top",
    "Newest first" : "Newest first",
    "Oldest first" : "Oldest first",
    "Default order" : "Default order",
    "Enable full text" : "Enable full text",
    "Disable full text" : "Disable full text",
    "from" : "from",
    "Share within Instance" : "Share within Instance",
    "Toggle star article" : "Toggle star article",
    "shared by" : "shared by",
    "by" : "by",
    "Play audio" : "Play audio",
    "Download audio" : "Download audio",
    "Download video" : "Download video",
    "Open website" : "Open website",
    "Keep article unread" : "Keep article unread",
    "Toggle keep current article unread" : "Toggle keep current article unread",
    "Remove keep article unread" : "Remove keep article unread",
    "Default" : "Default",
    "Off" : "Off",
    "Never" : "Never",
    "General" : "General",
    "Disable mark read through scrolling" : "Disable mark read through scrolling",
    "Reverse ordering (oldest on top)" : "Reverse ordering (oldest on top)",
    "Media" : "Media",
    "Import" : "Import",
    "Export" : "Export",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Refresh" : "Refresh",
    "Jump to previous article" : "Jump to previous article",
    "Jump to next article" : "Jump to next article",
    "Open article in new tab" : "Open article in new tab",
    "Resources" : "Resources",
    "Folder" : "Folder",
    "Not available" : "Not available",
    "All Articles" : "All Articles",
    "No feeds found to add" : "No feeds found to add",
    "Subscribe to" : "Subscribe to",
    "Unread Articles" : "Unread Articles",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax or webcron mode detected! Your feeds will not be updated!",
    "How to set up the operating system cron" : "How to set up the operating system cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Install and set up a faster parallel updater that uses the News app's update API"
},
"nplurals=2; plural=(n!=1);");
