OC.L10N.register(
    "news",
    {
    "News" : "Novice",
    "Someone" : "Nekdo",
    "%1$s shared \"%2$s\" with you" : "Uporabnik %1$s je omogočil souporabo \"%2$s\"",
    "News feeds" : "Viri novic",
    "Unread articles" : "Neprebrani prispevki",
    "News folders" : "Mape novic",
    "News articles" : "Novičarski prispevki",
    "Shared with me" : "V souporabi z mano",
    "An RSS/Atom feed reader" : "Bralnik virov RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Bralnik virov RSS/Atom za okolje Nextcloud\n\n- 📲 Omogoča sočasno usklajevanje virov z več mobilnimi in namiznimi [programi](https://nextcloud.github.io/news/clients/)\n- 🔄 Samodejno posodablja vire novic\n- 🆓 Je prosto in brezplačno orodje, objavljeno pod pogoji dovoljenjaAGPLv3, brez oglasov, brez dodatnih plačljivih možnosti\n\n**Za delovanje mora biti zagnano okolje Cron**\n\nZahteve programa so objavljene med podrobnostmi [namestitve](https://nextcloud.github.io/news/install/#dependencies)\n\nPodrobnosti objave so na voljo v datoteki [Changelog.md](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nPoročila o hroščih pa se zbirajo na spletišču [GitHub](https://github.com/nextcloud/news/issues/new/choose)\n\nO [predlogih novih zmožnosti](https://github.com/nextcloud/news/discussions/new) razpravlja živahna skupnost\n\nNapake objave vira, pa je mogoče objavljati med [pogovori](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Prejmi",
    "Close" : "Zapri",
    "Web address" : "Spletni naslov",
    "No folder" : "Ni mape",
    "Folder name" : "Ime mape",
    "Username" : "Uporabniško ime",
    "Password" : "Geslo",
    "Feed exists already!" : "Vir že obstaja!",
    "New folder" : "Nova mapa",
    "Folder exists already!" : "Mapa že obstaja!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Osnovni overitveni podatki HTTP Auth morajo biti shranjeni nekodirani! Vsakdo z dostopom do podatkovne zbirke bo imel omogočen dostop!",
    "Credentials" : "Poverila",
    "Auto discover Feed" : "Samodejno odkrivanje Vira",
    "Subscribe" : "Naročilo",
    "Successfully updated news configuration" : "Nastavitve novic so uspešno posodobljene",
    "Unable to update news config" : "Ni mogoče posodobiti nastavitev novic",
    "Last job ran {relativeTime}." : "Osvežitev je bila nazadnje izvedena {relativeTime}.",
    "Maximum read count per feed" : "Največje število prikazanih virov",
    "Maximum redirects" : "Največje število preusmeritev",
    "Feed fetcher timeout" : "Časovni pretek pridobivanja vira",
    "Explore Service URL" : "Razišči spletni naslov storitve",
    "Update interval" : "Razmik posodobitev",
    "Use system cron for updates" : "Za posodobitve uporabi sistemski program »cron«",
    "Disable this if you use a custom updater." : "Možnost onemogočite, če uporabljate posodabljalnik po meri.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Določa največje število prispevkov vira, ki bodo ostali vidni po čiščenju zgodovine. Če se pojavljajo starejši prispevki, je določilo nastavljeno prenizko. Vrednost -1 onemogoči izvajanje možnosti.",
    "Delete unread articles automatically" : "Samodejno izbriši neprebrane prispevke",
    "Enable this if you also want to delete unread articles." : "Možnost omogoča brisanje neprebranih prispevkov.",
    "How many redirects the feed fetcher should follow." : "Koliko preusmeritvam naj sledi bralnik virov",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Čas, namenjen nalaganju virov RSS in Atom. Če traja dlje je nalaganje virov prekinjeno.",
    "Interval in seconds in which the feeds will be updated." : "Časovni zamik v sekundah za posodabljanje spletnih virov.",
    "No article selected" : "Ni izbranega prispevka",
    "Show all articles" : "Pokaži vse prispevke",
    "Move" : "Premakni",
    "User Name" : "Uporabniško ime",
    "Share" : "Souporaba",
    "Share with" : "Omogoči souporabo …",
    "Rename Folder" : "Preimenuj mapo",
    "Are you sure you want to delete?" : "Ali ste prepričani, da želite predmet izbrisati?",
    "Mark read" : "Označi kot prebrano",
    "All articles" : "Vsi prispevki",
    "Starred" : "Z zvezdico",
    "Explore" : "Razišči",
    "Rename" : "Preimenuj",
    "Delete" : "Izbriši",
    "Rename Feed" : "Preimenuj vir",
    "Open Feed URL" : "Odpri naslov URL vira",
    "Unpin from top" : "Odpni z vrha",
    "Pin to top" : "Pripni na vrh",
    "Newest first" : "najprej najnovejše",
    "Oldest first" : "najprej najstarejše",
    "Default order" : "Privzeta razvrstitev",
    "Enable full text" : "Omogoči polno besedilo",
    "Disable full text" : "Omogoči polno besedilo",
    "from" : "od",
    "Toggle star article" : "Preklopi označevanje z zvezdico",
    "Mark unread" : "Označi kot neprebrano",
    "Close details" : "Zapri podrobnosti",
    "shared by" : "omogoča",
    "by" : "od",
    "Play audio" : "Predvajaj zvok",
    "Download audio" : "Prejmi zvok",
    "Download video" : "Prejmi video",
    "Open website" : "Odpri spletišče",
    "Keep article unread" : "Obdrži kot neprebrano",
    "Toggle keep current article unread" : "Preklopi ohranjanje prispevka kot neprebranega",
    "Remove keep article unread" : "Odstrani možnost ohranjanja prispevkov neprebranih",
    "Default" : "privzeto",
    "Vertical" : "Navpično",
    "Horizontal" : "Vodoravno",
    "Always" : "Vedno",
    "Never" : "nikoli",
    "General" : "Splošno",
    "Disable mark read through scrolling" : "Onemogoči označevanje prebranosti med drsenjem",
    "Reverse ordering (oldest on top)" : "Obrni razvrstitev (najstarejši na vrh)",
    "Appearance" : "Videz",
    "Import" : "Uvozi",
    "Export" : "Izvozi",
    "Please wait" : "Počakajte ...",
    "Keyboard shortcuts" : "Tipkovne bližnjice",
    "Refresh" : "Osveži",
    "Jump to previous article" : "Skoči na predhodni prispevek",
    "Jump to next article" : "Skoči na naslednji prispevek",
    "Open article in new tab" : "Odpri prispevek v novem zavihku",
    "Resources" : "Viri",
    "Last update" : "Zadnja posodobitev",
    "Title" : "Naslov",
    "Folder" : "Mapa",
    "All Articles" : "Vsi prispevki",
    "No feeds found to add" : "Ni najdenih virov  za dodajanje",
    "Subscribe to" : "Naročnina na",
    "Unread Articles" : "Neprebrani prispevki",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "V uporabi je ali način Ajax ali pa webcron, kar pomeni, da izbrani viri ne bodo posodobljeni!",
    "How to set up the operating system cron" : "Oglejte si navodila, kako nastaviti opravila cron operacijskega sistema. ↗",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Namesti je mogoče vzporedni posodabljalnik, ki uporablja vmesnik API programa News ↗."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
