OC.L10N.register(
    "news",
    {
    "News" : "Novas",
    "an article" : "un artigo",
    "Someone" : "Alguén",
    "%1$s shared \"%2$s\" with you" : "%1$s compartiu «%2$s» con Vde.",
    "{user} shared \"{article}\" with you" : "{user} compartiu «{article}» con Vde.",
    "News feeds" : "Fontes de novas",
    "Unread articles" : "Artigos sen ler",
    "News folders" : "Cartafoles de novas",
    "News articles" : "Artigos de novas",
    "Shared with me" : "Compartido comigo",
    "Untitled article" : "Artigo sen título",
    "An RSS/Atom feed reader" : "Un lector de fontes RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Unha aplicación de lector de RSS/Atom Feed para Nextcloud\n\n- 📲 Sincroniza as súas fontes con varios [clientes](https://nextcloud.github.io/news/clients/) de móbil ou de escritorio \n- 🔄 Actualizacións automáticas das súas fontes de novas\n- 🆓 De Código aberto, libre e de balde, baixo AGPLv3, sen anuncios nin funcións de pago ou subscrición\n\n**Actualmente precísase do sistema «cron» para que esta aplicación funcione**\n\nOs requisitos pódense atopar [aquí](https://nextcloud.github.io/news/install/#dependencies)\n\nAs notas da versión están dispoñíbeis [aquí](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCrear un [informe de fallos](https://github.com/nextcloud/news/issues/new/choose)\n\nCrear unha [solicitude de función](https://github.com/nextcloud/news/discussions/new)\n\nInformar dun [problema de fontes](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Descargar",
    "Close" : "Pechar",
    "Internal server error!" : "Produciuse un erro interno do servidor!",
    "Unknown error!" : "Produciuse un erro descoñecido!",
    "Web address" : "Enderezo web",
    "Please check your data/nextcloud.log file for additional information!" : "Produciuse un erro interno do servidor! Verifique o ficheiro data/nextcloud.log para obter máis información!",
    "No folder" : "Sen cartafol",
    "Folder name" : "Nome do cartafol",
    "Username" : "Nome de usuario",
    "Password" : "Contrasinal",
    "Feed exists already!" : "Esta fonte de novas xa existe!",
    "New folder" : "Novo cartafol",
    "Folder exists already!" : "Xa existe o cartafol!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "As credenciais para a autenticación básica HTTP (Basic Auth) deben estar gardadas sen cifrar! Calquera persoa con acceso ao servidor poderá acceder a elas!",
    "Credentials" : "Credenciais",
    "Auto discover Feed" : "Fonte de achado automático",
    "Subscribe" : "Subscribirse",
    "Successfully updated news configuration" : "Actualizouse correctamente a configuración de novas",
    "Unable to update news config" : "Non é posíbel actualizar a configuración de noticias",
    "Logo purge has never been run." : "A purga do logotipo nunca foi executada.",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "Foi executada a última purga do logotipo {relativeLastLogoPurge}. Algo foi mal.",
    "Last logo purge job ran {relativeLastLogoPurge}." : "O último traballo de purga de logotipo foi executado {relativeLastLogoPurge}.",
    "No job execution data available. The cron job may not be running properly." : "Non hai datos de execución de traballo dispoñíbeis. É posíbel que o traballo cron non estea a funcionar correctamente.",
    "Last job execution ran {relativeTime}. Something is wrong." : "A última execución do traballo executouse o {relativeTime}. Algo vai mal.",
    "Last job ran {relativeTime}." : "O último traballo executouse ás {relativeTime}.",
    "Maximum read count per feed" : "Número máximo de lecturas por fonte",
    "Maximum redirects" : "Redireccionamentos máximos",
    "Feed fetcher timeout" : "Caducidade do recuperador de fontes",
    "Explore Service URL" : "Examinar o URL de servizo",
    "Update interval" : "Intervalo de actualización",
    "Use system cron for updates" : "Use o cron do sistema para as actualizacións",
    "Disable this if you use a custom updater." : "Desactive isto se usa un actualizador personalizado.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Define a cantidade máxima de artigos que se poden ler por fonte que non se eliminarán polo traballo de limpeza; se reaparecen artigos antigos após de ser lidos, aumenta este valor; valores negativos como -1 desactivarán esta función.",
    "Delete unread articles automatically" : "Eliminar automaticamente os artigos non lidos",
    "Enable this if you also want to delete unread articles." : "Active isto se tamén quere eliminar os artigos non lidos.",
    "How many redirects the feed fetcher should follow." : "Cantos redirecionamentos debe seguir o recuperador de fontes.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Número máximo de segundos agardando por unha fonte RSS ou Atom para cargar; se lle leva máis tempo a actualización será interrompida.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Se é fornecido, consultarase o URL deste servizo para amosar as fontes na sección de exame da fonte. Para volver ao servizo de exploración incorporado, deixe esta entrada baleira.",
    "Interval in seconds in which the feeds will be updated." : "Intervalo, en segundos, no que se actualizarán as fontes.",
    "Use next update time for feed updates" : "Usar a próxima hora de actualización para as actualizacións de fontes",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Activar esta opción para usar a hora calculada da próxima actualización para as actualizacións das fontess. Desactivar para actualizar as fontes baseándose unicamente no intervalo de actualización.",
    "Article list" : "Lista de artigos",
    "Article details" : "Detalles do artigo",
    "No article selected" : "Non seleccionou ningún artigo",
    "Please select an article from the list." : "Seleccione un artigo da lista.",
    "Show all articles" : "Amosar todos os artigos",
    "Move feed" : "Mover a fonte",
    "Please select the new folder" : "Seleccione un novo cartafol.",
    "Move" : "Mover",
    "User Name" : "Nome de usuario",
    "Share" : "Compartir",
    "Share with" : "Compartir con",
    "Share with {num} users" : "Compartir con {num} usuarios",
    "Rename Folder" : "Cambiar o nome do cartafol",
    "Are you sure you want to delete?" : "Confirma que quere eliminar?",
    "Unable to save starred open state" : "Non é posíbel gardar o estado aberto salientado con estrela",
    "Mark read" : "Marcar como lido",
    "All articles" : "Todos os artigos",
    "Recently viewed" : "Visto recentemente",
    "Starred" : "Salientado cunha estrela",
    "Has feeds with errors!" : "Ten fontes con erros!",
    "Explore" : "Examinar",
    "Feed settings" : "Axustes de fonte de novas",
    "News settings" : "Axustes de novas",
    "Rename" : "Cambiar o nome",
    "Delete" : "Eliminar",
    "Rename Feed" : "Cambiar o nome da fonte",
    "Open Feed URL" : "Abrir o URL da fonte",
    "Unpin from top" : "Desprender de enriba",
    "Pin to top" : "Fixar enriba",
    "Newest first" : "Primeiro o máis recente",
    "Oldest first" : "Primeiro o máis antigo",
    "Default order" : "Orde predeterminado",
    "Enable full text" : "Activar o texto completo",
    "Disable full text" : "Desactivar o texto completo",
    "Mark as unread on update" : "Marcar como non lido na actualización",
    "Keep read status on update" : "Manter o estado de lectura na actualización",
    "Sync disabled" : "Sincronización desactivada",
    "Sync enabled" : "Sincronización activada",
    "Show external media" : "Amosar os multimedia externos",
    "from" : "desde",
    "External media loaded from" : "Multimedia externos cargados desde",
    "Previous Item" : "Elemento anterior",
    "Next Item" : "Seguinte elemento",
    "Share within Instance" : "Compartir dentro da instancia",
    "Toggle star article" : "Marcar/desmarcar os artigos con estrela",
    "Mark unread" : "Marcar como sen ler",
    "Close details" : "Pechar os detalles",
    "shared by" : "compartido por",
    "by" : "por",
    "Play audio" : "Reproducir son",
    "Download audio" : "Descargar son",
    "Download video" : "Descargar vídeo",
    "Refresh list" : "Actualizar a lista",
    "Open website" : "Abrir o sitio web",
    "Keep article unread" : "Conservar o artigo como non lido",
    "Toggle keep current article unread" : "Conservar/retirar o artigo actual como non lido",
    "Remove keep article unread" : "Retirar a marca de artigo sen ler",
    "Default" : "Predeterminado",
    "Compact" : "Compacto",
    "Screenreader" : "Lector de pantalla",
    "Vertical" : "Vertical",
    "Horizontal" : "Horizontal",
    "Off" : "Apagado",
    "Always" : "Sempre",
    "Ask" : "Preguntar",
    "Never" : "Nunca",
    "Please select a valid OPML file" : "Seleccione un ficheiro OPML válido",
    "File successfully uploaded" : "O ficheiro foi enviado satisfactoriamente",
    "Error uploading the opml file" : "Produciuse un erro ao enviar o ficheiro opml",
    "Error connecting to the server" : "Produciuse un erro ao conectar co servidor",
    "Error retrieving the opml file" : "Produciuse un erro ao recuperar o ficheiro opml",
    "Please select a valid json file" : "Seleccione un ficheiro json válido",
    "Error uploading the json file" : "Produciuse un erro ao enviar o ficheiro json",
    "Error retrieving the json file" : "Produciuse un erro ao recuperar o ficheiro json",
    "General" : "Xeral",
    "Disable mark read through scrolling" : "Desactivar o marcado como lido co desprazamento",
    "Reverse ordering (oldest on top)" : "Ordenado inverso (máis vellos enriba)",
    "Disable automatic refresh" : "Desactivar a actualización automática",
    "Media" : "Multimedia",
    "Show enclosure images" : "Amosar as imaxes do cercado",
    "Show images in the article text" : "Amosar as imaxes no texto do artigo",
    "Show iframes in the article text" : "Amosar os «iframe» no texto do artigo",
    "Appearance" : "Aparencia",
    "Display mode" : "Modo de vista",
    "Split mode" : "Modo dividido",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Abonnements (OPML)" : "Subscricións (OPML)",
    "Importing feeds" : "Importación de fontes",
    "Please wait" : "Agarde",
    "Articles (JSON)" : "Artigos (JSON)",
    "Keyboard shortcuts" : "Atallos de teclado",
    "Refresh" : "Actualizar",
    "Screenreader mode only" : "Só modo lector de pantalla",
    "Jump to previous article" : "Ir ao artigo anterior",
    "Jump to next article" : "Ir ao seguinte artigo",
    "Item navigation and control" : "Navegación e control de elementos",
    "Open article in new tab" : "Abrir o artigo nunha nova lapela",
    "Show article details in compact view" : "Amosar os detalles do artigo na vista compacta",
    "Close article details in compact view" : "Pechar os detalles do artigo na vista compacta",
    "Feed/Folder navigation and control" : "Navegación e control de fontes/cartafoles",
    "Jump to previous feed" : "Ir á fonte anterior",
    "Jump to next feed" : "Ir á fonte seguinte",
    "Jump to previous folder" : "Ir ao cartafol anterior",
    "Jump to next folder" : "Ir ao seguinte cartafol",
    "Mark current articles feed/folder as read" : "Marcar os actuais artigos de fonte/cartafol como lidos",
    "Resources" : "Recursos",
    "Last update" : "Última actualización",
    "Time when the feed was last downloaded" : "Hora na que se descargou a fonte por última vez",
    "Next update" : "Próxima actualización",
    "Time when the next feed update will be done" : "Hora na que se fará a próxima actualización de fontes",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Só se está activado na configuración da administración, se non, empregase o intervalo de actualización regular",
    "Articles per update" : "Artigos por actualización",
    "Maximum number of articles reached in a feed update" : "Número máximo de artigos acadado nunha actualización de fontes",
    "Error Count" : "Conta de erros",
    "Number of errors that have occurred since the last successful feed update" : "Número de erros que se produciron desde a última actualización correcta de fontes",
    "Title" : "Titulo",
    "Folder" : "Cartafol",
    "Not available" : "Non dispoñíbel",
    "All Articles" : "Todos os artigos",
    "No feeds found to add" : "Non se atopou ningunha fonte para engadir",
    "Subscribe to" : "Subscribirse a",
    "Unread Articles" : "Artigos sen ler",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Detectouse o modo Ajax ou webcron! As súas fontes non van ser actualizadas!",
    "How to set up the operating system cron" : "Cómo configurar o cron do sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instalar e configurar un actualizador paralelo máis rápido que utilice a API de actualización da aplicación Novas"
},
"nplurals=2; plural=(n != 1);");
