OC.L10N.register(
    "news",
    {
    "News" : "Навіны",
    "Download" : "Спампаваць",
    "Close" : "Закрыць",
    "Internal server error!" : "Унутраная памылка сервера!",
    "Unknown error!" : "Невядомая памылка!",
    "Folder name" : "Назва папкі",
    "Username" : "Імя карыстальніка",
    "Password" : "Пароль",
    "New folder" : "Новая папка",
    "Credentials" : "Уліковыя даныя",
    "Please select the new folder" : "Выберыце новую папку",
    "Move" : "Перамясціць",
    "User Name" : "Імя карыстальніка",
    "Share" : "Абагуліць",
    "Rename Folder" : "Перайменаваць папку",
    "Are you sure you want to delete?" : "Вы ўпэўнены, што хочаце выдаліць?",
    "Mark read" : "У прачытанае",
    "All articles" : "Усе артыкулы",
    "Rename" : "Перайменаваць",
    "Delete" : "Выдаліць",
    "Newest first" : "Спачатку новыя",
    "Oldest first" : "Спачатку старыя",
    "Sync disabled" : "Сінхранізацыя адключана",
    "Sync enabled" : "Сінхранізацыя ўключана",
    "Previous Item" : "Папярэдні элемент",
    "Next Item" : "Наступны элемент",
    "Play audio" : "Прайграць аўдыя",
    "Download audio" : "Спампаваць аўдыя",
    "Download video" : "Спампаваць відэа",
    "Refresh list" : "Абнавіць спіс",
    "Open website" : "Адкрыць вэб-сайт",
    "Default" : "Прадвызначаныя",
    "Compact" : "Кампактны",
    "Off" : "Выкл.",
    "Always" : "Заўсёды",
    "Ask" : "Пытацца",
    "Never" : "Ніколі",
    "File successfully uploaded" : "Файл паспяхова запампаваны",
    "General" : "Агульныя",
    "Media" : "Медыя",
    "Appearance" : "Знешні выгляд",
    "Import" : "Імпарт",
    "Export" : "Экспарт",
    "Please wait" : "Пачакайце",
    "Keyboard shortcuts" : "Спалучэнні клавіш",
    "Refresh" : "Абнавіць",
    "Jump to previous article" : "Перайсці да папярэдняга артыкула",
    "Jump to next article" : "Перайсці да наступнага артыкула",
    "Resources" : "Рэсурсы",
    "Title" : "Загаловак",
    "Folder" : "Папка"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
