OC.L10N.register(
    "news",
    {
    "Unread articles" : "Articulos non legite",
    "Download" : "Discargar",
    "Close" : "Clauder",
    "Web address" : "Adresse Web",
    "No folder" : "Nulle dossier",
    "Folder name" : "Nomine de dossier",
    "Username" : "Nomine de usator",
    "Password" : "Contrasigno",
    "Feed exists already!" : "Syndication ja existe!",
    "New folder" : "Nove dossier",
    "Folder exists already!" : "Dossier ja existe!",
    "Credentials" : "Datos de authentication",
    "Subscribe" : "Subscribe",
    "Show all articles" : "Monstrar tote articulos",
    "Move" : "Mover",
    "Share" : "Compartir",
    "All articles" : "Tote articulos",
    "Starred" : "Favoritate",
    "Explore" : "Explorar",
    "Rename" : "Renominar",
    "Delete" : "Deler",
    "from" : "ex",
    "Toggle star article" : "Alternar stato de favorito del articulo",
    "by" : "per",
    "Play audio" : "Reproducer audio",
    "Download audio" : "Discargar audio",
    "Download video" : "Discargar video",
    "Open website" : "Aperir sito web",
    "Keep article unread" : "Mantener articulo como non legite",
    "Never" : "Nunquam",
    "General" : "General",
    "Disable mark read through scrolling" : "Disactivar le marcation como legite per rolamento",
    "Reverse ordering (oldest on top)" : "Ordination reverse (le plus ancian in le topo)",
    "Export" : "Exportar",
    "Keyboard shortcuts" : "Combinationes de claves",
    "Refresh" : "Refrescar",
    "Jump to previous article" : "Saltar al articulo previe",
    "Jump to next article" : "Saltar al articulo sequente",
    "Open article in new tab" : "Aperir articulo in nove scheda",
    "Folder" : "Dossier"
},
"nplurals=2; plural=(n != 1);");
