OC.L10N.register(
    "news",
    {
    "Unread articles" : "អត្ថបទ​ដែល​មិន​ទាន់​អាន",
    "Download" : "ទាញយក",
    "Close" : "បិទ",
    "Folder name" : "ឈ្មោះ​ថត",
    "Username" : "ឈ្មោះ​អ្នកប្រើ",
    "Password" : "ពាក្យសម្ងាត់",
    "New folder" : "ថត​ថ្មី",
    "Credentials" : "Credentials",
    "Move" : "Move",
    "Share" : "ចែក​រំលែក",
    "All articles" : "អត្ថបទ​ទាំង​អស់",
    "Starred" : "បាន​ដាក់​ផ្កាយ",
    "Rename" : "ប្ដូរ​ឈ្មោះ",
    "Delete" : "លុប",
    "from" : "ពី",
    "by" : "ដោយ",
    "Always" : "រាល់ពេល",
    "General" : "ទូទៅ",
    "Import" : "នាំយកចូល",
    "Export" : "នាំចេញ",
    "Folder" : "ថត"
},
"nplurals=1; plural=0;");
