OC.L10N.register(
    "news",
    {
    "News" : "Nyheter",
    "Someone" : "Noen",
    "%1$s shared \"%2$s\" with you" : "%1$s delte \"%2$s\" med deg",
    "News feeds" : "Nyhetsstrømmer",
    "Unread articles" : "Uleste artikler",
    "News folders" : "Nyhetsmapper",
    "News articles" : "Nyhetsartikler",
    "Shared with me" : "Delt med meg",
    "An RSS/Atom feed reader" : "En RSS/Atom-leser",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 En RSS/Atom Feed leseapp for Nextcloud\n\n- 📲 Synkroniser feed'ene dine med flere mobil eller desktop [klienter](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatisk oppdatering av nyhetsfeeder\n- 🆓 Gratis og open source under AGPLv3, ingen reklame eller premium funksjoner\n\n**System Cron er for øyeblikket påkrevet for at denne appen skal fungere**\n\nKrav kan bli funnet [her](https://nextcloud.github.io/news/install/#dependencies)\n\nEndringslogg er tilgjengelig [her](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nOpprett en [bug rapport](https://github.com/nextcloud/news/issues/new/choose)\n\nOpprett en [feature request](https://github.com/nextcloud/news/discussions/new)\n\nRapporter ett [feed problem](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Last ned",
    "Close" : "Lukk",
    "Web address" : "Internettadresse",
    "No folder" : "Ingen mappe",
    "Folder name" : "Mappenavn",
    "Username" : "Brukernavn",
    "Password" : "Passord",
    "Feed exists already!" : "Strømmen finnes allerede!",
    "New folder" : "Ny mappe",
    "Folder exists already!" : "Mappe finnes allerede!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Detaljer for HTTP Basic Auth må lagres ukryptert! Alle med tilgang til serveren eller databasen vil være i stand til å nå dem!",
    "Credentials" : "Påloggingsdetaljer",
    "Auto discover Feed" : "Automatisk oppdag strøm",
    "Subscribe" : "Abonner",
    "Successfully updated news configuration" : "Nyhetskonfigurasjonen er oppdatert",
    "Unable to update news config" : "Kan ikke oppdatere nyhetskonfigurasjonen",
    "Last job ran {relativeTime}." : "Siste jobb kjørte {relativeTime}.",
    "Maximum read count per feed" : "Maksimalt antall lest pr. strøm",
    "Maximum redirects" : "Maksimalt antall videresendinger",
    "Feed fetcher timeout" : "Tidsavbrudd for henting av strøm",
    "Explore Service URL" : "URL for utforskertjeneste",
    "Update interval" : "Oppdateringsintervall",
    "Use system cron for updates" : "Bruk system-cron for oppdateringer",
    "Disable this if you use a custom updater." : "Deaktiver dette hvis du bruker en egen oppdaterer.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Definerer maksimalt antall artikler som kan leses per strøm som ikke vil bli slettet av oppryddingsjobben; hvis gamle artikler dukker opp igjen etter å ha blitt lest, øk denne verdien; negative verdier som -1 vil slå av denne funksjonen.",
    "Delete unread articles automatically" : "Slett uleste artikler automatisk",
    "Enable this if you also want to delete unread articles." : "Aktiver dette hvis du også ønsker å slette uleste artikler.",
    "How many redirects the feed fetcher should follow." : "Hvor mange omdirigeringer strøm-henteren skal følge.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimalt antall sekunder å vente på at en RSS- eller Atom-strøm skal lastes; hvis det tar lengre tid vil oppdateringen bli avbrutt.",
    "Interval in seconds in which the feeds will be updated." : "Intervall i sekunder som strømmene vil bli oppdatert.",
    "No article selected" : "Ingen artikkel valgt",
    "Show all articles" : "Vis alle artikler",
    "Move" : "Flytt",
    "User Name" : "Brukernavn",
    "Share" : "Del",
    "Share with" : "Del med",
    "Share with {num} users" : "Del med {num} brukere",
    "Rename Folder" : "Omdøp mappe",
    "Are you sure you want to delete?" : "Er du sikker på at du vil slette?",
    "Mark read" : "Merk som lest",
    "All articles" : "Alle artikler",
    "Starred" : "Merket",
    "Explore" : "Utforsk",
    "Rename" : "Gi nytt navn",
    "Delete" : "Slett",
    "Rename Feed" : "Omdøp strøm",
    "Open Feed URL" : "Åpne nyhetsstrømadresse",
    "Unpin from top" : "Fjern feste fra topp",
    "Pin to top" : "Fest til topp",
    "Newest first" : "Nyeste først",
    "Oldest first" : "Eldste først",
    "Default order" : "Forvalgt rekkefølge",
    "Enable full text" : "Skru på fulltekst",
    "Disable full text" : "Skru av fulltekst",
    "from" : "fra",
    "Share within Instance" : "Del med forekomst",
    "Toggle star article" : "Veksle stjernemerking av artikkel",
    "Mark unread" : "Marker som ulest",
    "Close details" : "Lukk detaljer",
    "shared by" : "delt av",
    "by" : "av",
    "Play audio" : "Spill lyd",
    "Download audio" : "Last ned lyd",
    "Download video" : "Last ned video",
    "Open website" : "Åpne nettside",
    "Keep article unread" : "Behold artikkelen ulest",
    "Toggle keep current article unread" : "Veksle å beholde denne artikkelen ulest",
    "Remove keep article unread" : "Fjern behold artikkelen ulest",
    "Default" : "Forvalg",
    "Vertical" : "Vertikal",
    "Horizontal" : "Horisontal",
    "Off" : "Av",
    "Never" : "Aldri",
    "General" : "Generell",
    "Disable mark read through scrolling" : "Slå av merk som lest ved blading",
    "Reverse ordering (oldest on top)" : "Omvendt sortering (elste øverst)",
    "Media" : "Media",
    "Appearance" : "Utseende",
    "Import" : "Importer",
    "Export" : "Eksporter",
    "Please wait" : "Vent",
    "Keyboard shortcuts" : "Tastatursnarveier",
    "Refresh" : "Oppdater",
    "Jump to previous article" : "Gå til forrige artikkel",
    "Jump to next article" : "Gå til neste artikkel",
    "Open article in new tab" : "Åpne artikkel i ny fane",
    "Resources" : "Ressurser",
    "Title" : "Navn",
    "Folder" : "Mappe",
    "Not available" : "Ikke ledig",
    "All Articles" : "Alle artikler",
    "No feeds found to add" : "Ingen nyhetsstrømmer funnet å legge til",
    "Subscribe to" : "Abonner på",
    "Unread Articles" : "Uleste artikler",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax eller webcron-metode påvist! Strømmene dine vil ikke bli oppdaterte!",
    "How to set up the operating system cron" : "Hvordan sette opp operativsystemets Cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installer og sett opp en raskere parallel oppdaterer som bruker nyhetsappens oppdaterings-API"
},
"nplurals=2; plural=(n != 1);");
