OC.L10N.register(
    "news",
    {
    "News" : "Notícias",
    "an article" : "um artigo",
    "Someone" : "Alguém",
    "%1$s shared \"%2$s\" with you" : "%1$s compartilhou \"%2$s\" com você",
    "{user} shared \"{article}\" with you" : "{user} compartilhou \"{article}\" com você",
    "News feeds" : "Feed de notícias",
    "Unread articles" : "Artigos não lidos",
    "News folders" : "Pastas de notícias",
    "News articles" : "Artigos de notícias",
    "Shared with me" : "Compartilhado comigo",
    "Untitled article" : "Artigo sem título",
    "An RSS/Atom feed reader" : "Um leitor de RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Um aplicativo leitor de Feeds RSS/Atom para Nextcloud\n\n- 📲 Sincronize seus feeds com vários [clientes](https://nextcloud.github.io/news/clients/) móveis ou de desktop\n- 🔄 Atualizações automáticas de seus feeds de notícias\n- 🆓 Livre e de código aberto sob AGPLv3, sem propaganda ou funções premium\n\n**Atualmente, o Cron do sistema é necessário para que este aplicativo funcione**\n\nOs requisitos podem ser encontrados [aqui](https://nextcloud.github.io/news/install/#dependencies)\n\nO registro de alterações está disponível [aqui](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCrie um [relatório de bug](https://github.com/nextcloud/news/issues/new/choose)\n\nCrie uma [solicitação de recurso](https://github.com/nextcloud/news/discussions/new)\n\nRelate um [problema de feed](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Baixar",
    "Close" : "Fechar",
    "Internal server error!" : "Erro interno do servidor!",
    "Unknown error!" : "Erro desconhecido!",
    "Web address" : "Endereço web",
    "Please check your data/nextcloud.log file for additional information!" : "Por favor, verifique seu arquivo data/nextcloud.log para obter informações adicionais!",
    "No folder" : "Nenhuma pasta",
    "Folder name" : "Nome da pasta",
    "Username" : "Nome de usuário",
    "Password" : "Senha",
    "Feed exists already!" : "Este feed já existe!",
    "New folder" : "Nova pasta",
    "Folder exists already!" : "Esta pasta já existe!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Credenciais Básicas de Autenticação HTTP devem ser armazenadas sem criptografia! Todos com acesso ao servidor ou banco de dados serão capazes de acessá-los!",
    "Credentials" : "Credenciais",
    "Auto discover Feed" : "Autodescobrir Feed",
    "Subscribe" : "Assinar",
    "Successfully updated news configuration" : "Configuração de notícias atualizada com sucesso",
    "Unable to update news config" : "Não foi possível atualizar a configuração de notícias",
    "Logo purge has never been run." : "A limpeza dos logotipos nunca foi executada.",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "A última limpeza dos logotipos ocorreu {relativeLastLogoPurge}. Algo está errado.",
    "Last logo purge job ran {relativeLastLogoPurge}." : "A última limpeza dos logotipos ocorreu {relativeLastLogoPurge}.",
    "No job execution data available. The cron job may not be running properly." : "Não há dados de execução de tarefas disponíveis. O trabalho cron pode não estar sendo executado corretamente.",
    "Last job execution ran {relativeTime}. Something is wrong." : "A última tarefa foi executada {relativeTime}. Algo está errado.",
    "Last job ran {relativeTime}." : "A última tarefa foi executada {relativeTime}.",
    "Maximum read count per feed" : "O número máximo de leituras por feed",
    "Maximum redirects" : "Redirecionamentos máximos",
    "Feed fetcher timeout" : "Tempo limite do buscador de feed",
    "Explore Service URL" : "Explorar Serviços URL",
    "Update interval" : "Intervalo de atualização",
    "Use system cron for updates" : "Usar o sistema Cron para atualizações",
    "Disable this if you use a custom updater." : "Desative isso se você usar um atualizador personalizado.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Define a quantidade máxima de artigos que podem ser lidos por feed que não serão excluídos pelo trabalho de limpeza; se artigos antigos reaparecerem após serem lidos, aumente este valor; valores negativos, como -1, desativarão este recurso.",
    "Delete unread articles automatically" : "Remover artigos não-lidos automaticamente",
    "Enable this if you also want to delete unread articles." : "Ative esta opção se você também quiser excluir artigos não lidos.",
    "How many redirects the feed fetcher should follow." : "Quantos redirecionamentos o buscador de feed deve seguir.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "O número máximo de segundos para esperar por um feed RSS ou Atom carregar; se ele demorar muito a atualização será cancelada.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Se fornecido, o URL deste serviço será consultado para exibir os feeds na seção de feeds de exploração. Para voltar ao serviço de exploração incorporado, deixe esta entrada vazia.",
    "Interval in seconds in which the feeds will be updated." : "Intervalo em segundos em que os feeds serão atualizados.",
    "Use next update time for feed updates" : "Usar o horário da próxima atualização para atualizações de feed",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Ative esta opção para usar o tempo calculado da próxima atualização para atualizações de feed. Desative para atualizar os feeds com base apenas no intervalo de atualização.",
    "Article list" : "Lista de artigos",
    "Article details" : "Detalhes do artigo",
    "No article selected" : "Nenhum artigo selecionado",
    "Please select an article from the list." : "Por favor, selecione um artigo da lista.",
    "Show all articles" : "Exibir todos os artigos",
    "Move feed" : "Mover feed",
    "Please select the new folder" : "Por favor, selecione a nova pasta",
    "Move" : "Mover",
    "User Name" : "Nome de usuário",
    "Share" : "Compartilhar",
    "Share with" : "Compartilhar com",
    "Share with {num} users" : "Compartilhe com {num} usuários",
    "Rename Folder" : "Renomear Pasta",
    "Are you sure you want to delete?" : "Tem certeza de que deseja excluir?",
    "Unable to save starred open state" : "Não é possível salvar o estado aberto com estrela",
    "Mark read" : "Marcar como lido",
    "All articles" : "Todos os artigos",
    "Recently viewed" : "Visto recentemente",
    "Starred" : "Destacado",
    "Has feeds with errors!" : "Tem feeds com erros!",
    "Explore" : "Explorar",
    "Feed settings" : "Configurações do feed",
    "News settings" : "Configurações das notícias",
    "Rename" : "Renomear",
    "Delete" : "Excluir",
    "Rename Feed" : "Renomear Feed",
    "Open Feed URL" : "Abrir URL do Feed",
    "Unpin from top" : "Tirar  destacados no topo",
    "Pin to top" : "Destacados no topo",
    "Newest first" : "Mais recentes primeiro",
    "Oldest first" : "Mais antigos primeiro",
    "Default order" : "Ordem padrão",
    "Enable full text" : "Habilita texto completo",
    "Disable full text" : "Desabilitar texto completo",
    "Mark as unread on update" : "Marcar como não lido na atualização",
    "Keep read status on update" : "Manter o status de leitura na atualização",
    "Sync disabled" : "Sincronização desativada",
    "Sync enabled" : "Sincronização ativada",
    "Show external media" : "Exibir mídia externa",
    "from" : "de",
    "External media loaded from" : "Mídia externa carregada de",
    "Previous Item" : "Item Anterior",
    "Next Item" : "Próximo Item",
    "Share within Instance" : "Compartilhar dentro da Instância",
    "Toggle star article" : "Alternar destaque do arquivo",
    "Mark unread" : "Marcar como não lido",
    "Close details" : "Fechar detalhes",
    "shared by" : "compartilhado por",
    "by" : "por",
    "Play audio" : "Reproduzir áudio",
    "Download audio" : "Baixar áudio",
    "Download video" : "Baixar vídeo",
    "Refresh list" : "Atualizar lista",
    "Open website" : "Abrir website",
    "Keep article unread" : "Manter artigo não lido",
    "Toggle keep current article unread" : "Alternar manter o presente artigo não lido",
    "Remove keep article unread" : "Excluir manter artigo não lido",
    "Default" : "Padrão",
    "Compact" : "Compacto",
    "Screenreader" : "Leitor de tela",
    "Vertical" : "Vertical",
    "Horizontal" : "Horizontal",
    "Off" : "Desativado",
    "Always" : "Sempre",
    "Ask" : "Perguntar",
    "Never" : "Nunca",
    "Please select a valid OPML file" : "Por favor, selecione um arquivo OPML válido",
    "File successfully uploaded" : "Arquivo carregado com sucesso",
    "Error uploading the opml file" : "Erro ao carregar o aquivo opml",
    "Error connecting to the server" : "Error ao conectar ao servidor",
    "Error retrieving the opml file" : "Erro ao recuperar o arquivo opml",
    "Please select a valid json file" : "Por favor, selecione um arquivo JSON válido",
    "Error uploading the json file" : "Erro ao fazer upload do arquivo JSON",
    "Error retrieving the json file" : "Erro ao obter o arquivo JSON",
    "General" : "Geral",
    "Disable mark read through scrolling" : "Desativar a marca de lido durante a rolagem",
    "Reverse ordering (oldest on top)" : "Ordem inversa (mais antigo no topo)",
    "Disable automatic refresh" : "Desativar atualização automática",
    "Media" : "Mídia",
    "Show embedded thumbnails" : "Mostrar miniaturas incorporadas",
    "Show enclosure images" : "Mostrar imagens do anexo",
    "Show images in the article text" : "Exibir imagens no texto do artigo",
    "Show iframes in the article text" : "Exibir iframes no texto do artigo",
    "Appearance" : "Aparência",
    "Display mode" : "Modo de exibição",
    "Split mode" : "Modo dividido",
    "Import" : "Importação",
    "Export" : "Exportação",
    "Abonnements (OPML)" : "Inscrições (OPML)",
    "Importing feeds" : "Importando feeds",
    "Please wait" : "Por favor, espere",
    "Articles (JSON)" : "Artigos (JSON) ",
    "Keyboard shortcuts" : "Atalhos de teclado",
    "Refresh" : "Atualizar",
    "Screenreader mode only" : "Apenas modo leitor de tela",
    "Jump to previous article" : "Voltar para o artigo anterior",
    "Jump to next article" : "Avançar para o próximo artigo",
    "Item navigation and control" : "Navegação e controle de itens",
    "Open article in new tab" : "Abrir o artigo em nova aba",
    "Show article details in compact view" : "Mostrar detalhes do artigo em visualização compacta",
    "Close article details in compact view" : "Fechar detalhes do artigo em visualização compacta",
    "Feed/Folder navigation and control" : "Navegação e controle de feed/pasta",
    "Jump to previous feed" : "Ir para o feed anterior",
    "Jump to next feed" : "Ir para o próximo feed",
    "Jump to previous folder" : "Ir para a pasta anterior",
    "Jump to next folder" : "Ir para a próxima pasta",
    "Mark current articles feed/folder as read" : "Marcar feed/pasta de artigos atual como lido",
    "Resources" : "Recursos",
    "Last update" : "Última atualização",
    "Time when the feed was last downloaded" : "Hora em que o feed foi baixado pela última vez",
    "Next update" : "Próxima atualização",
    "Time when the next feed update will be done" : "Hora em que será feita a próxima atualização do feed",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Somente se ativado nas configurações do administrador; caso contrário, será usado o intervalo de atualização regular",
    "Articles per update" : "Artigos por atualização",
    "Maximum number of articles reached in a feed update" : "Número máximo de artigos recuperados em uma atualização de feed",
    "Error Count" : "Número de Erros",
    "Number of errors that have occurred since the last successful feed update" : "Número de erros que ocorreram desde a última atualização bem-sucedida do feed",
    "Title" : "Título",
    "Folder" : "Pasta",
    "Not available" : "Não disponível",
    "All Articles" : "Todos os Artigos",
    "No feeds found to add" : "Nenhum feed encontrado para adicionar",
    "Subscribe to" : "Inscrever-se em",
    "Unread Articles" : "Artigos Não Lidos",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Modo ajax ou webcron detectado! Seus feeds não serão atualizados!",
    "How to set up the operating system cron" : "Como configurar o Cron do sistema operacional",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instale e configure um atualizador rápido paralelo que usa os novos aplicativos API para atualizar"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
