OC.L10N.register(
    "news",
    {
    "%1$s shared \"%2$s\" with you" : "%1$s paylaşdı \"%2$s\" sizinlə",
    "Unread articles" : "Oxunulmamış məqalə",
    "Download" : "Yüklə",
    "Close" : "Bağla",
    "Folder name" : "Qovluq adı",
    "Username" : "İstifadəçi adı",
    "Password" : "Şifrə",
    "New folder" : "Yeni qovluq",
    "Credentials" : "Səlahiyyətlər",
    "Subscribe" : "Abunə",
    "Last job ran {relativeTime}." : "Son işin icra vaxtı {relativeTime}.",
    "Move" : "Move",
    "Share" : "Paylaş",
    "All articles" : "Bütün məqalələr",
    "Starred" : "Ulduzlu",
    "Rename" : "Adı dəyiş",
    "Delete" : "Sil",
    "from" : "ondan",
    "by" : "onunla",
    "Always" : "Həmişə",
    "Never" : "Heç vaxt",
    "General" : "Ümumi",
    "Import" : "Əlavə et",
    "Export" : "Çıxarış",
    "Refresh" : "Yenilə",
    "Resources" : "Resurslar",
    "Folder" : "Qovluq"
},
"nplurals=2; plural=(n != 1);");
