OC.L10N.register(
    "news",
    {
    "News" : "Notícias",
    "Someone" : "Alguém",
    "%1$s shared \"%2$s\" with you" : "%1$s partilhou \"%2$s\" consigo",
    "News feeds" : "Feeds de notícias",
    "Unread articles" : "Artigos não lidos",
    "News folders" : "Novas pastas",
    "Shared with me" : "Partilhadas comigo",
    "An RSS/Atom feed reader" : "Leitor de feeds RSS/Atom",
    "Download" : "Transferir",
    "Close" : "Fechar",
    "Web address" : "Endereço da Web",
    "No folder" : "Sem Pasta",
    "Folder name" : "Nome da pasta",
    "Username" : "Nome de utilizador",
    "Password" : "Senha",
    "Feed exists already!" : "A feed já existe!",
    "New folder" : "Nova Pasta",
    "Folder exists already!" : "A pasta já existe!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "As credenciais de autenticação básica HTTP têm de ser armazenadas de forma não encriptada. Qualquer pessoa com acesso ao servidor ou base de dados poderá vê-las!",
    "Credentials" : "Credenciais",
    "Subscribe" : "Subscrever",
    "Maximum read count per feed" : "Número máximo de leituras por feed",
    "Maximum redirects" : "Máximo de redirecionamentos",
    "Feed fetcher timeout" : "A obtenção do feed expirou",
    "Explore Service URL" : "Explorar Serviço URL",
    "Update interval" : "Intervalo de atualização",
    "Use system cron for updates" : "Use o programador do sistema para as atualizações",
    "Disable this if you use a custom updater." : "Desative isto se é um sistema de atualizações feito à medida.",
    "Show all articles" : "Mostrar todos os artigos",
    "Move" : "Mover",
    "Share" : "Partilhar",
    "Share with" : "Partilhar com",
    "Mark read" : "Marcar como lido",
    "All articles" : "Todos os artigos",
    "Starred" : "Marcado",
    "Explore" : "Explorar",
    "Rename" : "Renomear",
    "Delete" : "Apagar",
    "Rename Feed" : "Renomear Feed",
    "Open Feed URL" : "Abrir URL da Feed",
    "Newest first" : "Recentes primeiro",
    "Oldest first" : "Antigos primeiro",
    "from" : "De",
    "Toggle star article" : "Alternar estrela do artigo",
    "Mark unread" : "Marcar como não lido",
    "shared by" : "partilhado por",
    "by" : "por",
    "Play audio" : "Reproduzir áudio",
    "Download audio" : "Transferir áudio",
    "Download video" : "Transferir vídeo",
    "Open website" : "Abrir site da web",
    "Keep article unread" : "Marcar artigo como não lido",
    "Toggle keep current article unread" : "Alternar manter o artigo atual como não lido",
    "Remove keep article unread" : "Remover marcação de artigo não lido",
    "Default" : "Predefinido",
    "Vertical" : "Vertical",
    "Horizontal" : "Horizontal",
    "Always" : "Sempre",
    "Never" : "Nunca",
    "General" : "Geral",
    "Disable mark read through scrolling" : "Desativar marcar ler através de movimento",
    "Reverse ordering (oldest on top)" : "Ordem inversa (antigos no topo)",
    "Media" : "Media",
    "Appearance" : "Aspeto",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Please wait" : "Por favor aguarde",
    "Keyboard shortcuts" : "Atalhos de teclado",
    "Refresh" : "Atualizar",
    "Jump to previous article" : "Ir para o artigo anterior",
    "Jump to next article" : "Ir para o artigo seguinte",
    "Open article in new tab" : "Abrir artigo num separador novo",
    "Resources" : "Recursos",
    "Last update" : "Último refrescamento",
    "Time when the feed was last downloaded" : "A hora em que a \"feed\" foi transferida pela última vez",
    "Title" : "Título",
    "Folder" : "Pasta",
    "Not available" : "Não disponível",
    "How to set up the operating system cron" : "Como configurar o cron no sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instale e configure um atualizador paralelo mais rápido que use a API de atualizações da aplicação Notícias"
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
