OC.L10N.register(
    "news",
    {
    "News" : "News",
    "Someone" : "ບາງຄົນ",
    "%1$s shared \"%2$s\" with you" : "%1$sແບ່ງປັນ\"%2$s\"ດ້ວຍທ່ານ",
    "News feeds" : "News feeds",
    "Unread articles" : "Unread articles",
    "News folders" : "News folders",
    "News articles" : "News articles",
    "Shared with me" : "Shared with me",
    "An RSS/Atom feed reader" : "An RSS/Atom feed reader",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "ດາວໂຫລດ",
    "Close" : "ປິດ",
    "Internal server error!" : "Internal server error!",
    "Unknown error!" : "Unknown error!",
    "Web address" : "Web address",
    "Please check your data/nextcloud.log file for additional information!" : "Please check your data/nextcloud.log file for additional information!",
    "No folder" : "No folder",
    "Folder name" : "ຊື່ໂຟນເດີ",
    "Username" : "ຊື່ຜູ້ໃຊ້",
    "Password" : "ລະຫັດຜ່ານ",
    "Feed exists already!" : "Feed exists already!",
    "New folder" : "ໂຟນເດີໃຫມ່",
    "Folder exists already!" : "Folder exists already!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!",
    "Credentials" : "ຂໍມູນປະຈຳຕົວ",
    "Auto discover Feed" : "Auto discover Feed",
    "Subscribe" : "Subscribe",
    "Successfully updated news configuration" : "Successfully updated news configuration",
    "Unable to update news config" : "Unable to update news config",
    "Logo purge has never been run." : "Logo purge has never been run.",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "Last logo purge ran {relativeLastLogoPurge}. Something is wrong.",
    "Last logo purge job ran {relativeLastLogoPurge}." : "Last logo purge job ran {relativeLastLogoPurge}.",
    "No job execution data available. The cron job may not be running properly." : "No job execution data available. The cron job may not be running properly.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Last job execution ran {relativeTime}. Something is wrong.",
    "Last job ran {relativeTime}." : "Last job ran {relativeTime}.",
    "Maximum read count per feed" : "Maximum read count per feed",
    "Maximum redirects" : "Maximum redirects",
    "Feed fetcher timeout" : "Feed fetcher timeout",
    "Explore Service URL" : "Explore Service URL",
    "Update interval" : "Update interval",
    "Use system cron for updates" : "Use system cron for updates",
    "Disable this if you use a custom updater." : "Disable this if you use a custom updater.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off.",
    "Delete unread articles automatically" : "Delete unread articles automatically",
    "Enable this if you also want to delete unread articles." : "Enable this if you also want to delete unread articles.",
    "How many redirects the feed fetcher should follow." : "How many redirects the feed fetcher should follow.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty.",
    "Interval in seconds in which the feeds will be updated." : "Interval in seconds in which the feeds will be updated.",
    "Use next update time for feed updates" : "Use next update time for feed updates",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval.",
    "Article list" : "Article list",
    "Article details" : "Article details",
    "No article selected" : "No article selected",
    "Please select an article from the list." : "Please select an article from the list.",
    "Show all articles" : "Show all articles",
    "Move feed" : "Move feed",
    "Please select the new folder" : "Please select the new folder",
    "Move" : "ຍ້າຍ",
    "User Name" : "User Name",
    "Share" : "ແບ່ງປັນ",
    "Share with" : "Share with",
    "Share with {num} users" : "Share with {num} users",
    "Rename Folder" : "Rename Folder",
    "Are you sure you want to delete?" : "Are you sure you want to delete?",
    "Mark read" : "Mark read",
    "All articles" : "All articles",
    "Recently viewed" : "Recently viewed",
    "Starred" : "Starred",
    "Has feeds with errors!" : "Has feeds with errors!",
    "Explore" : "Explore",
    "Rename" : "ປ່ຽນຊື່",
    "Delete" : "ລຶບ",
    "Rename Feed" : "Rename Feed",
    "Open Feed URL" : "Open Feed URL",
    "Unpin from top" : "Unpin from top",
    "Pin to top" : "Pin to top",
    "Newest first" : "ໃໝ່ທີ່ສຸດກ່ອນ",
    "Oldest first" : "ເກົ່າທີ່ສຸດກ່ອນ",
    "Default order" : "Default order",
    "Enable full text" : "Enable full text",
    "Disable full text" : "Disable full text",
    "Mark as unread on update" : "Mark as unread on update",
    "Keep read status on update" : "Keep read status on update",
    "Sync disabled" : "Sync disabled",
    "Sync enabled" : "Sync enabled",
    "from" : "ຈາກ",
    "Previous Item" : "Previous Item",
    "Next Item" : "Next Item",
    "Share within Instance" : "Share within Instance",
    "Toggle star article" : "Toggle star article",
    "Mark unread" : "Mark unread",
    "Close details" : "Close details",
    "shared by" : "shared by",
    "by" : "by",
    "Play audio" : "Play audio",
    "Download audio" : "Download audio",
    "Download video" : "Download video",
    "Refresh list" : "Refresh list",
    "Open website" : "Open website",
    "Keep article unread" : "Keep article unread",
    "Toggle keep current article unread" : "Toggle keep current article unread",
    "Remove keep article unread" : "Remove keep article unread",
    "Default" : "ເລີ່ມຕົ້ນ",
    "Compact" : "Compact",
    "Screenreader" : "Screenreader",
    "Vertical" : "Vertical",
    "Horizontal" : "Horizontal",
    "Off" : "Off",
    "Always" : "Always",
    "Never" : "ບໍ່ເຄີຍ",
    "Please select a valid OPML file" : "Please select a valid OPML file",
    "File successfully uploaded" : "File successfully uploaded",
    "Error uploading the opml file" : "Error uploading the opml file",
    "Error connecting to the server" : "Error connecting to the server",
    "Error retrieving the opml file" : "Error retrieving the opml file",
    "General" : "ທົ່ວໄປ",
    "Disable mark read through scrolling" : "Disable mark read through scrolling",
    "Reverse ordering (oldest on top)" : "Reverse ordering (oldest on top)",
    "Disable automatic refresh" : "Disable automatic refresh",
    "Media" : "ຊື່ມວນຊົນ",
    "Appearance" : "ຮູບລັກ",
    "Display mode" : "Display mode",
    "Split mode" : "Split mode",
    "Import" : "ນຳເຂົ້າ",
    "Export" : "ສົ່ງອອກ",
    "Abonnements (OPML)" : "Abonnements (OPML)",
    "Importing feeds" : "Importing feeds",
    "Please wait" : "Please wait",
    "Keyboard shortcuts" : "Keyboard shortcuts",
    "Refresh" : "Refresh",
    "Jump to previous article" : "Jump to previous article",
    "Jump to next article" : "Jump to next article",
    "Open article in new tab" : "Open article in new tab",
    "Show article details in compact view" : "Show article details in compact view",
    "Close article details in compact view" : "Close article details in compact view",
    "Mark current articles feed/folder as read" : "Mark current articles feed/folder as read",
    "Resources" : "ຊັບພະຍາກອນ",
    "Last update" : "Last update",
    "Time when the feed was last downloaded" : "Time when the feed was last downloaded",
    "Next update" : "Next update",
    "Time when the next feed update will be done" : "Time when the next feed update will be done",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Only if activated in the admin settings, otherwise the regular update interval is used",
    "Articles per update" : "Articles per update",
    "Maximum number of articles reached in a feed update" : "Maximum number of articles reached in a feed update",
    "Error Count" : "Error Count",
    "Number of errors that have occurred since the last successful feed update" : "Number of errors that have occurred since the last successful feed update",
    "Title" : "ຫົວຂໍ້",
    "Folder" : "Folder",
    "Not available" : "Not available",
    "All Articles" : "All Articles",
    "No feeds found to add" : "No feeds found to add",
    "Subscribe to" : "Subscribe to",
    "Unread Articles" : "Unread Articles",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax or webcron mode detected! Your feeds will not be updated!",
    "How to set up the operating system cron" : "How to set up the operating system cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Install and set up a faster parallel updater that uses the News app's update API"
},
"nplurals=1; plural=0;");
