OC.L10N.register(
    "news",
    {
    "Download" : "Sider",
    "Close" : "Mdel",
    "Folder name" : "Isem n ukaram",
    "Username" : "Isem n useqdac",
    "Password" : "Awal uffir",
    "New folder" : "Akaram amaynut",
    "Move" : "Senkez",
    "Share" : "Bḍu",
    "Rename" : "Beddel isem",
    "Delete" : "Kkes",
    "Newest first" : "Imaynuten d imezwura",
    "Oldest first" : "Iqbuṛen d imezwura",
    "Default" : "Prédéfini(e)",
    "Off" : "Ur irmid ara",
    "General" : "Amatu",
    "Media" : "Amidya",
    "Appearance" : "Udem",
    "Export" : "Sifeḍ",
    "Keyboard shortcuts" : "Inegzumen n unasiw",
    "Refresh" : "Sismeḍ",
    "Title" : "Azwel",
    "Folder" : "Akaram"
},
"nplurals=2; plural=(n != 1);");
