OC.L10N.register(
    "news",
    {
    "Download" : "Llwytho i lawr",
    "Close" : "Cau",
    "Web address" : "Cyfeiriad gwe",
    "Username" : "Enw defnyddiwr",
    "Password" : "Cyfrinair",
    "New folder" : "Ffolder newydd",
    "Credentials" : "Credentials",
    "Subscribe" : "Tanysgrifio",
    "Move" : "Symud",
    "Share" : "Rhannu",
    "Mark read" : "Marcio wedi'i ddarllen",
    "Rename" : "Ailenwi",
    "Delete" : "Dileu",
    "Newest first" : "Diweddaraf gyntaf",
    "Oldest first" : "Hynaf gyntaf",
    "from" : "oddi wrth",
    "Mark unread" : "Nodi heb ei ddarllen",
    "by" : "gan",
    "General" : "Cyffredinol",
    "Import" : "Mewnforio",
    "Export" : "Allforio",
    "Keyboard shortcuts" : "Llwybrau byr bysellfwrdd",
    "Refresh" : "Adnewyddu",
    "Resources" : "Adnoddau",
    "Folder" : "Plygell",
    "Not available" : "Ddim ar gael"
},
"nplurals=4; plural=(n==1) ? 0 : (n==2) ? 1 : (n != 8 && n != 11) ? 2 : 3;");
