OC.L10N.register(
    "news",
    {
    "News" : "News",
    "Someone" : "Quelqu'un",
    "%1$s shared \"%2$s\" with you" : "%1$s a partagé \"%2$s\" avec vous",
    "News feeds" : "Flux d'actualités",
    "Unread articles" : "Articles non lus",
    "News folders" : "Dossiers dans News",
    "News articles" : "Articles dans News",
    "Shared with me" : "Partagé avec moi",
    "An RSS/Atom feed reader" : "Un lecteur de flux RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Un lecteur de flux RSS/Atom pour Nextcloud\n\n- 📲 Synchronisez vos flux sur plusieurs [clients](https://nextcloud.github.io/news/clients/) mobiles ou de bureau\n- 🔄 Mise à jour automatique de vox flux d'actualité\n- 🆓 Libre et open source sous licence AGPLv3, sans publicité et sans fonctionnalités premium\n\n**L'utilisation du Cron système est requise pour le fonctionnement de cette application**\n\nLa liste des prérequis est disponible [ici](https://nextcloud.github.io/news/install/#dependencies)\n\nLe journal de versions est consultable [ici](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nSignaler un [bug](https://github.com/nextcloud/news/issues/new/choose)\n\nDemander une [fonctionnalité](https://github.com/nextcloud/news/discussions/new)\n\nSignaler un [problème avec l'application](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Télécharger",
    "Close" : "Fermer",
    "Internal server error!" : "Erreur interne du serveur !",
    "Unknown error!" : "Erreur inconnue !",
    "Web address" : "Adresse web",
    "Please check your data/nextcloud.log file for additional information!" : "Merci de vérifier votre fichier data/nextcloud.log pour plus d'informations !",
    "No folder" : "Aucun dossier",
    "Folder name" : "Nom du dossier",
    "Username" : "Nom d’utilisateur",
    "Password" : "Mot de passe",
    "Feed exists already!" : "Le flux existe déjà !",
    "New folder" : "Nouveau dossier",
    "Folder exists already!" : "Le dossier existe déjà !",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Les identifiants d'authentification de base HTTP doivent être stockées en clair ! Toute personne ayant accès au serveur ou à la base de données y aura accès !",
    "Credentials" : "Identifiants",
    "Auto discover Feed" : "Découverte automatique du flux",
    "Subscribe" : "S’abonner",
    "Successfully updated news configuration" : "Mise à jour réussie de la configuration des actualités",
    "Unable to update news config" : "Impossible de mettre à jour la configuration des actualités",
    "No job execution data available. The cron job may not be running properly." : "Aucune information disponible sur l'exécution de tâche. La tâche cron ne fonctionne peut-être pas correctement.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Dernière tâche cron exécutée : {relativeTime}. Quelque chose s'est mal passé.",
    "Last job ran {relativeTime}." : "Dernière tâche exécutée en {relativeTime}.",
    "Maximum read count per feed" : "Nombre maximum de lecture par flux",
    "Maximum redirects" : "Nombre maximal de redirections",
    "Feed fetcher timeout" : "Délai d'attente maximum du récupérateur de flux",
    "Explore Service URL" : "URL du service d'exploration",
    "Update interval" : "Intervalle de mise à jour",
    "Use system cron for updates" : "Utiliser le « cron » du système pour les mises à jour",
    "Disable this if you use a custom updater." : "Désactivez ceci si vous utilisez un outil de mise à jour personnalisé.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Définit le nombre maximum d’articles pouvant être lus par flux qui ne seront pas supprimés par la tâche de nettoyage ; si d'anciens articles réapparaissent après avoir été lus, augmentez cette valeur ; les valeurs négatives telles que -1 vont désactiver cette fonctionnalité.",
    "Delete unread articles automatically" : "Supprimer automatiquement les articles non lus",
    "Enable this if you also want to delete unread articles." : "Activez ceci si vous voulez aussi supprimer les articles non lus.",
    "How many redirects the feed fetcher should follow." : "Nombre de redirections que le récupérateur de flux doit suivre",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Nombre maximal de secondes que peut prendre un flux RSS ou Atom pour être chargé. Si le délai est dépassé, la mise à jour sera annulée",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Si indiquée, l'URL de ce service sera interrogée pour afficher les flux dans la section d'exploration. Pour revenir au service d'exploration par défaut, laissez ce champ vide.",
    "Interval in seconds in which the feeds will be updated." : "Fréquence à laquelle les flux seront mis à jour (en secondes).",
    "Use next update time for feed updates" : "Utiliser la prochaine période de mise à jour pour mettre à jour les flux",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Activer ceci pour utiliser la prochaine période de mise à jour calculée pour la mise à jour des flux. Désactiver le pour mettre à jour les flux en fonction seulement de l'intervalle de mise à jour.",
    "Article list" : "Liste des articles",
    "Article details" : "Détails de l'article",
    "No article selected" : "Aucun article sélectionné",
    "Please select an article from the list." : "Veuillez sélectionner un article dans la liste",
    "Show all articles" : "Afficher tous les articles",
    "Move" : "Déplacer",
    "User Name" : "Nom d'utilisateur",
    "Share" : "Partager",
    "Share with" : "Partager avec",
    "Share with {num} users" : "Partager avec {num} utilisateurs",
    "Rename Folder" : "Renommer le dossier",
    "Are you sure you want to delete?" : "Êtes-vous sûr de vouloir supprimer ?",
    "Mark read" : "Marquer comme lu",
    "All articles" : "Tous les articles",
    "Recently viewed" : "Récemment consulté",
    "Starred" : "Épinglés",
    "Has feeds with errors!" : "Contient des flux avec des erreurs!",
    "Explore" : "Explorer",
    "Rename" : "Renommer",
    "Delete" : "Supprimer",
    "Rename Feed" : "Renommer le flux",
    "Open Feed URL" : "Ouvrir l'URL du flux",
    "Unpin from top" : "Désépingler du haut",
    "Pin to top" : "Épingler en haut",
    "Newest first" : "Les plus récents en premier",
    "Oldest first" : "Les plus anciens en premier",
    "Default order" : "Ordre par défaut",
    "Enable full text" : "Activer le texte intégral",
    "Disable full text" : "Désactiver le texte intégral",
    "Mark as unread on update" : "Marquer comme non lu après mise à jour",
    "Keep read status on update" : "Conserver le statut de lecture après modification",
    "Sync disabled" : "Synchronisation désactivée",
    "Sync enabled" : "Synchronisation activée",
    "from" : "du",
    "Previous Item" : "Elément précédent",
    "Next Item" : "Elément suivant",
    "Share within Instance" : "Partager au sein de l'instance",
    "Toggle star article" : "Épingler/Désépingler l'article",
    "Mark unread" : "Marquer comme non-lu",
    "Close details" : "Fermer les détails",
    "shared by" : "Partagé par",
    "by" : "par",
    "Play audio" : "Écouter",
    "Download audio" : "Télécharger le fichier audio",
    "Download video" : "Télécharger la vidéo",
    "Refresh list" : "Actualiser la liste",
    "Open website" : "Ouvrir le site web",
    "Keep article unread" : "Marquer l’article comme non lu",
    "Toggle keep current article unread" : "Activer/désactiver le fait de garder l'article actuel « non lu »",
    "Remove keep article unread" : "Marquer l’article comme lu",
    "Default" : "Défaut",
    "Compact" : "Compact",
    "Screenreader" : "Lecteur d'écran",
    "Vertical" : "Vertical",
    "Horizontal" : "Horizontal",
    "Off" : "Désactiver",
    "Always" : "Toujours",
    "Never" : "Jamais",
    "Please select a valid OPML file" : "Veuillez sélectionner un fichier OPML valide",
    "File successfully uploaded" : "Fichier téléversé avec succès",
    "Error uploading the opml file" : "Erreur lors du téléversement du fichier opml",
    "Error connecting to the server" : "Erreur de connexion au serveur",
    "Error retrieving the opml file" : "Erreur lors de la récupération du fichier opml",
    "General" : "Général",
    "Disable mark read through scrolling" : "Ne pas marquer les articles comme lus lors du parcours des listes",
    "Reverse ordering (oldest on top)" : "Ordre inverse (les plus anciens en haut)",
    "Disable automatic refresh" : "Désactiver le rafraîchissement automatique",
    "Media" : "Médias",
    "Appearance" : "Apparence",
    "Display mode" : "Mode d'affichage",
    "Split mode" : "Mode découpé",
    "Import" : "Importer",
    "Export" : "Exporter",
    "Abonnements (OPML)" : "Abonnements (OPML)",
    "Importing feeds" : "Importer les flux",
    "Please wait" : "Veuillez patienter",
    "Keyboard shortcuts" : "Raccourcis clavier",
    "Refresh" : "Rafraîchir",
    "Jump to previous article" : "Aller à l’article précédent",
    "Jump to next article" : "Aller au prochain article",
    "Open article in new tab" : "Ouvrir l'article dans un nouvel onglet",
    "Show article details in compact view" : "Afficher les détails de l'article dans la vue compacte",
    "Close article details in compact view" : "Fermer les détails de l'article dans la vue compacte",
    "Mark current articles feed/folder as read" : "Marquer les articles actuels flux/dossier comme lus",
    "Resources" : "Ressources",
    "Last update" : "Dernière mise à jour",
    "Time when the feed was last downloaded" : "Moment auquel le flux a été téléchargé la dernière fois",
    "Next update" : "Prochaine mise à jour",
    "Time when the next feed update will be done" : "Moment où la prochaine mise à jour du flux sera effectuée",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Seulement si activé dans les paramètres d'administration, sinon l'intervalle de mise à jour standard est utilisé",
    "Articles per update" : "Articles par mise à jour",
    "Maximum number of articles reached in a feed update" : "Nombre maximum d'articles atteint dans une mise à jour de flux",
    "Error Count" : "Nombre d'erreurs",
    "Number of errors that have occurred since the last successful feed update" : "Nombre d'erreurs survenues depuis la dernière mise à jour de flux réussie",
    "Title" : "Titre",
    "Folder" : "Dossier",
    "Not available" : "Non disponible",
    "All Articles" : "Tous les articles",
    "No feeds found to add" : "Aucun flux à ajouter trouvé",
    "Subscribe to" : "S'abonner à ",
    "Unread Articles" : "Articles non lus",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Mode Ajax ou Webcron détecté ! Vos flux ne seront pas mis à jour !",
    "How to set up the operating system cron" : "Comment configurer le cron du système d’exploitation",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installer et configurer un outil de mise à jour parallèle plus rapide qui utilise l'API de mise à jour de l'application News."
},
"nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
