OC.L10N.register(
    "news",
    {
    "Unread articles" : "অপঠিত লেখা",
    "Download" : "ডাউনলোড",
    "Close" : "বন্ধ",
    "Web address" : "ওয়েব ঠিকানা",
    "Folder name" : "ফোলডারের নাম",
    "Username" : "ব্যবহারকারী",
    "Password" : "কূটশব্দ",
    "Feed exists already!" : "ফিড পূর্বে থেকেই বিদ্যমান",
    "New folder" : "নব ফােলডার",
    "Folder exists already!" : "ফোল্ডার ইতোমধ্যে বিদ্যমান!",
    "Credentials" : "Credentials",
    "Subscribe" : "গ্রাহক হোন",
    "Move" : "Move",
    "Share" : "ভাগাভাগি কর",
    "All articles" : "সব লেখা",
    "Starred" : "তারা চিহ্নিত",
    "Rename" : "পূনঃনামকরণ",
    "Delete" : "মুছে",
    "from" : "হইতে",
    "by" : "কর্তৃক",
    "Always" : "সর্বদা",
    "General" : "সাধারণ",
    "Import" : "আমদানি",
    "Export" : "রপ্তানি",
    "Keyboard shortcuts" : "কী-বোর্ড শর্টকাট",
    "Refresh" : "নবোদ্যম",
    "Folder" : "ফোল্ডার"
},
"nplurals=2; plural=(n != 1);");
