OC.L10N.register(
    "news",
    {
    "News" : "Новини",
    "Someone" : "Хтось",
    "%1$s shared \"%2$s\" with you" : "%1$s поділив(-ла-)ся %2$s з вами",
    "News feeds" : "Стрічки новин",
    "Unread articles" : "Непрочитані статті",
    "News folders" : "Папки з новинами",
    "News articles" : "Новинні статті",
    "Shared with me" : "Поділилися зі мною",
    "An RSS/Atom feed reader" : "Програма для читання RSS/Atom-стрічок",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Застосунок для читання RSS/Atom-каналів для Nextcloud\n\n- 📲 Синхронізуйте свої канали з декількома мобільними або настільними [клієнтами](https://nextcloud.github.io/news/clients/)\n- 🔄 Автоматичне оновлення ваших новинних каналів\n- 🆓 Безкоштовний та відкритий код під ліцензією AGPLv3, без реклами та преміум-функцій\n\n**Для роботи цього додатка наразі необхідний системний Cron**\n\nВимоги можна знайти [тут](https://nextcloud.github.io/news/install/#dependencies)\n\nЖурнал змін доступний [тут](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nСтворити [звіт про помилку](https://github.com/nextcloud/news/issues/new/choose)\n\nСтворити [запит на функцію](https://github.com/nextcloud/news/discussions/new)\n\nПовідомити про [проблему з стрічкою новин](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Звантажити",
    "Close" : "Закрити",
    "Internal server error!" : "Внутрішня помилка сервера!",
    "Unknown error!" : "Невідома помилка!",
    "Web address" : "Веб адреса",
    "Please check your data/nextcloud.log file for additional information!" : "Будь ласка, перевірте ваш файл data/nextcloud.log для отримання додаткової інформації!",
    "No folder" : "Відсутній каталог",
    "Folder name" : "Назва каталогу",
    "Username" : "Ім'я користувача",
    "Password" : "Пароль",
    "Feed exists already!" : "Стрічка вже існує !",
    "New folder" : "Новий каталог",
    "Folder exists already!" : "Каталог вже існує !",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Облікові дані HTTP Basic Auth повинні зберігатися незашифрованими! Усі, хто має доступ до сервера або бази даних, зможуть отримати до них доступ!",
    "Credentials" : "Облікові дані",
    "Auto discover Feed" : "Автоматичне виявлення стрічки",
    "Subscribe" : "Підписатися",
    "Successfully updated news configuration" : "Конфігурацію новин успішно оновлено",
    "Unable to update news config" : "Не вдається оновити конфігурацію новин",
    "No job execution data available. The cron job may not be running properly." : "Дані про виконання завдання відсутні. Можливо, завдання cron не виконується належним чином.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Останнє завдання виконувалося {relativeTime}. Щось пішло не так.",
    "Last job ran {relativeTime}." : "Останнє завдання виконано {relativeTime}.",
    "Maximum read count per feed" : "Максимальна кількість статей для стрічки",
    "Maximum redirects" : "Максимум перенаправлень",
    "Feed fetcher timeout" : "Час очікування для завантажувача стрічки",
    "Explore Service URL" : "URL сервісу дослідження",
    "Update interval" : "Інтервал оновлення",
    "Use system cron for updates" : "Використовуйте системний cron для оновлень",
    "Disable this if you use a custom updater." : "Вимкніть цей параметр, якщо ви використовуєте користувацький апдейтер.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Визначає максимальну кількість статей, які можна прочитати на канал, які не будуть видалені під час завдання очищення; якщо старі статті знову з’являються після прочитання, збільште це значення; від'ємні значення, такі як -1, вимкнуть цю функцію.",
    "Delete unread articles automatically" : "Автоматично видаляти непрочитані статті",
    "Enable this if you also want to delete unread articles." : "Увімкніть цю опцію, якщо ви також хочете видаляти непрочитані статті.",
    "How many redirects the feed fetcher should follow." : "Скільки перенаправлень повинен виконати кормозаготівельник.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Максимальна кількість секунд очікування завантаження RSS- або Atom-каналу; якщо завантаження триває довше, оновлення буде припинено.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Якщо вказано, URL-адреса цієї служби буде запитуватися для відображення каналів у розділі «Досліджувати канали». Щоб повернутися до вбудованої служби «Досліджувати», залиште це поле порожнім.",
    "Interval in seconds in which the feeds will be updated." : "Інтервал в секундах, через який будуть оновлюватися канали.",
    "Use next update time for feed updates" : "Використовуйте час наступного оновлення для оновлення стрічки",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Увімкніть цю опцію, щоб використовувати розрахований час наступного оновлення для оновлень каналу. Вимкніть, щоб оновлювати канали виключно на основі інтервалу оновлення.",
    "Article list" : "Список статей",
    "Article details" : "Деталі статті",
    "No article selected" : "Не вибрано жодної статті",
    "Please select an article from the list." : "Будь ласка, виберіть статтю зі списку.",
    "Show all articles" : "Показати всі статті",
    "Move" : "Перемістити",
    "User Name" : "Ім'я користувача",
    "Share" : "Спільний доступ",
    "Share with" : "Поділитися з",
    "Share with {num} users" : "Поділітися з {num} користувачами",
    "Rename Folder" : "Перейменувати каталог",
    "Are you sure you want to delete?" : "Ви впевнені, що хочете видалити?",
    "Mark read" : "Позначити як прочитане",
    "All articles" : "Всі статті",
    "Recently viewed" : "Нещодавно переглянуті",
    "Starred" : "Із зірочкою",
    "Has feeds with errors!" : "Має фіди з помилками!",
    "Explore" : "Дослідити",
    "Rename" : "Перейменувати",
    "Delete" : "Вилучити",
    "Rename Feed" : "Перейменувати стрічку",
    "Open Feed URL" : "Відкрийте URL-адресу стрічки",
    "Unpin from top" : "Зняти закріплення",
    "Pin to top" : "Закріпити нагорі",
    "Newest first" : "Новіші спочатку",
    "Oldest first" : "Старіші спочатку",
    "Default order" : "Порядок за замовчуванням",
    "Enable full text" : "Увімкнути контекстний",
    "Disable full text" : "Вимкнути контекстний",
    "Mark as unread on update" : "Позначити як непрочитане при оновленні",
    "Keep read status on update" : "Тримайте статус читання в курсі оновлень",
    "from" : "з",
    "Previous Item" : "Попередній пункт",
    "Next Item" : "Наступний пункт",
    "Share within Instance" : "Ділитися в межах екземпляра",
    "Toggle star article" : "Позначити статтю",
    "Mark unread" : "Позначити як не прочитане",
    "Close details" : "Ближче до деталей",
    "shared by" : "поділилися",
    "by" : "по",
    "Play audio" : "Відтворення аудіо",
    "Download audio" : "Звантажити аудіо",
    "Download video" : "Звантажити відео",
    "Refresh list" : "Оновити список",
    "Open website" : "Відкрити веб-сайт",
    "Keep article unread" : "Залишити статтю непрочитаною",
    "Toggle keep current article unread" : "Залишити статтю непрочитаною",
    "Remove keep article unread" : "Позначити статтю як прочитану",
    "Default" : "Типово",
    "Compact" : "Компактний",
    "Screenreader" : "Зчитувач екрану",
    "Vertical" : "Вертикальний",
    "Horizontal" : "Горизонтальний",
    "Off" : "Вимкнено",
    "Always" : "Завжди",
    "Never" : "Ніколи",
    "Please select a valid OPML file" : "Будь ласка, виберіть правильний файл OPML",
    "File successfully uploaded" : "Файл успішно завантажено",
    "Error uploading the opml file" : "Помилка при завантаженні opml-файлу",
    "Error connecting to the server" : "Помилка підключення до сервера",
    "Error retrieving the opml file" : "Помилка при отриманні opml-файлу",
    "General" : "Загальне",
    "Disable mark read through scrolling" : "Вимкнути читання поміток при прокрутці",
    "Reverse ordering (oldest on top)" : "Зворотний порядок (найстаріші зверху)",
    "Disable automatic refresh" : "Вимкнути автоматичне оновлення",
    "Media" : "Зображення та відео",
    "Appearance" : "Вигляд",
    "Display mode" : "Режим відображення",
    "Split mode" : "Роздільний режим",
    "Import" : "Імпорт",
    "Export" : "Експортувати",
    "Abonnements (OPML)" : "Підписки (OPML)",
    "Importing feeds" : "Імпорт кормів",
    "Please wait" : "Будь ласка, зачекайте",
    "Keyboard shortcuts" : "Клавіатурні скорочення",
    "Refresh" : "Оновити",
    "Jump to previous article" : "Попередня стаття",
    "Jump to next article" : "Наступна стаття",
    "Open article in new tab" : "Відкрити статтю в новій вкладці",
    "Show article details in compact view" : "Показати деталі статті в компактному вигляді",
    "Close article details in compact view" : "Закрийте деталі статті в компактному вигляді",
    "Mark current articles feed/folder as read" : "Позначити поточну стрічку/папку зі статтями як прочитану",
    "Resources" : "Ресурси",
    "Last update" : "Останнє оновлення",
    "Time when the feed was last downloaded" : "Час останнього завантаження стрічки",
    "Next update" : "Наступне оновлення",
    "Time when the next feed update will be done" : "Час наступного оновлення стрічки",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Тільки якщо активовано в налаштуваннях адміністратора, інакше використовується звичайний інтервал оновлення",
    "Articles per update" : "Статті за одне оновлення",
    "Maximum number of articles reached in a feed update" : "Максимальна кількість статей, досягнута в оновленні стрічки",
    "Error Count" : "Кількість помилок",
    "Number of errors that have occurred since the last successful feed update" : "Кількість помилок, що виникли з моменту останнього успішного оновлення каналу",
    "Title" : "Заголовок",
    "Folder" : "Каталог",
    "Not available" : "Не доступно",
    "All Articles" : "Всі статті",
    "No feeds found to add" : "Не знайдено кормів для додавання",
    "Subscribe to" : "Підпишіться на",
    "Unread Articles" : "Непрочитані статті",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Виявлено режим Ajax або webcron! Ваші канали не будуть оновлюватися!",
    "How to set up the operating system cron" : "Як налаштувати cron операційної системи",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Встановіть та налаштуйте швидший паралельний засіб оновлення, який використовуватиме API оновлення застосунку \"Новини\""
},
"nplurals=4; plural=(n % 1 == 0 && n % 10 == 1 && n % 100 != 11 ? 0 : n % 1 == 0 && n % 10 >= 2 && n % 10 <= 4 && (n % 100 < 12 || n % 100 > 14) ? 1 : n % 1 == 0 && (n % 10 ==0 || (n % 10 >=5 && n % 10 <=9) || (n % 100 >=11 && n % 100 <=14 )) ? 2: 3);");
