OC.L10N.register(
    "news",
    {
    "News" : "Vijesti",
    "an article" : "članak",
    "Someone" : "Netko",
    "%1$s shared \"%2$s\" with you" : "%1$s dijeli \"%2$s\" s vama",
    "{user} shared \"{article}\" with you" : "{user} je s vama podijelio/la \"{article}\"",
    "News feeds" : "Sažeci vijesti",
    "Unread articles" : "Nepročitani članci",
    "News folders" : "Mape vijesti",
    "News articles" : "Članci vijesti",
    "Shared with me" : "Dijeljeno sa mnom",
    "Untitled article" : "Članak bez naslova",
    "An RSS/Atom feed reader" : "RSS/Atom čitač sažetaka",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📮 Aplikacija čitača RSS/Atom izvora za Nextcloud\n\n- 📲 Sinkronizirajte svoje izvore s više mobilnih ili desktop [klijenata](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatsko ažuriranje vaših izvora vijesti\n- 🆓 Besplatno i otvorenog koda pod AGPLv3, bez oglasa ili premium funkcija\n\n**Za rad ove aplikacije trenutačno je potreban System Cron**\n\nPreduvjeti se nalaze [ovdje](https://nextcloud.github.io/news/install/#dependencies)\n\nPopis promjena dostupan je [ovdje](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nPrijavite [grešku](https://github.com/nextcloud/news/issues/new/choose)\n\nPredložite [novu značajku](https://github.com/nextcloud/news/discussions/new)\n\nPrijavite [problem s izvorom](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Preuzmi",
    "Close" : "Zatvori",
    "Internal server error!" : "Interna pogreška poslužitelja!",
    "Unknown error!" : "Nepoznata pogreška!",
    "Web address" : "Web adresa",
    "Please check your data/nextcloud.log file for additional information!" : "Provjerite datoteku data/nextcloud.log za dodatne informacije!",
    "No folder" : "Nema mape",
    "Folder name" : "Naziv mape",
    "Username" : "Korisničko ime",
    "Password" : "Zaporka",
    "Feed exists already!" : "Sažetak već postoji!",
    "New folder" : "Nova mapa",
    "Folder exists already!" : "Mapa već postoji!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth vjerodajnice moraju biti pohranjene nešifrirane! Svi koji imaju pristup poslužitelju ili bazi podataka moći će im pristupiti!",
    "Credentials" : "Vjerodajnice",
    "Auto discover Feed" : "Automatsko otkrivanje sažetaka događaja",
    "Subscribe" : "Preplata",
    "Successfully updated news configuration" : "Konfiguracija Vijesti uspješno je ažurirana",
    "Unable to update news config" : "Nije moguće ažurirati konfiguraciju Vijesti",
    "Logo purge has never been run." : "Čišćenje logotipa nikada nije pokrenuto.",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "Zadnje čišćenje logotipa izvršeno je {relativeLastLogoPurge}. Nešto nije u redu.",
    "Last logo purge job ran {relativeLastLogoPurge}." : "Zadatak čišćenja logotipa zadnji je put izvršen {relativeLastLogoPurge}.",
    "No job execution data available. The cron job may not be running properly." : "Nema dostupnih podataka o izvršavanju zadataka. Cron zadatak možda ne radi ispravno.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Zadnje izvršavanje zadatka bilo je {relativeTime}. Nešto nije u redu.",
    "Last job ran {relativeTime}." : "Posljednji zadatak je izvršen {relativeTime}.",
    "Maximum read count per feed" : "Maksimalni broj čitanja po sažetku",
    "Maximum redirects" : "Maksimalni broj preusmjeravanja",
    "Feed fetcher timeout" : "Vremensko ograničenje hvatača sažetaka",
    "Explore Service URL" : "Istražite URL servisa",
    "Update interval" : "Interval ažuriranja",
    "Use system cron for updates" : "Koristi sustav cron za ažuriranja",
    "Disable this if you use a custom updater." : "Onemogućite ovo ako koristite prilagođenim alatom za ažuriranje.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Određuje maksimalan broj članaka po izvoru koji se mogu označiti kao pročitani, a da ih posao čišćenja neće obrisati; ako se stari članci nakon čitanja ponovno pojavljuju, povećajte ovu vrijednost; negativne vrijednosti, poput -1, isključuju ovu značajku.",
    "Delete unread articles automatically" : "Automatski briši nepročitane članke",
    "Enable this if you also want to delete unread articles." : "Omogućite ovo ako želite brisati i nepročitane članke.",
    "How many redirects the feed fetcher should follow." : "Koliko preusmjeravanja bi hvatač sažetaka trebao pratiti.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimalni broj sekundi koliko se čeka učitavanje RSS i Atom sažetaka; ako učitavanje duže traje, nadogradnja se prekida.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Ako je navedeno, URL ove usluge upit će se kako bi se izvori prikazali u odjeljku Istraži izvore. Za povratak na ugrađenu uslugu istraživanja, ostavite ovo polje prazno.",
    "Interval in seconds in which the feeds will be updated." : "Interval u sekundama u kojem će se sažeci ažurirati.",
    "Use next update time for feed updates" : "Koristi vrijeme sljedećeg ažuriranja za ažuriranje izvora",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Omogućite ovo kako bi se za ažuriranje izvora koristilo izračunato vrijeme sljedećeg ažuriranja. Onemogućite za ažuriranje izvora isključivo prema intervalu ažuriranja.",
    "Article list" : "Popis članaka",
    "Article details" : "Detalji članka",
    "No article selected" : "Nijedan članak nije odabran",
    "Please select an article from the list." : "Odaberite članak s popisa.",
    "Show all articles" : "Prikaži sve članke",
    "Move feed" : "Premjesti izvor",
    "Please select the new folder" : "Odaberite novu mapu",
    "Move" : "Premjesti",
    "User Name" : "Korisničko ime",
    "Share" : "Dijeli",
    "Share with" : "Dijeli s",
    "Share with {num} users" : "Dijeli s {num} korisnika",
    "Rename Folder" : "Preimenuj mapu",
    "Are you sure you want to delete?" : "Jeste li sigurni da želite izbrisati?",
    "Unable to save starred open state" : "Nije moguće spremiti stanje otvaranja označenih zvjezdicom",
    "Mark read" : "Označi kao pročitano",
    "All articles" : "Svi članci",
    "Recently viewed" : "Nedavno pregledano",
    "Starred" : "Označeno zvjezdicom",
    "Has feeds with errors!" : "Sadrži izvore s pogreškama!",
    "Explore" : "Istraži",
    "Feed settings" : "Postavke izvora",
    "News settings" : "Postavke Vijesti",
    "Rename" : "Preimenuj",
    "Delete" : "Izbriši",
    "Rename Feed" : "Preimenuj sažetak",
    "Open Feed URL" : "Otvori URL izvora",
    "Unpin from top" : "Skini s vrha",
    "Pin to top" : "Prikvači na vrh",
    "Newest first" : "Najnoviji prvi",
    "Oldest first" : "Najstariji prvi",
    "Default order" : "Zadani poredak",
    "Enable full text" : "Omogući cijeli tekst",
    "Disable full text" : "Onemogući cijeli tekst",
    "Mark as unread on update" : "Pri ažuriranju označi kao nepročitano",
    "Keep read status on update" : "Pri ažuriranju zadrži status pročitano",
    "Sync disabled" : "Sinkronizacija onemogućena",
    "Sync enabled" : "Sinkronizacija omogućena",
    "Show external media" : "Prikaži vanjski medijski sadržaj",
    "from" : "od",
    "External media loaded from" : "Vanjski medijski sadržaj učitan s",
    "Previous Item" : "Prethodna stavka",
    "Next Item" : "Sljedeća stavka",
    "Share within Instance" : "Dijeli unutar instance",
    "Toggle star article" : "Postavi/ukloni zvjezdicu s članka",
    "Mark unread" : "Označi kao nepročitano",
    "Close details" : "Zatvori pojedinosti",
    "shared by" : "dijeli",
    "by" : "preko",
    "Play audio" : "Reproduciraj zvuk",
    "Download audio" : "Preuzmi zvuk",
    "Download video" : "Preuzmi videozapis",
    "Refresh list" : "Osvježi popis",
    "Open website" : "Otvori web-mjesto",
    "Keep article unread" : "Drži članak kao nepročitan",
    "Toggle keep current article unread" : "Prebaci i zadržati trenutni članak nepročitanim",
    "Remove keep article unread" : "Makni održavanje članaka nepročitanim",
    "Default" : "Zadani",
    "Compact" : "Kompaktno",
    "Screenreader" : "Čitač zaslona",
    "Vertical" : "Okomito",
    "Horizontal" : "Vodoravno",
    "Off" : "Isključeno",
    "Always" : "Uvijek",
    "Ask" : "Pitaj",
    "Never" : "Nikad",
    "Please select a valid OPML file" : "Odaberite valjanu OPML datoteku",
    "File successfully uploaded" : "Datoteka je uspješno prenesena",
    "Error uploading the opml file" : "Pogreška pri prijenosu OPML datoteke",
    "Error connecting to the server" : "Pogreška pri povezivanju s poslužiteljem",
    "Error retrieving the opml file" : "Pogreška pri dohvaćanju OPML datoteke",
    "Please select a valid json file" : "Odaberite valjanu JSON datoteku",
    "Error uploading the json file" : "Pogreška pri prijenosu JSON datoteke",
    "Error retrieving the json file" : "Pogreška pri dohvaćanju JSON datoteke",
    "General" : "Općenito",
    "Disable mark read through scrolling" : "Onemogući označavanje kao pročitano pri pomicanju",
    "Reverse ordering (oldest on top)" : "Obrnuti poredak (prvo najstariji)",
    "Disable automatic refresh" : "Onemogući automatsko osvježavanje",
    "Media" : "Medij",
    "Show enclosure images" : "Prikaži slike privitaka",
    "Show images in the article text" : "Prikaži slike u tekstu članka",
    "Show iframes in the article text" : "Prikaži iframeove u tekstu članka",
    "Appearance" : "Izgled",
    "Display mode" : "Način prikaza",
    "Split mode" : "Podijeljeni prikaz",
    "Import" : "Uvezi",
    "Export" : "Izvoz",
    "Abonnements (OPML)" : "Pretplate (OPML)",
    "Importing feeds" : "Uvoz izvora",
    "Please wait" : "Pričekajte",
    "Articles (JSON)" : "Članci (JSON)",
    "Keyboard shortcuts" : "Tipkovni prečaci",
    "Refresh" : "Osvježi",
    "Screenreader mode only" : "Samo način rada za čitač zaslona",
    "Jump to previous article" : "Prijeđi na prethodni članak",
    "Jump to next article" : "Prijeđi na sljedeći članak",
    "Item navigation and control" : "Navigacija i upravljanje stavkama",
    "Open article in new tab" : "Otvori članak u novoj kartici",
    "Show article details in compact view" : "Prikaži detalje članka u kompaktnom prikazu",
    "Close article details in compact view" : "Zatvori detalje članka u kompaktnom prikazu",
    "Feed/Folder navigation and control" : "Navigacija i upravljanje izvorima/mapama",
    "Jump to previous feed" : "Skoči na prethodni izvor",
    "Jump to next feed" : "Skoči na sljedeći izvor",
    "Jump to previous folder" : "Skoči na prethodnu mapu",
    "Jump to next folder" : "Skoči na sljedeću mapu",
    "Mark current articles feed/folder as read" : "Označi trenutačni izvor/mapu kao pročitano",
    "Resources" : "Resursi",
    "Last update" : "Zadnje ažuriranje",
    "Time when the feed was last downloaded" : "Vrijeme kada je izvor zadnji put preuzet",
    "Next update" : "Sljedeće ažuriranje",
    "Time when the next feed update will be done" : "Vrijeme kada će se izvršiti sljedeće ažuriranje izvora",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Samo ako je aktivirano u administratorskim postavkama; u suprotnom se koristi uobičajeni interval ažuriranja",
    "Articles per update" : "Članaka po ažuriranju",
    "Maximum number of articles reached in a feed update" : "Dosegnut je maksimalan broj članaka pri ažuriranju izvora",
    "Error Count" : "Broj pogrešaka",
    "Number of errors that have occurred since the last successful feed update" : "Broj pogrešaka koje su se dogodile od zadnjeg uspješnog ažuriranja izvora",
    "Title" : "Naslov",
    "Folder" : "Mapa",
    "Not available" : "Nije dostupno",
    "All Articles" : "Svi članci",
    "No feeds found to add" : "Nisu pronađeni izvori za dodavanje",
    "Subscribe to" : "Pretplati se na",
    "Unread Articles" : "Nepročitani članci",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Otkriven je Ajax ili webcron! Vaši sažeci neće biti ažurirani!",
    "How to set up the operating system cron" : "Kako postaviti cron operacijskog sustava",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instalirajte i postavite brži paralelni program za ažuriranje koji se koristi API-jem za ažuriranje aplikacije Vijesti"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
