<?php

namespace OCA\News\Vendor\Http\Adapter\Guzzle7\Exception;

use OCA\News\Vendor\Http\Client\Exception;
final class UnexpectedValueException extends \UnexpectedValueException implements Exception
{
}
