OC.L10N.register(
    "news",
    {
    "News" : "Notizie",
    "Someone" : "Qualcuno",
    "%1$s shared \"%2$s\" with you" : "%1$s ha condiviso \"%2$s\" con te",
    "News feeds" : "Fonti di notizie",
    "Unread articles" : "Articoli non letti",
    "News folders" : "Cartelle delle notizie",
    "Shared with me" : "Condivisi con me",
    "An RSS/Atom feed reader" : "Un lettore di fonti RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Un'applicazione per la lettura di fonti RSS/Atom per Nextcloud\n\n- 📲 Sincronizza le tue fonti con più [clienti] mobili o desktop (https://nextcloud.github.io/news/clients/)\n- 🔄 Aggiornamenti automatici delle tue fonti di notizie\n- 🆓 Gratuito e open source sotto AGPLv3, senza pubblicità o funzioni premium\n\n**System Cron è attualmente richiesto per il funzionamento di questa applicazione**\n\nI requisiti possono essere trovati [qui](https://nextcloud.github.io/news/install/#dependencies)\n\nIl Changelog è disponibile [qui](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCrea una [segnalazione di bug](https://github.com/nextcloud/news/issues/new/choose)\n\nCrea una [richiesta di funzionalità](https://github.com/nextcloud/news/discussions/new)\n\nSegnala un [problema di feed](https://github.com/nextcloud/news/discussions/new) ",
    "Download" : "Scarica",
    "Close" : "Chiudi",
    "Internal server error!" : "Errore interno del server",
    "Unknown error!" : "Errore sconosciuto",
    "Web address" : "Indirizzo web",
    "No folder" : "Nessuna cartella",
    "Folder name" : "Nome della cartella",
    "Username" : "Nome utente",
    "Password" : "Password",
    "Feed exists already!" : "La fonte esiste già!",
    "New folder" : "Nuova cartella",
    "Folder exists already!" : "La cartella esiste già!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Le credenziali HTTP Basic Auth devono essere memorizzate senza cifratura! Chiunque abbia accesso al server o al database sarà in grado di accedervi!",
    "Credentials" : "Credenziali",
    "Auto discover Feed" : "Scoperta automatica fonte",
    "Subscribe" : "Sottoscrivi",
    "Last job ran {relativeTime}." : "Ultima esecuzione: {relativeTime}.",
    "Maximum read count per feed" : "Numero massimo di letture per fonte",
    "Maximum redirects" : "Numero massimo di redirezioni",
    "Feed fetcher timeout" : "Ritardo massimo di attesa per il recupero della fonte",
    "Explore Service URL" : "URL del servizio Esplora",
    "Update interval" : "Intervallo di aggiornamento",
    "Use system cron for updates" : "Usa cron di sistema per gli aggiornamenti",
    "Disable this if you use a custom updater." : "Disabilita questa opzione se esegui uno strumento di aggiornamento personalizzato.",
    "Delete unread articles automatically" : "Elimina automaticamente gli articoli non letti",
    "Enable this if you also want to delete unread articles." : "Abilita questa opzione se desideri anche eliminare gli articoli non letti.",
    "How many redirects the feed fetcher should follow." : "Quante redirezioni può seguire lo strumento di recupero delle fonti.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Numero massimo di secondi di attesa per il caricamento di una fonte RSS o Atom; se richiede troppo tempo l'aggiornamento sarà interrotto.",
    "Interval in seconds in which the feeds will be updated." : "Intervallo in secondi nel quale le fonti saranno aggiornate.",
    "Article details" : "Dettagli dell'articolo",
    "No article selected" : "Nessun articolo selezionato",
    "Show all articles" : "Mostra tutti gli articoli",
    "Move feed" : "Sposta fonte",
    "Move" : "Sposta",
    "User Name" : "Nome utente",
    "Share" : "Condividi",
    "Share with" : "Condividi con",
    "Share with {num} users" : "Condividi con {num} utenti",
    "Rename Folder" : "Rinomina cartella",
    "Are you sure you want to delete?" : "Sei sicuro di voler eliminare?",
    "Mark read" : "Marca letti",
    "All articles" : "Tutti gli articoli",
    "Starred" : "Preferiti",
    "Explore" : "Esplora",
    "Rename" : "Rinomina",
    "Delete" : "Elimina",
    "Rename Feed" : "Rinomina fonte",
    "Unpin from top" : "Rimuovi dalla cima",
    "Pin to top" : "Appunta in cima",
    "Newest first" : "Prima i più recenti",
    "Oldest first" : "Prima i più datati",
    "Default order" : "Ordine predefinito",
    "Enable full text" : "Abilita intero testo",
    "Disable full text" : "Disabilita intero testo",
    "from" : "da",
    "Previous Item" : "Elemento precedente",
    "Next Item" : "Elemento successivo",
    "Toggle star article" : "Commuta l'aggiunta ai preferiti di un articolo",
    "Mark unread" : "Marca come non letto",
    "Close details" : "Chiudi dettagli",
    "shared by" : "condiviso da",
    "by" : "da",
    "Play audio" : "Riproduci audio",
    "Download audio" : "Scarica audio",
    "Download video" : "Scarica video",
    "Open website" : "Apri sito web",
    "Keep article unread" : "Mantieni l'articolo come non letto",
    "Toggle keep current article unread" : "Commuta il mantenimento dell'articolo come non letto",
    "Remove keep article unread" : "Rimuovi il mantenimento dell'articolo come non letto",
    "Default" : "Predefinito",
    "Compact" : "Compatto",
    "Vertical" : "Verticale",
    "Horizontal" : "Orizzontale",
    "Off" : "Spento",
    "Always" : "Sempre",
    "Never" : "Mai",
    "General" : "Generale",
    "Disable mark read through scrolling" : "Disabilita la marcatura come letto durante lo scorrimento",
    "Reverse ordering (oldest on top)" : "Ordine inverso (più vecchio in alto)",
    "Media" : "Media",
    "Appearance" : "Aspetto",
    "Import" : "Importa",
    "Export" : "Esporta",
    "Please wait" : "Attendere",
    "Articles (JSON)" : "Articoli (JSON)",
    "Keyboard shortcuts" : "Scorciatoie da tastiera",
    "Refresh" : "Aggiorna",
    "Jump to previous article" : "Salta all'articolo precedente",
    "Jump to next article" : "Salta all'articolo successivo",
    "Open article in new tab" : "Apri articolo in una nuova scheda",
    "Resources" : "Risorse",
    "Last update" : "Ultimo aggiornamento",
    "Title" : "Titolo",
    "Folder" : "Cartella",
    "Not available" : "Non disponibile",
    "All Articles" : "Tutti gli articoli",
    "No feeds found to add" : "Nessuna fonte trovata da aggiungere",
    "Subscribe to" : "Sottoscrivi",
    "Unread Articles" : "Articoli non letti",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Rilevata modalità cron Ajax o webcron! Le tue fonti non saranno aggiornate!",
    "How to set up the operating system cron" : "Come configurare cron del sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installa e configura uno strumento di aggiornamento parallelo più veloce che utilizza le API di aggiornamento dell'applicazione News"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
