OC.L10N.register(
    "news",
    {
    "Download" : "Escargar",
    "Close" : "Zarrar",
    "Folder name" : "Nombre de carpeta",
    "Username" : "Nombre d'usuario",
    "Password" : "Clau",
    "New folder" : "Nueva carpeta",
    "Share" : "Compartir",
    "Rename" : "Renombrar",
    "Delete" : "Borrar",
    "Never" : "Nunca"
},
"nplurals=2; plural=(n != 1);");
