OC.L10N.register(
    "news",
    {
    "News" : "Новости",
    "Someone" : "Некој",
    "%1$s shared \"%2$s\" with you" : "%1$s сподели \"%2$s\" со тебе",
    "Unread articles" : "Непрочитани статии",
    "Download" : "Преземи",
    "Close" : "Затвори",
    "Folder name" : "Име на папка",
    "Username" : "Корисничко име",
    "Password" : "Лозинка",
    "Feed exists already!" : "Каналот веќе постои!",
    "New folder" : "Нова папка",
    "Credentials" : "Акредитиви",
    "Subscribe" : "Претплата",
    "Last job ran {relativeTime}." : "Последната процедура се изврши пред {relativeTime}.",
    "Move" : "Премести",
    "Share" : "Сподели",
    "Mark read" : "Означи како прочитано",
    "All articles" : "Сите статии",
    "Starred" : "Со ѕвезда",
    "Explore" : "Истражувај",
    "Rename" : "Преименувај",
    "Delete" : "Избриши",
    "Newest first" : "Новите прво",
    "Oldest first" : "Старите прво",
    "from" : "од",
    "Mark unread" : "Означи како непрочитано",
    "by" : "од",
    "Open website" : "Отвори вебсајт",
    "Default" : "Предефиниран",
    "Vertical" : "Вертикално",
    "Horizontal" : "Хоризонтално",
    "Always" : "Секогаш",
    "Never" : "Никогаш",
    "General" : "Општо",
    "Media" : "Медија",
    "Appearance" : "Изглед",
    "Import" : "Увези",
    "Export" : "Извези",
    "Keyboard shortcuts" : "Кратенки преку тастатура",
    "Refresh" : "Освежи",
    "Resources" : "Ресурси",
    "Title" : "Наслов",
    "Folder" : "Папка",
    "Not available" : "Недостапно"
},
"nplurals=2; plural=(n % 10 == 1 && n % 100 != 11) ? 0 : 1;");
