OC.L10N.register(
    "news",
    {
    "News" : "Noticias",
    "%1$s shared \"%2$s\" with you" : "%1$s ha compartido \"%2$s\" contigo",
    "Unread articles" : "Artículos sin leer",
    "Shared with me" : "Compartido conmigo",
    "Download" : "Descargar",
    "Close" : "Cerrar",
    "Web address" : "Dirección web",
    "No folder" : "No hay carpetas",
    "Folder name" : "Nombre de la carpeta",
    "Username" : "Usuario",
    "Password" : "Contraseña",
    "Feed exists already!" : "¡La fuente ya existe!",
    "New folder" : "Carpeta nueva ",
    "Folder exists already!" : "¡La carpeta ya existe!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "¡Las credenciales HTTP Basic Auth deben ser almacenadas decriptadas! ¡Todos aquellos que tengan acceso al servidor o a la base de datos tendrán acceso a ellas!",
    "Credentials" : "Credenciales",
    "Subscribe" : "Suscribir",
    "Maximum read count per feed" : "Conteo máximo de lecturas por fuente",
    "Maximum redirects" : "Redirecciones máximas",
    "Feed fetcher timeout" : "Tiempo de vida para el buscador de fuentes",
    "Explore Service URL" : "Explorar la URL del Servicio",
    "Use system cron for updates" : "Usa el cron del sistema para las actualizaciones",
    "Show all articles" : "Mostrar todos los artículos",
    "Move" : "Mover",
    "Share" : "Compartir",
    "Mark read" : "Marcar como leído",
    "All articles" : "Todos los artículos",
    "Starred" : "Marcados",
    "Explore" : "Explorar",
    "Rename" : "Renombrar",
    "Delete" : "Borrar",
    "Rename Feed" : "Renombrar la Fuente",
    "Unpin from top" : "Desanclar a la parte superior",
    "Pin to top" : "Anclar a la parte superior",
    "Newest first" : "Más reciente primero",
    "Oldest first" : "Más antiguo primero",
    "Default order" : "Ordenamiento predeterminado",
    "Enable full text" : "Habilitar texto completo",
    "Disable full text" : "Deshabilitar texto completo",
    "from" : "de",
    "Toggle star article" : "Alternar artículos marcados",
    "Close details" : "Cerrar detalles",
    "by" : "por",
    "Play audio" : "Reproducir audio",
    "Download audio" : "Descargar audio",
    "Download video" : "Descargar video",
    "Open website" : "Abrir sitio web",
    "Keep article unread" : "Mantener el artículo como no-leído",
    "Toggle keep current article unread" : "Alternar mantener artículo actual como no leído",
    "Remove keep article unread" : "Eliminar mantener artículo como no leído",
    "Never" : "Nunca",
    "General" : "General",
    "Disable mark read through scrolling" : "Deshabilitar el marcar como leído al desplazar",
    "Reverse ordering (oldest on top)" : "Orden inverso (más antiguo arriba)",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Please wait" : "Por favor aguarda",
    "Keyboard shortcuts" : "Atajos del teclado",
    "Refresh" : "Actualizar",
    "Jump to previous article" : "Ir al artículo anterior",
    "Jump to next article" : "Ir al artículo siguiente ",
    "Open article in new tab" : "Abrir el artículo en una nueva pestaña",
    "Resources" : "Recursos",
    "Folder" : "Carpeta",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "¡Se ha detectado el modo Ajax o webron! ¡Tus fuentes no serán actualizadas!",
    "How to set up the operating system cron" : "Cómo establecer las tareas programadas del sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instala y configura un actualizador en paralelo más rápido que use el API de actualización de la nueva aplicación"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
