OC.L10N.register(
    "news",
    {
    "News" : "Haberler",
    "an article" : "bir yazı",
    "Someone" : "Biri",
    "%1$s shared \"%2$s\" with you" : "%1$s, sizinle \"%2$s\" ögesini paylaştı",
    "{user} shared \"{article}\" with you" : "{user} sizinle \"{article}\" paylaştı",
    "News feeds" : "Haber akışları",
    "Unread articles" : "Okunmamış yazılar",
    "News folders" : "Haberler klasörleri",
    "News articles" : "Haber yazıları",
    "Shared with me" : "Benimle paylaşılanlar",
    "Untitled article" : "Başlıksız yazı",
    "An RSS/Atom feed reader" : "Bu uygulama RSS/Atom akışlarının okunmasını sağlar",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Nextcloud için RSS/Atom akışı okuyucusu\n\n- 📲 Akışlarınızı birkaç mobil ya da bilgisayar [istemci](https://nextcloud.github.io/news/clients/) ile eşitler\n- 🔄 Haber akışlarını otomatik olarak günceller\n- 🆓 Özgür ve açık kaynaklıdır, AGPLv3 lisansı koşulları altında dağıtılır, reklam ya da ücretli özellikler bulundurmaz\n\n**Bu uygulamanın çalışması için sistem zamanlanmış görevi gereklidir**\n\nGereksinimler için [buraya bakabilirsiniz](https://nextcloud.github.io/news/install/#dependencies)\n\nDeğişiklik günlüğü için [buraya bakabilirsiniz](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\n[Hata bildiriminde bulunun](https://github.com/nextcloud/news/issues/new/choose)\n\n[Özellik isteğinde bulunun](https://github.com/nextcloud/news/discussions/new)\n\n[Bir akış sorununu bildirin](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "İndir",
    "Close" : "Kapat",
    "Internal server error!" : "İç sunucu sorunu!",
    "Unknown error!" : "Sorun bilinmiyor!",
    "Web address" : "Site adresi",
    "Please check your data/nextcloud.log file for additional information!" : "Ek bilgi almak için data/nextcloud.log dosyasına bakabilirsiniz!",
    "No folder" : "Klasör yok",
    "Folder name" : "Klasör adı",
    "Username" : "Kullanıcı adı",
    "Password" : "Parola",
    "Feed exists already!" : "Akış zaten var!",
    "New folder" : "Yeni klasör",
    "Folder exists already!" : "Klasör zaten var!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth kimlik doğrulama bilgilerinin şifrelenmemiş olarak depolanması gerektiğinden, sunucu ya da veri tabanına erişimi olan herkes bu bilgilere erişebilir!",
    "Credentials" : "Kimlik doğrulama bilgileri",
    "Auto discover Feed" : "Akışı otomatik bul",
    "Subscribe" : "Abone ol",
    "Successfully updated news configuration" : "Haberler yapılandırması güncellendi",
    "Unable to update news config" : "Haberler yapılandırması güncellenemedi",
    "Logo purge has never been run." : "Logo temizleme işlemi hiç yürütülmemiş.",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "Son logo temizleme işlemi yürütülmesi: {relativeLastLogoPurge}. Bir sorun var.",
    "Last logo purge job ran {relativeLastLogoPurge}." : "Son logo temizleme işlemi yürütülmesi: {relativeLastLogoPurge}.",
    "No job execution data available. The cron job may not be running properly." : "Görevin yürütülme verileri bulunamadı. Zamanlanmış görev düzgün çalışmıyor olabilir.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Son görev yürütülmesi: {relativeTime}. Bir sorun var.",
    "Last job ran {relativeTime}." : "Son görev yürütülmesi: {relativeTime}.",
    "Maximum read count per feed" : "Bir akış için en fazla okuma sayısı",
    "Maximum redirects" : "En fazla yönlendirme",
    "Feed fetcher timeout" : "Akış alma zaman aşımı",
    "Explore Service URL" : "Keşfetme hizmeti adresi",
    "Update interval" : "Güncelleme sıklığı",
    "Use system cron for updates" : "Güncellemeler için sistem zamanlanmış görevi kullanılsın",
    "Disable this if you use a custom updater." : "Özel bir güncelleyici çalıştırıyorsanız bu seçeneği kapatın.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Temizleme görevi tarafından silinmeyecek, bir akış için okunabilecek en fazla yazı sayısını belirtir. Eski yazılar okunduktan sonra yeniden görüntüleniyorsa bu değeri arttırın. -1 gibi negatif değerler bu özelliği kapatır.",
    "Delete unread articles automatically" : "Okunmamış yazılar otomatik olarak silinsin",
    "Enable this if you also want to delete unread articles." : "Okunmamış yazıların da silinmesini istiyorsanız bu seçeneği açın.",
    "How many redirects the feed fetcher should follow." : "Akış getiricinin izleyeceği yönlendirme sayısı.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Bir RSS ya da Atom akışının yüklenmesi için beklenecek en fazla süre. İşlem bu süre içinde tamamlanmaz ise güncellemeden vazgeçilir.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Varsa, akışları keşfet bölümünde akışların görüntülenmesi için sorgulanacak hizmetin adresi. İç keşfetme hizmetinin kullanılması için bu alanı boş bırakın.",
    "Interval in seconds in which the feeds will be updated." : "Saniye cinsinden, akışların güncellenme sıklığı.",
    "Use next update time for feed updates" : "Akışlar bir sonraki güncelleme zamanında güncellensin",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Açıldığında, akışlar hesaplanan bir sonraki güncelleme zamanında güncellenir. Akışların yalnızca güncelleme aralığına göre güncellenmesi için kapatın.",
    "Article list" : "Yazı listesi",
    "Article details" : "Yazı ayrıntıları",
    "No article selected" : "Herhangi bir yazı seçilmemiş",
    "Please select an article from the list." : "Lütfen listeden bir yazı seçin.",
    "Show all articles" : "Tüm yazıları görüntüle",
    "Move feed" : "Akışı taşı",
    "Please select the new folder" : "Lütfen yeni klasörü seçin",
    "Move" : "Taşı",
    "User Name" : "Kullanıcı adı",
    "Share" : "Paylaş",
    "Share with" : "Şunlarla paylaş",
    "Share with {num} users" : "{num} kullanıcı ile paylaş",
    "Rename Folder" : "Klasörü yeniden adlandır",
    "Are you sure you want to delete?" : "Silmek istediğinize emin misiniz?",
    "Unable to save starred open state" : "Yıldızlı açık durumu kaydedilemedi",
    "Mark read" : "Okunmuş olarak işaretle",
    "All articles" : "Tüm yazılar",
    "Recently viewed" : "Son bakılanlar",
    "Starred" : "Yıldızlı",
    "Has feeds with errors!" : "Sorunlu akışları var!",
    "Explore" : "Keşfet",
    "Feed settings" : "Akış ayarları",
    "News settings" : "Haberler ayarları",
    "Rename" : "Yeniden adlandır",
    "Delete" : "Sil",
    "Rename Feed" : "Akışı yeniden adlandır",
    "Open Feed URL" : "Akış adresini aç",
    "Unpin from top" : "Üstten kaldır",
    "Pin to top" : "Üste sabitle",
    "Newest first" : "Yeniden eskiye",
    "Oldest first" : "Eskiden yeniye",
    "Default order" : "Varsayılan sıralama",
    "Enable full text" : "Tam yazı kullanılsın",
    "Disable full text" : "Tam yazı kullanılmasın",
    "Mark as unread on update" : "Güncellemede okunmamış olarak işaretlensin",
    "Keep read status on update" : "Güncellemede okunmuş durumu korunsun",
    "Sync disabled" : "Eşitleme kapalı",
    "Sync enabled" : "Eşitleme açık",
    "Show external media" : "Dış ortamı görüntüle",
    "from" : "başlangıç",
    "External media loaded from" : "Dış ortam şuradan yüklendi",
    "Previous Item" : "Önceki öge",
    "Next Item" : "Sonraki öge",
    "Share within Instance" : "Kopya içinden paylaş",
    "Toggle star article" : "Yazıya yıldız koy/kaldır",
    "Mark unread" : "Okunmamış olarak işaretle",
    "Close details" : "Ayrıntıları kapat",
    "shared by" : "paylaşan",
    "by" : "yazar",
    "Play audio" : "Sesi oynat",
    "Download audio" : "Sesi indir",
    "Download video" : "Görüntüyü indir",
    "Refresh list" : "Listeyi yenile",
    "Open website" : "Siteyi aç",
    "Keep article unread" : "Yazıyı okunmamış olarak tut",
    "Toggle keep current article unread" : "Geçerli yazıyı okunmamış olarak işaretle/kaldır",
    "Remove keep article unread" : "Yazıyı okunmamış olarak tutma",
    "Default" : "Varsayılan",
    "Compact" : "Dar",
    "Screenreader" : "Ekran okuyucu",
    "Vertical" : "Dikey",
    "Horizontal" : "Yatay",
    "Off" : "Kapalı",
    "Always" : "Her zaman",
    "Ask" : "Sorulsun",
    "Never" : "Yok",
    "Please select a valid OPML file" : "Lütfen geçerli bir OPML dosyası seçin",
    "File successfully uploaded" : "Dosya yüklendi",
    "Error uploading the opml file" : "OPML dosyası yüklenirken sorun çıktı",
    "Error connecting to the server" : "Sunucu ile bağlantı kurulurken sorun çıktı",
    "Error retrieving the opml file" : "OPML dosyası alınırken sorun çıktı",
    "Please select a valid json file" : "Lütfen geçerli bir JSON dosyası seçin",
    "Error uploading the json file" : "JSON dosyası yüklenirken sorun çıktı",
    "Error retrieving the json file" : "JSON dosyası alınırken sorun çıktı",
    "General" : "Genel",
    "Disable mark read through scrolling" : "Kaydırma sırasında okunmuş olarak işaretlenmesin",
    "Reverse ordering (oldest on top)" : "Sıralamayı tersine çevir (eskiden yeniye)",
    "Disable automatic refresh" : "Otomatik yenilenmesin",
    "Media" : "Ortam",
    "Show enclosure images" : "Kutu görselleri görüntülensin",
    "Show images in the article text" : "Görseller yazı içeriğinde görüntülensin ",
    "Show iframes in the article text" : "Iframe nesneleri yazı içeriğinde görüntülensin",
    "Appearance" : "Görünüm",
    "Display mode" : "Görüntüleme kipi",
    "Split mode" : "Bölünmüş kip",
    "Import" : "İçe aktar",
    "Export" : "Dışa aktar",
    "Abonnements (OPML)" : "Abonelikler (OPML)",
    "Importing feeds" : "Akışlar içe aktarılıyor",
    "Please wait" : "Lütfen bekleyin",
    "Articles (JSON)" : "Yazılar (JSON)",
    "Keyboard shortcuts" : "Kısayol tuşları",
    "Refresh" : "Yenile",
    "Screenreader mode only" : "Yalnızca ekran okuyucu kipi ",
    "Jump to previous article" : "Önceki yazıya geç",
    "Jump to next article" : "Sonraki yazıya geç",
    "Item navigation and control" : "Öge gezinmesi ve denetimi",
    "Open article in new tab" : "Yazıyı yeni sekmede aç",
    "Show article details in compact view" : "Dar görünümde yazı ayrıntıları görüntülensin",
    "Close article details in compact view" : "Dar görünümde yazı ayrıntıları görüntülenmesin",
    "Feed/Folder navigation and control" : "Akış/Klasör gezinmesi ve denetimi",
    "Jump to previous feed" : "Önceki akışa geç",
    "Jump to next feed" : "Sonraki akışa geç",
    "Jump to previous folder" : "Önceki klasöre geç",
    "Jump to next folder" : "Sonraki klasöre geç",
    "Mark current articles feed/folder as read" : "Geçerli yazı akışını/klasörünü okunmuş olarak işaretle",
    "Resources" : "Kaynaklar",
    "Last update" : "Son güncelleme",
    "Time when the feed was last downloaded" : "Akışın son indirildiği zaman",
    "Next update" : "Sonraki güncelleme",
    "Time when the next feed update will be done" : "Akışın sonraki güncellenme zamanı",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Yalnızca yönetici ayarlarından açıldığında. Yoksa normal güncelleme aralığı kullanılır",
    "Articles per update" : "Bir güncellemedeki yazı sayısı",
    "Maximum number of articles reached in a feed update" : "Bir akış güncellemesinde ulaşılan en fazla yazı sayısı",
    "Error Count" : "Hata sayısı",
    "Number of errors that have occurred since the last successful feed update" : "Son sorunsuz akış güncellemesinden bu yana çıkan sorun sayısı",
    "Title" : "Başlık",
    "Folder" : "Klasör",
    "Not available" : "Kullanılamaz",
    "All Articles" : "Tüm yazılar",
    "No feeds found to add" : "Eklenebilecek bir akış bulunamadı",
    "Subscribe to" : "Şuna abone ol",
    "Unread Articles" : "Okunmamış yazılar",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax ya da internet zamanlanmış görev kipi algılandı! Akışlarınız güncellenmeyecek!",
    "How to set up the operating system cron" : "İşletim sistemi zamanlanmış görevi nasıl ayarlanır",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Haberler uygulamasının güncelleme API yazılımını kullanan daha hızlı bir paralel güncelleyici kurun ve ayarlayın"
},
"nplurals=2; plural=(n > 1);");
