OC.L10N.register(
    "news",
    {
    "News" : "Uudised",
    "an article" : "artikkel",
    "Someone" : "Keegi",
    "%1$s shared \"%2$s\" with you" : "%1$s jagas sinuga „%2$s“",
    "{user} shared \"{article}\" with you" : "{user} jagas sinuga „{article}“ artiklit",
    "News feeds" : "Uudisvood",
    "Unread articles" : "Lugemata artiklid",
    "News folders" : "Uudiste kaustad",
    "News articles" : "Uudiste artiklid",
    "Shared with me" : "Jagatud minuga",
    "Untitled article" : "Pealkirjata artikkel",
    "An RSS/Atom feed reader" : "RSS/Atom uudisvoogude lugeja",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 RSS/Atom uudisvoogude lugeja Nextcloudi jaoks\n\n- 📲 sünkroniseeri oma uudisvooge mitmete nutiseadmetele või töölauale [mõeldud klientidega](https://nextcloud.github.io/news/clients/)\n- 🔄 sinu uudisvoogude automaatsed uuendused\n- 🆓 vaba ja avatud lähtekoodil põhinev rakendus on litsentseeritud AGPLv3 alusel ning siin pole reklaame ega tasulist lisafunktsionaalsust\n\n**Selle rakenduse toimimiseks on serveris vajalik cron-teenuse olemasolu**\n\nTäpsemad nõuded [on siin](https://nextcloud.github.io/news/install/#dependencies)\n\nMuudatuste logi [leidub siin](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nTeata meile [vigadest siin](https://github.com/nextcloud/news/issues/new/choose)\n\nKoosta [arendusettepanek siin](https://github.com/nextcloud/news/discussions/new)\n\nTeata [uudisvoogude vigadest siin](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Laadi alla",
    "Close" : "Sulge",
    "Internal server error!" : "Serveri sisemine viga!",
    "Unknown error!" : "Tundmatu viga!",
    "Web address" : "Veebiaadress",
    "Please check your data/nextcloud.log file for additional information!" : "Lisateavet leiad data/nextcloud.log failist!",
    "No folder" : "Kausta pole",
    "Folder name" : "Kausta nimi",
    "Username" : "Kasutajanimi",
    "Password" : "Salasõna",
    "Feed exists already!" : "Uudisvoog on juba olemas!",
    "New folder" : "Uus kaust",
    "Folder exists already!" : "Kaust on juba olemas!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "„HTTP Basic Auth“ jaoks vajalikud salasõna ja kasutajanimi peavad olema salvestatud krüptimata kujul! Kõik, kellel on serverisse või andmebaasi ligipääs, saavad neid ilmselt lugeda!",
    "Credentials" : "Kasutajatunnus/salasõna",
    "Auto discover Feed" : "Tuvasta uudisvoog automaatselt",
    "Subscribe" : "Telli",
    "Successfully updated news configuration" : "Uudisvoogude lugeja seadistuste uuendamine õnnestus",
    "Unable to update news config" : "Uudisvoogude lugeja seadistusi ei õnnestu uuendada",
    "Logo purge has never been run." : "Logode kustutamist pole kunagi käivitatud.",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "Viimane logode kustutamine toimus {relativeLastLogoPurge}. Midagi on valesti.",
    "Last logo purge job ran {relativeLastLogoPurge}." : "Viimane logode kustutamine toimus {relativeLastLogoPurge}.",
    "No job execution data available. The cron job may not be running properly." : "Taustatööde käivituste andmeid pole saadaval. Võib-olla cron ei toimi korrektselt.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Viimane taustatöö käivitus toimus {relativeTime}. See pole päris õige.",
    "Last job ran {relativeTime}." : "Viimane käivitus toimus {relativeTime}.",
    "Maximum read count per feed" : "Maksimaalne lugemiste arv uudisvoo kohta",
    "Maximum redirects" : "Maksimaalseid ümbersuunamisi",
    "Feed fetcher timeout" : "Voo ühenduse aegumine",
    "Explore Service URL" : "Sirvi teenuse URL-i",
    "Update interval" : "Uuendamise välp",
    "Use system cron for updates" : "Kasuta süsteemi croni uuendusteks",
    "Disable this if you use a custom updater." : "Kui kasutada enda valitud uuendajat, siis lülita see eelistus välja.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Määrab maksimaalse loetavate artiklite arvu uudisvoo kohta mida ei kustutata andmehaldustoimingute poolt; kui vanad artiklid tekivad uuesti peale lugemist, suurenda seda väärtust; negatiivsed väärtused nagu -1  keeravad selle funktsioonaalsuse täielikult kinni.",
    "Delete unread articles automatically" : "Kustuta automaatselt lugemata artiklid",
    "Enable this if you also want to delete unread articles." : "Selle eelistusega kustutad ka lugemata artiklid.",
    "How many redirects the feed fetcher should follow." : "Kui palju ümbersuunamisi peaks uudisvoo uuendaja järgima.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimaalne ootamise aeg sekundites RSS või Atom uudisvoo laadimisel - kui see kestab kauem, siis uuendamine lõppeb.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Kui see väli on täidetud, siis sisestatud võrguaadressi kasutatakse uudisvoogude kuvamiseks. Vaikimisi teenuse kasutamiseks jäta väli tühjaks.",
    "Interval in seconds in which the feeds will be updated." : "Uudisvoogude uuendamise välp sekundites",
    "Use next update time for feed updates" : "Uudisvoogude uuendamiseks kasuta järgmist plaanitud aega",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Lülita see valik sisse, kui soovid uudisvoogude uuenduseks kasutada arvutuslikku järgmise uuenduse aega. Lülita see valik välja, kui soovid kasutada vaid uuendusvälpa.",
    "Article list" : "Artiklite loend",
    "Article details" : "Artikli üksikasjad",
    "No article selected" : "Ükski artikkel pole valitud",
    "Please select an article from the list." : "Palun vali loendist artikkel.",
    "Show all articles" : "Näita kõiki artikleid",
    "Move feed" : "Teisalda uudisvoog",
    "Please select the new folder" : "Palun vali uus kaust",
    "Move" : "Teisalda",
    "User Name" : "Kasutajanimi",
    "Share" : "Jaga",
    "Share with" : "Jaga kasutajaga",
    "Share with {num} users" : "Jaga {num} kasutajaga",
    "Rename Folder" : "Muuda kausta nime",
    "Are you sure you want to delete?" : "Kas oled kindel, et tahad kustutada?",
    "Unable to save starred open state" : "Lemmikuks märkimise olekut ei õnnestu salvestada",
    "Mark read" : "Märgi loetuks",
    "All articles" : "Kõik artiklid",
    "Recently viewed" : "Hiljuti vaadatud",
    "Starred" : "Tärniga märgitud",
    "Has feeds with errors!" : "Uudisvoogudes on vigu!",
    "Explore" : "Sirvi",
    "Feed settings" : "Uudisvoo seadistused",
    "News settings" : "Uudiste seadistused",
    "Rename" : "Muuda nime",
    "Delete" : "Kustuta",
    "Rename Feed" : "Muuda uudisvoo nime",
    "Open Feed URL" : "Ava uudisvoo võrguaadress",
    "Unpin from top" : "Lõpeta esiletõstmine",
    "Pin to top" : "Tõsta esile",
    "Newest first" : "Uuemad eespool",
    "Oldest first" : "Vanemad eespool",
    "Default order" : "Vaikejärjestus",
    "Enable full text" : "Kasuta täistekstivaadet",
    "Disable full text" : "Ära lasuta täistekstivaadet",
    "Mark as unread on update" : "Uuendamisel märgi mitteloetuks",
    "Keep read status on update" : "Uuendamisel säilita lugemise olek",
    "Sync disabled" : "Sünkroonimine pole kasutusel",
    "Sync enabled" : "Sünkroonimine on kasutusel",
    "Show external media" : "Näita väliseid meediafaile",
    "from" : "saatja",
    "External media loaded from" : "Välised meediafailid on laaditud asukohast",
    "Previous Item" : "Eelmine kirje",
    "Next Item" : "Järgmine kirje",
    "Share within Instance" : "Jaga serveriga liitpilves",
    "Toggle star article" : "Lülita artikli tähtekest",
    "Mark unread" : "Märgi mitteloetuks",
    "Close details" : "Sulge üksikasjad",
    "shared by" : "mida jagas",
    "by" : "lisas",
    "Play audio" : "Esita heli",
    "Download audio" : "Laadi helifail alla",
    "Download video" : "Laadi video alla",
    "Refresh list" : "Uuenda loendit",
    "Open website" : "Ava veebisait",
    "Keep article unread" : "Hoia kui lugemata",
    "Toggle keep current article unread" : "Lülita 'hoia olemasolev artikkel lugemata'",
    "Remove keep article unread" : "Eemalda märgistus 'Hoia kui lugemata'",
    "Default" : "Vaikimisi",
    "Compact" : "Kompaktne",
    "Screenreader" : "Ekraanilugeja",
    "Vertical" : "Vertikaalne",
    "Horizontal" : "Horisontaalne",
    "Off" : "Pole kasutusel",
    "Always" : "Alati",
    "Ask" : "Küsi",
    "Never" : "Mitte kunagi",
    "Please select a valid OPML file" : "Palun vali korrektne opml-fail",
    "File successfully uploaded" : "Faili üleslaadimine õnnestus",
    "Error uploading the opml file" : "Viga opml-faili üleslaadimisel",
    "Error connecting to the server" : "Viga ühenduse loomisel serveriga",
    "Error retrieving the opml file" : "Viga opml-faili laadimisel",
    "Please select a valid json file" : "Palun vali korrektne JSON-fail",
    "Error uploading the json file" : "Viga JSON-faili üleslaadimisel",
    "Error retrieving the json file" : "Viga JSON-faili laadimisel",
    "General" : "Üldine",
    "Disable mark read through scrolling" : "Lülita kerimisel loetuks märkimine välja",
    "Reverse ordering (oldest on top)" : "Pööratud järjestus (vanemad eespool)",
    "Disable automatic refresh" : "Lülita automaatsed uuendused välja",
    "Media" : "Meediafailid",
    "Show embedded thumbnails" : "Näita lõimitud pisipilte",
    "Show enclosure images" : "Näita lõimitud pilte",
    "Show images in the article text" : "Näita artikli tekstis pilte",
    "Show iframes in the article text" : "Näita artikli tekstis iframe'e",
    "Appearance" : "Välimus",
    "Display mode" : "Kuvamise viis",
    "Split mode" : "Poolitatud vaade",
    "Import" : "Impordi",
    "Export" : "Ekspordi",
    "Abonnements (OPML)" : "Tellimused (OPML)",
    "Importing feeds" : "Impordin uudisvooge",
    "Please wait" : "Palun oota",
    "Articles (JSON)" : "Artiklid (JSON-vormingus)",
    "Keyboard shortcuts" : "Klaviatuuri otseteed",
    "Refresh" : "Värskenda",
    "Screenreader mode only" : "Vaid ekraanilugeja režiim",
    "Jump to previous article" : "Hüppa eelmise artikli juurde",
    "Jump to next article" : "Hüppa järgmise artikli juurde",
    "Item navigation and control" : "Liikumine kirjetes ja nende juhtimine",
    "Open article in new tab" : "Ava artikkel uuel kaardil",
    "Show article details in compact view" : "Näita artikli üksikasju kompaktses vaates",
    "Close article details in compact view" : "Sulge artikli üksikasjad kompaktses vaates",
    "Feed/Folder navigation and control" : "Liikumine kaustades ja uudisvoogude vahel",
    "Jump to previous feed" : "Suundu eelmise uudisvoo juurde",
    "Jump to next feed" : "Suundu järgmise uudisvoo juurde",
    "Jump to previous folder" : "Suundu eelmise kausta juurde",
    "Jump to next folder" : "Suundu järgmise kausta juurde",
    "Mark current articles feed/folder as read" : "Märgi see artiklite uudisvoog või kaust loetuks",
    "Resources" : "Ressursid",
    "Last update" : "Viimati uuendatud",
    "Time when the feed was last downloaded" : "Uudisvoo viimase allalaadimise aeg",
    "Next update" : "Järgmine uuendus",
    "Time when the next feed update will be done" : "Uudisvoo järgmise uuenduse aeg",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Toimib vaid siis, kui on peakasutaja seadistustes lülitatud sisse, muul juhul kasutatakse tavalist uuendusvälpa",
    "Articles per update" : "Artikleid uuenduse kohta",
    "Maximum number of articles reached in a feed update" : "Uudisvoo uuenduses lubatud artiklite ülempiir on käes",
    "Error Count" : "Vigade arv",
    "Number of errors that have occurred since the last successful feed update" : "Peale viimast uudisvoo õnnestunud uuendust on tekkinud mitu viga",
    "Title" : "Pealkiri",
    "Folder" : "Kaust",
    "Not available" : "Pole saadaval",
    "All Articles" : "Kõik artiklid",
    "No feeds found to add" : "Ei leia lisamiseks ühtegi uudisvoogu",
    "Subscribe to" : "Telli",
    "Unread Articles" : "Lugemata artiklid",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax või webcron aktiveeritud! Su voogusid ei uuendata!",
    "How to set up the operating system cron" : "Kuidas seadistada operatsioonisüsteemi ajastatud tegevust",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Paigalda ja seadista kiirem rööptöötlust kasutav uuendaja, mis põhineb uudisterakenduse liidestusel"
},
"nplurals=2; plural=(n != 1);");
