OC.L10N.register(
    "news",
    {
    "News" : "خەۋەرلەر",
    "Someone" : "بىرەيلەن",
    "%1$s shared \"%2$s\" with you" : "%1$s سىز بىلەن ئورتاقلاشتى \\ \"%2$s $ s \"",
    "News feeds" : "خەۋەرلەر",
    "Unread articles" : "ئوقۇلمىغان ماقالىلەر",
    "News folders" : "خەۋەر قىسقۇچلىرى",
    "News articles" : "خەۋەر ماقالىلىرى",
    "Shared with me" : "مەن بىلەن ئورتاقلاشتى",
    "An RSS/Atom feed reader" : "RSS / ئاتوم يەم ئوقۇغۇچ",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "Next Nextcloud ئۈچۈن RSS / Atom Feed ئوقۇغۇچ دېتالى\n\n- feed يەملىرىڭىزنى كۆپ كۆچمە ياكى ئۈستەل يۈزى [خېرىدارلار] بىلەن ماسقەدەملەڭ (https://nextcloud.github.io/news/clients/)\n- news خەۋەرلىرىڭىزنىڭ ئاپتوماتىك يېڭىلىنىشى\n- AG AGPLv3 دىكى ھەقسىز ۋە ئوچۇق مەنبە ، ھېچقانداق ئېلان ياكى يۇقىرى ئىقتىدار يوق\n\n** بۇ دېتالنىڭ ئىشلىشى ئۈچۈن سىستېما Cron ھازىر تەلەپ قىلىنىدۇ **\n\nتەلەپلەرنى [بۇ يەردىن] تاپقىلى بولىدۇ (https://nextcloud.github.io/news/install/#dependencies)\n\nChangelog نى بۇ يەردە ئىشلەتكىلى بولىدۇ (https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\n[خاتالىق دوكلاتى] قۇر (https://github.com/nextcloud/news/issues/new/choose)\n\n[ئىقتىدار تەلىپى] قۇرۇڭ (https://github.com/nextcloud/news/discussions/new)\n\n[يەم-خەشەك مەسىلىسى] نى دوكلات قىلىڭ (https://github.com/nextcloud/news/discussions/new)",
    "Download" : "چۈشۈر",
    "Close" : "ياپ",
    "Internal server error!" : "ئىچكى مۇلازىمېتىر خاتالىقى",
    "Unknown error!" : "نامەلۇم خاتالىق",
    "Web address" : "تور ئادرېسى",
    "Please check your data/nextcloud.log file for additional information!" : "قوشۇمچە ئۇچۇرلار ئۈچۈن سانلىق مەلۇماتلىرىڭىزنى / nextcloud.log ھۆججىتىنى تەكشۈرۈپ بېقىڭ!",
    "No folder" : "ھۆججەت قىسقۇچ يوق",
    "Folder name" : "قىسقۇچ ئاتى",
    "Username" : "ئىشلەتكۈچى ئاتى",
    "Password" : "ئىم",
    "Feed exists already!" : "يەم ئاللىقاچان مەۋجۇت!",
    "New folder" : "يېڭى قىسقۇچ",
    "Folder exists already!" : "ھۆججەت قىسقۇچ ئاللىبۇرۇن مەۋجۇت!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth كىنىشكىسى شىفىرسىز ساقلىنىشى كېرەك! مۇلازىمېتىر ياكى سانداننى زىيارەت قىلالايدىغانلارنىڭ ھەممىسى ئۇلارنى زىيارەت قىلالايدۇ!",
    "Credentials" : "سالاھىيەتلەر",
    "Auto discover Feed" : "ئاپتوماتىك بايقاش",
    "Subscribe" : "مۇشتەرى بولۇش",
    "Successfully updated news configuration" : "خەۋەر سەپلىمىسى مۇۋەپپەقىيەتلىك يېڭىلاندى",
    "Unable to update news config" : "خەۋەر سەپلىمىسىنى يېڭىلاشقا ئامالسىز",
    "Logo purge has never been run." : "لوگونى ئۆچۈرۈش ئەزەلدىن ئىجرا قىلىنمىدى.",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "ئاخىرقى لوگو ئۆچۈرۈش {relativeLastLogoPurge} دا ئىجرا قىلىندى. بىر نەرسە خاتادەك قىلىدۇ.",
    "Last logo purge job ran {relativeLastLogoPurge}." : "ئاخىرقى لوگو ئۆچۈرۈش {relativeLastLogoPurge} دا ئىجرا قىلىندى.",
    "No job execution data available. The cron job may not be running properly." : "خىزمەت ئىجرا قىلىش سانلىق-مەلۇماتى يوق. cron خىزمىتى توغرا ئىجرا بولمىغاندەك قىلىدۇ.",
    "Last job execution ran {relativeTime}. Something is wrong." : "ئاخىرقى خىزمەت ئىجراسى {relativeTime} دا ئىجرا قىلىندى. بىر نەرسە خاتادەك قىلىدۇ.",
    "Last job ran {relativeTime}." : "ئاخىرقى خىزمەت {relativeTime} ئىجرا بولدى.",
    "Maximum read count per feed" : "ھەر بىر يەمنىڭ ئەڭ كۆپ ئوقۇش سانى",
    "Maximum redirects" : "ئەڭ چوڭ قايتا نىشانلاش",
    "Feed fetcher timeout" : "بېقىش ۋاقتى",
    "Explore Service URL" : "مۇلازىمەت URL نى ئىزدەڭ",
    "Update interval" : "ئارىلىقنى يېڭىلاش",
    "Use system cron for updates" : "يېڭىلاش ئۈچۈن سىستېما كرون ئىشلىتىڭ",
    "Disable this if you use a custom updater." : "ئىختىيارى يېڭىلاشنى ئىشلەتسىڭىز بۇنى چەكلەڭ.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "تازىلاش خىزمىتى تەرىپىدىن ئۆچۈرۈلمەيدىغان ھەر بىر يەم-خەشەكنى ئوقۇغىلى بولىدىغان ماقالىنىڭ ئەڭ يۇقىرى سانىغا ئېنىقلىما بېرىدۇ. ئەگەر كونا ماقالىلەر ئوقۇپ بولغاندىن كېيىن قايتا كۆرۈلسە ، بۇ قىممەتنى ئاشۇرۇڭ. -1 قاتارلىق سەلبىي قىممەتلەر بۇ ئىقتىدارنى ئېتىۋېتىدۇ.",
    "Delete unread articles automatically" : "ئوقۇلمىغان ماقالىلەرنى ئاپتوماتىك ئۆچۈرۈڭ",
    "Enable this if you also want to delete unread articles." : "ئەگەر ئوقۇلمىغان ماقالىلەرنى ئۆچۈرمەكچى بولسىڭىز بۇنى قوزغىتىڭ.",
    "How many redirects the feed fetcher should follow." : "يەم-خەشەك ئەۋەتكۈچى قانچىلىك ئەگىشىشى كېرەك.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "RSS ياكى ئاتوم يەملىرىنىڭ يۈكلىنىشىنى ساقلاش ئۈچۈن ئەڭ كۆپ سېكۇنت. ئۇزۇنراق ۋاقىت كەتسە يېڭىلاش ئەمەلدىن قالدۇرۇلىدۇ.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "ئەگەر بېرىلگەن بولسا، بۇ مۇلازىمەتنىڭ URL ئادرېسى تەكشۈرۈش لىنىيىسى بۆلىكىدىكى لىنىيىلەرنى كۆرسىتىش ئۈچۈن سورىلىدۇ. ئىچكى تەكشۈرۈش مۇلازىمىتىگە قايتىش ئۈچۈن، بۇ كىرگۈزۈشنى بوش قالدۇرۇڭ.",
    "Interval in seconds in which the feeds will be updated." : "يەم-خەشەكلەر يېڭىلىنىدىغان سېكۇنتتا ئارىلىق.",
    "Use next update time for feed updates" : "يېڭىلاش يىمىكى ئۈچۈن كىيىنكى يېڭىلاش ۋاقتىنى ئىشلەت",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "بۇنى قوزغىتىپ، ھېسابلانغان كېيىنكى يېڭىلاش ۋاقتىنى ئۇچۇر يېڭىلاش ئۈچۈن ئىشلىتىڭ. پەقەت يېڭىلاش ئارىلىقىغا ئاساسەن ئۇچۇر يېڭىلاش ئۈچۈن چەكلەڭ.",
    "Article list" : "ماقالە تىزىملىكى",
    "Article details" : "ماقالە تەپسىلاتى",
    "No article selected" : "ھېچقانداق ماقالە تاللانمىدى",
    "Please select an article from the list." : "بۇ تىزىملىكتىن بىر ماقالە تاللاڭ.",
    "Show all articles" : "بارلىق ماقالىلەرنى كۆرسەت",
    "Move feed" : "يەمنى يۆتكە",
    "Please select the new folder" : "يېڭى قىسقۇچ تاللاڭ",
    "Move" : "يۆتكە",
    "User Name" : "ئىشلەتكۈچى ئىسمى",
    "Share" : "ھەمبەھىر",
    "Share with" : "بىلەن ئورتاقلىشىش",
    "Share with {num} users" : "{num} ئىشلەتكۈچىلەر بىلەن ئورتاقلىشىڭ",
    "Rename Folder" : "ھۆججەت قىسقۇچنىڭ نامىنى ئۆزگەرتىڭ",
    "Are you sure you want to delete?" : "ئۆچۈرمەكچىمۇ؟",
    "Mark read" : "مارك ئوقۇدى",
    "All articles" : "بارلىق ماقالىلەر",
    "Recently viewed" : "يېقىندا كۆرۈلگ",
    "Starred" : "يۇلتۇزلۇق",
    "Has feeds with errors!" : "خاتالىقى بار يەم مەۋجۇت!",
    "Explore" : "ئىزدىنىش",
    "Rename" : "ئات ئۆزگەرت",
    "Delete" : "ئۆچۈر",
    "Rename Feed" : "يەمنىڭ نامىنى ئۆزگەرتىش",
    "Open Feed URL" : "Feed URL نى ئېچىڭ",
    "Unpin from top" : "يۇقىرىدىن ئۆچۈرۈڭ",
    "Pin to top" : "ئۈستىدىن پىن",
    "Newest first" : "ئەڭ يېڭى",
    "Oldest first" : "ئەڭ كونا",
    "Default order" : "كۆڭۈلدىكى تەرتىپ",
    "Enable full text" : "تولۇق تېكىستنى قوزغىتىڭ",
    "Disable full text" : "تولۇق تېكىستنى چەكلەڭ",
    "Mark as unread on update" : "يېڭىلانغاندا ئوقۇمىغانلىك بەلگىسىنى قوي",
    "Keep read status on update" : "يېڭىلانغاندا ئوقۇش ھالىتىنى ساقلا",
    "Sync disabled" : "ماس-قەدەملەش ئىتىلدى",
    "Sync enabled" : "ماس-قەدەملەش ئېچىلدى",
    "from" : "from",
    "Previous Item" : "ئالدىنقى تۈر",
    "Next Item" : "كىيىنكى تۈر",
    "Share within Instance" : "بۇ دائىرە ئىچىدە ھەمبەھىرلە",
    "Toggle star article" : "چولپان ماقالىسىنى ئالماشتۇرۇڭ",
    "Mark unread" : "ئۇقۇمىغانلىق بەلگىسىنى قوي",
    "Close details" : "تەپسىلاتىنى ياپ",
    "shared by" : "ئورتاقلاشتى",
    "by" : "سەنئەتكار",
    "Play audio" : "ئاۋاز قويۇڭ",
    "Download audio" : "ئاۋازلىق چۈشۈرۈش",
    "Download video" : "سىن چۈشۈرۈش",
    "Refresh list" : "تىزىملىكنى يېڭىلا",
    "Open website" : "توربېكەتنى ئېچىڭ",
    "Keep article unread" : "ماقالىنى ئوقۇماڭ",
    "Toggle keep current article unread" : "Toggle نۆۋەتتىكى ماقالىنى ئوقۇمايدۇ",
    "Remove keep article unread" : "ماقالىنى ئوقۇماسلىقنى ئۆچۈرۈڭ",
    "Default" : "سۈكۈتتىكى",
    "Compact" : "ئىخچام",
    "Screenreader" : "ئېكران ئوقۇغۇ",
    "Vertical" : "ۋېرتىكال",
    "Horizontal" : "توغرىسىغا",
    "Off" : "ئىتىك",
    "Always" : "ھەمىشە",
    "Never" : "ھەرگىز",
    "Please select a valid OPML file" : "بىر ئىناۋەتلىك OPML ھۆججىتى تاللاڭ",
    "File successfully uploaded" : "ھۆججەت مۇۋاپىقىيەتلىك چىقىرىلدى",
    "Error uploading the opml file" : "opml ھۆججىتىنى چىقىرىش خاتالىقى",
    "Error connecting to the server" : "مۇلازىمېتىرغا ئۇلاش خاتالىقى",
    "Error retrieving the opml file" : "opml ھۆججىتىنى چۈشۈرۈش خاتالىقى",
    "General" : "ئۇمۇمىي",
    "Disable mark read through scrolling" : "سىيرىلما ئارقىلىق ئوقۇش بەلگىسىنى چەكلەڭ",
    "Reverse ordering (oldest on top)" : "تەتۈر زاكاز قىلىش (ئۈستىدىكى ئەڭ كونا)",
    "Disable automatic refresh" : "ئاپتۇماتىك يېڭىلاشنى تاقا",
    "Media" : "كۆپ-ۋاستە",
    "Appearance" : "كۆرۈنۈش",
    "Display mode" : "كۆرسىتىش ھالىتى",
    "Split mode" : "بۆلۈنۈش ھالىتى",
    "Import" : "ئەكىر",
    "Export" : "ئېكسپورت",
    "Abonnements (OPML)" : "Abonnements (OPML)",
    "Importing feeds" : "يەملەرنى كىرگۈزىۋاتىدۇ",
    "Please wait" : "ساقلاپ تۇرۇڭ",
    "Keyboard shortcuts" : "كۇنۇپكا تاختىسى تېزلەتمىسى",
    "Refresh" : "يېڭىلا",
    "Jump to previous article" : "ئالدىنقى ماقالىگە ئاتلاڭ",
    "Jump to next article" : "كېيىنكى ماقالىگە ئاتلاڭ",
    "Open article in new tab" : "يېڭى بەتكۈچتە ماقالە ئېچىڭ",
    "Show article details in compact view" : "ماقالە تەپسىلاتىنى ئىخچام كۆرۈنۈشتە كۆرسەت",
    "Close article details in compact view" : "ماقالە تەپسىلاتىنى ئىخچاش كۆرۈنۈشتىن ياپ",
    "Mark current articles feed/folder as read" : "نۆۋەتتىكى ماقالىلەرنىڭ يەم / ھۆججەت قىسقۇچىنى ئوقۇغاندەك بەلگە قويۇڭ",
    "Resources" : "بايلىق",
    "Last update" : "ئاخىرقى يېڭىلاش",
    "Time when the feed was last downloaded" : "يەمنىڭ ئاخىرقى چۈشۈرۈلگەن ۋاقتى",
    "Next update" : "كىيىنكى يېڭىلاش",
    "Time when the next feed update will be done" : "كىيىنكى يەم يېڭىلىندىغان ۋاقىت",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "پەقەت باشقۇرۇش تەڭشەكلىرىدە ئاكتىپلانغاندا، بولمىسا دائىملىق يېڭىلاش ئارىلىقى ئىشلىتىلىدۇ.",
    "Articles per update" : "ھەر يېڭىلاشتىكى ماقالىلەر",
    "Maximum number of articles reached in a feed update" : "بىر قېتىملىق يەم يېڭىلاشتا ئەڭ كۆپ ماقالە سانىغا يەتتى",
    "Error Count" : "خاتالىق سانى",
    "Number of errors that have occurred since the last successful feed update" : "ئاخىرقى مۇۋاپىقىيەتلىك يەم يېڭىلاشتىن كىيىنكى يۈز بەرگەن خاتالىق سانى",
    "Title" : "ماۋزۇ",
    "Folder" : "قىسقۇچ",
    "Not available" : "ئىشلەتكىلى بولمايدۇ",
    "All Articles" : "بارلىق ماقالىلەر",
    "No feeds found to add" : "قوشۇشقا بولىدىغان يەم تېپىلمىدى",
    "Subscribe to" : "مۇشتەرى بولۇش",
    "Unread Articles" : "ئوقۇلمىغان ماقالىلەر",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax ياكى webcron ھالىتى بايقالدى! يەملىرىڭىز يېڭىلانمايدۇ!",
    "How to set up the operating system cron" : "مەشغۇلات سىستېمىسى كروننى قانداق تەڭشەش كېرەك",
    "Install and set up a faster parallel updater that uses the News app's update API" : "News ئەپنىڭ يېڭىلاش API نى ئىشلىتىدىغان تېخىمۇ تېز پاراللېل يېڭىلاش ئۈسكۈنىسىنى قاچىلاڭ"
},
"nplurals=2; plural=(n != 1);");
