OC.L10N.register(
    "news",
    {
    "News" : "Uutiset",
    "Someone" : "Joku",
    "%1$s shared \"%2$s\" with you" : "%1$s jakoi kohteen \"%2$s\" kanssasi",
    "News feeds" : "Syötteet",
    "Unread articles" : "Lukemattomat artikkelit",
    "News folders" : "Syötekansiot",
    "News articles" : "Uutisartikkelit",
    "Shared with me" : "Jaettu kanssasi",
    "An RSS/Atom feed reader" : "RSS-/Atom-syötteiden lukija",
    "Download" : "Lataa",
    "Close" : "Sulje",
    "Web address" : "Verkko-osoite",
    "No folder" : "Ei kansiota",
    "Folder name" : "Kansion nimi",
    "Username" : "Käyttäjätunnus",
    "Password" : "Salasana",
    "Feed exists already!" : "Syöte on jo olemassa!",
    "New folder" : "Uusi kansio",
    "Folder exists already!" : "Kansio on jo olemassa!",
    "Credentials" : "Tilitiedot",
    "Auto discover Feed" : "Löydä syöte automaattisesti",
    "Subscribe" : "Tilaa",
    "Last job ran {relativeTime}." : "Viimeisin työ ajettiin {relativeTime}.",
    "Maximum read count per feed" : "Syötekohtainen lukukertojen enimmäismäärä",
    "Maximum redirects" : "Uudelleenohjausten enimmäismäärä",
    "Feed fetcher timeout" : "Syötteen hakemisen aikakatkaisu",
    "Explore Service URL" : "Syöte-ehdotusten palvelun URL",
    "Update interval" : "Päivitysväli",
    "Use system cron for updates" : "Käytä järjestelmän cronia päivityksille",
    "Disable this if you use a custom updater." : "Poista tämä käytöstä, jos käytät erillistä päivitintä.",
    "Delete unread articles automatically" : "Poista lukemattomat artikkelit automaattisesti",
    "How many redirects the feed fetcher should follow." : "Kuinka montaa uudelleenohjausta syötteen noutajan tulisi seurata.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimiaika sekunteina, jonka aikana RSS- tai Atom-syöte odotetaan ladattavaksi. Jos lataus kestää pidempään, se perutaan.",
    "Interval in seconds in which the feeds will be updated." : "Syötteiden päivitysväli sekunteina.",
    "No article selected" : "Artikkelia ei ole valittu",
    "Show all articles" : "Näytä kaikki artikkelit",
    "Move" : "Siirrä",
    "User Name" : "Käyttäjänimi",
    "Share" : "Jaa",
    "Share with" : "Jaa",
    "Share with {num} users" : "Jaa {num} käyttäjän kanssa",
    "Rename Folder" : "Nimeä kansio uudelleen",
    "Are you sure you want to delete?" : "Haluatko varmasti poistaa?",
    "Mark read" : "Merkitse luetuksi",
    "All articles" : "Kaikki artikkelit",
    "Starred" : "Suosikit",
    "Explore" : "Löydä uusia",
    "Rename" : "Nimeä uudelleen",
    "Delete" : "Poista",
    "Rename Feed" : "Nimeä syöte uudelleen",
    "Open Feed URL" : "Avaa syötteen osoite",
    "Unpin from top" : "Poista kiinnitys ylhäältä",
    "Pin to top" : "Kiinnitä ylös",
    "Newest first" : "Uusin ensin",
    "Oldest first" : "Vanhin ensin",
    "Default order" : "Oletusjärjestys",
    "Enable full text" : "Lataa koko teksti",
    "Disable full text" : "Älä lataa koko tekstiä",
    "from" : "Lähettäjä",
    "Toggle star article" : "Suosikkimerkintä päälle/pois",
    "Mark unread" : "Merkitse lukemattomaksi",
    "Close details" : "Sulje tiedot",
    "shared by" : "jakanut",
    "by" : "Kirjoittaja:",
    "Play audio" : "Toista äänet",
    "Download audio" : "Lataa äänet",
    "Download video" : "Lataa video",
    "Open website" : "Avaa verkkosivu",
    "Keep article unread" : "Pidä artikkeli lukemattomana",
    "Toggle keep current article unread" : "Pidä lukemattomana/aseta luetuksi",
    "Remove keep article unread" : "Poista artikkelin pitäminen lukemattomana",
    "Default" : "Oletus",
    "Vertical" : "Pystysuora",
    "Horizontal" : "Vaakasuora",
    "Always" : "Aina",
    "Never" : "Ei koskaan",
    "General" : "Yleiset",
    "Disable mark read through scrolling" : "Älä merkitse luetuksi vierittäessä",
    "Reverse ordering (oldest on top)" : "Käänteinen järjestys (vanhimmat ensin)",
    "Media" : "Media",
    "Appearance" : "Ulkoasu",
    "Import" : "Tuo",
    "Export" : "Vie",
    "Please wait" : "Odota hetki",
    "Keyboard shortcuts" : "Pikanäppäimet",
    "Refresh" : "Päivitä",
    "Jump to previous article" : "Siirry edelliseen artikkeliin",
    "Jump to next article" : "Siirry seuraavaan artikkeliin",
    "Open article in new tab" : "Avaa artikkeli uudessa välilehdessä",
    "Resources" : "Resurssit",
    "Title" : "Nimeke",
    "Folder" : "Kansio",
    "All Articles" : "Kaikki artikkelit",
    "Subscribe to" : "Tilaa",
    "Unread Articles" : "Lukemattomat artikkelit",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax tai webcron on käytössä! Syötteitä ei päivitetä!",
    "How to set up the operating system cron" : "Käyttöjärjestelmän cronin asettaminen",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Asenna ja ota käyttöön rinnakkainen päivitys käyttäen News-sovelluksen API:a"
},
"nplurals=2; plural=(n != 1);");
