OC.L10N.register(
    "news",
    {
    "News" : "Noticies",
    "Someone" : "Daquień",
    "%1$s shared \"%2$s\" with you" : "%1$s compartío \"%2$s\" contigo",
    "News feeds" : "Feeds de noticies",
    "Unread articles" : "Artículos ensin lleer",
    "News folders" : "Carpetes de noticies",
    "News articles" : "Artículos de noticies",
    "Shared with me" : "Compartióse conmigo",
    "An RSS/Atom feed reader" : "Un llector de ficheros RSS/Atom",
    "Download" : "Baxar",
    "Close" : "Zarrar",
    "Web address" : "Direición web",
    "No folder" : "Nun hai nenguna carpeta",
    "Folder name" : "Nome de la carpeta",
    "Username" : "Nome d'usuariu",
    "Password" : "Contraseña",
    "Feed exists already!" : "¡El feed yá esiste!",
    "New folder" : "Carpeta nueva",
    "Folder exists already!" : "¡La carpeta yá esiste!",
    "Subscribe" : "Soscribise",
    "Successfully updated news configuration" : "La configuración de les noticies anovóse correutamente",
    "Unable to update news config" : "Nun ye posible anovar la configuración de les noticies",
    "Last job ran {relativeTime}." : "L'últimu trabayu executó {relativeTime}.",
    "Maximum redirects" : "Redireiciones máximes",
    "Explore Service URL" : "URL del serviciu d'esploración",
    "Update interval" : "Intervalu d'anovamientu",
    "Use system cron for updates" : "Usar el cron del sistema pa los anovamientos",
    "No article selected" : "Nun se seleicionó nengún artículu",
    "Show all articles" : "Amosar tolos artículos",
    "Move" : "Mover",
    "Share" : "Compartir",
    "Share with" : "Compartir con",
    "Rename Folder" : "Renomar la carpeta",
    "All articles" : "Tolos artículos",
    "Explore" : "Esplorar",
    "Rename" : "Renomar",
    "Delete" : "Desaniciar",
    "Rename Feed" : "Renomar el feed",
    "Open Feed URL" : "Abrir l'URL del feed",
    "Unpin from top" : "Lliberar",
    "Pin to top" : "Fixar no cimero",
    "Newest first" : "Primero lo nuevo",
    "Oldest first" : "Primero lo antiguo",
    "Default order" : "Orde predetermináu",
    "Enable full text" : "Activar el testu completu",
    "Disable full text" : "Desactivar el testu completu",
    "from" : "de",
    "by" : "por",
    "Play audio" : "Reproducir l'audiu",
    "Download audio" : "Baxar l'audiu",
    "Download video" : "Baxar el videu",
    "Open website" : "Abrir el sitiu web",
    "Default" : "Por defeutu",
    "Vertical" : "Vertical",
    "Horizontal" : "Horizontal",
    "Off" : "Non",
    "Always" : "Siempres",
    "Never" : "Enxamás",
    "General" : "Xeneral",
    "Media" : "Multimedia",
    "Appearance" : "Aspeutu",
    "Import" : "Importa",
    "Export" : "Esportar",
    "Please wait" : "Espera",
    "Keyboard shortcuts" : "Atayos del tecláu",
    "Refresh" : "Anovar",
    "Resources" : "Recursos",
    "Title" : "Títulu",
    "Folder" : "Carpeta",
    "Not available" : "Nun ta disponible",
    "All Articles" : "Tolos artículos",
    "Subscribe to" : "Soscribise a",
    "Unread Articles" : "Artículos ensin lleer",
    "How to set up the operating system cron" : "Cómo configurar el cron del sistema operativu"
},
"nplurals=2; plural=(n != 1);");
