OC.L10N.register(
    "news",
    {
    "News" : "Νέα",
    "Someone" : "Κάποιος",
    "%1$s shared \"%2$s\" with you" : "Ο %1$s διαμοιράστηκε το \"%2$s\" με εσάς",
    "News feeds" : "Ροές ειδήσεων",
    "Unread articles" : "Μη αναγνωσμένα άρθρα",
    "News folders" : "Φάκελοι ειδήσεων",
    "News articles" : "Άρθρα ειδήσεων",
    "Shared with me" : "Διαμοιρασμένα με εμένα",
    "An RSS/Atom feed reader" : "Τροφοδότης ροής RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Μια εφαρμογή ανάγνωσης RSS/Atom Feed για το Nextcloud\n\n- 📲 Συγχρονίστε τα feeds σας με πολλαπλούς [πελάτες](https://nextcloud.github.io/news/clients/) για κινητά ή επιτραπέζιους υπολογιστές\n- 🔄 Αυτόματες ενημερώσεις των feeds ειδήσεων σας\n- 🆓 Δωρεάν και ανοιχτού κώδικα υπό AGPLv3, χωρίς διαφημίσεις ή premium λειτουργίες\n\n**Για να λειτουργήσει αυτή η εφαρμογή απαιτείται το System Cron**\n\nΟι απαιτήσεις βρίσκονται [εδώ](https://nextcloud.github.io/news/install/#dependencies)\n\nΤο αρχείο αλλαγών είναι διαθέσιμο [εδώ](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nΔημιουργήστε μια [αναφορά σφάλματος](https://github.com/nextcloud/news/issues/new/choose)\n\nΔημιουργήστε ένα [αίτημα για λειτουργία](https://github.com/nextcloud/news/discussions/new)\n\nΑναφέρετε ένα [πρόβλημα με το feed](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Λήψη",
    "Close" : "Κλείσιμο",
    "Internal server error!" : "Εσωτερικό σφάλμα διακομιστή!",
    "Unknown error!" : "Άγνωστο σφάλμα!",
    "Web address" : "Διεύθυνση ιστοσελίδας",
    "Please check your data/nextcloud.log file for additional information!" : "Παρακαλούμε ελέγξτε το αρχείο data/nextcloud.log για πρόσθετες πληροφορίες!",
    "No folder" : "Κανένας φάκελος",
    "Folder name" : "Όνομα φακέλου",
    "Username" : "Όνομα χρήστη",
    "Password" : "Κωδικός πρόσβασης",
    "Feed exists already!" : "Η ροή υπάρχει ήδη!",
    "New folder" : "Νέος φάκελος",
    "Folder exists already!" : "Ο φάκελος υπάρχει ήδη!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Τα διαπιστευτήρια Βασικής Πιστοποίησης HTTP πρέπει να αποθηκεύονται χωρίς κρυπτογράφηση! Όλοι με πρόσβαση στον διακομιστή ή τη βάση δεδομένων θα έχουν πρόσβαση σε αυτά!",
    "Credentials" : "Πιστοποιητικά",
    "Auto discover Feed" : "Αυτόματη ανακάλυψη Ροής",
    "Subscribe" : "Εγγραφή",
    "Successfully updated news configuration" : "Επιτυχής ενημέρωση ρύθμισης ειδήσεων",
    "Unable to update news config" : "Αδυναμία ενημέρωσης ρύθμισης ειδήσεων",
    "No job execution data available. The cron job may not be running properly." : "Δεν υπάρχουν διαθέσιμα δεδομένα εκτέλεσης εργασίας. Η cron εργασία μπορεί να μην εκτελείται σωστά.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Η τελευταία εκτέλεση εργασίας έτρεξε {relativeTime}. Κάτι πήγε στραβά.",
    "Last job ran {relativeTime}." : "Η τελευταία εργασία εκτελέστηκε {relativeTime}.",
    "Maximum read count per feed" : "Ο μέγιστος αριθμός διαβασμένων ανά ροή",
    "Maximum redirects" : "Μέγιστος αριθμός ανακατευθύνσεων",
    "Feed fetcher timeout" : "Χρόνος λήξης δέκτη ροής",
    "Explore Service URL" : "URL Υπηρεσίας Εξερεύνησης",
    "Update interval" : "Διάστημα ενημέρωσης",
    "Use system cron for updates" : "Χρήση του cron του συστήματος για ενημερώσεις",
    "Disable this if you use a custom updater." : "Απενεργοποιήστε αυτό εάν χρησιμοποιείτε προσαρμοσμένο ενημερωτή.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Καθορίζει τον μέγιστο αριθμό άρθρων που μπορούν να διαβαστούν ανά ροή τα οποία δεν θα διαγραφούν από την εργασία καθαρισμού· εάν παλιά άρθρα εμφανίζονται ξανά μετά την ανάγνωση, αυξήστε αυτή την τιμή· αρνητικές τιμές όπως -1 θα απενεργοποιήσουν αυτή τη λειτουργία.",
    "Delete unread articles automatically" : "Αυτόματη διαγραφή μη διαβασμένων άρθρων",
    "Enable this if you also want to delete unread articles." : "Ενεργοποιήστε αυτό εάν θέλετε επίσης να διαγράφονται τα μη διαβασμένα άρθρα.",
    "How many redirects the feed fetcher should follow." : "Πόσες ανακατευθύνσεις θα μπορεί να ακολουθεί η υπηρεσία ροών.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Μέγιστος χρόνος σε δευτερόλεπτα, αναμονής φόρτωσης μιας ροής RSS ή Atom; εάν χρειαστεί περισσότερο χρόνο η ενημέρωση θα ματαιωθεί.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Εάν παρέχεται, το URL αυτής της υπηρεσίας θα ερωτηθεί για να εμφανίσει τις ροές στο τμήμα εξερεύνησης ροών. Για να επιστρέψετε στην ενσωματωμένη υπηρεσία εξερεύνησης, αφήστε αυτή την εισαγωγή κενή.",
    "Interval in seconds in which the feeds will be updated." : "Διάστημα σε δευτερόλεπτα στο οποίο θα ενημερωθούν οι ροές.",
    "Use next update time for feed updates" : "Χρήση επόμενου χρόνου ενημέρωσης για ενημερώσεις ροών",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Ενεργοποιήστε αυτό για να χρησιμοποιήσετε τον υπολογισμένο επόμενο χρόνο ενημέρωσης για ενημερώσεις ροών. Απενεργοποιήστε για να ενημερώνετε τις ροές βασισμένες αποκλειστικά στο διάστημα ενημέρωσης.",
    "Article list" : "Λίστα άρθρων",
    "Article details" : "Λεπτομέρειες άρθρου",
    "No article selected" : "Δεν έχει επιλεγεί άρθρο",
    "Please select an article from the list." : "Παρακαλώ επιλέξτε ένα άρθρο από τη λίστα.",
    "Show all articles" : "Εμφάνιση όλων των άρθρων",
    "Move feed" : "Μετακίνηση ροής",
    "Please select the new folder" : "Παρακαλώ επιλέξτε τον νέο φάκελο",
    "Move" : "Μετακίνηση",
    "User Name" : "Όνομα Χρήστη",
    "Share" : "Διαμοιρασμός",
    "Share with" : "Διαμοιρασμός με",
    "Share with {num} users" : "Διαμοιρασμός με {num} χρήστες",
    "Rename Folder" : "Μετονομασία Φακέλου",
    "Are you sure you want to delete?" : "Είστε σίγουροι ότι θέλετε να διαγράψετε;",
    "Mark read" : "Σημείωση ως διαβασμένου",
    "All articles" : "Όλα τα άρθρα",
    "Recently viewed" : "Πρόσφατα προβεβλημένα",
    "Starred" : "Με αστέρι",
    "Has feeds with errors!" : "Υπάρχουν ροές με σφάλματα!",
    "Explore" : "Εξερεύνηση",
    "Rename" : "Μετονομασία",
    "Delete" : "Διαγραφή",
    "Rename Feed" : "Μετονομασία Ροής",
    "Open Feed URL" : "Άνοιγμα URL Ροής",
    "Unpin from top" : "Ξεκαρφίτσωμα από την κορυφή",
    "Pin to top" : "Καρφίτσωμα στην κορυφή",
    "Newest first" : "Νεότερο πρώτα",
    "Oldest first" : "Παλαιότερο πρώτα",
    "Default order" : "Προεπιλεγμένη σειρά",
    "Enable full text" : "Ενεργοποίηση πλήρους κειμένου",
    "Disable full text" : "Απενεργοποίηση πλήρους κειμένου",
    "Mark as unread on update" : "Σήμανση ως μη διαβασμένου κατά την ενημέρωση",
    "Keep read status on update" : "Διατήρηση κατάστασης ανάγνωσης κατά την ενημέρωση",
    "Sync disabled" : "Συγχρονισμός απενεργοποιημένος",
    "Sync enabled" : "Συγχρονισμός ενεργοποιημένος",
    "from" : "από",
    "Previous Item" : "Προηγούμενο Αντικείμενο",
    "Next Item" : "Επόμενο Αντικείμενο",
    "Share within Instance" : "Διαμοιρασμός εντός της Εγκατάστασης",
    "Toggle star article" : "Εναλλαγή επισήμανσης άρθρου με αστέρι",
    "Mark unread" : "σημειώστε ως μη αναγνωσμένο",
    "Close details" : "Κλείσιμο λεπτομερειών",
    "shared by" : "σε κοινή χρήση από",
    "by" : "από",
    "Play audio" : "Αναπαραγωγή ήχου",
    "Download audio" : "Λήψη ήχου",
    "Download video" : "Κατεβάστε το βίντεο",
    "Refresh list" : "Ανανέωση λίστας",
    "Open website" : "Άνοιγμα ιστοσελίδας",
    "Keep article unread" : "Διατήρηση άρθρου ως μη διαβασμένου",
    "Toggle keep current article unread" : "Εναλλαγή διατήρησης τρέχοντος άρθρου ως μη διαβασμένου",
    "Remove keep article unread" : "Αφαίρεση διατήρησης άρθρου ως μη διαβασμένου",
    "Default" : "Προεπιλογή",
    "Compact" : "Συμπαγής",
    "Screenreader" : "Αναγνώστης οθόνης",
    "Vertical" : "Κάθετα",
    "Horizontal" : "Οριζόντια",
    "Off" : "Απενεργοποιημένο",
    "Always" : "Πάντα",
    "Never" : "Ποτέ",
    "Please select a valid OPML file" : "Παρακαλώ επιλέξτε ένα έγκυρο αρχείο OPML",
    "File successfully uploaded" : "Το αρχείο μεταφορτώθηκε με επιτυχία",
    "Error uploading the opml file" : "Σφάλμα κατά τη μεταφόρτωση του αρχείου opml",
    "Error connecting to the server" : "Σφάλμα σύνδεσης με τον διακομιστή",
    "Error retrieving the opml file" : "Σφάλμα ανάκτησης του αρχείου opml",
    "General" : "Γενικά",
    "Disable mark read through scrolling" : "Απενεργοποίηση σημείωσης ως διαβασμένων κατά τη κύλιση",
    "Reverse ordering (oldest on top)" : "Ανεστραμμένη ταξινόμηση (παλαιότερα στην κορυφή)",
    "Disable automatic refresh" : "Απενεργοποίηση αυτόματης ανανέωσης",
    "Media" : "Μέσα ενημέρωσης",
    "Appearance" : "Εμφάνιση",
    "Display mode" : "Λειτουργία εμφάνισης",
    "Split mode" : "Λειτουργία διαχωρισμού",
    "Import" : "Εισαγωγή",
    "Export" : "Εξαγωγή",
    "Abonnements (OPML)" : "Συνδρομές (OPML)",
    "Importing feeds" : "Εισαγωγή ροών",
    "Please wait" : "Παρακαλούμε περιμένετε",
    "Keyboard shortcuts" : "Συντομεύσεις πλητρολογίου",
    "Refresh" : "Ανανέωση",
    "Jump to previous article" : "Μετάβαση στο προηγούμενο άρθρο",
    "Jump to next article" : "Επόμενο άρθρο",
    "Open article in new tab" : "Άνοιγμα άρθρου σε νέα καρτέλα",
    "Show article details in compact view" : "Εμφάνιση λεπτομερειών άρθρου σε συμπαγή προβολή",
    "Close article details in compact view" : "Κλείσιμο λεπτομερειών άρθρου σε συμπαγή προβολή",
    "Mark current articles feed/folder as read" : "Σήμανση τρέχουσας ροής/φακέλου άρθρων ως διαβασμένων",
    "Resources" : "Πόροι",
    "Last update" : "Τελευταία ενημέρωση",
    "Time when the feed was last downloaded" : "Χρόνος που η ροή κατέβηκε τελευταία φορά",
    "Next update" : "Επόμενη ενημέρωση",
    "Time when the next feed update will be done" : "Χρόνος που θα γίνει η επόμενη ενημέρωση ροής",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Μόνο εάν ενεργοποιηθεί στις ρυθμίσεις διαχειριστή, διαφορετικά χρησιμοποιείται το κανονικό διάστημα ενημέρωσης",
    "Articles per update" : "Άρθρα ανά ενημέρωση",
    "Maximum number of articles reached in a feed update" : "Ο μέγιστος αριθμός άρθρων που επιτεύχθηκε σε μια ενημέρωση ροής",
    "Error Count" : "Αριθμός Σφαλμάτων",
    "Number of errors that have occurred since the last successful feed update" : "Αριθμός σφαλμάτων που έχουν συμβεί από την τελευταία επιτυχή ενημέρωση ροής",
    "Title" : "Τίτλος",
    "Folder" : "Φάκελος",
    "Not available" : "Μη διαθέσιμο",
    "All Articles" : "Όλα τα Άρθρα",
    "No feeds found to add" : "Δεν βρέθηκαν ροές για προσθήκη",
    "Subscribe to" : "Εγγραφή στο",
    "Unread Articles" : "Μη Διαβασμένα Άρθρα",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax ή webcron κατάσταση εντοπίστηκε! Οι ροές σας δεν θα ενημερωθούν!",
    "How to set up the operating system cron" : "Πώς να ρυθμίσετε την υπηρεσία cron του λειτουργικού συστήματος",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Εγκαταστήστε και ρυθμίστε μιά παράλληλη γρηγορότερη ενημέρωση που χρησιμοποιεί το ΑΡΙ ενημέρωσης της εφαρμογής Νέα"
},
"nplurals=2; plural=(n != 1);");
