OC.L10N.register(
    "news",
    {
    "News" : "Noas",
    "Someone" : "Calecuna persone",
    "%1$s shared \"%2$s\" with you" : "%1$s at cumpartzidu \"%2$s\" cun tegus",
    "News feeds" : "Fontes de noas",
    "Unread articles" : "Artìculos non lèghidos",
    "News folders" : "Cartellas de noas",
    "News articles" : "Artìculos de noas",
    "Shared with me" : "Cumpartzidos cun megus",
    "An RSS/Atom feed reader" : "Unu letore de fontes RSS/Atom",
    "Download" : "Iscàrriga",
    "Close" : "Serra",
    "Web address" : "Indiritzu web",
    "No folder" : "Peruna cartella",
    "Folder name" : "Nùmene de sa cartella",
    "Username" : "Nùmene utente",
    "Password" : "Crae",
    "Feed exists already!" : "Sa fonte b'est giai!",
    "New folder" : "Cartella noa",
    "Folder exists already!" : "Sa cartella b'est giai!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Is credentziales HTTP Basic Auth si depent memorizare sena tzifradura! Chie si siat potzat intrare a su serbidore o a sa base de datos at a èssere a tretu de b'intrare!",
    "Credentials" : "Credentziales",
    "Auto discover Feed" : "Iscoberta automàtica fonte",
    "Subscribe" : "Sutaiscrie",
    "Successfully updated news configuration" : "Cunfiguratzione de noas agiornada",
    "Maximum read count per feed" : "Nùmeru màssimu de leturas a fonte",
    "Maximum redirects" : "Nùmeru màssimu de rediretziones",
    "Feed fetcher timeout" : "Ritardu màssimu de isetu pro su recùperu de sa fonte",
    "Explore Service URL" : "URL de su servìtziu Esplora",
    "Update interval" : "Tretu de agiornamentu",
    "Use system cron for updates" : "Imprea su cron de su sistema pro is agiornamentos",
    "Disable this if you use a custom updater." : "Disativa custu su pones in esecutzione una funtzione de agiornamentu personalizada.",
    "How many redirects the feed fetcher should follow." : "Cantas rediretziones podet sighire su trastu de recùperu de is fontes.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Nùmeru màssimu de segundos pro isetare su carrigamentu de una fonte RSS o Atom; si bi ponet tropu tempus s'agiornamentu s'at a firmare.",
    "Interval in seconds in which the feeds will be updated." : "Tretu in segundos pro agiornare is fontes.",
    "Show all articles" : "Mustra is artìculos",
    "Move" : "Tràmuda",
    "Share" : "Cumpartzi",
    "Mark read" : "Marca lèghidos",
    "All articles" : "Totu is artìculos",
    "Starred" : "Preferidos",
    "Explore" : "Esplorare",
    "Rename" : "Torra a numenare",
    "Delete" : "Cantzella",
    "Rename Feed" : "Torra a numenare Fonte",
    "Unpin from top" : "Boga dae sa chima",
    "Pin to top" : "Piga nota in artu",
    "Newest first" : "In antis is prus reghentes",
    "Oldest first" : "In antis is prus betzos",
    "Default order" : "Òrdine predefinidu",
    "Enable full text" : "Ativa totu su testu",
    "Disable full text" : "Disativa totu su testu",
    "from" : "dae",
    "Toggle star article" : "Còmmuta s'agiunta a is preferidos de un'artìculu",
    "Mark unread" : "Marca comente no lèghidu",
    "shared by" : "cumpartzidu cun",
    "by" : "dae",
    "Play audio" : "Reprodue àudiu",
    "Download audio" : "Iscàrriga àudiu",
    "Download video" : "iscàrriga vìdeu",
    "Open website" : "Aberi situ web",
    "Keep article unread" : "Mantene s'artìculu sena ddu lèghere",
    "Toggle keep current article unread" : "Còmmunta su mantenimentu de s'artìculu comente non lèghidu",
    "Remove keep article unread" : "Boga su mantenimentu de s'artìculu comente non lèghidu",
    "Default" : "Predefinidu",
    "Always" : "Semper",
    "Never" : "Mai",
    "Disable mark read through scrolling" : "Disativa su de marcare comente non lèghidu in s'iscurrimentu",
    "Reverse ordering (oldest on top)" : "Òrdine invertidu (su prus betzu in artu)",
    "Media" : "Elementos multimediales",
    "Appearance" : "Aspetu",
    "Import" : "Importa",
    "Export" : "Esporta",
    "Keyboard shortcuts" : "Curtziadòrgios de tecladu",
    "Refresh" : "Agiorna",
    "Jump to previous article" : "Brinca a s'artìculu de in antis",
    "Jump to next article" : "Brinca a s'artìculu imbeniente",
    "Open article in new tab" : "Aberi artìculu in un'ischeda noa",
    "Resources" : "Risorsas",
    "Title" : "Tìtulu",
    "Folder" : "Cartella",
    "All Articles" : "Totu is artìculos",
    "Subscribe to" : "Sutaiscrie",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Rilevada modalidade crom Ajax o webcron! Is fontes tuas non ant a èssere agiornadas!",
    "How to set up the operating system cron" : "Comente cunfigurare su cron de su sistema operativu",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installa e cunfigura una funtzione de atualizatzione parallelu prus lestra chi impreat is API de atualizatzione de s'aplicatzione News"
},
"nplurals=2; plural=(n != 1);");
