<?php
/**
 * Nextcloud - News
 *
 * This file is licensed under the Affero General Public License version 3 or
 * later. See the COPYING file.
 */

namespace OCA\News;

class Constants
{
    public const LOGO_IMAGE_DIR = 'feedLogoImage';
    public const LOGO_INFO_DIR = 'feedLogoInfo';
    public const LOGO_PRUNE_INTERVAL = 604800; // 1 week
}
