OC.L10N.register(
    "news",
    {
    "News" : "სიახლეები",
    "%1$s shared \"%2$s\" with you" : "%1$s-სგან გაგიზიარდათ \"%2$s\"",
    "Unread articles" : "წაუკითხავი არტიკლები",
    "Shared with me" : "გაზიარებულია ჩემთან",
    "Download" : "ჩამოტვირთვა",
    "Close" : "დახურვა",
    "Web address" : "Web მისამართი",
    "No folder" : "დირექტორია არაა",
    "Folder name" : "დირექტორიის სახელი",
    "Username" : "მომხმარებლის სახელი",
    "Password" : "პაროლი",
    "Feed exists already!" : "ლენტა უკვე არსებობს!",
    "New folder" : "ახალი დირექტორია",
    "Folder exists already!" : "დირექტორია უკვე არსებობს!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP ძირითადი აუტენტიფიკაციის მონაცემები არ უნდა იყოს დაშიფრული! სერვერთან ან მონაცემთა ბაზის წვდომის უფლებებით ყველა შეძლებს მათ ნახვას.",
    "Credentials" : "უფლებამოსილებები",
    "Subscribe" : "გამოწერა",
    "Maximum read count per feed" : "თითო ლენტაზე მაქისმალური კითხვის რაოდენობა",
    "Maximum redirects" : " მაქს. გადამისამართებები",
    "Feed fetcher timeout" : "ლენტის მომპოვებლის დროის ამოწურვა",
    "Explore Service URL" : "სერვის მისამართის დათვალიერება",
    "Use system cron for updates" : "განახლებისთვის გამოიყენეთ სისტემური კრონი",
    "Show all articles" : "ყველა არტიკლის ჩვენება",
    "Move" : "გადატანა",
    "Share" : "გაზიარება",
    "Mark read" : "მონიშნეთ წაკითხულად",
    "All articles" : "ყველა არტიკლი",
    "Starred" : "ვარსკვლავმინიჭებული",
    "Explore" : "მიმოხილვა",
    "Rename" : "გადარქმევა",
    "Delete" : "გაუქმება",
    "Rename Feed" : "ლენტის სახელის ცვლილება",
    "Unpin from top" : "ზევიდან ამოღება",
    "Pin to top" : "ზევით დამატება",
    "Newest first" : "ჯერ ახლები",
    "Oldest first" : "ჯერ ძველები",
    "Default order" : "საწყისი განლაგება",
    "Enable full text" : "სრული ტექსტის ამოქმედება",
    "Disable full text" : "სრული ტექსტის გათიშვა",
    "from" : "ვისგან",
    "Toggle star article" : "არტიკლის ვარსკლავის გადართვა",
    "Close details" : "დეტალების დახურვა",
    "by" : "მიერ",
    "Play audio" : "აუდიოს დაკვრა",
    "Download audio" : "აუდიოს ჩამოტვირთვა",
    "Download video" : "ვიდეოს ჩამოტვირთვა",
    "Open website" : "ვებ-საიტის გახსნა",
    "Keep article unread" : "დატოვეთ არტიკლი წაუკითხავი",
    "Toggle keep current article unread" : "გადართეთ არტიკლის წაუკთხავად დატოვება",
    "Remove keep article unread" : "მოაშორეთ არტიკლს წაუკითხავად დატოვება",
    "Default" : "საწყისი პარამეტრები",
    "Never" : "არასდროს",
    "General" : "ზოგადი",
    "Disable mark read through scrolling" : "გადახვევით წაკითხულად ქცევის გათიშვა",
    "Reverse ordering (oldest on top)" : "უკუგანლაგება (ძველები ზემოთ)",
    "Import" : "იმპორტი",
    "Export" : "ექსპორტი",
    "Please wait" : "გთხოვთ მოითმინოთ",
    "Keyboard shortcuts" : "კლავიატურის კომბინაციები",
    "Refresh" : "განახლება",
    "Jump to previous article" : "წინა არტიკლზე გადასვლა",
    "Jump to next article" : "შემდეგ არტიკლზე გადასვლა",
    "Open article in new tab" : "არტიკლის ახალ ტაბში გახნსა",
    "Resources" : "რესურსები",
    "Title" : "სათაური",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "არჩეულია Ajax-ის ან webcron-ის რეჟიმი! თქვენი ლენტა არ განახლდება!",
    "How to set up the operating system cron" : "როგორ დავაყენოთ ოპერაციული სისტემის კრონი",
    "Install and set up a faster parallel updater that uses the News app's update API" : "დააყენეთ და მოაწყვეთ უფრო სწრაფი პარალელური განახლება რომელიც მოიხმარს სიახლეების აპლიკაციის განახლების პროგრამულ ინტერფეისს"
},
"nplurals=2; plural=(n!=1);");
