OC.L10N.register(
    "news",
    {
    "News" : "뉴스",
    "%1$s shared \"%2$s\" with you" : "%1$s 님이 \"%2$s\" 항목을 여러분과 공유했습니다",
    "News feeds" : "뉴스 피드",
    "Unread articles" : "읽지 않은 글",
    "News folders" : "뉴스 폴더",
    "News articles" : "뉴스 기사",
    "Shared with me" : "나와 공유됨",
    "An RSS/Atom feed reader" : "RSS/Atom 피드 리더",
    "Download" : "다운로드",
    "Close" : "닫기",
    "Web address" : "웹 주소",
    "No folder" : "폴더 없음",
    "Folder name" : "폴더 이름",
    "Username" : "사용자 이름",
    "Password" : "암호",
    "Feed exists already!" : "피드가 이미 존재합니다!",
    "New folder" : "새 폴더",
    "Folder exists already!" : "폴더가 이미 존재합니다!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP 기본 인증 정보는 암호화되지 않은 상태로 저장됩니다! 서버나 데이터베이스에 접근한 모든 사용자들이 접근할 수 있습니다!",
    "Credentials" : "인증 정보",
    "Subscribe" : "구독",
    "Successfully updated news configuration" : "뉴스 설정을 성공적으로 갱신함",
    "Unable to update news config" : "뉴스 설정을 갱신할 수 없음",
    "Last job ran {relativeTime}." : "마지막 작업이 {relativeTime}에 실행되었음",
    "Maximum read count per feed" : "피드당 최대 읽은 글 개수",
    "Maximum redirects" : "최대 넘겨주기 수",
    "Feed fetcher timeout" : "피드 가져오기 시간 제한",
    "Explore Service URL" : "탐색 서비스 URL",
    "Update interval" : "갱신 주기",
    "Use system cron for updates" : "시스템 cron으로 업데이트",
    "Disable this if you use a custom updater." : "사용자 지정 업데이터를 사용할 경우 이 옵션을 비활성화하십시오.",
    "Delete unread articles automatically" : "읽지 않은 글 자동으로 삭제",
    "Enable this if you also want to delete unread articles." : "읽지 않은 글을 자동으로 삭제하고자 할 경우 이 옵션을 활성화하십시오.",
    "No article selected" : "선택한 글 없음",
    "Show all articles" : "모든 글 보기",
    "Move" : "이동",
    "User Name" : "사용자 이름",
    "Share" : "공유",
    "Share with" : "다음과 공유",
    "Share with {num} users" : "{num}명의 사용자와 공유",
    "Rename Folder" : "폴더 이름 바꾸기",
    "Are you sure you want to delete?" : "삭제하시겠습니까?",
    "Mark read" : "읽은 상태로 표시",
    "All articles" : "모든 글",
    "Starred" : "별표",
    "Explore" : "탐색",
    "Rename" : "이름 바꾸기",
    "Delete" : "삭제",
    "Rename Feed" : "비드 이름 바꾸기",
    "Unpin from top" : "목록에서 고정 해제",
    "Pin to top" : "목록에 고정",
    "Newest first" : "새 항목 먼저",
    "Oldest first" : "오래된 항목 먼저",
    "Default order" : "기본 순서",
    "Enable full text" : "전문 사용",
    "Disable full text" : "전문 사용 안 함",
    "from" : "보낸 사람",
    "Share within Instance" : "인스턴스 내에서 공유",
    "Toggle star article" : "글 별표 전환",
    "Mark unread" : "읽지 않음 상태로 표시",
    "Close details" : "자세한 정보 숨기기",
    "shared by" : "다음 사용자가 공유함:",
    "by" : "작성:",
    "Play audio" : "오디오 재생",
    "Download audio" : "오디오 다운로드",
    "Download video" : "동영상 다운로드",
    "Open website" : "웹 사이트 열기",
    "Keep article unread" : "읽지 않은 상태로 유지",
    "Toggle keep current article unread" : "현재 글 읽지 않은 상태로 유지 전환",
    "Remove keep article unread" : "읽지 않은 상태로 유지하지 않음",
    "Default" : "디폴트",
    "Vertical" : "세로",
    "Horizontal" : "가로",
    "Always" : "항상",
    "Never" : "하지 않음",
    "General" : "일반",
    "Disable mark read through scrolling" : "스크롤 시 읽은 상태로 표시 비활성화",
    "Reverse ordering (oldest on top)" : "순서 뒤집기(오래된 항목 먼저)",
    "Media" : "미디어",
    "Appearance" : "외형",
    "Import" : "가져오기",
    "Export" : "내보내기",
    "Please wait" : "기다려 주세요.",
    "Keyboard shortcuts" : "키보드 단축키",
    "Refresh" : "새로 고침",
    "Jump to previous article" : "이전 글로 이동",
    "Jump to next article" : "다음 글로 이동",
    "Open article in new tab" : "새 탭으로 글 열기",
    "Resources" : "자원",
    "Title" : "제목",
    "Folder" : "폴더",
    "All Articles" : "모든 글",
    "No feeds found to add" : "추가할 피드를 없음",
    "Subscribe to" : "다음을 구독",
    "Unread Articles" : "읽지 않은 글",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax 및 웹 cron 모드가 감지되었습니다! 피드를 업데이트하지 않습니다!",
    "How to set up the operating system cron" : "운영 체제 cron 설정 방법",
    "Install and set up a faster parallel updater that uses the News app's update API" : "뉴스 앱의 업데이트 API를 사용하는 빠른 병렬 업데이터 설치 및 설정"
},
"nplurals=1; plural=0;");
