OC.L10N.register(
    "news",
    {
    "News" : "Novinky",
    "an article" : "článek",
    "Someone" : "Někdo",
    "%1$s shared \"%2$s\" with you" : "%1$s vám nasdílel(a) „%2$s“",
    "{user} shared \"{article}\" with you" : "{user} vám nasdílel/a „{article}“",
    "News feeds" : "Kanály novinek",
    "Unread articles" : "Nepřečtené články",
    "News folders" : "Složky novinek",
    "News articles" : "Nové články",
    "Shared with me" : "Sdíleno se mnou",
    "Untitled article" : "Článek bez názvu",
    "An RSS/Atom feed reader" : "Čtečka RSS/Atom kanálů",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Aplikace čtečka RSS/Atom kanálů pro Nextcloud\n\n- 📲 Synchronizujte vámi odebírané kanály s vícero mobilními nebo desktopovými [klienty](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatické aktualizace vašich kanálů s novinkami\n- 🆓 Svobodné a open source pod licencí AGPLv3, žádné reklamy nebo funkce přístupné až po zaplacení\n\n**Aby tato aplikace fungovala, je v tuto chvíli zapotřebí systémový plánovač (cron)**\n\nPožadavky na instalaci dalších součástí jsou k nalezení [zde](https://nextcloud.github.io/news/install/#dependencies)\n\nSeznam změn je k dispozici [zde](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nVytvořte [hlášení chyby](https://github.com/nextcloud/news/issues/new/choose)\n\nVytvořte [žádost o přidání funkce](https://github.com/nextcloud/news/discussions/new)\n\nNahlaste [problém s kanálem}(https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Stáhnout",
    "Close" : "Zavřít",
    "Internal server error!" : "Vnitřní chyba serveru!",
    "Unknown error!" : "Neznámá chyba!",
    "Web address" : "Webová adresa",
    "Please check your data/nextcloud.log file for additional information!" : "Podrobnosti naleznete v souboru data/nextcloud.log !",
    "No folder" : "Žádná složka",
    "Folder name" : "Název složky",
    "Username" : "Uživatelské jméno",
    "Password" : "Heslo",
    "Feed exists already!" : "Kanál už existuje!",
    "New folder" : "Nová složka",
    "Folder exists already!" : "Složka už existuje!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Je třeba, aby přihlašovací údaje pro HTTP Basic Auth byly uloženy nešifrovaně! Každý s přístupem k serveru nebo databázi je ovšem bude moci přečíst!",
    "Credentials" : "Přihlašovací údaje",
    "Auto discover Feed" : "Automaticky objevit kanál",
    "Subscribe" : "Přihlásit se k odběru",
    "Successfully updated news configuration" : "Nastavení pro Novinky úspěšně zaktualizováno",
    "Unable to update news config" : "Nedaří se aktualizovat nastavení pro Novinky",
    "Logo purge has never been run." : "Vyčištění log nebylo ještě nikdy spuštěno.",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "Minulé vykonání vyčištění log bylo {relativeLastLogoPurge}. Něco není v pořádku.",
    "Last logo purge job ran {relativeLastLogoPurge}." : "Poslední úloha vyčištění log proběhla {relativeLastLogoPurge}.",
    "No job execution data available. The cron job may not be running properly." : "Nejsou k dispozici žádné údaje pro vykonání úlohy. Může se stát, že naplánovaná úloha (cron) neproběhne správně.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Minulé vykonání úlohy bylo {relativeTime}. Zdá se, že něco není v pořádku.",
    "Last job ran {relativeTime}." : "Poslední úloha proběhla {relativeTime}.",
    "Maximum read count per feed" : "Maximální počet načítaných novinek na kanál",
    "Maximum redirects" : "Nejvyšší počet přesměrování",
    "Feed fetcher timeout" : "Časový limit při stahování článků",
    "Explore Service URL" : "URL služby pro objevování",
    "Update interval" : "Interval aktualizace",
    "Use system cron for updates" : "Pro aktualizace používat službu systémového plánovače (cron)",
    "Disable this if you use a custom updater." : "Toto vypněte, pokud používáte uživatelsky určený nástroj pro aktualizace.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Určuje nejvyšší nastavený počet článků, které je z jednotlivých kanálů možné číst a které tím nebudou mazány při čištění. Pokud se staré už přečtené články znovu objevují, navyšte tuto hodnotu (záporné hodnoty jako např. -1 tuto funkci úplně vypnou).",
    "Delete unread articles automatically" : "Automaticky mazat i nepřečtené články",
    "Enable this if you also want to delete unread articles." : "Pokud chcete mazat také nepřečtené články, zapněte toto.",
    "How many redirects the feed fetcher should follow." : "Kolik až přesměrování může být následováno při stahování článků.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Nejdelší přijatelné čekání (v sekundách) na načtení RSS nebo Atom kanálu. Při překročení bude pokus o aktualizaci přerušen.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Pokud zadána, bude URL této služby dotazována ohledně zobrazování kanálů v rámci sekce pro jejich objevování. Pokud se chcete vrátit k výchozí službě pro objevování, ponechte tuto kolonku nevyplněnou.",
    "Interval in seconds in which the feeds will be updated." : "Interval (v sekundách) ve kterém budou kanály aktualizovány.",
    "Use next update time for feed updates" : "Použít příští čas aktualizace pro nakrmení aktualizací",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Toto zapněte pro použití vypočítaného času příští aktualizace pro nakrmení aktualizací. Vypněte pro kanály založené čistě na intervalu aktualizace.",
    "Article list" : "Seznam článku",
    "Article details" : "Podrobnosti o článku",
    "No article selected" : "Nevybrán žádný článek",
    "Please select an article from the list." : "Vyberte jiný článek ze seznamu.",
    "Show all articles" : "Zobrazit všechny články",
    "Move feed" : "Přesunout kanál",
    "Please select the new folder" : "Vyberte novou složku",
    "Move" : "Přesunout",
    "User Name" : "Uživatelské jméno",
    "Share" : "Sdílet",
    "Share with" : "Sdílet s",
    "Share with {num} users" : "Nasdílet {num} uživatelům",
    "Rename Folder" : "Přejmenovat složku",
    "Are you sure you want to delete?" : "Opravdu chcete smazat?",
    "Unable to save starred open state" : "Nebylo možné uložit otevřený stav označený hvězdičkou",
    "Mark read" : "Označit jako přečtené",
    "All articles" : "Všechny články",
    "Recently viewed" : "Nedávno zobrazené",
    "Starred" : "S hvězdičkou",
    "Has feeds with errors!" : "Má kanál s chybami!",
    "Explore" : "Objevit",
    "Feed settings" : "Nastavení kanálu",
    "News settings" : "Nastavení pro Novinky",
    "Rename" : "Přejmenovat",
    "Delete" : "Smazat",
    "Rename Feed" : "Přejmenovat kanál",
    "Open Feed URL" : "Otevřít URL kanálu",
    "Unpin from top" : "Odepnout od shora",
    "Pin to top" : "Připnout nahoru",
    "Newest first" : "První nejnovější",
    "Oldest first" : "První nejstarší",
    "Default order" : "Výchozí pořadí",
    "Enable full text" : "Zobrazovat celý text",
    "Disable full text" : "Nezobrazovat celý text",
    "Mark as unread on update" : "Při aktualizaci označit jako nepřečtené",
    "Keep read status on update" : "I po aktualizaci ponechat stav přečtené",
    "Sync disabled" : "Synchronizace vypnuta",
    "Sync enabled" : "Synchronizace zapnuta",
    "Show external media" : "Zobrazit externí média",
    "from" : "od",
    "External media loaded from" : "Externí média načtena z",
    "Previous Item" : "Předchozí položka",
    "Next Item" : "Další položka",
    "Share within Instance" : "Nasdílet v rámci instance",
    "Toggle star article" : "Označit / zrušit označení článku hvězdičkou",
    "Mark unread" : "Označit jako nepřečtené",
    "Close details" : "Zavřít podrobnosti",
    "shared by" : "sdílí",
    "by" : "od",
    "Play audio" : "Přehrát zvuk",
    "Download audio" : "Stáhnout si zvuk",
    "Download video" : "Stáhnout si video",
    "Refresh list" : "Znovu načíst seznam",
    "Open website" : "Otevřít webovou stránku",
    "Keep article unread" : "Ponechat stav článku jako nepřečtený",
    "Toggle keep current article unread" : "Vyp/zap. ponechání stávajícího článku jako nepřečteného",
    "Remove keep article unread" : "Odebrat článku stav nepřečteného",
    "Default" : "Výchozí",
    "Compact" : "Zhuštěné",
    "Screenreader" : "Čtečka obrazovky",
    "Vertical" : "Svislé",
    "Horizontal" : "Vodorovné",
    "Off" : "Vypnuto",
    "Always" : "Vždy",
    "Ask" : "Zeptat se",
    "Never" : "Nikdy",
    "Please select a valid OPML file" : "Vyberte platný OPML soubor",
    "File successfully uploaded" : "Soubor úspěšně nahrán",
    "Error uploading the opml file" : "Chyba při nahrávání opml souboru",
    "Error connecting to the server" : "Chyba při připojování k serveru",
    "Error retrieving the opml file" : "Chyba při získávání opml souboru",
    "Please select a valid json file" : "Vyberte platný json soubor",
    "Error uploading the json file" : "Chyba při nahrávání json souboru",
    "Error retrieving the json file" : "Chyba při získávání json souboru",
    "General" : "Obecné",
    "Disable mark read through scrolling" : "Po posunutí na jejich konec, neoznačovat automaticky články jako přečtené.",
    "Reverse ordering (oldest on top)" : "Opačné řazení (od nejstarších)",
    "Disable automatic refresh" : "Vypnout automatické znovunačítání",
    "Media" : "Média",
    "Show enclosure images" : "Zobrazovat obrázky obalu",
    "Show images in the article text" : "V textu článku zobrazovat obrázky",
    "Show iframes in the article text" : "V textu článku zobrazovat iframe rámce",
    "Appearance" : "Vzhled",
    "Display mode" : "Režim zobrazení",
    "Split mode" : "Dělený režim",
    "Import" : "Naimportovat",
    "Export" : "Exportovat",
    "Abonnements (OPML)" : "Odběry (OPML)",
    "Importing feeds" : "Importování kanálů",
    "Please wait" : "Vyčkejte",
    "Articles (JSON)" : "Ćlánky (JSON)",
    "Keyboard shortcuts" : "Klávesové zkratky",
    "Refresh" : "Znovu načíst",
    "Screenreader mode only" : "Pouze režim čtečky obrazovky",
    "Jump to previous article" : "Přejít na předchozí článek",
    "Jump to next article" : "Přejít na další článek",
    "Item navigation and control" : "Navigace a ovládání položky",
    "Open article in new tab" : "Otevřít článek v novém panelu",
    "Show article details in compact view" : "V kompaktním zobrazení ukázat podrobnosti o článku",
    "Close article details in compact view" : "V kompaktním zobrazení zavřít podrobnosti o článku",
    "Feed/Folder navigation and control" : "Navigace a ovládání kanálu/složky",
    "Jump to previous feed" : "Přejít na předchozí kanál",
    "Jump to next feed" : "Přejít na další kanál",
    "Jump to previous folder" : "Přejít do předchozí složky",
    "Jump to next folder" : "Přejít do další složky",
    "Mark current articles feed/folder as read" : "Označit stávající články kanálu/složky jako přečtené",
    "Resources" : "Prostředky",
    "Last update" : "Naposledy aktualizováno",
    "Time when the feed was last downloaded" : "Okamžik kdy byl kanál naposledy stažen",
    "Next update" : "Příští aktualizace",
    "Time when the next feed update will be done" : "Okamžik kdy bude kanál znovu zaktualizován",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Pouze pokud aktivováno v nastavení pro správu – pokud ne, je použit běžný interval aktualizace",
    "Articles per update" : "Článků na aktualizaci",
    "Maximum number of articles reached in a feed update" : "V rámci aktualizace kanálu dosaženo nejvyššího umožněného počtu článků",
    "Error Count" : "Počet chyb",
    "Number of errors that have occurred since the last successful feed update" : "Počet chyb, ke kterým došlo od poslední úspěšné aktualizace kanálu",
    "Title" : "Titul",
    "Folder" : "Složka",
    "Not available" : "Není k dispozici",
    "All Articles" : "Všechny články",
    "No feeds found to add" : "Nenalezeny žádné kanály, které by bylo možné přidat",
    "Subscribe to" : "Přihlásit se k odběru",
    "Unread Articles" : "Nepřečtené články",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Zjištěn ajax nebo web cron režim! Kanály nebudou aktualizovány!",
    "How to set up the operating system cron" : "Jak nastavit službu plánovače operačního systému (cron)",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Nainstalovat a nastavit rychlejší paralelní systém aktualizace využívající aktualizační aplikační program. rozhraní (API) aplikace Novinky"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
