OC.L10N.register(
    "news",
    {
    "News" : "Noticias",
    "Someone" : "Alguien",
    "%1$s shared \"%2$s\" with you" : "%1$s ha compartido \"%2$s\" contigo",
    "News feeds" : "Fuentes de noticias",
    "Unread articles" : "Artículos sin leer",
    "News folders" : "Carpetas nuevas",
    "News articles" : "Artículos de noticias",
    "Shared with me" : "Compartido conmigo",
    "An RSS/Atom feed reader" : "Un lector de feeds RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 App de lectura de fuentes de noticias RSS/Atom para Nextcloud\n\n- 📲 Sincronice sus fuentes de noticias con múltiples [clientes](https://nextcloud.github.io/news/clients/) móviles o de escritorio.\n- 🔄 Actualizaciones automáticas de sus fuentes de noticias.\n- 🆓 Gratis y de código abierto bajo AGPLv3, sin anuncios o funciones premium.\n\n**Se requiere el Cron del sistema para que esta aplicación funcione**\n\nLos requisitos se pueden encontrar [aquí](https://nextcloud.github.io/news/install/#dependencies)\n\nLa lista de cambios se encuentra [aquí](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCrear un [reporte de bug](https://github.com/nextcloud/news/issues/new/choose)\nCrear una [solicitud de función](https://github.com/nextcloud/news/discussions/new)\n\nInformar de un [problema en fuente](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Descargar",
    "Close" : "Cerrar",
    "Internal server error!" : "¡Error interno del servidor!",
    "Unknown error!" : "¡Error desconocido!",
    "Web address" : "Dirección web",
    "Please check your data/nextcloud.log file for additional information!" : "¡Por favor, comprueba el archivo data/nextcloud.log para más información!",
    "No folder" : "Sin carpeta",
    "Folder name" : "Nombre de la carpeta",
    "Username" : "Nombre de usuario",
    "Password" : "Contraseña",
    "Feed exists already!" : "Esa fuente ya existe.",
    "New folder" : "Nueva carpeta",
    "Folder exists already!" : "¡La carpeta ya existe!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "¡Las credenciales para HTTP Basic Auth deben estar guardadas sin cifrar! ¡Pero cualquiera con acceso al servidor podría acceder a ellas!",
    "Credentials" : "Credenciales",
    "Auto discover Feed" : "Auto descubrir Fuentes",
    "Subscribe" : "Suscribirse",
    "Successfully updated news configuration" : "Se actualizó la configuración de noticias de forma exitosa",
    "Unable to update news config" : "No se puede actualizar la configuración de las noticias",
    "No job execution data available. The cron job may not be running properly." : "No hay datos de ejecución de trabajos disponible. El trabajo cron podría no estar ejecutándose apropiadamente.",
    "Last job execution ran {relativeTime}. Something is wrong." : "La última ejecución fue en {relativeTime}. Algo está mal.",
    "Last job ran {relativeTime}." : "Último trabajo realizado {relativeTime}.",
    "Maximum read count per feed" : "Máximo número de lecturas por fuente",
    "Maximum redirects" : "Máximo de redirecciones",
    "Feed fetcher timeout" : "Tiempo de espera agotado para la descarga de la fuente",
    "Explore Service URL" : "Explorar URL del Servicio",
    "Update interval" : "Intervalo de actualización",
    "Use system cron for updates" : "Usa el cron del sistema para las actualizaciones",
    "Disable this if you use a custom updater." : "Desactiva esto si ejecutas un actualizador personalizado.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Define la cantidad de artículos máxima que se pueden leer por fuente que no se borrarán mediante el trabajo de limpieza, si reaparecen artículos viejos después de que los hayas leído, aumenta este valor, valores negativos como -1 desactivarán esta característica.",
    "Delete unread articles automatically" : "Borrar artículos no leídos de forma automática",
    "Enable this if you also want to delete unread articles." : "Habilite esta opción si además quiere borrar los artículos no leídos.",
    "How many redirects the feed fetcher should follow." : "Cuántas redirecciones debería seguir el capturador de fuentes.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Número máximo de segundos que esperara a que una fuente RSS o Atom cargue; si tarda más se abortará la actualización.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Si se proporciona, se consultará la URL de este servicio para mostrar las fuentes en la sección de exploración de fuentes. Para utilizar el servicio de exploración incorporado, deje este campo vacío.",
    "Interval in seconds in which the feeds will be updated." : "Intervalo en segundos en el que se actualizarán las fuentes.",
    "Use next update time for feed updates" : "Usar la siguiente hora de actualización para las fuentes",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Activa esta opción para actualizar la fuente a la hora calculada de la siguiente actualización. Desactívala para actualizar fuentes basándose solo en el intervalo de actualización.",
    "Article list" : "Lista de artículos",
    "Article details" : "Detalles del artículo",
    "No article selected" : "Ningún artículo seleccionado",
    "Please select an article from the list." : "Por favor, seleccione un artículo de la lista.",
    "Show all articles" : "Mostrar todos los artículos",
    "Move feed" : "Mover fuente",
    "Please select the new folder" : "Por favor, seleccione la carpeta nueva",
    "Move" : "Mover",
    "User Name" : "Nombre de usuario",
    "Share" : "Compartir",
    "Share with" : "Compartir con",
    "Share with {num} users" : "Compartir con {num} usuarios",
    "Rename Folder" : "Renombrar Carpeta",
    "Are you sure you want to delete?" : "¿Seguro que quieres borrar?",
    "Mark read" : "Marcar como leído",
    "All articles" : "Todos los artículos",
    "Recently viewed" : "Vistos recientemente",
    "Starred" : "Favoritos",
    "Has feeds with errors!" : "¡Tiene fuentes con errores!",
    "Explore" : "Explorar",
    "Rename" : "Renombrar",
    "Delete" : "Eliminar",
    "Rename Feed" : "Renombrar Fuente",
    "Open Feed URL" : "Abrir URL de la fuente",
    "Unpin from top" : "Soltar de arriba",
    "Pin to top" : "Fijar arriba",
    "Newest first" : "Más nuevos primero",
    "Oldest first" : "Más viejos primero",
    "Default order" : "Orden por defecto",
    "Enable full text" : "Habilitar texto completo",
    "Disable full text" : "Deshabilitar texto completo",
    "Mark as unread on update" : "Marcar como no leído al actualizar",
    "Keep read status on update" : "Mantener el estado de lectura al actualizar",
    "Sync disabled" : "Sincronización deshabilitada",
    "Sync enabled" : "Sincronización habilitada",
    "from" : "de",
    "Previous Item" : "Ítem previo",
    "Next Item" : "Ítem siguiente",
    "Share within Instance" : "Compartir en la instancia",
    "Toggle star article" : "Marcar como favorito",
    "Mark unread" : "Marcar como no leído",
    "Close details" : "Cerrar detalles",
    "shared by" : "compartido con",
    "by" : "por",
    "Play audio" : "Reproducir audio",
    "Download audio" : "Descargar audio",
    "Download video" : "Descargar vídeo",
    "Refresh list" : "Refrescar lista",
    "Open website" : "Abrir página web",
    "Keep article unread" : "Mantener el artículo como no-leído.",
    "Toggle keep current article unread" : "Marcar como no leído",
    "Remove keep article unread" : "Elimina mantener el artículo como no-leído.",
    "Default" : "Por defecto",
    "Compact" : "Compacto",
    "Screenreader" : "Lector de pantalla",
    "Vertical" : "Vertical",
    "Horizontal" : "Horizontal",
    "Off" : "Apagado",
    "Always" : "Siempre",
    "Never" : "Nunca",
    "Please select a valid OPML file" : "Por favor, selecciona un archivo OPML válido",
    "File successfully uploaded" : "Archivo cargado correctamente",
    "Error uploading the opml file" : "Error al cargar el archivo OPML",
    "Error connecting to the server" : "Error al conectar al servidor",
    "Error retrieving the opml file" : "Error al obtener el archivo OPML",
    "General" : "General",
    "Disable mark read through scrolling" : "Deshabilitar marca de lectura mientras se desplaza",
    "Reverse ordering (oldest on top)" : "Ordenación inversa (la más antigua en la parte superior)",
    "Disable automatic refresh" : "Desactivar el refresco automático",
    "Media" : "Medios",
    "Appearance" : "Apariencia",
    "Display mode" : "Modo de visualización",
    "Split mode" : "Modo partido",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Abonnements (OPML)" : "Suscripciones (OPML)",
    "Importing feeds" : "Importando fuentes",
    "Please wait" : "Por favor espere",
    "Keyboard shortcuts" : "Atajos de teclado",
    "Refresh" : "Actualizar",
    "Jump to previous article" : "Ir al artículo anterior",
    "Jump to next article" : "Ir al artículo siguiente",
    "Open article in new tab" : "Abrir artículo en una nueva pestaña",
    "Show article details in compact view" : "Mostrar detalles del artículo en la vista compacta",
    "Close article details in compact view" : "Ocultar detalles del artículo en la vista compacta",
    "Mark current articles feed/folder as read" : "Marcar artículos de la carpeta/fuente actual como leídos",
    "Resources" : "Recursos",
    "Last update" : "Última actualización",
    "Time when the feed was last downloaded" : "Hora de la última descarga de la fuente",
    "Next update" : "Siguiente actualización",
    "Time when the next feed update will be done" : "Hora de la próxima actualización programada de la fuente",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Solo si está activado en los ajustes del administrador, si no, se utiliza el intervalo de actualización normal",
    "Articles per update" : "Artículos por actualización",
    "Maximum number of articles reached in a feed update" : "Número máximo de artículos vistos en una actualización de la fuente",
    "Error Count" : "Contador de errores",
    "Number of errors that have occurred since the last successful feed update" : "Número de errores que han occurido desde la última actualización correcta de la fuente",
    "Title" : "Título",
    "Folder" : "Carpeta",
    "Not available" : "No disponible",
    "All Articles" : "Todos los artículos",
    "No feeds found to add" : "No se han encontrado fuentes a añadir",
    "Subscribe to" : "Subscribirse a",
    "Unread Articles" : "Artículos sin leer",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "¡Detectado modo Ajax o webcron! ¡Tus fuentes no se actualizarán!",
    "How to set up the operating system cron" : "Cómo configurar el cron del sistema operativo",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instala y configura un actualizador paralelo más rápido que utiliza la API de actualización de la app News"
},
"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
