<?php return array(
    'root' => array(
        'name' => 'nextcloud/news',
        'pretty_version' => '28.0.0',
        'version' => '28.0.0.0',
        'reference' => '30f0f6586211138652d7cca102630e492aa64a38',
        'type' => 'project',
        'install_path' => __DIR__ . '/../../',
        'aliases' => array(),
        'dev' => false,
    ),
    'versions' => array(
        'arthurhoaro/favicon' => array(
            'pretty_version' => 'v2.0.1',
            'version' => '2.0.1.0',
            'reference' => '2f2af255e4a2ea0abff2a1b34b51cf4e57e6a230',
            'type' => 'library',
            'install_path' => __DIR__ . '/../arthurhoaro/favicon',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'bamarni/composer-bin-plugin' => array(
            'pretty_version' => '1.9.1',
            'version' => '1.9.1.0',
            'reference' => '641d0663f5ac270b1aeec4337b7856f76204df47',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../bamarni/composer-bin-plugin',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'fivefilters/readability.php' => array(
            'pretty_version' => 'v3.3.3',
            'version' => '3.3.3.0',
            'reference' => 'e2ee7b9e49eae89ac7ed2c74b15718100a73b4c8',
            'type' => 'library',
            'install_path' => __DIR__ . '/../fivefilters/readability.php',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'guzzlehttp/guzzle' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '*',
            ),
        ),
        'guzzlehttp/psr7' => array(
            'pretty_version' => '2.8.0',
            'version' => '2.8.0.0',
            'reference' => '21dc724a0583619cd1652f673303492272778051',
            'type' => 'library',
            'install_path' => __DIR__ . '/../guzzlehttp/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'league/uri' => array(
            'pretty_version' => '7.6.0',
            'version' => '7.6.0.0',
            'reference' => 'f625804987a0a9112d954f9209d91fec52182344',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/uri',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'league/uri-interfaces' => array(
            'pretty_version' => '7.6.0',
            'version' => '7.6.0.0',
            'reference' => 'ccbfb51c0445298e7e0b7f4481b942f589665368',
            'type' => 'library',
            'install_path' => __DIR__ . '/../league/uri-interfaces',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'masterminds/html5' => array(
            'pretty_version' => '2.10.0',
            'version' => '2.10.0.0',
            'reference' => 'fcf91eb64359852f00d921887b219479b4f21251',
            'type' => 'library',
            'install_path' => __DIR__ . '/../masterminds/html5',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'nextcloud/news' => array(
            'pretty_version' => '28.0.0',
            'version' => '28.0.0.0',
            'reference' => '30f0f6586211138652d7cca102630e492aa64a38',
            'type' => 'project',
            'install_path' => __DIR__ . '/../../',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'nyholm/psr7' => array(
            'pretty_version' => '1.8.2',
            'version' => '1.8.2.0',
            'reference' => 'a71f2b11690f4b24d099d6b16690a90ae14fc6f3',
            'type' => 'library',
            'install_path' => __DIR__ . '/../nyholm/psr7',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-feed-io/feed-io' => array(
            'pretty_version' => 'v6.2.0',
            'version' => '6.2.0.0',
            'reference' => '2ce072d4b20188bf8ecdaed40ee60ea739287102',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-feed-io/feed-io',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/async-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '*',
                1 => '1.0',
            ),
        ),
        'php-http/client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '*',
                1 => '1.0',
            ),
        ),
        'php-http/discovery' => array(
            'pretty_version' => '1.20.0',
            'version' => '1.20.0.0',
            'reference' => '82fe4c73ef3363caed49ff8dd1539ba06044910d',
            'type' => 'composer-plugin',
            'install_path' => __DIR__ . '/../php-http/discovery',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/guzzle7-adapter' => array(
            'pretty_version' => '1.1.0',
            'version' => '1.1.0.0',
            'reference' => '03a415fde709c2f25539790fecf4d9a31bc3d0eb',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-http/guzzle7-adapter',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/httplug' => array(
            'pretty_version' => '2.4.1',
            'version' => '2.4.1.0',
            'reference' => '5cad731844891a4c282f3f3e1b582c46839d22f4',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-http/httplug',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'php-http/message-factory-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '1.0',
            ),
        ),
        'php-http/promise' => array(
            'pretty_version' => '1.3.1',
            'version' => '1.3.1.0',
            'reference' => 'fc85b1fba37c169a69a07ef0d5a8075770cc1f83',
            'type' => 'library',
            'install_path' => __DIR__ . '/../php-http/promise',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-client' => array(
            'pretty_version' => '1.0.3',
            'version' => '1.0.3.0',
            'reference' => 'bb5906edc1c324c9a05aa0873d40117941e5fa90',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-client',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-client-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '*',
                1 => '1.0',
            ),
        ),
        'psr/http-factory' => array(
            'pretty_version' => '1.1.0',
            'version' => '1.1.0.0',
            'reference' => '2b4765fddfe3b508ac62f829e852b1501d3f6e8a',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-factory',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-factory-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '*',
                1 => '1.0',
            ),
        ),
        'psr/http-message' => array(
            'pretty_version' => '2.0',
            'version' => '2.0.0.0',
            'reference' => '402d35bcb92c70c026d1a6a9883f06b2ead23d71',
            'type' => 'library',
            'install_path' => __DIR__ . '/../psr/http-message',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'psr/http-message-implementation' => array(
            'dev_requirement' => false,
            'provided' => array(
                0 => '*',
                1 => '1.0',
            ),
        ),
        'psr/log' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '*',
            ),
        ),
        'ralouphie/getallheaders' => array(
            'pretty_version' => '3.0.3',
            'version' => '3.0.3.0',
            'reference' => '120b605dfeb996808c31b6477290a714d356e822',
            'type' => 'library',
            'install_path' => __DIR__ . '/../ralouphie/getallheaders',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
        'symfony/console' => array(
            'dev_requirement' => false,
            'replaced' => array(
                0 => '*',
            ),
        ),
        'symfony/html-sanitizer' => array(
            'pretty_version' => 'v7.3.6',
            'version' => '7.3.6.0',
            'reference' => '3855e827adb1b675adcb98ad7f92681e293f2d77',
            'type' => 'library',
            'install_path' => __DIR__ . '/../symfony/html-sanitizer',
            'aliases' => array(),
            'dev_requirement' => false,
        ),
    ),
);
