OC.L10N.register(
    "news",
    {
    "News" : "Habari",
    "Someone" : "Mtu fulani",
    "%1$s shared \"%2$s\" with you" : "%1$s shirikiwa \"%2$s\" na wewe",
    "News feeds" : "Mipasho ya habari",
    "Unread articles" : "Makala ambayo hayajasomwa",
    "News folders" : "Folda ya Habari",
    "News articles" : "Makala ya habari",
    "Shared with me" : "Imeshirikiwa nami",
    "An RSS/Atom feed reader" : "Msomaji wa maingizo ya RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Programu ya kusoma RSS/Atom Feed ya Nextcloud\n\n- 📲 Sawazisha milisho yako na [wateja] wengi wa simu au kompyuta ya mezani(https://nextcloud.github.io/news/clients/)\n- 🔄 Masasisho ya kiotomatiki ya milisho yako ya habari\n- 🆓 Chanzo huria na huria chini ya AGPLv3, hakuna matangazo au vipengele vinavyolipiwa\n\n**Cron ya Mfumo inahitajika kwa sasa ili programu hii ifanye kazi**\n\nMahitaji yanaweza kupatikana [hapa](https://nextcloud.github.io/news/install/#dependencies)\n\nChangelog inapatikana [hapa](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nUnda [ripoti ya hitilafu](https://github.com/nextcloud/news/issues/new/choose)\n\nUnda [ombi la kipengele](https://github.com/nextcloud/news/discussions/new)\n\nRipoti [suala la mipasho](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Pakua",
    "Close" : "Funga",
    "Internal server error!" : "Hitilafu ya seva ya ndani!",
    "Unknown error!" : "Hitilafu isiyojulikana!",
    "Web address" : "Anwani ya wavuti",
    "Please check your data/nextcloud.log file for additional information!" : "Tafadhali angalia faili yako ya data/nextcloud.log kwa maelezo zaidi!",
    "No folder" : "Hakuna folda",
    "Folder name" : "Jina la kisanduku",
    "Username" : "Jina la mtumiaji",
    "Password" : "Nenosiri",
    "Feed exists already!" : "Ingizo tayari lipo",
    "New folder" : "Folda mpya",
    "Folder exists already!" : "Folda tayari ipo!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Vitambulisho vya HTTP Basic Auth lazima vihifadhiwe bila kufichwa! Kila mtu aliye na ufikiaji wa seva au hifadhidata ataweza kuzifikia!",
    "Credentials" : "Hati za utambulisho",
    "Auto discover Feed" : "Gundua Mipasho kiotomatiki",
    "Subscribe" : "Jisajili",
    "Successfully updated news configuration" : "Imefanikiwa kusasisha usanidi wa habari",
    "Unable to update news config" : "Imeshindwa kusasisha usanidi wa habari",
    "No job execution data available. The cron job may not be running properly." : "Hakuna data ya utekelezaji wa kazi. Kazi ya cron inaweza kuwa haifanyi kazi ipasavyo.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Utekelezaji wa kazi wa mwisho ulifanyika {relativeTime}. Kuna kitu kibaya.",
    "Last job ran {relativeTime}." : "Kazi ya mwisho iliyofanyika {relativeTime}.",
    "Maximum read count per feed" : "Idadi ya juu zaidi ya kusoma kwa kila mlisho",
    "Maximum redirects" : "Mielekeo ya juu",
    "Feed fetcher timeout" : "Muda wa kuchota mipasho umeisha",
    "Explore Service URL" : "Chunguza URL ya Huduma",
    "Update interval" : "Muda wa kusasisha",
    "Use system cron for updates" : "Tumia cron ya mfumo kwa masasisho",
    "Disable this if you use a custom updater." : "Zima hii ikiwa unatumia kisasishi maalum.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Inafafanua idadi ya juu ya makala ambazo zinaweza kusomwa kwa kila chanzo ambazo hazitaondolewa na kazi ya kusafisha; ikiwa makala za zamani zinaonekana tena baada ya kusomwa, ongeza thamani hii; thamani hasi kama -1 itazima kipengele hiki.",
    "Delete unread articles automatically" : "Futa makala yasiyosomwa kiotomatiki",
    "Enable this if you also want to delete unread articles." : "Washa hii ikiwa pia unataka kufuta makala ambazo hazijasomwa.",
    "How many redirects the feed fetcher should follow." : "Ni miongozo mingapi mfuatiliaji wa malisho anapaswa kufuata.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Idadi ya juu zaidi ya sekunde za kusubiri ili RSS au Atom kupakia; ikiwa itachukua muda zaidi sasisho litasitishwa.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Ikitolewa, URL ya huduma hii itaulizwa ili kuonyesha milisho katika sehemu ya mipasho ya chunguza. Ili kurudi kwenye huduma iliyojengewa ndani ya kuchunguza, acha ingizo hili tupu.",
    "Interval in seconds in which the feeds will be updated." : "Muda katika sekunde ambazo milisho itasasishwa.",
    "Use next update time for feed updates" : "Tumia wakati unaofuata wa sasisho kwa masasisho ya maingizo",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Washa hii ili kutumia muda uliokokotolewa wa sasisho unaofuata kwa masasisho ya mipasho. Zima kusasisha milisho kulingana na muda wa sasisho pekee.",
    "Article list" : "Orodha ya makala",
    "Article details" : "Maelezo ya makala",
    "No article selected" : "Hakuna makala iliyochaguliwa",
    "Please select an article from the list." : "Tafadhali chagua makala kutoka kwenye orodha.",
    "Show all articles" : "Onesha makala zote",
    "Move feed" : "Hamisha ingizo",
    "Please select the new folder" : "Tafadhali chagua folda mpya",
    "Move" : "Hamisha",
    "User Name" : "Jina la mtumiaji",
    "Share" : "Shirikisha",
    "Share with" : "Shiriki na",
    "Share with {num} users" : "Shiriki na {num}watumiaji",
    "Rename Folder" : "Badilisha Jina la Folda",
    "Are you sure you want to delete?" : "Je, una uhakika unataka kufuta?",
    "Mark read" : "Weka alama nyekundu",
    "All articles" : "Makala zote",
    "Recently viewed" : "Imetazamwa hivi karibuni",
    "Starred" : "Yenye nyota",
    "Has feeds with errors!" : "Una mlisho wenye makosa!",
    "Explore" : "Gundua",
    "Rename" : "Ipe jina jipya",
    "Delete" : "Futa",
    "Rename Feed" : "Badilisha jina la Mlisho",
    "Open Feed URL" : "Fungua URL ya Mlisho",
    "Unpin from top" : "Ondoa kutoka juu",
    "Pin to top" : "Weka mpaka juu",
    "Newest first" : "Mpya kwanza",
    "Oldest first" : "Ya zamani kwanza",
    "Default order" : "Agizo chaguomsingi",
    "Enable full text" : "Washa maandishi kamili",
    "Disable full text" : "Zima maandishi kamili",
    "Mark as unread on update" : "Weka alama kama haijasomwa kwenye sasisho",
    "Keep read status on update" : "Weka hali ya kusoma kwenye sasisho",
    "Sync disabled" : "Usawazishaji umezimwa",
    "Sync enabled" : "Usawazishaji umewezeshwa",
    "Previous Item" : "Kipengee kilichotangulia",
    "Next Item" : "Kipengee Kinachofuata",
    "Share within Instance" : "Shiriki ndani ya Mfano",
    "Toggle star article" : "Toggle star article",
    "Mark unread" : "Weka alama kuwa haijasomwa",
    "Close details" : "Funga maelezo",
    "shared by" : "imeshirikiwa na",
    "by" : "na",
    "Play audio" : "Cheza sauti",
    "Download audio" : "Pakua sauti",
    "Download video" : "Pakua video",
    "Refresh list" : "Onyesha upya orodha",
    "Open website" : "Fungua tovuti",
    "Keep article unread" : "Weka makala isisomwe",
    "Toggle keep current article unread" : "Badilisha kuweka makala ya sasa isiyosomwa",
    "Remove keep article unread" : "Ondoa weka makala isisomwe",
    "Default" : "Chaguo msingi",
    "Compact" : "Makubaliano/maafikiano",
    "Screenreader" : "Kisoma-skrini",
    "Vertical" : "Wima",
    "Horizontal" : "Mlalo",
    "Off" : "Imezimwa",
    "Always" : "Daima",
    "Never" : "Kamwe",
    "Please select a valid OPML file" : "Tafadhali chagua faili sahihi ya OPML",
    "File successfully uploaded" : "Faili imepakiwa kwa mafanikio",
    "Error uploading the opml file" : "Hitilafu katika kupakia faili ya opml",
    "Error connecting to the server" : "Hitilafu katika kuunganisha kwenye seva",
    "Error retrieving the opml file" : "Hitilafu katika kurejesha faili ya opml",
    "General" : "Kuu",
    "Disable mark read through scrolling" : "Lemaza alama inayosomwa kupitia kusogeza",
    "Reverse ordering (oldest on top)" : "Kupanga kwa mpangilio wa zamani (ya zamani juu)",
    "Disable automatic refresh" : "Zima upya kiotomatiki",
    "Media" : "Midia",
    "Appearance" : "Mwonekano",
    "Display mode" : "Hali ya kuonyesha",
    "Split mode" : "Hali ya mgawanyiko",
    "Import" : "Ingiza",
    "Export" : "Agiza",
    "Abonnements (OPML)" : "Usajili (OPML)",
    "Importing feeds" : "Kuagiza milisho",
    "Please wait" : "Tafadhali subiri",
    "Keyboard shortcuts" : "Mikato ya keyboard",
    "Refresh" : "Onyesha upya",
    "Jump to previous article" : "Nenda kwenye makala iliyotangulia",
    "Jump to next article" : "Rukia makala inayofuata",
    "Open article in new tab" : "Fungua makala katika kichupo kipya",
    "Show article details in compact view" : "Onyesha maelezo ya makala katika mwonekano thabiti",
    "Close article details in compact view" : "Funga maelezo ya makala katika mwonekano thabiti",
    "Mark current articles feed/folder as read" : "Weka alama kwenye mlisho/folda ya makala ya sasa kama ilivyosomwa",
    "Resources" : "Rasilimali/nyenzo",
    "Last update" : "Sasisho la mwisho",
    "Time when the feed was last downloaded" : "Wakati ambapo milisho ilipakuliwa mara ya mwisho",
    "Next update" : "Sasisho jipya",
    "Time when the next feed update will be done" : "Wakati ambapo sasisho la mlisho linalofuata litafanywa",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Ikiwa tu imeamilishwa katika mipangilio ya msimamizi, vinginevyo muda wa sasisho wa kawaida hutumiwa",
    "Articles per update" : "Makala kwa kila sasisho",
    "Maximum number of articles reached in a feed update" : "Idadi ya juu zaidi ya makala iliyofikiwa katika sasisho la mlisho",
    "Error Count" : "Idadi ya Makosa",
    "Number of errors that have occurred since the last successful feed update" : "Idadi ya makosa ambayo yametokea tangu sasisho la mwisho la mipasho iliyofaulu",
    "Title" : "Kichwa cha habari",
    "Folder" : "Kisanduku",
    "Not available" : "Haipatikani",
    "All Articles" : "Makala zote",
    "No feeds found to add" : "Hakuna milisho yaliyopatikana ya kuongeza",
    "Subscribe to" : "Jisajili kwa",
    "Unread Articles" : "Makala ambazo hazijasomwa",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax au hali ya webcron imegunduliwa! Milisho yako haitasasishwa!",
    "How to set up the operating system cron" : "Jinsi ya kusanidi cron ya mfumo wa uendeshaji",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Sakinisha na uweke kisasisho sambamba cha haraka zaidi kinachotumia API ya kusasisha programu ya Habari"
},
"nplurals=2; plural=(n != 1);");
