OC.L10N.register(
    "news",
    {
    "News" : "Hírek",
    "Someone" : "Valaki",
    "%1$s shared \"%2$s\" with you" : "%1$s megosztotta Önnel: „%2$s”",
    "News feeds" : "Hírcsatornák",
    "Unread articles" : "Olvasatlan cikkek",
    "News folders" : "Hírek mappái",
    "News articles" : "Hírcikkek",
    "Shared with me" : "Megosztva velem",
    "An RSS/Atom feed reader" : "Egy RSS/Atom-hírcsatorna olvasó",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Egy RSS/Atom hírolvasó alkalmazás a Nextcloudhoz\n\n- 📲 Hírcsatornák szinkronizálása több mobil- vagy asztali [klienssel](https://nextcloud.github.io/news/clients/)\n- 🔄 Hírcsatornák automatikus frissítése\n- 🆓 Szabad és nyílt forráskódú, AGPLv3 licenc alatt, hirdetések és prémium funkciók nélkül\n\n**Az alkalmazás működéséhez jelenleg a rendszer cron használata szükséges**\n\nA követelmények [itt találhatók](https://nextcloud.github.io/news/install/#dependencies)\n\nA változásnapló pedig [itt](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nKészítsen egy [hibajelentést](https://github.com/nextcloud/news/issues/new/choose)\n\nKészítsen egy [funkciókérést](https://github.com/nextcloud/news/discussions/new)\n\nJelentse egy [hírcsatorna problémáját](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Letöltés",
    "Close" : "Bezárás",
    "Web address" : "Webcím",
    "No folder" : "Nincs mappa",
    "Folder name" : "Mappanév",
    "Username" : "Felhasználónév",
    "Password" : "Jelszó",
    "Feed exists already!" : "A hírcsatorna már létezik.",
    "New folder" : "Új mappa",
    "Folder exists already!" : "A mappa már létezik.",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "A HTTP Basic hitelesítési adatokat titkosítás nélkül kell tárolni. Bárki, aki hozzáfér a kiszolgálóhoz vagy az adatbázishoz, olvashatja azt.",
    "Credentials" : "Hitelesítő adatok",
    "Auto discover Feed" : "Hírcsatorna automatikus felderítése",
    "Subscribe" : "Feliratkozás",
    "Successfully updated news configuration" : "A hírek beállítása sikeresen frissítve",
    "Unable to update news config" : "A hírek beállításai nem frissíthetők",
    "Last job ran {relativeTime}." : "Utolsó feladatfuttatás: {relativeTime}.",
    "Maximum read count per feed" : "Maximális olvasási szám hírfolyamonként",
    "Maximum redirects" : "Maximum átirányítás",
    "Feed fetcher timeout" : "Hírfolyam letöltő időtúllépés",
    "Explore Service URL" : "Szolgáltatásfelderítési URL",
    "Update interval" : "Frissítési időszak",
    "Use system cron for updates" : "A rendszer cron használata a frissítésekhez",
    "Disable this if you use a custom updater." : "Tiltsa le, ha egyéni frissítőt használ.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Meghatározza a hírcsatornánként olvasható cikkek maximális mennyiségét, amelyeket a törlési feladat nem töröl; ha a régi cikkek újra megjelennek olvasás után, növelje ezt az értéket; negatív értékek, például a -1 kikapcsolja ezt a funkciót.",
    "Delete unread articles automatically" : "Az olvasatlan cikkek automatikus törlése",
    "Enable this if you also want to delete unread articles." : "Kapcsolja be, ha törölni szeretné az olvasatlan cikkeket.",
    "How many redirects the feed fetcher should follow." : "Hány átirányítást kell követnie a hírcsatornának.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "A maximális idő, amennyit egy RSS vagy Atom hírcsatorna olvasására vár. Ha tovább tart, akkor a frissítés meg lesz szakítva.",
    "Interval in seconds in which the feeds will be updated." : "A hírcsatornák frissítési intervalluma másodpercekben.",
    "Show all articles" : "Minden cikk megjelenítése",
    "Move" : "Áthelyezés",
    "User Name" : "Felhasználónév",
    "Share" : "Megosztás",
    "Share with" : "Megosztva a következővel",
    "Share with {num} users" : "Megosztás {num} felhasználóval",
    "Rename Folder" : "Mappa átnevezése",
    "Are you sure you want to delete?" : "Biztos, hogy törli?",
    "Mark read" : "Olvasottnak jelölés",
    "All articles" : "Minden cikk",
    "Starred" : "Csillagozott",
    "Explore" : "Felfedezés",
    "Rename" : "Átnevezés",
    "Delete" : "Törlés",
    "Rename Feed" : "Hírfolyam átnevezése",
    "Unpin from top" : "Rögzítés feloldása",
    "Pin to top" : "Rögzítés a tetejére",
    "Newest first" : "Legújabb először",
    "Oldest first" : "Legrégebbi először",
    "Default order" : "Alapértelmezett sorrend",
    "Enable full text" : "Teljes szöveges mód engedélyezése",
    "Disable full text" : "Teljes szöveges mód letiltása",
    "from" : "ettől:",
    "Toggle star article" : "Cikk csillagozása be/ki",
    "Mark unread" : "Olvasatlannak jelölés",
    "Close details" : "Részletek bezárása",
    "shared by" : "megosztotta:",
    "by" : "közreadta:",
    "Play audio" : "Hang lejátszása",
    "Download audio" : "Hang letöltése",
    "Download video" : "Videó letöltése",
    "Open website" : "Weboldal megnyitása",
    "Keep article unread" : "Cikk olvasatlanul hagyása",
    "Toggle keep current article unread" : "Cikk olvasatlanul hagyása be/ki",
    "Remove keep article unread" : "Cikk olvasatlanul hagyásának eltávolítása",
    "Default" : "Alapértelmezett",
    "Vertical" : "Függőleges",
    "Horizontal" : "Vízszintes",
    "Off" : "Ki",
    "Always" : "Mindig",
    "Never" : "Soha",
    "General" : "Általános",
    "Disable mark read through scrolling" : "Görgetés közbeni olvasottnak jelölés kikapcsolása",
    "Reverse ordering (oldest on top)" : "Fordított sorrend (régebbi felül)",
    "Media" : "Média",
    "Appearance" : "Megjelenés",
    "Import" : "Importálás",
    "Export" : "Exportálás",
    "Please wait" : "Kis türelmet",
    "Keyboard shortcuts" : "Gyorsbillentyűk",
    "Refresh" : "Frissítés",
    "Jump to previous article" : "Ugrás az előző cikkre",
    "Jump to next article" : "Ugrás a következő cikkre",
    "Open article in new tab" : "Cikk megnyitása új lapon",
    "Resources" : "Erőforrások",
    "Last update" : "Utolsó frissítés",
    "Title" : "Cím",
    "Folder" : "Mappa",
    "Not available" : "Nem érhető el",
    "All Articles" : "Minden cikk",
    "Subscribe to" : "Feliratkozás:",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax vagy webcron mód észlelve. A hírcsatornái nem lesznek frissítve.",
    "How to set up the operating system cron" : "Hogyan állítsa be az operációs rendszer cron időzítőjét",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Új gyorsabb, párhuzamosított frissítő telepítése, amely a Hírek alkalmazás frissítési API-ját használja"
},
"nplurals=2; plural=(n != 1);");
