OC.L10N.register(
    "news",
    {
    "News" : "Nyhende",
    "Download" : "Last ned",
    "Close" : "Lukk",
    "Web address" : "Nettadresse",
    "Folder name" : "Mappenamn",
    "Username" : "Brukarnamn",
    "Password" : "Passord",
    "New folder" : "Ny mappe",
    "Credentials" : "Credentials",
    "Show all articles" : "Vis alle artiklar",
    "Move" : "Move",
    "Share" : "Del",
    "Rename" : "Endra namn",
    "Delete" : "Ta bort",
    "Newest first" : "Nyaste fyrst",
    "Oldest first" : "Eldste fyrst",
    "from" : "frå",
    "by" : "av",
    "Download video" : "Last ned video",
    "General" : "Generelt",
    "Appearance" : "Utsjånad",
    "Import" : "Importer",
    "Export" : "Eksporter",
    "Keyboard shortcuts" : "Tastatursnarvegar",
    "Refresh" : "Oppfrisk",
    "Folder" : "Mappe"
},
"nplurals=2; plural=(n != 1);");
