OC.L10N.register(
    "news",
    {
    "News" : "Nyheder",
    "Someone" : "Nogen",
    "%1$s shared \"%2$s\" with you" : "%1$s delte \"%2$s\" med dig",
    "News feeds" : "Nyhedsfeeds",
    "Unread articles" : "Ulæste artikler",
    "News folders" : "Nyhedsmapper",
    "News articles" : "Nyheds artikler",
    "Shared with me" : "Delt med mig",
    "An RSS/Atom feed reader" : "En RSS/Atom-feedlæser",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 En RSS/Atom Feed-læser-app til Nextcloud\n\n- 📲 Synkroniser dine feeds med flere mobile eller desktop [klienter](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatiske opdateringer af dine nyhedsfeeds\n- 🆓 Gratis og open source under AGPLv3, ingen annoncer eller premium-funktioner\n\n**System Cron er i øjeblikket påkrævet for at denne app kan fungere**\n\nKravene kan findes [her](https://nextcloud.github.io/news/install/#dependencies)\n\nÆndringsloggen er tilgængelig [her](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nOpret en [fejlrapport](https://github.com/nextcloud/news/issues/new/choose)\n\nOpret en [funktionsanmodning](https://github.com/nextcloud/news/discussions/new)\n\nRapporter et [feedproblem](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Download",
    "Close" : "Luk",
    "Internal server error!" : "Intern serverfejl!",
    "Unknown error!" : "Ukendt fejl!",
    "Web address" : "Web adresse",
    "Please check your data/nextcloud.log file for additional information!" : "Tjek venligst din data/nextcloud.log fil for yderligere information!",
    "No folder" : "Ingen Mappe",
    "Folder name" : "Mappenavn",
    "Username" : "Brugernavn",
    "Password" : "Adgangskode",
    "Feed exists already!" : "Feedet findes allerede!",
    "New folder" : "Ny mappe",
    "Folder exists already!" : "Mappen findes allerede!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Grundlæggende HTTP legitimationsoplysninger skal lagres ikke-krypteret! Alle med adgang til server eller database vil være i stand til at få adgang til dem!",
    "Credentials" : "Legitimationsoplysninger",
    "Auto discover Feed" : "Automatisk opdage feed",
    "Subscribe" : "Abonner",
    "Successfully updated news configuration" : "Nyhedskonfigurationen blev opdateret",
    "Unable to update news config" : "Kunne ikke opdatere nyhedskonfigurationen",
    "No job execution data available. The cron job may not be running properly." : "Ingen jobudførselsdata tilgængelig. Cron jobbet kører måske ikke korrekt",
    "Last job execution ran {relativeTime}. Something is wrong." : "Sidste jobkørsel var {relativeTime}. Der er noget galt.",
    "Last job ran {relativeTime}." : "Sidste job kørte {relativeTime}.",
    "Maximum read count per feed" : "Det maksimale antal læsninger per feed",
    "Maximum redirects" : "Maksimum for videredirigeringer",
    "Feed fetcher timeout" : "Tidsudløb for feed-indhenter",
    "Explore Service URL" : "Udforsk tjenestens URL",
    "Update interval" : "Opdateringsinterval",
    "Use system cron for updates" : "Anvend system cron til opdateringer",
    "Disable this if you use a custom updater." : "Deaktiver dette, hvis du bruger en brugerdefineret opdatering.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Definerer den maksimale mængde af artikler, der kan læses pr. feed, som ikke vil blive slettet af oprydningsjobbet; hvis gamle artikler dukker op igen efter at være blevet læst, skal du øge denne værdi; negative værdier såsom -1 vil slå denne funktion fra.",
    "Delete unread articles automatically" : "Slet automatisk ulæste artikler",
    "Enable this if you also want to delete unread articles." : "Aktivere dette hvis du også vil slette ulæste artikler.",
    "How many redirects the feed fetcher should follow." : "Hvor mange omdirigeringer feedhenteren skal følge.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksimalt antal sekunder at vente på, at et RSS- eller Atom-feed indlæses; hvis det tager længere tid, vil opdateringen blive afbrudt.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Hvis angivet, så vil URLen for denne service blive forespurgt for at vise feeds'ene i feed sektionen gennemse. For at falde tilbage på den indbyggede gennemsynsservice, efterlad dette felt tomt.",
    "Interval in seconds in which the feeds will be updated." : "Interval i sekunder, hvori feeds vil blive opdateret.",
    "Use next update time for feed updates" : "Brug næste opdateringstidspunkt til feedopdateringer",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Aktiver dette for at bruge det beregnede næste opdateringstidspunkt til feedopdateringer. Deaktiver for at opdatere feeds udelukkende baseret på opdateringsintervallet.",
    "Article list" : "Artikel liste",
    "Article details" : "Artikel detaljer",
    "No article selected" : "Der er ikke valgt nogen artikel",
    "Please select an article from the list." : "Vælg venligst en artikel fra listen.",
    "Show all articles" : "Vis alle artikler",
    "Move feed" : "Flyt feed",
    "Please select the new folder" : "Vælg venligst den nye mappe",
    "Move" : "Flyt",
    "User Name" : "Brugernavn",
    "Share" : "Del",
    "Share with" : "Del med",
    "Share with {num} users" : "Del med %n brugere",
    "Rename Folder" : "Omdøb mappe",
    "Are you sure you want to delete?" : "Er du sikker på at du vil slette?",
    "Mark read" : "Marker som læst",
    "All articles" : "Alle artikler",
    "Recently viewed" : "Senest vist",
    "Starred" : "Stjernemarkeret",
    "Has feeds with errors!" : "Har feeds med fejl!",
    "Explore" : "Udforsk",
    "Rename" : "Omdøb",
    "Delete" : "Slet",
    "Rename Feed" : "Omdøb feed",
    "Open Feed URL" : "Åbn feed-URL",
    "Unpin from top" : "Frigør fra toppen",
    "Pin to top" : "Fastgør til toppen",
    "Newest first" : "Nyeste først",
    "Oldest first" : "Ældste først",
    "Default order" : "Standard rækkefølge",
    "Enable full text" : "Slå fuld tekst til",
    "Disable full text" : "Slå fuld tekst fra",
    "Mark as unread on update" : "Markér som ulæst ved opdatering",
    "Keep read status on update" : "Behold læsestatus ved opdatering",
    "Sync disabled" : "Synkronisering deaktiveret",
    "Sync enabled" : "Synkronisering aktiveret",
    "from" : "fra",
    "Previous Item" : "Forrige element",
    "Next Item" : "Næste element",
    "Share within Instance" : "Del i instansen",
    "Toggle star article" : "Slå stjerne for artikel til/fra",
    "Mark unread" : "Marker som ulæst",
    "Close details" : "Luk detaljer",
    "shared by" : "delt af",
    "by" : "af",
    "Play audio" : "Afspil lydfil",
    "Download audio" : "Hent lydfil",
    "Download video" : "Hent video",
    "Refresh list" : "Genopfrisk liste",
    "Open website" : "Åbn websted",
    "Keep article unread" : "Bevar artikel ulæst",
    "Toggle keep current article unread" : "Slå \"bevar nuværende artikel ulæst\" til/fra",
    "Remove keep article unread" : "Fjern \"bevar artikel ulæst\"",
    "Default" : "Standard",
    "Compact" : "Kompakt",
    "Screenreader" : "Skærmlæser",
    "Vertical" : "Lodret",
    "Horizontal" : "Vandret",
    "Off" : "Deaktiver",
    "Never" : "Aldrig",
    "Please select a valid OPML file" : "Vælg venligst en gyldig OPML fil",
    "File successfully uploaded" : "Fil uploadet",
    "Error uploading the opml file" : "Fejl under upload af OPML fil",
    "Error connecting to the server" : "Fejl under forbindelse til server",
    "Error retrieving the opml file" : "Fejl under hentning af OPML fil",
    "General" : "Generelt",
    "Disable mark read through scrolling" : "Slå marker som læst fra når der rulles",
    "Reverse ordering (oldest on top)" : "Vend om på rækkefølgen (ældste øverst)",
    "Disable automatic refresh" : "Deaktivér automatisk genopfriskning",
    "Media" : "Medier",
    "Appearance" : "Udseende",
    "Display mode" : "Visningstilstand",
    "Split mode" : "Delt tilstand",
    "Import" : "Importér",
    "Export" : "Eksportér",
    "Abonnements (OPML)" : "Abonnementer (OPML)",
    "Importing feeds" : "Importerer feeds",
    "Please wait" : "Vent venligst",
    "Keyboard shortcuts" : "Tastaturgenveje",
    "Refresh" : "Opdatér",
    "Jump to previous article" : "Gå til forrige artikel",
    "Jump to next article" : "Gå til næste artikel",
    "Open article in new tab" : "Åbn artikel i en ny fane",
    "Show article details in compact view" : "Vis artikeldetaljer i kompakt visning",
    "Close article details in compact view" : "Luk artikeldetaljer i kompakt visning",
    "Mark current articles feed/folder as read" : "Markér aktuelle artikler feed/mappe som læst",
    "Resources" : "Ressourcer",
    "Last update" : "Seneste opdatering",
    "Time when the feed was last downloaded" : "Tidspunkt hvor feedet senest blev downloadet",
    "Next update" : "Næste opdatering",
    "Time when the next feed update will be done" : "Tidspunktet for den næste feed opdatering",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Kun hvis aktiveret i admin indstillingerne, ellers vil det regulære opdateringsinterval blive anvendt",
    "Articles per update" : "Artikler per opdatering",
    "Maximum number of articles reached in a feed update" : "Maksimum antal artikler der nås i en feed-opdatering",
    "Error Count" : "Antal fejl",
    "Number of errors that have occurred since the last successful feed update" : "Antallet af fejl som er forekommet siden den seneste succesfulde feed-opdatering",
    "Title" : "Titel",
    "Folder" : "Mappe",
    "Not available" : "Ikke tilgængelig",
    "All Articles" : "Alle artikler",
    "No feeds found to add" : "Der blev ikke fundet nogen feeds at tilføje",
    "Subscribe to" : "Abonnere på",
    "Unread Articles" : "Ulæste artikler",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax eller webcron tilstand opdaget! Dine feed vil ikke blive opdateret!",
    "How to set up the operating system cron" : "Sådan opsætter du cron i operativsystemet",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installér og opret et hurtigere parallelt opdateringsprogram, der bruger Nyheder app's opdaterings API"
},
"nplurals=2; plural=(n != 1);");
