<?php

/*
 * This file is part of the Symfony package.
 *
 * (c) Fabien Potencier <fabien@symfony.com>
 *
 * For the full copyright and license information, please view the LICENSE
 * file that was distributed with this source code.
 */
namespace OCA\News\Vendor\Symfony\Component\HtmlSanitizer\Visitor\Model;

use OCA\News\Vendor\Symfony\Component\HtmlSanitizer\Visitor\Node\NodeInterface;
/**
 * @author Titouan Galopin <galopintitouan@gmail.com>
 *
 * @internal
 */
final class Cursor
{
    public function __construct(public ?NodeInterface $node)
    {
    }
}
