OC.L10N.register(
    "news",
    {
    "News" : "Lajme",
    "%1$s shared \"%2$s\" with you" : "%1$s ndau me ju \"%2$s\"",
    "Unread articles" : "Artikujt e palexuar",
    "Shared with me" : "Ndarë me mua",
    "Download" : "Shkarko",
    "Close" : "Mbylle",
    "Web address" : "Adresë Web",
    "No folder" : "Pa dosje",
    "Folder name" : "Emër dosjeje",
    "Username" : "Emër përdoruesi",
    "Password" : "Fjalëkalim",
    "Feed exists already!" : "Prurja ekziston tashmë!",
    "New folder" : "Dosje e re",
    "Folder exists already!" : "Ka një dosje të tillë!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Kredencialet HTTP Basic Auth duhet të depozitohen të pafshehtëzuara! Cilido që ka hyrje te shërbyesi ose te baza e të dhënave do të jetë në gjendje të hyjë në to!",
    "Credentials" : "Kredenciale",
    "Subscribe" : "Pajtohuni",
    "Maximum read count per feed" : "Numër maksimum leximesh për prurje",
    "Maximum redirects" : "Maksimum ridrejtimesh",
    "Feed fetcher timeout" : "Mbarim kohe për sjellësin e prurjeve",
    "Explore Service URL" : "URL Shërbimi Eksplorimesh",
    "Use system cron for updates" : "Përdor sistemin cron për përditësime",
    "Show all articles" : "Shfaqi krejt artikujt",
    "Move" : "Zhvendos",
    "Share" : "Shpërndaje",
    "Mark read" : "Shëno të lexuar",
    "All articles" : "Krejt artikujt",
    "Starred" : "Me yll",
    "Explore" : "Eksploroni",
    "Rename" : "Riemërtojeni",
    "Delete" : "Fshij",
    "Rename Feed" : "Riemërtojeni Prurjen",
    "Unpin from top" : "Shfiksoje prej kreut",
    "Pin to top" : "Fikstoje në krye",
    "Newest first" : "Më të rejat në fillim",
    "Oldest first" : "Më të vjetrat në fillim",
    "Default order" : "Rradhë e parazgjedhur",
    "Enable full text" : "Aktivizo tekst të plotë",
    "Disable full text" : "Çaktivizo tekstin e plotë",
    "from" : "nga",
    "Toggle star article" : "Vëri/hiqi yll artikullit",
    "by" : "nga",
    "Play audio" : "Luaje audion",
    "Download audio" : "Shkarko audion",
    "Download video" : "Shkarko videon",
    "Open website" : "Hap sajtin",
    "Keep article unread" : "Mbaje artikullin si të palexuar",
    "Toggle keep current article unread" : "Vëri/hiqi gjendjen mbaje artikullin të palexuar",
    "Remove keep article unread" : "Hiqi gjendjen mbaje artikullin të palexuar",
    "Default" : "Paraprake",
    "Always" : "Përherë",
    "Never" : "Kurrë",
    "General" : "Të përgjithshme",
    "Disable mark read through scrolling" : "Çaktivizo shënime si të lexuar gjatë rrëshqitjesh",
    "Reverse ordering (oldest on top)" : "Renditje e përmbusyr (më të vjetrat në krye)",
    "Import" : "Import",
    "Export" : "Eksport",
    "Please wait" : "Ju lutem prisni",
    "Keyboard shortcuts" : "Shkurtore tastiere",
    "Refresh" : "Rifreskoje",
    "Jump to previous article" : "Hidhu te artikulli i mëparshëm",
    "Jump to next article" : "Hidhu te artikulli pasues",
    "Open article in new tab" : "Hape artikullin në skedë të re",
    "Resources" : "Burimet",
    "Title" : "Titulli",
    "Folder" : "Dosje",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Zbulohet modaliteti Ajax ose webcron! Feedet tuaja nuk do të përditësohen!",
    "How to set up the operating system cron" : "Si të rregullohet cron-i i sistemit operativ",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instaloni dhe rregulloni për punë një përditësues paralel më të shpejtë që përdor për përditësime API-n e aplikacionit Lajme"
},
"nplurals=2; plural=(n != 1);");
