OC.L10N.register(
    "news",
    {
    "News" : "Berita",
    "Someone" : "Seseorang",
    "%1$s shared \"%2$s\" with you" : "%1$s dibagikan \"%2$s\" kepada Anda",
    "News feeds" : "Umpan berita",
    "Unread articles" : "Artikel belum dibaca",
    "News folders" : "Folder berita",
    "News articles" : "Artikel berita",
    "Shared with me" : "Dibagikan dengan saya",
    "An RSS/Atom feed reader" : "Sebuah pembaca umpan RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Aplikasi pembaca umpan RSS/Atom untuk Nextcloud\n\n- 📲 Sinkronkan umpan Anda dengan beberapa [klien](https://nextcloud.github.io/news/clients/) seluler atau desktop\n- 🔄 Pembaruan otomatis umpan berita Anda\n- 🆓 Bebas dan sumber terbuka di bawah AGPLv3, tanpa iklan atau fungsi premium\n\n**System Cron saat ini diperlukan agar aplikasi ini berfungsi**\n\nPersyaratan dapat ditemukan [di sini](https://nextcloud.github.io/news/install/#dependencies)\n\nPerubahan tersedia [di sini](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nBuat [laporan kutu](https://github.com/nextcloud/news/issues/new/choose)\n\nBuat [permintaan fitur](https://github.com/nextcloud/news/discussions/new)\n\nLaporkan [masalah umpan](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Unduh",
    "Close" : "Tutup",
    "Internal server error!" : "Kesalahan server internal!",
    "Unknown error!" : "Kesalahan tidak diketahui!",
    "Web address" : "Alamat web",
    "Please check your data/nextcloud.log file for additional information!" : "Silakan periksa berkas data/nextcloud.log Anda untuk informasi tambahan!",
    "No folder" : "Tidak ada folder",
    "Folder name" : "Nama folder",
    "Username" : "Nama pengguna",
    "Password" : "Kata Sandi",
    "Feed exists already!" : "Feed sudah ada!",
    "New folder" : "Folder baru",
    "Folder exists already!" : "Folder sudah ada!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Kredensial HTTP Basic Auth harus disimpan tidak terenkripsi! Semua dengan akses ke server atau database akan bisa mengaksesnya!",
    "Credentials" : "Kredensial",
    "Auto discover Feed" : "Jelajahi umpan otomatis",
    "Subscribe" : "Berlangganan",
    "Successfully updated news configuration" : "Berhasil memperbarui konfigurasi berita",
    "Unable to update news config" : "Tidak dapat memperbarui konfigurasi berita",
    "Logo purge has never been run." : "Pembersihan logo belum pernah dijalankan.",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "Pembersihan logo terakhir dijalankan {relativeLastLogoPurge}. Ada yang salah.",
    "Last logo purge job ran {relativeLastLogoPurge}." : "Tugas pembersihan logo terakhir dijalankan {relativeLastLogoPurge}.",
    "No job execution data available. The cron job may not be running properly." : "Tidak ada data eksekusi tugas yang tersedia. Tugas cron mungkin tidak berjalan dengan benar.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Eksekusi tugas terakhir berjalan {relativeTime}. Ada yang salah.",
    "Last job ran {relativeTime}." : "Tugas terakhir dijalankan {relativeTime}.",
    "Maximum read count per feed" : "Jumlah baca maksimum per feed",
    "Maximum redirects" : "Pengalihan maksimum",
    "Feed fetcher timeout" : "Pengambil feed kehabisan waktu",
    "Explore Service URL" : "URL Layanan Jelajah",
    "Update interval" : "Interval pembaruan",
    "Use system cron for updates" : "Gunakan cron sistem untuk pembaruan",
    "Disable this if you use a custom updater." : "Nonaktifkan ini juga Anda menggunakan pembaru kustom.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Mendefinisikan jumlah maksimum artikel yang dapat dibaca per umpan yang tidak akan dihapus oleh tugas pembersihan; jika artikel lama muncul kembali setelah dibaca, naikkan nilai ini; nilai negatif seperti -1 akan menonaktifkan fitur ini.",
    "Delete unread articles automatically" : "Hapus artikel yang tidak dibaca secara otomatis",
    "Enable this if you also want to delete unread articles." : "Aktifkan ini jika Anda juga ingin menghapus artikel yang tidak dibaca.",
    "How many redirects the feed fetcher should follow." : "Berapa arahan pembaca umpan harus mengikuti.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Jumlah maksimum untuk menunggu umpan RSS atau Atom untuk dimuat; jika membutuhkan waktu yang lama, pembaruan akan dibatalkan.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Jika diberikan, URL layanan ini akan diquery untuk menampilkan feed di bagian feed jelajahi. Untuk kembali menggunakan layanan jelajahi bawaan, biarkan input ini kosong.",
    "Interval in seconds in which the feeds will be updated." : "Interval dalam detik di mana umpan akan diperbarui.",
    "Use next update time for feed updates" : "Gunakan waktu pembaruan berikutnya untuk pembaruan feed",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Aktifkan ini untuk menggunakan waktu pembaruan berikutnya yang dihitung untuk pembaruan feed. Nonaktifkan untuk memperbarui feed hanya berdasarkan interval pembaruan.",
    "Article list" : "Daftar artikel",
    "Article details" : "Detail artikel",
    "No article selected" : "Tidak ada artikel yang dipilih",
    "Please select an article from the list." : "Silakan pilih artikel dari daftar.",
    "Show all articles" : "Tampilkan semua artikel",
    "Move feed" : "Pindahkan feed",
    "Please select the new folder" : "Silakan pilih folder baru",
    "Move" : "Pindah",
    "User Name" : "Nama pengguna",
    "Share" : "Bagikan",
    "Share with" : "Bagikan dengan",
    "Share with {num} users" : "Bagikan dengan {num} pengguna",
    "Rename Folder" : "Ganti nama folder",
    "Are you sure you want to delete?" : "Apakah Anda yakin ingin menghapus?",
    "Unable to save starred open state" : "Tidak dapat menyimpan status terbuka berbintang",
    "Mark read" : "Tandai sebagai dibaca",
    "All articles" : "Semua artikel",
    "Recently viewed" : "Baru dilihat",
    "Starred" : "Dibintangi",
    "Has feeds with errors!" : "Memiliki feed dengan kesalahan!",
    "Explore" : "Jelajah",
    "Feed settings" : "Pengaturan feed",
    "News settings" : "Pengaturan News",
    "Rename" : "Ubah nama",
    "Delete" : "Hapus",
    "Rename Feed" : "Ubah Nama Feed",
    "Open Feed URL" : "Buka URL Feed",
    "Unpin from top" : "Lepaskan pin dari atas",
    "Pin to top" : "Sematkan ke atas",
    "Newest first" : "Terbaru",
    "Oldest first" : "Paling lama",
    "Default order" : "Urutan bawaan",
    "Enable full text" : "Aktifkan teks lengkap",
    "Disable full text" : "Nonaktifkan teks lengkap",
    "Mark as unread on update" : "Tandai sebagai belum dibaca saat pembaruan",
    "Keep read status on update" : "Pertahankan status dibaca saat pembaruan",
    "Sync disabled" : "Sinkronisasi dinonaktifkan",
    "Sync enabled" : "Sinkronisasi diaktifkan",
    "from" : "dari",
    "Previous Item" : "Item sebelumnya",
    "Next Item" : "Item berikutnya",
    "Share within Instance" : "Bagikan dalam Instance",
    "Toggle star article" : "Tombol alih bintangi artikel",
    "Mark unread" : "Tandai belum dibaca",
    "Close details" : "Tutup detail",
    "shared by" : "dibagikan oleh",
    "by" : "oleh",
    "Play audio" : "Putar audio",
    "Download audio" : "Unduh audio",
    "Download video" : "Unduh video",
    "Refresh list" : "Muat ulang daftar",
    "Open website" : "Buka situs web",
    "Keep article unread" : "Tandai artikel belum dibaca",
    "Toggle keep current article unread" : "Tombol alih tandai artikel saat ini belum dibaca",
    "Remove keep article unread" : "Hapus tanda artikel belum dibaca",
    "Default" : "Default",
    "Compact" : "Ringkas",
    "Screenreader" : "Pembaca layar",
    "Vertical" : "Vertikal",
    "Horizontal" : "Horizontal",
    "Off" : "Nonaktif",
    "Always" : "Selalu",
    "Never" : "Tidak pernah",
    "Please select a valid OPML file" : "Silakan pilih berkas OPML yang valid",
    "File successfully uploaded" : "Berkas berhasil diunggah",
    "Error uploading the opml file" : "Kesalahan saat mengunggah berkas OPML",
    "Error connecting to the server" : "Kesalahan saat terhubung ke server",
    "Error retrieving the opml file" : "Kesalahan saat mengambil berkas OPML",
    "Please select a valid json file" : "Silakan pilih berkas JSON yang valid",
    "Error uploading the json file" : "Kesalahan saat mengunggah berkas JSON",
    "Error retrieving the json file" : "Kesalahan saat mengambil berkas JSON",
    "General" : "Umum",
    "Disable mark read through scrolling" : "Menonaktifkan tandai baca melalui pengguliran",
    "Reverse ordering (oldest on top)" : "Pengurutan terbalik (yang lama diatas)",
    "Disable automatic refresh" : "Nonaktifkan penyegaran otomatis",
    "Media" : "Media",
    "Appearance" : "Tampilan",
    "Display mode" : "Mode tampilan",
    "Split mode" : "Mode pemisahan",
    "Import" : "Impor",
    "Export" : "Ekspor",
    "Abonnements (OPML)" : "Langganan (OPML)",
    "Importing feeds" : "Mengimpor feed",
    "Please wait" : "Mohon tunggu",
    "Articles (JSON)" : "Artikel (JSON)",
    "Keyboard shortcuts" : "Pintasan keyboard",
    "Refresh" : "Segarkan",
    "Screenreader mode only" : "Hanya mode pembaca layar",
    "Jump to previous article" : "Lompat ke artikel sebelumnya",
    "Jump to next article" : "Lompat ke artikel berikutnya",
    "Item navigation and control" : "Navigasi dan kontrol item",
    "Open article in new tab" : "Buka artikel di tab baru",
    "Show article details in compact view" : "Tampilkan detail artikel dalam tampilan ringkas",
    "Close article details in compact view" : "Tutup detail artikel dalam tampilan ringkas",
    "Feed/Folder navigation and control" : "Navigasi dan kontrol Feed/Folder",
    "Jump to previous feed" : "Lompat ke feed sebelumnya",
    "Jump to next feed" : "Lompat ke feed berikutnya",
    "Jump to previous folder" : "Lompat ke folder sebelumnya",
    "Jump to next folder" : "Lompat ke folder berikutnya",
    "Mark current articles feed/folder as read" : "Tandai artikel pada feed/folder saat ini sebagai dibaca",
    "Resources" : "Sumber daya",
    "Last update" : "Pembaruan terakhir",
    "Time when the feed was last downloaded" : "Waktu saat feed terakhir kali diunduh",
    "Next update" : "Pembaruan berikutnya",
    "Time when the next feed update will be done" : "Waktu saat pembaruan feed berikutnya akan dilakukan",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Hanya jika diaktifkan di pengaturan admin, jika tidak, interval pembaruan reguler yang digunakan",
    "Articles per update" : "Artikel per pembaruan",
    "Maximum number of articles reached in a feed update" : "Jumlah maksimum artikel yang tercapai dalam pembaruan feed",
    "Error Count" : "Jumlah kesalahan",
    "Number of errors that have occurred since the last successful feed update" : "Jumlah kesalahan yang terjadi sejak pembaruan feed terakhir yang berhasil",
    "Title" : "Judul",
    "Folder" : "Folder",
    "Not available" : "Tidak tersedia",
    "All Articles" : "Semua Artikel",
    "No feeds found to add" : "Tidak ada feed yang ditemukan untuk ditambahkan",
    "Subscribe to" : "Berlangganan ke",
    "Unread Articles" : "Artikel Belum Dibaca",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Mode AJAX atau Webcron dideteksi! Umpan Anda tidak akan diperbarui! ",
    "How to set up the operating system cron" : "Bagaimana cara menyetel cron sistem operasi",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Pasang dan atur pembaruan paralel yang lebih cepat yang menggunakan API pembaruan aplikasi Berita"
},
"nplurals=1; plural=0;");
