OC.L10N.register(
    "news",
    {
    "%1$s shared \"%2$s\" with you" : "%1$s ได้แชร์ \"%2$s\" กับคุณ",
    "Unread articles" : "บทความที่ยังไม่ได้อ่าน",
    "Download" : "ดาวน์โหลด",
    "Close" : "ปิด",
    "Web address" : "ที่อยู่เว็บ",
    "No folder" : "ไม่มีโฟลเดอร์",
    "Folder name" : "ชื่อโฟลเดอร์",
    "Username" : "ชื่อผู้ใช้",
    "Password" : "รหัสผ่าน",
    "Feed exists already!" : "ฟีดมีอยู่แล้ว!",
    "New folder" : "โฟลเดอร์ใหม่",
    "Folder exists already!" : "โฟลเดอร์มีอยู่แล้ว!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "ข้อมูลประจำตัวการตรวจสอบสิทธิ์พื้นฐานของ HTTP จะต้องเก็บไว้แบบไม่เข้ารหัส! ทุกคนที่มีการเข้าถึงเซิร์ฟเวอร์หรือฐานข้อมูลจะสามารถเข้าถึงมันได้!",
    "Credentials" : "ข้อมูลประจำตัว",
    "Subscribe" : "สมัครรับข้อมูล",
    "Maximum read count per feed" : "จำนวนอ่านสูงสุดต่อฟีด",
    "Maximum redirects" : "เปลี่ยนเส้นทางสูงสุด",
    "Feed fetcher timeout" : "ตัวเรียกฟีดหมดเวลา",
    "Explore Service URL" : "URL บริการสำรวจ",
    "Show all articles" : "แสดงบทความทั้งหมด",
    "Move" : "ย้าย",
    "Share" : "แชร์",
    "All articles" : "บทความทั้งหมด",
    "Starred" : "ติดดาวแล้ว",
    "Explore" : "สำรวจ",
    "Rename" : "เปลี่ยนชื่อ",
    "Delete" : "ลบ",
    "Rename Feed" : "เปลี่ยนชื่อฟีด",
    "Newest first" : "ใหม่ที่สุดก่อน",
    "Oldest first" : "เก่าที่สุดก่อน",
    "from" : "จาก",
    "Toggle star article" : "สลับการติดดาวบทความ",
    "by" : "โดย",
    "Play audio" : "เล่นเสียง",
    "Download audio" : "ดาวน์โหลดเสียง",
    "Download video" : "ดาวน์โหลดวิดีโอ",
    "Open website" : "เปิดเว็บไซต์",
    "Keep article unread" : "ตั้งเป็นบทความยังไม่ได้อ่าน",
    "Toggle keep current article unread" : "สลับให้บทความในปัจจุบันยังไม่ได้อ่าน",
    "Remove keep article unread" : "การลบคงสถานะบทความยังไม่ได้อ่าน",
    "Always" : "เสมอ",
    "Never" : "ไม่เคย",
    "General" : "ทั่วไป",
    "Disable mark read through scrolling" : "ปิดการทำเป็นอ่านแล้วขณะเลื่อนผ่าน",
    "Reverse ordering (oldest on top)" : "เรียงในลำดับย้อนกลับ (เก่าสุดอยู่ด้านบน)",
    "Media" : "สื่อ",
    "Appearance" : "ลักษณะที่ปรากฏ",
    "Import" : "นำเข้า",
    "Export" : "ส่งออก",
    "Please wait" : "โปรดรอ",
    "Keyboard shortcuts" : "แป้นพิมพ์ลัด",
    "Refresh" : "รีเฟรช",
    "Jump to previous article" : "ข้ามไปยังบทความก่อนหน้า",
    "Jump to next article" : "ข้ามไปยังบทความถัดไป",
    "Open article in new tab" : "เปิดบทความในแท็บใหม่",
    "Resources" : "ทรัพยากร",
    "Folder" : "โฟลเดอร์",
    "How to set up the operating system cron" : "วิธีการตั้งค่า cron ของระบบปฏิบัติการ",
    "Install and set up a faster parallel updater that uses the News app's update API" : "ติดตั้งและตั้งค่าตัวอัปเดตขนานที่เร็วขึ้น ซึ่งใช้ API การอัปเดตของแอปข่าว"
},
"nplurals=1; plural=0;");
