OC.L10N.register(
    "news",
    {
    "News" : "Novaĵo",
    "%1$s shared \"%2$s\" with you" : "%1$s kunhavigis „%2$s“ kun vi",
    "Unread articles" : "Nelegitaj artikoloj",
    "Download" : "Elŝuti",
    "Close" : "Fermi",
    "Web address" : "TTT-adreso",
    "No folder" : "Neniu dosierujo",
    "Folder name" : "Dosierujnomo",
    "Username" : "Uzantonomo",
    "Password" : "Pasvorto",
    "New folder" : "Nova dosierujo",
    "Folder exists already!" : "Dosierujo jam ekzistas!",
    "Credentials" : "Aŭtentigiloj",
    "Subscribe" : "Aboni",
    "Show all articles" : "Montri ĉiujn artikolojn",
    "Move" : "Movi",
    "Share" : "Kunhavigi",
    "Share with" : "Kunhavigi kun",
    "Mark read" : "Marki kiel legita",
    "All articles" : "Ĉiuj artikoloj",
    "Starred" : "Markita",
    "Rename" : "Alinomigi",
    "Delete" : "Forigi",
    "Newest first" : "Pli novaj unue",
    "Oldest first" : "Malpli novaj unue",
    "from" : "de",
    "Mark unread" : "Marki kiel nelegita",
    "Close details" : "Fermi detalojn",
    "by" : "de",
    "Open website" : "Malfermi TTT-ejon",
    "Always" : "Ĉiam",
    "Never" : "Neniam",
    "General" : "Ĝenerala",
    "Import" : "Importi",
    "Export" : "Eksporti",
    "Keyboard shortcuts" : "Fulmoklavoj",
    "Refresh" : "Refreŝigi",
    "Resources" : "Rimedoj",
    "Folder" : "Dosierujo",
    "Not available" : "Ne disponeble"
},
"nplurals=2; plural=(n != 1);");
