OC.L10N.register(
    "news",
    {
    "%1$s shared \"%2$s\" with you" : "%1$s huet \"%2$s\" mat dir gedeelt",
    "Unread articles" : "Ongeliesen Artikelen",
    "Download" : "Download",
    "Close" : "Zoumaachen",
    "Web address" : "Link",
    "No folder" : "Keen Dossier",
    "Folder name" : "Dossiers Numm:",
    "Username" : "Benotzernumm",
    "Password" : "Passwuert",
    "New folder" : "Neien Dossier",
    "Folder exists already!" : "Dësen Dossier gëtt et schonns!",
    "Credentials" : "Credentials",
    "Subscribe" : "Umellen",
    "Show all articles" : "All d'Artikelen uweisen",
    "Move" : "Verschieben",
    "Share" : "Deelen",
    "All articles" : "All Artikelen",
    "Explore" : "Erfuerschen",
    "Rename" : "Ëm-benennen",
    "Delete" : "Läschen",
    "from" : "vun",
    "by" : "vun",
    "Play audio" : "Toun ofspillen",
    "Download audio" : "Toun eroflueden",
    "Download video" : "Video eroflueden",
    "Open website" : "Oppe Websäit",
    "General" : "Allgemeng",
    "Import" : "Import",
    "Export" : "Exportéieren",
    "Refresh" : "Opfrëschen",
    "Jump to previous article" : "Op den Artikel vu virdru sprangen",
    "Jump to next article" : "Op den nächsten Artikel sprangen",
    "Open article in new tab" : "Den Artikel an engem neien Tab opmaachen",
    "Folder" : "Dossier"
},
"nplurals=2; plural=(n != 1);");
