<?php

declare (strict_types=1);
namespace OCA\News\Vendor\FeedIo\Reader;

use OCA\News\Vendor\FeedIo\FeedInterface;
use OCA\News\Vendor\Monolog\Logger;
use Psr\Log\LoggerInterface;
abstract class FixerAbstract
{
    protected LoggerInterface $logger;
    public function setLogger(LoggerInterface $logger): FixerAbstract
    {
        $this->logger = $logger;
        return $this;
    }
    abstract public function correct(Result $result): FixerAbstract;
}
