OC.L10N.register(
    "news",
    {
    "Download" : "Yuklab olish",
    "Close" : "Yopish",
    "Folder name" : "Folder name",
    "Username" : "Username",
    "Password" : "Password",
    "New folder" : "New folder",
    "Credentials" : "Hisob ma'lumotlari",
    "Subscribe" : "Obuna boʻlish",
    "Move" : "Move",
    "Share" : "Ulashish",
    "Rename" : "Nomini o'zgartirish",
    "Delete" : "O'chirish",
    "Default" : "Standart",
    "Off" : "Oʻchirilgan",
    "Always" : "Har doim",
    "Never" : "Hech qachon",
    "General" : "Umumiy",
    "Appearance" : "Tashqi ko'rinish",
    "Import" : "Import",
    "Export" : "Eksport",
    "Keyboard shortcuts" : "Klaviatura yorliqlari",
    "Refresh" : "Refresh",
    "Resources" : "Resurslar",
    "Title" : "Sarlavha",
    "Not available" : "Mavjud emas"
},
"nplurals=1; plural=0;");
