OC.L10N.register(
    "news",
    {
    "News" : "Wiadomości",
    "an article" : "artykuł",
    "Someone" : "Ktoś",
    "%1$s shared \"%2$s\" with you" : "%1$s udostępnił Tobie \"%2$s\"",
    "{user} shared \"{article}\" with you" : "{user} udostępnił Ci \"{article}\"",
    "News feeds" : "Kanały wiadomości",
    "Unread articles" : "Nieprzeczytane artykuły",
    "News folders" : "Katalogi z wiadomościami",
    "News articles" : "Artykuły z wiadomościami",
    "Shared with me" : "Udostępnione dla mnie",
    "Untitled article" : "Artykuł bez tytułu",
    "An RSS/Atom feed reader" : "Czytnik kanałów RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Aplikacja do czytania kanałów RSS/Atom dla Nextcloud\n\n- 📲 Synchronizuj swoje kanały z wieloma [klientami](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatyczne aktualizacje kanałów informacyjnych\n- 🆓 Darmowe i otwarte źródło w ramach AGPLv3, bez reklam i funkcji premium\n\n**System Cron jest obecnie wymagany do działania tej aplikacji**\n\nWymagania można znaleźć [tutaj](https://nextcloud.github.io/news/install/#dependencies)\n\nDziennik zmian jest dostępna [tutaj](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nUtwórz [raport o błędzie](https://github.com/nextcloud/news/issues/new/choose)\n\nUtwórz [żądanie funkcji](https://github.com/nextcloud/news/discussions/new)\n\nZgłoś [problem z kanałem](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Pobierz",
    "Close" : "Zamknij",
    "Internal server error!" : "Błąd wewnętrzny serwera!",
    "Unknown error!" : "Nieznany błąd!",
    "Web address" : "Adres web",
    "Please check your data/nextcloud.log file for additional information!" : "Sprawdź plik data/nextcloud.log, aby uzyskać dodatkowe informacje!",
    "No folder" : "Brak katalogu",
    "Folder name" : "Nazwa katalogu",
    "Username" : "Nazwa użytkownika",
    "Password" : "Hasło",
    "Feed exists already!" : "Kanał już istnieje!",
    "New folder" : "Nowy katalog",
    "Folder exists already!" : "Katalog już istnieje!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Podstawowe poświadczenia uwierzytelnienia HTTP muszą być zapisane odszyfrowane! Każdy posiadający dostęp do serwera lub bazy danych będzie mógł je odczytać!",
    "Credentials" : "Poświadczenia",
    "Auto discover Feed" : "Automatyczne wykrywanie kanału",
    "Subscribe" : "Subskrybuj",
    "Successfully updated news configuration" : "Pomyślnie zaktualizowano konfigurację wiadomości",
    "Unable to update news config" : "Nie można zaktualizować konfiguracji wiadomości",
    "Logo purge has never been run." : "Czyszczenie logo nigdy nie było uruchomione.",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "Ostatnie czyszczenie logo było uruchomione {relativeLastLogoPurge}. Coś jest nie tak.",
    "Last logo purge job ran {relativeLastLogoPurge}." : "Ostatnie czyszczenie logo było uruchomione {relativeLastLogoPurge}.",
    "No job execution data available. The cron job may not be running properly." : "Brak danych dotyczących wykonania zadania. Zadanie cron może nie działać poprawnie.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Ostatnie wykonanie zadania trwało {relativeTime}. Coś jest nie tak.",
    "Last job ran {relativeTime}." : "Ostatnie zadanie zostało uruchomione {relativeTime}.",
    "Maximum read count per feed" : "Maksymalna ilość odczytów na kanał",
    "Maximum redirects" : "Maksymalna liczba przekierowań",
    "Feed fetcher timeout" : "Czas braku odpowiedzi dla ściągania kanału",
    "Explore Service URL" : "Zbadaj adres URL usługi",
    "Update interval" : "Interwał aktualizacji",
    "Use system cron for updates" : "Użyj systemowego crona do aktualizacji",
    "Disable this if you use a custom updater." : "Wyłącz tę opcję, jeśli używasz niestandardowego aktualizatora.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Definiuje maksymalną ilość artykułów, które mogą być odczytane przez kanał, a nie będą usuwane podczas zadania czyszczenia; zwiększ wartość jeśli starsze artykuły pojawią się ponownie po przeczytaniu; ujemne wartości jak -1 wyłączą tę funkcjonalność całkowicie.",
    "Delete unread articles automatically" : "Automatycznie usuwaj nieprzeczytane artykuły",
    "Enable this if you also want to delete unread articles." : "Włącz tę opcję, jeśli chcesz również usuwać nieprzeczytane artykuły.",
    "How many redirects the feed fetcher should follow." : "Za iloma przekierowaniami ma nastąpić podążanie przy pobieraniu kanałów.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maksymalna liczba sekund oczekiwania na wczytanie kanału RSS lub Atom; jeśli potrwa to zbyt długo, aktualizacja zostanie przerwana.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Jeśli podano, adres URL tej usługi zostanie użyty do wyświetlenia kanałów w sekcji eksploracji. Aby użyć wbudowanej usługi eksploracji, pozostaw to pole puste.",
    "Interval in seconds in which the feeds will be updated." : "Przedział czasu w sekundach, w którym kanały będą zaktualizowane.",
    "Use next update time for feed updates" : "Użyj następnego czasu aktualizacji dla kanałów",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Włącz, aby używać obliczonego następnego czasu aktualizacji dla kanałów. Wyłącz, aby aktualizować kanały wyłącznie na podstawie interwału aktualizacji.",
    "Article list" : "Lista artykułów",
    "Article details" : "Szczegóły artykułu",
    "No article selected" : "Nie wybrano artykułu",
    "Please select an article from the list." : "Wybierz artykuł z listy.",
    "Show all articles" : "Pokaż wszystkie artykuły",
    "Move feed" : "Przenieś kanał",
    "Please select the new folder" : "Proszę wybrać nowy folder",
    "Move" : "Przenieś",
    "User Name" : "Nazwa użytkownika",
    "Share" : "Udostępnij",
    "Share with" : "Udostępnij dla",
    "Share with {num} users" : "Udostępnij {num} użytkownikom",
    "Rename Folder" : "Zmień nazwę katalogu",
    "Are you sure you want to delete?" : "Czy na pewno chcesz usunąć?",
    "Unable to save starred open state" : "Nie można zapisać stanu oznaczenia jako ulubione i otwartego stanu",
    "Mark read" : "Oznacz jako przeczytane",
    "All articles" : "Wszystkie artykuły",
    "Recently viewed" : "Ostatnio oglądane",
    "Starred" : "Oznaczone",
    "Has feeds with errors!" : "Kanały z błędami!",
    "Explore" : "Przeglądaj",
    "Feed settings" : "Ustawienia kanałów",
    "News settings" : "Ustawienia aktualności",
    "Rename" : "Zmień nazwę",
    "Delete" : "Usuń",
    "Rename Feed" : "Zmień nazwę kanału",
    "Open Feed URL" : "Otwórz adres URL kanału",
    "Unpin from top" : "Odepnij od góry",
    "Pin to top" : "Przypnij do góry",
    "Newest first" : "Najnowsze najpierw",
    "Oldest first" : "Najstarsze najpierw",
    "Default order" : "Kolejność domyślna",
    "Enable full text" : "Włącz pełny tekst",
    "Disable full text" : "Wyłącz pełny tekst",
    "Mark as unread on update" : "Oznacz jako nieprzeczytane przy aktualizacji",
    "Keep read status on update" : "Zachowaj status przeczytania przy aktualizacji",
    "Sync disabled" : "Synchronizacja wyłączona",
    "Sync enabled" : "Synchronizacja włączona",
    "from" : "od",
    "Previous Item" : "Poprzednia pozycja",
    "Next Item" : "Następna pozycja",
    "Share within Instance" : "Udostępnij w instancji",
    "Toggle star article" : "Oznacz artykuł gwiazdką",
    "Mark unread" : "Oznacz jako nie przeczytane",
    "Close details" : "Ukryj szczegóły",
    "shared by" : "udostępnione przez",
    "by" : "przez",
    "Play audio" : "Odtwarzaj plik audio",
    "Download audio" : "Pobierz audio",
    "Download video" : "Pobierz film",
    "Refresh list" : "Odśwież listę",
    "Open website" : "Otwórz stronę",
    "Keep article unread" : "Oznacz jako nieprzeczytany",
    "Toggle keep current article unread" : "Przełącz oznaczenie aktualnego artykuły jako nieprzeczytany",
    "Remove keep article unread" : "Usuń oznaczenie jako nieprzeczytany",
    "Default" : "Domyślny",
    "Compact" : "Kompaktowy",
    "Screenreader" : "Czytnik ekranu",
    "Vertical" : "Pionowo",
    "Horizontal" : "Poziomo",
    "Off" : "Wyłączone",
    "Always" : "Zawsze",
    "Never" : "Nigdy",
    "Please select a valid OPML file" : "Wybierz prawidłowy plik OPML",
    "File successfully uploaded" : "Plik został pomyślnie przesłany",
    "Error uploading the opml file" : "Błąd podczas przesyłania pliku OPML",
    "Error connecting to the server" : "Błąd podczas łączenia z serwerem",
    "Error retrieving the opml file" : "Błąd podczas pobierania pliku OPML",
    "Please select a valid json file" : "Wybierz prawidłowy plik JSON",
    "Error uploading the json file" : "Błąd podczas przesyłania pliku JSON",
    "Error retrieving the json file" : "Błąd podczas pobierania pliku JSON",
    "General" : "Ogólne",
    "Disable mark read through scrolling" : "Zablokuj oznaczanie jako przeczytane podczas przewijania",
    "Reverse ordering (oldest on top)" : "Odwrotna kolejność (najstarsze na górze)",
    "Disable automatic refresh" : "Wyłącz automatyczne odświeżanie",
    "Media" : "Multimedia",
    "Appearance" : "Wygląd",
    "Display mode" : "Tryb wyświetlania",
    "Split mode" : "Tryb podziału",
    "Import" : "Importuj",
    "Export" : "Eksportuj",
    "Abonnements (OPML)" : "Subskrypcje (OPML)",
    "Importing feeds" : "Importowanie kanałów",
    "Please wait" : "Proszę czekać",
    "Articles (JSON)" : "Artykuły (JSON)",
    "Keyboard shortcuts" : "Skróty klawiaturowe",
    "Refresh" : "Odśwież",
    "Screenreader mode only" : "Tylko tryb czytnika ekranu",
    "Jump to previous article" : "Przejdź do poprzedniego artykułu",
    "Jump to next article" : "Przejdź do następnego artykułu",
    "Item navigation and control" : "Nawigacja i sterowanie elementami",
    "Open article in new tab" : "Otwórz artykuł w nowej karcie",
    "Show article details in compact view" : "Pokaż szczegóły artykułu w widoku kompaktowym",
    "Close article details in compact view" : "Zamknij szczegóły artykułu w widoku kompaktowym",
    "Feed/Folder navigation and control" : "Nawigacja i sterowanie kanałami/folderami",
    "Jump to previous feed" : "Przejdź do poprzedniego kanału",
    "Jump to next feed" : "Przejdź do następnego kanału",
    "Jump to previous folder" : "Przejdź do poprzedniego folderu",
    "Jump to next folder" : "Przejdź do następnego folderu",
    "Mark current articles feed/folder as read" : "Oznacz bieżący kanał/katalog artykułów jako przeczytany",
    "Resources" : "Zasoby",
    "Last update" : "Ostatnia aktualizacja",
    "Time when the feed was last downloaded" : "Czas ostatniego pobrania kanału",
    "Next update" : "Następna aktualizacja",
    "Time when the next feed update will be done" : "Czas, kiedy zostanie wykonana następna aktualizacja kanału",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Tylko jeśli włączone w ustawieniach administratora, w przeciwnym razie używany jest standardowy interwał aktualizacji",
    "Articles per update" : "Artykuły na aktualizację",
    "Maximum number of articles reached in a feed update" : "Osiągnięto maksymalną liczbę artykułów w aktualizacji kanału",
    "Error Count" : "Liczba błędów",
    "Number of errors that have occurred since the last successful feed update" : "Liczba błędów, które wystąpiły od ostatniej udanej aktualizacji kanału",
    "Title" : "Tytuł",
    "Folder" : "Katalog",
    "Not available" : "Brak dostępności",
    "All Articles" : "Wszystkie artykuły",
    "No feeds found to add" : "Nie znaleziono kanałów do dodania",
    "Subscribe to" : "Subskrybuj",
    "Unread Articles" : "Nieprzeczytane artykuły",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Wykryto ustawienie Ajax lub webcron! Twoje kanały nie będą aktualizowane!",
    "How to set up the operating system cron" : "Jak ustawić cron systemu operacyjnego",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Zainstaluj i ustaw szybszy równoległy aktualizator, który używa do aktualizacji API aplikacji News"
},
"nplurals=4; plural=(n==1 ? 0 : (n%10>=2 && n%10<=4) && (n%100<12 || n%100>14) ? 1 : n!=1 && (n%10>=0 && n%10<=1) || (n%10>=5 && n%10<=9) || (n%100>=12 && n%100<=14) ? 2 : 3);");
