OC.L10N.register(
    "news",
    {
    "%1$s shared \"%2$s\" with you" : "Cho-roinn %1$s “%2$s” leat",
    "Download" : "Luchdaich a-nuas",
    "Close" : "Dùin",
    "Folder name" : "Ainm a’ phasgain",
    "Username" : "Ainm-cleachdaiche",
    "Password" : "Facal-faire",
    "New folder" : "Pasgan ùr",
    "Move" : "Gluais",
    "Share" : "Co-roinn",
    "Rename" : "Thoir ainm ùr air",
    "Delete" : "Sguab às",
    "Newest first" : "As ùire an toiseach",
    "Oldest first" : "As sine an toiseach",
    "Default" : "Bunaiteach",
    "General" : "Coitcheann",
    "Media" : "Meadhanan",
    "Refresh" : "Ath-nuadhaich"
},
"nplurals=4; plural=(n==1 || n==11) ? 0 : (n==2 || n==12) ? 1 : (n > 2 && n < 20) ? 2 : 3;");
