OC.L10N.register(
    "news",
    {
    "News" : "Nieuws",
    "Someone" : "Iemand",
    "%1$s shared \"%2$s\" with you" : "%1$s deelde \"%2$s\" met jou",
    "News feeds" : "Nieuwsfeeds",
    "Unread articles" : "Ongelezen artikelen",
    "News folders" : "Nieuwsmappen",
    "Shared with me" : "Gedeeld met mij",
    "An RSS/Atom feed reader" : "Een RSS/Atom kanaal lezer",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Een RSS/Atom Feed lezer App voor Nextcloud\n\n- 📲 Synchronizeer je feeds met meerdere mobiele of desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatische updates van je nieuwsfeeds\n- 🆓 Gratis en open source onder AGPLv3, geen advertenties of premium functies\n\n**Systeem Cron is momenteel vereist om deze app te laten werken**\n\nBenodigdheden kunnen [hier](https://nextcloud.github.io/news/install/#dependencies) gevonden worden\n\nHet Veranderingslogboek is [hier](https://github.com/nextcloud/news/blob/master/CHANGELOG.md) beschikbaar\n\nCreëer een [bug rapport](https://github.com/nextcloud/news/issues/new/choose)\n\nCreëer een [functie aanvraag](https://github.com/nextcloud/news/discussions/new)\n\nRapporteer een [feed probleem](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Downloaden",
    "Close" : "Sluiten",
    "Web address" : "Webadres",
    "No folder" : "Geen map",
    "Folder name" : "Mapnaam",
    "Username" : "Gebruikersnaam",
    "Password" : "Wachtwoord",
    "Feed exists already!" : "Feed bestaat al!",
    "New folder" : "Nieuwe map",
    "Folder exists already!" : "Map bestaat al!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP basis auth gegevens moeten ongecodeerd worden opgeslagen! Iederen die toegang heeft tot de server of database kan deze benaderen! ",
    "Credentials" : "Inloggegevens",
    "Auto discover Feed" : "Autodiscover Feed",
    "Subscribe" : "Abonneren",
    "Last job ran {relativeTime}." : "Laatste taak liep {relativeTime}.",
    "Maximum read count per feed" : "Maximaal aantal gelezen per feed",
    "Maximum redirects" : "Maximum redirects",
    "Feed fetcher timeout" : "Feed ophaler timeout",
    "Explore Service URL" : "Verken service URL",
    "Update interval" : "Update interval",
    "Use system cron for updates" : "Gebruik system cron voor updates",
    "Disable this if you use a custom updater." : "Schakel dit uit als je een aangepaste updater gebruikt.",
    "How many redirects the feed fetcher should follow." : "Hoeveel omleidingen de feed-fetcher moet volgen.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maximaal aantal seconden om te wachten tot een RSS- of Atom-feed is geladen; als het langer duurt, wordt de update afgebroken.",
    "Interval in seconds in which the feeds will be updated." : "Interval in seconden waarin de feeds worden bijgewerkt.",
    "Show all articles" : "Toon alle artikelen",
    "Move" : "Verplaatsen",
    "Share" : "Delen",
    "Are you sure you want to delete?" : "Weet je zeker dat je wilt verwijderen?",
    "Mark read" : "Als gelezen markeren",
    "All articles" : "Alle artikelen",
    "Starred" : "Ster gegeven",
    "Explore" : "Verkennen",
    "Rename" : "Naam wijzigen",
    "Delete" : "Verwijderen",
    "Rename Feed" : "Hernoem feed",
    "Unpin from top" : "Bovenaan losmaken",
    "Pin to top" : "Bovenaan vastprikken",
    "Newest first" : "Nieuwste eerst",
    "Oldest first" : "Oudste eerst",
    "Default order" : "Standaard volgorde",
    "Enable full text" : "Inschakelen volledige tekst",
    "Disable full text" : "Uitschakelen volledige tekst",
    "from" : "van",
    "Toggle star article" : "Omswitchen artikelmarkering ",
    "Mark unread" : "Markeer ongelezen",
    "Close details" : "Sluit details",
    "shared by" : "gedeeld door",
    "by" : "door",
    "Play audio" : "Geluid afspelen",
    "Download audio" : "Audio downloaden",
    "Download video" : "Downloaden video",
    "Open website" : "Open website",
    "Keep article unread" : "Bewaar artikel als ongelezen",
    "Toggle keep current article unread" : "Omswitchen hou huidig artikel ongelezen",
    "Remove keep article unread" : "Verwijder ongelezen houden artikel",
    "Default" : "Standaard",
    "Compact" : "Compact",
    "Off" : "Uit",
    "Always" : "Altijd",
    "Never" : "Nooit",
    "General" : "Algemeen",
    "Disable mark read through scrolling" : "Niet als gelezen markeren door scrollen",
    "Reverse ordering (oldest on top)" : "Omgekeerde volgorde (oudste boven)",
    "Media" : "Media",
    "Appearance" : "Uiterlijk",
    "Import" : "Import",
    "Export" : "Exporteren",
    "Please wait" : "Even geduld",
    "Keyboard shortcuts" : "Sneltoetsen",
    "Refresh" : "Vernieuwen",
    "Jump to previous article" : "Ga naar voorgaand artikel",
    "Jump to next article" : "Ga naar volgend artikel",
    "Open article in new tab" : "Open artikel in nieuwe tab",
    "Resources" : "Bronnen",
    "Last update" : "Laatste update",
    "Title" : "Titel",
    "Folder" : "Map",
    "Subscribe to" : "Abonneren op",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax of Web cron mode gedetecteerd! Je feeds worden niet bijgewerkt!",
    "How to set up the operating system cron" : "Hoe wordt de cron-service van het operating system ingesteld",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installeer en configureer een snellere parallel updater die gebruik maakt van de update API van de Nieuws app"
},
"nplurals=2; plural=(n != 1);");
