OC.L10N.register(
    "news",
    {
    "News" : "Новини",
    "Someone" : "Някой",
    "%1$s shared \"%2$s\" with you" : "%1$s сподели с вас \"%2$s\"",
    "News feeds" : "Емисии за новини",
    "Unread articles" : "Непрочетени статии",
    "News folders" : "Нови папки",
    "News articles" : "Новинарски статии",
    "Shared with me" : "Споделено с мен",
    "An RSS/Atom feed reader" : "Четец за RSS/Atom емисии",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Приложение за четене на RSS/Atom Feed за Nextcloud\n\n- 📲 Синхронизирайте емисиите си с множество мобилни или настолни [клиенти](https://nextcloud.github.io/news/clients/)\n- 🔄 Автоматични актуализации на вашите новинарски емисии\n- 🆓 Безплатен и отворен код под AGPLv3, без реклами или премиум функции\n\n**За да работи това приложение, в момента се изисква System Cron**\n\nИзискванията могат да бъдат намерени [тук](https://nextcloud.github.io/news/install/#dependencies)\n\nРегистърът на промените е достъпен [тук](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nСъздайте [отчет за грешка](https://github.com/nextcloud/news/issues/new/choose)\n\nСъздайте [заявка за функция](https://github.com/nextcloud/news/discussions/new)\n\nПодайте сигнал за [проблем с емисия](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Изтегли",
    "Close" : "Затваряне",
    "Web address" : "Уеб адрес",
    "No folder" : "Няма папка",
    "Folder name" : "Име на папката",
    "Username" : "Потребител",
    "Password" : "Парола",
    "Feed exists already!" : "Емисията вече съществува!",
    "New folder" : "Нова папка",
    "Folder exists already!" : "Папката вече съществува!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth credentials (потребителското име и паролата) ще бъдат записани в некриптиран вид! Те ще бъдат видими за всеки с достъп до сървъра!",
    "Credentials" : "Потребител и парола",
    "Auto discover Feed" : "Емисия за автоматично откриване",
    "Subscribe" : "Абониране",
    "Successfully updated news configuration" : "Успешно актуализирана конфигурация за новини",
    "Unable to update news config" : "Не може да се актуализира конфигурацията за новини",
    "Last job ran {relativeTime}." : "Последната задача се изпълни {relativeTime}.",
    "Maximum read count per feed" : "Максимален брой прочитания на емисия",
    "Maximum redirects" : "Максимален брой пренасочвания",
    "Feed fetcher timeout" : "Максимално време за изчакване",
    "Explore Service URL" : "Разгледайте URL адреса на услугата",
    "Update interval" : "Интервал за актуализиране",
    "Use system cron for updates" : "Използване на системния cron за актуализации",
    "Disable this if you use a custom updater." : "Деактивирайте това, ако използвате персонализирана програма за актуализиране.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Задава максималния брой статии, които могат да бъдат прочетени за всяка емисия, които няма да бъдат изтрити от автоматичната програма за почистване; ако стари статии се появят отново след като са били прочетени, може да увеличите стойността; отрицателни стойности, като \"-1\", изключват напълно тази функционалност.",
    "Delete unread articles automatically" : "Автоматично изтриване на непрочетени статии",
    "Enable this if you also want to delete unread articles." : "Разрешаване на опцията ако искате и да изтривате непрочетени статии.",
    "How many redirects the feed fetcher should follow." : "Колко пренасочвания трябва да следва инструментът за извличане на емисии.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Максималното време в секунди за изчакване зареждането на RSS или Atom емисия; ако отнема по-дълго актуализирането се прекратява",
    "Interval in seconds in which the feeds will be updated." : "Интервал в секунди, в който емисиите ще бъдат актуализирани.",
    "Show all articles" : "Показвай всички статии",
    "Move" : "Преместване",
    "Share" : "Споделяне",
    "Are you sure you want to delete?" : "Сигурни ли сте, че искате да изтриете?",
    "Mark read" : "Означи като прочетена",
    "All articles" : "Всички статии",
    "Starred" : "Със звезда",
    "Explore" : "Проучи",
    "Rename" : "Преименувай",
    "Delete" : "Изтрий",
    "Rename Feed" : "Преименуване на емисията",
    "Unpin from top" : "Откачи от най-отгоре",
    "Pin to top" : "Закачи най-отгоре",
    "Newest first" : "Най-нов",
    "Oldest first" : "Най-стар",
    "Default order" : "Стандартна подредба",
    "Enable full text" : "Показвай целия текст",
    "Disable full text" : "Не показвай целия текст",
    "from" : "от",
    "Toggle star article" : "Превключи означаването със звезда",
    "Mark unread" : "Маркирай като непрочетено",
    "shared by" : "споделено от",
    "by" : "от",
    "Play audio" : "Стартирай аудио",
    "Download audio" : "Изтегли аудио",
    "Download video" : "Изтегли видео",
    "Open website" : "Отвори интернет станица",
    "Keep article unread" : "Постоянното означаване като непрочетена",
    "Toggle keep current article unread" : "Промяна запазва статуса на статията като непрочетена",
    "Remove keep article unread" : "Премахни постоянното означаване като непрочетена",
    "Default" : "По подразбиране",
    "Vertical" : "Вертикално",
    "Horizontal" : "Хоризонтално",
    "Off" : "Изключен",
    "Always" : "Винаги",
    "Never" : "Никога",
    "General" : "Общи",
    "Disable mark read through scrolling" : "Без означаване като \"Прочетена\" след скролиране",
    "Reverse ordering (oldest on top)" : "Обратен ред (най-старите отгоре)",
    "Appearance" : "Изглед",
    "Import" : "Импортиране /внасяне/",
    "Export" : "Експорт /изнасям/",
    "Please wait" : "Моля, изчакайте",
    "Keyboard shortcuts" : "Клавишни комбинации",
    "Refresh" : "Опресняване",
    "Jump to previous article" : "Отиди на предната статия",
    "Jump to next article" : "Отиди на следващата статия",
    "Open article in new tab" : "Отвори статия в нов таб",
    "Resources" : "Ресурси",
    "Title" : "Заглавие",
    "Folder" : "Папка",
    "Subscribe to" : "Абониране за",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Засечен е Ajax или webcron режим! Емисиите няма да бъдат актуализирани!",
    "How to set up the operating system cron" : "Как се настройва работещия системен cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Инсталирайте и настройте по-бърза паралелна програма за актуализиране, която използва API за актуализиране на приложението Новини"
},
"nplurals=2; plural=(n != 1);");
