OC.L10N.register(
    "news",
    {
    "News" : "Notí­cies",
    "Someone" : "Algú",
    "%1$s shared \"%2$s\" with you" : "%1$s us ha compartit %2$s",
    "News feeds" : "Fonts de notícies",
    "Unread articles" : "Articles sense llegir",
    "News folders" : "Carpetes de notícies",
    "News articles" : "Articles de notícies",
    "Shared with me" : "Compartit amb mi",
    "An RSS/Atom feed reader" : "Un lector de notícies RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Una aplicació de lectura RSS/Atom Feed per a Nextcloud\n\n- 📲 Sincronitzeu els vostres canals amb diversos [clients] mòbils o d'escriptori (https://nextcloud.github.io/news/clients/)\n- 🔄 Actualitzacions automàtiques dels vostres canals de notícies\n- 🆓 Gratuït i de codi obert sota AGPLv3, sense anuncis ni funcions premium\n\n** Actualment es requereix el sistema Cron perquè aquesta aplicació funcioni**\n\nEls requisits es poden trobar [aquí] (https://nextcloud.github.io/news/install/#dependencies)\n\nEl registre de canvis està disponible [aquí] (https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreeu un [informe d'errors](https://github.com/nextcloud/news/issues/new/choose)\n\nCreeu una [sol·licitud de funció](https://github.com/nextcloud/news/discussions/new)\n\nInforma d'un [problema de feed] (https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Baixa",
    "Close" : "Tanca",
    "Internal server error!" : "Error intern del servidor!",
    "Unknown error!" : "Error desconegut!",
    "Web address" : "Adreça web",
    "Please check your data/nextcloud.log file for additional information!" : "Comproveu el vostre fitxer de dades/nextcloud.log per obtenir informació addicional!",
    "No folder" : "Sense carpeta",
    "Folder name" : "Nom de la carpeta",
    "Username" : "Nom d'usuari",
    "Password" : "Contrasenya",
    "Feed exists already!" : "El canal ja existeix!",
    "New folder" : "Carpeta nova",
    "Folder exists already!" : "La carpeta ja existeix!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Les credencials d’Autenticació Bàsica d'HTTP s’han d’emmagatzemar sense xifrar. Tothom que tingui accés al servidor o a la base de dades hi podrà accedir!",
    "Credentials" : "Credencials",
    "Auto discover Feed" : "Font de descoberta automàtica",
    "Subscribe" : "Subscriu",
    "Successfully updated news configuration" : "Configuració de notícies actualitzada correctament",
    "Unable to update news config" : "No es pot actualitzar la configuració de notícies",
    "Last job ran {relativeTime}." : "L'última tasca es va executar {relativeTime}.",
    "Maximum read count per feed" : "Màxim nombre de lectures per canal",
    "Maximum redirects" : "Màxim de redirigits",
    "Feed fetcher timeout" : "Temps d'espera exhaurit per a la descàrrega del canal",
    "Explore Service URL" : "Explora l'URL del Servei",
    "Update interval" : "Interval d'actualització",
    "Use system cron for updates" : "Feu servir el sistema cron per a les actualitzacions",
    "Disable this if you use a custom updater." : "Inhabiliteu-ho si feu servir un actualitzador personalitzat.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Defineix la quantitat màxima d'articles que es poden llegir per canal que no es suprimiran pel treball de neteja; si els articles antics reapareixen després de ser llegits, augmenta aquest valor; valors negatius com -1 desactivaran aquesta funció.",
    "Delete unread articles automatically" : "Suprimeix automàticament els articles no llegits",
    "Enable this if you also want to delete unread articles." : "Habiliteu-ho si també voleu suprimir articles no llegits.",
    "How many redirects the feed fetcher should follow." : "Quantes redireccions hauria de suportar el descarregador de canals.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Nombre màxim de segons per esperar que carregui un canal RSS o Atom; si pren més temps, l'actualització serà cancel·lada.",
    "Interval in seconds in which the feeds will be updated." : "Interval en segons en què s'actualitzaran els canals de continguts.",
    "Use next update time for feed updates" : "Utilitzeu l'hora de la  següent actualització per a les actualitzacions del canal",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Activeu-ho per utilitzar l'hora d'actualització calculada per a les actualitzacions del canal. Inhabiliteu-ho per actualitzar els canals basats únicament en l'interval d'actualització.",
    "Article list" : "Llista d'articles",
    "Article details" : "Detalls de l'article",
    "No article selected" : "No s'ha seleccionat cap article",
    "Show all articles" : "Mostra tots els articles",
    "Move" : "Mou",
    "User Name" : "Nom d'usuari",
    "Share" : "Compartir",
    "Share with" : "Comparteix amb",
    "Share with {num} users" : "Comparteix amb {num} usuaris",
    "Rename Folder" : "Canvia el nom de la carpeta",
    "Are you sure you want to delete?" : "Esteu segur que voleu suprimir?",
    "Mark read" : "Marca com a llegit",
    "All articles" : "Tots els articles",
    "Starred" : "Destacats",
    "Has feeds with errors!" : "Té canals amb errors!",
    "Explore" : "Explora",
    "Rename" : "Canvia el nom",
    "Delete" : "Suprimeix",
    "Rename Feed" : "Canvia el nom del canal",
    "Open Feed URL" : "Obre l'URL del canal",
    "Unpin from top" : "Desancora-ho de la part superior",
    "Pin to top" : "Ancora-ho a la part superior",
    "Newest first" : "Més nou primer",
    "Oldest first" : "Més antic primer",
    "Default order" : "Ordre per defecte",
    "Enable full text" : "Habilita el text complet",
    "Disable full text" : "Inhabilita el text complet",
    "from" : "de",
    "Previous Item" : "Element anterior",
    "Next Item" : "Element següent",
    "Share within Instance" : "Comparteix dins de la instància",
    "Toggle star article" : "Commuta l'article com a destacat",
    "Mark unread" : "Marca com a no llegit",
    "Close details" : "Tanca detalls",
    "shared by" : "compartit per",
    "by" : "per",
    "Play audio" : "Reprodueix l'àudio",
    "Download audio" : "Baixada de l'àudio",
    "Download video" : "Baixada del vídeo",
    "Open website" : "Obre el lloc web",
    "Keep article unread" : "Manté l'article com a no llegit",
    "Toggle keep current article unread" : "Commuta mantenir de l’article actual com a no llegit",
    "Remove keep article unread" : "Suprimir mantenir l'article no llegit",
    "Default" : "Per defecte",
    "Compact" : "Compacte",
    "Screenreader" : "Lector de pantalla",
    "Vertical" : "Vertical",
    "Horizontal" : "Horitzontal",
    "Off" : "Apagat",
    "Never" : "Mai",
    "Please select a valid OPML file" : "Seleccioneu un fitxer OPML vàlid",
    "File successfully uploaded" : "El fitxer s'ha pujat correctament",
    "Error uploading the opml file" : "S'ha produït un error en pujar el fitxer opml",
    "Error connecting to the server" : "Error en connectar-se al servidor",
    "Error retrieving the opml file" : "S'ha produït un error en recuperar el fitxer opml",
    "General" : "General",
    "Disable mark read through scrolling" : "Inhabilita la marca de lectura mitjançant el desplaçament",
    "Reverse ordering (oldest on top)" : "Ordre invers (més antic a la part superior)",
    "Disable automatic refresh" : "Inhabilita l'actualització automàtica",
    "Media" : "Multimèdia",
    "Appearance" : "Aparença",
    "Display mode" : "Mode de visualització",
    "Split mode" : "Mode dividit",
    "Import" : "Importa",
    "Export" : "Exporta",
    "Abonnements (OPML)" : "Abonaments (OPML)",
    "Please wait" : "Espereu si us plau",
    "Keyboard shortcuts" : "Dreceres de teclat",
    "Refresh" : "Refresca",
    "Jump to previous article" : "Vés a l'article anterior",
    "Jump to next article" : "Vés al següent article",
    "Open article in new tab" : "Obre l'article a una pestanya nova",
    "Show article details in compact view" : "Mostra els detalls de l'article en vista compacta",
    "Close article details in compact view" : "Tanca els detalls de l'article en vista compacta",
    "Mark current articles feed/folder as read" : "Marca el canal/carpeta d'articles actuals com a llegit",
    "Resources" : "Recursos",
    "Last update" : "Darrera actualització",
    "Time when the feed was last downloaded" : "Hora en què es va baixar el feed per última vegada",
    "Next update" : "Següent actualització",
    "Time when the next feed update will be done" : "Hora en què es farà la següent actualització del canal",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Només si està activat als paràmetres de administració, en cas contrari s'utilitza l'interval d'actualització regular",
    "Articles per update" : "Articles per actualització",
    "Maximum number of articles reached in a feed update" : "Nombre màxim d'articles assolit en una actualització del canal",
    "Error Count" : "Recompte d'errors",
    "Number of errors that have occurred since the last successful feed update" : "Nombre d'errors que s'han produït des de l'última actualització correcta del canal",
    "Title" : "Títol",
    "Folder" : "Carpeta",
    "Not available" : "No disponible",
    "All Articles" : "Tots els articles",
    "No feeds found to add" : "No s'han trobat canals per afegir",
    "Subscribe to" : "Subscriu a",
    "Unread Articles" : "Articles sense llegir",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "S'ha detectat el mode Ajax o webcron. Els vostres canals no s'actualitzaran!",
    "How to set up the operating system cron" : "Com configurar el cron del sistema operatiu",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instal·leu i configureu un actualitzador en paral·lel més ràpid que faci servir l'API d'actualització de l'aplicació de Notí­cies"
},
"nplurals=2; plural=(n != 1);");
