OC.L10N.register(
    "news",
    {
    "News" : "Новости",
    "Someone" : "Пользователь",
    "%1$s shared \"%2$s\" with you" : "%1$s предоставил(а) вам доступ к «%2$s»",
    "News feeds" : "Новостные ленты",
    "Unread articles" : "Непрочтённые статьи",
    "News folders" : "Каталог новостей",
    "News articles" : "Каталог статей",
    "Shared with me" : "Поделились с вами",
    "An RSS/Atom feed reader" : "Читалка RSS / Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Приложение для чтения RSS/Atom для Nextcloud\n\n- 📲 Синхронизация ваших лент с несколькими мобильными или настольными [клиентами] (https://nextcloud.github.io/news/clients/)\n- 🔄 Автоматическое обновление ваших новостных лент\n- 🆓 Бесплатно и с открытым исходным кодом по AGPLv3, без рекламы и премиум-функций\n\n**Для работы этого приложения требуется системный Cron**.\n\nТребования можно найти [здесь](https://nextcloud.github.io/news/install/#dependencies)\n\nСписок изменений доступен [здесь](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nСоздать [отчёт об ошибке](https://github.com/nextcloud/news/issues/new/choose)\n\nСоздать [запрос новой функции](https://github.com/nextcloud/news/discussions/new)\n\nСообщить [о проблеме](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Скачать",
    "Close" : "Закрыть",
    "Internal server error!" : " Внутренняя ошибка сервера!",
    "Unknown error!" : "Неизвестная ошибка!",
    "Web address" : "Веб адрес",
    "No folder" : "Нет папки",
    "Folder name" : "Имя папки",
    "Username" : "Имя пользователя",
    "Password" : "Пароль",
    "Feed exists already!" : "Лента уже существует!",
    "New folder" : "Новая папка",
    "Folder exists already!" : "Папка уже существует!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Аутентификационные данные HTTP Basic придётся сохранить в незашифрованном виде! Каждый, у кого есть доступ внутрь сервера или в базу данных, сможет прочитать их!",
    "Credentials" : "Учётные данные",
    "Auto discover Feed" : "Автообнаружение ленты",
    "Subscribe" : "Подписаться",
    "Successfully updated news configuration" : "Конфигурация новостей успешно обновлена",
    "Unable to update news config" : "Не удалось обновить конфигурацию новостей",
    "Last job execution ran {relativeTime}. Something is wrong." : "Последняя задача выполнялась {relativeTime}. Что-то пошло не так.",
    "Last job ran {relativeTime}." : "Последнее задание было запущено {relativeTime}.",
    "Maximum read count per feed" : "Максимальное количество статей для ленты",
    "Maximum redirects" : "Максимум перенаправлений",
    "Feed fetcher timeout" : "Время ожидания для загрузчика ленты",
    "Explore Service URL" : "URL службы обзора",
    "Update interval" : "Интервал обновления",
    "Use system cron for updates" : "Для получения обновлений используйте системный cron",
    "Disable this if you use a custom updater." : "Отключите эту функцию, если вы используете пользовательскую программу обновления.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Максимальное количество прочитанных статей для каждой ленты, которые не будут удалены при очистке; если старые статьи появляются снова после прочтения, то увеличьте это значение; отрицательное значения, например, -1, полностью отключает эту функцию.",
    "Delete unread articles automatically" : "Автоматическое удаление непрочитанных статей",
    "Enable this if you also want to delete unread articles." : "Включить, если вы хотите удалить непрочитанные статьи.",
    "How many redirects the feed fetcher should follow." : "Сколько перенаправлений должен обрабатывать загрузчик лент.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Максимальное количество секунд ожидания загрузки ленты RSS или Atom; если обновление занимает больше времени, то оно будет отменено",
    "Interval in seconds in which the feeds will be updated." : "Интервал обновления лент в секундах",
    "Use next update time for feed updates" : "Использовать следующее время обновления для обновлений ленты",
    "No article selected" : "Статья не выбрана",
    "Show all articles" : "Показать все статьи",
    "Move" : "Переместить",
    "User Name" : "Имя пользователя",
    "Share" : "Поделиться",
    "Share with" : "Поделиться",
    "Share with {num} users" : "Поделиться с {num} пользователями",
    "Rename Folder" : "Переименовать Папку",
    "Are you sure you want to delete?" : "Вы уверены, что хотите удалить?",
    "Mark read" : "Пометить прочтённым",
    "All articles" : "Все статьи",
    "Recently viewed" : "Недавно просмотрено",
    "Starred" : "Избранное",
    "Has feeds with errors!" : "Имеются ленты с ошибками!",
    "Explore" : "Обзор",
    "Rename" : "Переименовать",
    "Delete" : "Удалить",
    "Rename Feed" : "Переименовать Новостную ленту",
    "Open Feed URL" : "Открыть URL канала",
    "Unpin from top" : "Открепить сверу",
    "Pin to top" : "Прикрепить вверху",
    "Newest first" : "Новые-старые",
    "Oldest first" : "Старые-новые",
    "Default order" : "Порядок по умолчанию",
    "Enable full text" : "Включить полный текст",
    "Disable full text" : "Отключить полный текст",
    "Mark as unread on update" : "Отмечать как непрочитанное при обновлении",
    "Keep read status on update" : "Сохранять статус прочтения при обновлении",
    "from" : "С",
    "Previous Item" : "Предыдущий элемент",
    "Next Item" : "Следующий элемент",
    "Share within Instance" : "Поделиться в пределах экземпляра",
    "Toggle star article" : "Добавить/убрать из избранного",
    "Mark unread" : "Пометить как непрочитанное",
    "Close details" : "Закрыть подробные сведения",
    "shared by" : "поделился",
    "by" : "автор",
    "Play audio" : "Проиграть аудио-запись",
    "Download audio" : "Скачать аудио-запись",
    "Download video" : "Скачать видео",
    "Open website" : "Открыть веб-сайт",
    "Keep article unread" : "Оставить статью непрочитанной",
    "Toggle keep current article unread" : "Переключатель пометки текущей статьи непрочитанной",
    "Remove keep article unread" : "Удалить отметку от непрочтении",
    "Default" : "По умолчанию",
    "Compact" : "Компактный вид",
    "Vertical" : "По вертикали",
    "Horizontal" : "По горизонтали",
    "Off" : "Отключить",
    "Always" : "Всегда",
    "Never" : "Никогда",
    "Please select a valid OPML file" : "Выберите корректный OPML файл",
    "File successfully uploaded" : "Файл успешно загружен",
    "Error uploading the opml file" : "Ошибка при загрузке OPML файла",
    "Error connecting to the server" : "Ошибка при подключении к серверу",
    "Error retrieving the opml file" : "Ошибка при получении OPML файла",
    "General" : "Основные",
    "Disable mark read through scrolling" : "Отключить установку отметок о прочтении при прокрутке",
    "Reverse ordering (oldest on top)" : "Обратный порядок (самые старые сверху)",
    "Disable automatic refresh" : "Отключить автоматическое обновление",
    "Media" : "Медиа",
    "Appearance" : "Внешний вид",
    "Display mode" : "Режим отображения",
    "Split mode" : "Раздельный режим",
    "Import" : "Импортировать",
    "Export" : "Экспорт",
    "Abonnements (OPML)" : "Подписки (OPML)",
    "Importing feeds" : "Импортирование лент",
    "Please wait" : "Подождите",
    "Keyboard shortcuts" : "Горячие клавиши",
    "Refresh" : "Обновить",
    "Jump to previous article" : "Перейти на предыдущую статью",
    "Jump to next article" : "Перейти на следующую статью",
    "Open article in new tab" : "Открыть статью в новой вкладке",
    "Resources" : "Ресурсы",
    "Last update" : "Последнее обновление",
    "Time when the feed was last downloaded" : "Время последнего скачивания ленты",
    "Next update" : "Следующее обновление",
    "Time when the next feed update will be done" : "Время следующего обновления ленты",
    "Error Count" : "Счётчик ошибок",
    "Title" : "Название",
    "Folder" : "Каталог",
    "Not available" : "Не доступен",
    "All Articles" : "Все статьи",
    "No feeds found to add" : "Не найдено ни одного канала для добавления",
    "Subscribe to" : "Подписаться",
    "Unread Articles" : "Непрочитанные статьи",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Обнаружен режим планировщика задач Ajax или webcron! Ленты не будут обновляться!",
    "How to set up the operating system cron" : "Как настроить cron (планировщик задач) операционной системы",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Установить и настроить более быстрое средство параллельного обновления, которое использует собственный API обновлений приложения новостей"
},
"nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
