OC.L10N.register(
    "news",
    {
    "News" : "اخبار",
    "Someone" : "Someone",
    "%1$s shared \"%2$s\" with you" : "\"%2$s\" توسط %1$s با شما به اشتراک گذاشته شد",
    "News feeds" : "News feeds",
    "Unread articles" : "مطالب خوانده نشده",
    "News folders" : "News folders",
    "News articles" : "News articles",
    "Shared with me" : "Shared with me",
    "An RSS/Atom feed reader" : "An RSS/Atom feed reader",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "دانلود",
    "Close" : "بستن",
    "Web address" : "آدرس وب",
    "No folder" : "بدون پوشه",
    "Folder name" : "نام پوشه",
    "Username" : "نام کاربری",
    "Password" : "گذرواژه",
    "Feed exists already!" : "خوراک در حال حاضر وجود دارد!",
    "New folder" : "پوشه جدید",
    "Folder exists already!" : "پوشه در حال حاضر موجود است!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "اعتبارنامه HTTP Basic Auth باید بدون رمزگذاری ذخیره شود! هر کس با دسترسی به سرور یا بانک اطلاعاتی قادر به دسترسی به آنها خواهد بود!",
    "Credentials" : "اعتبارهای",
    "Auto discover Feed" : "Auto discover Feed",
    "Subscribe" : "اشتراک گذاری",
    "Successfully updated news configuration" : "Successfully updated news configuration",
    "Unable to update news config" : "Unable to update news config",
    "Last job ran {relativeTime}." : "آخرین کار در {time} اجرا شد.",
    "Maximum read count per feed" : "حداکثر تعداد خواندن در هر خوراک",
    "Maximum redirects" : "حداکثر تغییر مسیرها",
    "Feed fetcher timeout" : "خاتمه دادن به فست فایر",
    "Explore Service URL" : "URL سرویس را کاوش کنید",
    "Update interval" : "Update interval",
    "Use system cron for updates" : "برای بروزرسانی ها از سیستم cron استفاده کنید",
    "Disable this if you use a custom updater." : "Disable this if you use a custom updater.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off.",
    "Delete unread articles automatically" : "Delete unread articles automatically",
    "Enable this if you also want to delete unread articles." : "Enable this if you also want to delete unread articles.",
    "How many redirects the feed fetcher should follow." : "How many redirects the feed fetcher should follow.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted.",
    "Interval in seconds in which the feeds will be updated." : "Interval in seconds in which the feeds will be updated.",
    "Show all articles" : "نمایش تمامی مقالات",
    "Move" : "انتقال",
    "Share" : "هم‌رسانی",
    "Share with" : "به اشتراک گذاشتن با",
    "Are you sure you want to delete?" : "Are you sure you want to delete?",
    "Mark read" : "علامت گذاری به عنوان خوانده شده",
    "All articles" : "تمام مطالب",
    "Starred" : "ستاره دار",
    "Explore" : "کاوش",
    "Rename" : "تغییرنام",
    "Delete" : "حذف",
    "Rename Feed" : "تغییر نام خوراک",
    "Unpin from top" : "از بالای صفحه باز کنید",
    "Pin to top" : "از این صفحه",
    "Newest first" : "تازه ترین ها اول ",
    "Oldest first" : "قدیمی ترین ها اول ",
    "Default order" : "سفارش پیش فرض",
    "Enable full text" : "متن کامل را فعال کنید",
    "Disable full text" : "متن کامل را غیرفعال کنید",
    "from" : "از",
    "Toggle star article" : "مقاله ستاره را تغییر دهید",
    "Mark unread" : "علامت گذاری به عنوان خوانده نشده",
    "shared by" : "shared by",
    "by" : "با",
    "Play audio" : "پخش صوت",
    "Download audio" : "دانلود صوت",
    "Download video" : "دانلود ویدئو",
    "Open website" : "باز کردن وب‌سایت",
    "Keep article unread" : "مقاله را نخوانید",
    "Toggle keep current article unread" : "جستجوی مقاله فعلی خوانده نشده",
    "Remove keep article unread" : "مقاله را نخوانید حذف کنید",
    "Default" : "پیش‌فرض",
    "Compact" : "فشرده",
    "Vertical" : "Vertical",
    "Horizontal" : "Horizontal",
    "Always" : "همیشه",
    "Never" : "هرگز",
    "General" : "عمومی",
    "Disable mark read through scrolling" : "غیرفعال کردن علامت خوانده شده از طریق پیمایش",
    "Reverse ordering (oldest on top)" : "ترتیب معکوس (قدیمی ترین در بالا)",
    "Media" : "رسانه‌ها",
    "Appearance" : "ظاهر",
    "Import" : "وارد کردن",
    "Export" : "دریافت خروجی",
    "Please wait" : "Please wait",
    "Keyboard shortcuts" : "میان بر صفحه ی کلید",
    "Refresh" : "بازنمایی",
    "Jump to previous article" : "پرش به مقاله قبلی",
    "Jump to next article" : "پرش به مقاله بعدی",
    "Open article in new tab" : "باز کردن مقاله در تب جدید",
    "Resources" : "منابع",
    "Title" : "Title",
    "Folder" : "پوشه",
    "Not available" : "در دسترس نیست",
    "Subscribe to" : "Subscribe to",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "آژاکس یا حالت وبکرون شناسایی شد! فیدهای شما به روز نمی شوند!",
    "How to set up the operating system cron" : "نحوه تنظیم سیستم عامل کرن",
    "Install and set up a faster parallel updater that uses the News app's update API" : "یک بروزرسانی موازی سریعتر را که از API به روزرسانی برنامه News استفاده می کند ، نصب و تنظیم کنید"
},
"nplurals=2; plural=(n > 1);");
