OC.L10N.register(
    "news",
    {
    "%1$s shared \"%2$s\" with you" : "%1$s đã chia sẽ \"%2$s\" với bạn",
    "Unread articles" : "Bài chưa đọc",
    "Download" : "Tải về",
    "Close" : "Đóng",
    "Web address" : "Địa chỉ Web",
    "No folder" : "Không có thư mục nào",
    "Folder name" : "Tên thư mục",
    "Username" : "Tên đăng nhập",
    "Password" : "Mật khẩu",
    "Feed exists already!" : "Nguồn đã tồn tại",
    "New folder" : "Tạo thư mục",
    "Folder exists already!" : "Thư mục đã tồn tại!",
    "Credentials" : "Giấy chứng nhận",
    "Subscribe" : "Theo dõi",
    "Last job ran {relativeTime}." : "Công việc cuối cùng đã chạy {relativeTime}.",
    "Move" : "Dịch chuyển",
    "Share" : "Chia sẻ",
    "Mark read" : "Đánh dấu là đã đọc",
    "All articles" : "Mọi bài viết",
    "Starred" : "Starred",
    "Rename" : "Sửa tên",
    "Delete" : "Xóa",
    "Rename Feed" : "Đổi tên nguồn dữ liệu",
    "Newest first" : "Mới trước",
    "Oldest first" : "Cũ trước",
    "from" : "từ",
    "Mark unread" : "Đánh dấu là chưa đọc",
    "by" : "bởi",
    "Open website" : "Mở trang web",
    "Off" : "Tắt",
    "Always" : "Luôn luôn",
    "Never" : "Không bao giờ",
    "General" : "Cài đặt chung",
    "Media" : "Phương tiện",
    "Appearance" : "Giao diện",
    "Import" : "Nhập vào",
    "Export" : "Xuất ra",
    "Keyboard shortcuts" : "Phím tắt",
    "Refresh" : "Làm mới",
    "Resources" : "Các nguồn lực",
    "Title" : "Tên",
    "Folder" : "Thư mục",
    "Not available" : "Không khả dụng"
},
"nplurals=1; plural=0;");
