OC.L10N.register(
    "news",
    {
    "News" : "Nuus",
    "Someone" : "Iemand",
    "Shared with me" : "Gedeel met my",
    "Download" : "Laai Af",
    "Close" : "Sluit",
    "Web address" : "Webadres",
    "No folder" : "Geen vouer",
    "Folder name" : "Vouernaam",
    "Username" : "Gebruikersnaam",
    "Password" : "Wagwoord",
    "New folder" : "Nuwe vouer",
    "Folder exists already!" : "Vouers bestaan reeds!",
    "Subscribe" : "Teken in",
    "Move" : "Skuif",
    "Share" : "Deel",
    "All articles" : "Alle artikels",
    "Explore" : "Ontdek",
    "Rename" : "Hernoem",
    "Delete" : "Skrap",
    "Newest first" : "Nuutste eerste",
    "Oldest first" : "Oudste eerste",
    "from" : "van",
    "by" : "deur",
    "Play audio" : "Speel oudio af",
    "Download audio" : "Laai oudio af",
    "Download video" : "Laai video af",
    "Import" : "Invoer",
    "Export" : "Voer uit",
    "Keyboard shortcuts" : "Sneltoetse",
    "Refresh" : "Verfris",
    "Jump to previous article" : "Spring na vorige artikel",
    "Jump to next article" : "Spring na volgende artikel",
    "Resources" : "Hulpbronne",
    "Folder" : "Vouer"
},
"nplurals=2; plural=(n != 1);");
