OC.L10N.register(
    "news",
    {
    "%1$s shared \"%2$s\" with you" : "%1$s a partejat \"%2$s\" amb vos",
    "Unread articles" : "Articles pas legits",
    "Download" : "Telecargar",
    "Close" : "Tampar",
    "Web address" : "Adreça web",
    "No folder" : "Aucun dorsièr",
    "Folder name" : "Nom del dorsièr",
    "Username" : "Identificant",
    "Password" : "Senhal",
    "Feed exists already!" : "Lo flux existís ja !",
    "New folder" : "Novèl dorsièr",
    "Folder exists already!" : "Lo dorsièr existís ja !",
    "Credentials" : "Informacions d'identificacion",
    "Subscribe" : "S'abonar",
    "Maximum read count per feed" : "Nombre maximum de lectura per flux",
    "Maximum redirects" : "Nombre maximal de redireccions",
    "Feed fetcher timeout" : "Relambi d'espèra maximum del recuperador de flux",
    "Explore Service URL" : "URL del servici d'exploracion",
    "Show all articles" : "Afichar totes los articles",
    "Move" : "Desplaçar",
    "Share" : "Partejar",
    "Rename Folder" : "Renomenar lo dossièr",
    "All articles" : "Totes los articles",
    "Starred" : "Espingolats",
    "Explore" : "Explorar",
    "Rename" : "Renomenar",
    "Delete" : "Suprimir",
    "Rename Feed" : "Renomenar lo flux",
    "from" : "de",
    "Toggle star article" : "Espingolar / Desespingolar l'article",
    "by" : "per",
    "Play audio" : "Escotar",
    "Download audio" : "Telecargar lo son",
    "Download video" : "Telecargar la vidèo",
    "Open website" : "Dobrir lo site web",
    "Keep article unread" : "Marcar l'article coma pas legit",
    "Toggle keep current article unread" : "Marcar l'article coma Legit / Non legit",
    "Remove keep article unread" : "Marcar l'article coma legit",
    "Off" : "Atudat",
    "Always" : "Totjorn",
    "Never" : "Jamai",
    "General" : "Generals",
    "Disable mark read through scrolling" : "Marcar pas los articles coma legits al moment del percors de las listas",
    "Reverse ordering (oldest on top)" : "Òrdre invèrse (los mai ancians amont)",
    "Media" : "Mèdia",
    "Appearance" : "Aparéncia",
    "Import" : "Importar",
    "Export" : "Exportar",
    "Keyboard shortcuts" : "Acorchis de clavièr",
    "Refresh" : "Refrescar",
    "Jump to previous article" : "Anar a l'article precedent",
    "Jump to next article" : "Anar al prochain article",
    "Open article in new tab" : "Dobrir l'article dins un nouvel onglet",
    "Title" : "Títol",
    "Folder" : "Dorsièr",
    "How to set up the operating system cron" : "Cossí configurar lo cron del sistèma operatiu"
},
"nplurals=2; plural=(n > 1);");
