OC.L10N.register(
    "news",
    {
    "News" : "Nuacht",
    "an article" : "alt",
    "Someone" : "Duine éigin",
    "%1$s shared \"%2$s\" with you" : "Roinn %1$s \"%2$s\" leat",
    "{user} shared \"{article}\" with you" : "Roinn {user} \"{article}\" leat",
    "News feeds" : "Fothaí nuachta",
    "Unread articles" : "Ailt gan léamh",
    "News folders" : "Fillteáin nuachta",
    "News articles" : "Ailt nuachta",
    "Shared with me" : "Roinnte liom",
    "Untitled article" : "Airteagal gan teideal",
    "An RSS/Atom feed reader" : "Léitheoir fotha RSS/Atom",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Aip léitheora RSS/Atom Feed do Nextcloud\n\n- 📲 Sioncronaigh do chuid fothaí le il-cliaint soghluaiste nó deisce [cliaint] ( https://nextcloud.github.io/news/clients/)\n- 🔄 Nuashonruithe uathoibríocha ar do chuid fothaí nuachta\n- 🆓 Foinse saor in aisce agus oscailte faoi AGPLv3, gan aon fhógraí ná feidhmeanna préimhe\n\n**Tá System Cron ag teastáil faoi láthair le go n-oibreoidh an aip seo**\n\nIs féidir na riachtanais a fháil [anseo]( https://nextcloud.github.io/news/install/#dependencies)\n\nTá an Changelog ar fáil [anseo]( https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCruthaigh [tuairisc fhabht](https://github.com/nextcloud/news/issues/new/choose)\n\nCruthaigh [iarratas gné](https://github.com/nextcloud/news/discussions/new)\n\nDéan tuairisc ar [saincheist fotha] (https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Íoslódáil",
    "Close" : "Dún",
    "Internal server error!" : "Earráid freastalaí inmheánach!",
    "Unknown error!" : "Earráid anaithnid!",
    "Web address" : "Seoladh gréasáin",
    "Please check your data/nextcloud.log file for additional information!" : "Seiceáil do chomhad data/nextcloud.log le haghaidh tuilleadh faisnéise!",
    "No folder" : "Gan fillteán",
    "Folder name" : "Ainm fillteáin",
    "Username" : "Ainm úsáideora",
    "Password" : "Pasfhocal",
    "Feed exists already!" : "Tá beathú ann cheana féin!",
    "New folder" : "Fillteán nua",
    "Folder exists already!" : "Tá fillteán ann cheana féin!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Ní mór dintiúir HTTP Basic Auth a stóráil gan chriptiú! Beidh gach duine a bhfuil rochtain acu ar an bhfreastalaí nó ar an mbunachar sonraí in ann rochtain a fháil orthu!",
    "Credentials" : "Dintiúir",
    "Auto discover Feed" : "Fotha aimsithe go huathoibríoch",
    "Subscribe" : "Liostáil",
    "Successfully updated news configuration" : "Nuashonraíodh an chumraíocht nuachta go rathúil",
    "Unable to update news config" : "Ní féidir an chumraíocht nuachta a nuashonrú",
    "Logo purge has never been run." : "Níor reáchtáladh glanadh lógó riamh.",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "Rith an glanadh lógó deireanach {relativeLastLogoPurge}. Tá rud éigin cearr.",
    "Last logo purge job ran {relativeLastLogoPurge}." : "Rith an jab glantacháin lógó deireanach {relativeLastLogoPurge}.",
    "No job execution data available. The cron job may not be running properly." : "Níl aon sonraí forghníomhaithe poist ar fáil. B’fhéidir nach bhfuil an post cron ag rith i gceart.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Rith an forghníomhú poist deireanach {relativeTime}. Tá rud éigin cearr.",
    "Last job ran {relativeTime}." : "Rith an post deireanach {relativeTime}.",
    "Maximum read count per feed" : "An líon uasta léite in aghaidh an fhotha",
    "Maximum redirects" : "Uasmhéid atreoruithe",
    "Feed fetcher timeout" : "Teorainn ama gabhála beatha",
    "Explore Service URL" : "Déan iniúchadh ar URL na Seirbhíse",
    "Update interval" : "Eatramh nuashonraithe",
    "Use system cron for updates" : "Úsáid córas cron le haghaidh nuashonruithe",
    "Disable this if you use a custom updater." : "Díchumasaigh é seo má úsáideann tú nuashonróir saincheaptha.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Sainmhíníonn sé uasmhéid na n-alt is féidir a léamh in aghaidh an fhotha nach scriosfar leis an jab glanta; má thagann sean-ailt le feiceáil arís tar éis iad a léamh, cuir leis an luach seo; Múchfaidh luachanna diúltacha ar nós -1 an ghné seo.",
    "Delete unread articles automatically" : "Scrios ailt neamhléite go huathoibríoch",
    "Enable this if you also want to delete unread articles." : "Cumasaigh é seo más mian leat ailt neamhléite a scriosadh freisin.",
    "How many redirects the feed fetcher should follow." : "Cé mhéad athsheolaidh ba chóir don lorgaire beathaithe a leanúint.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Uaslíon soicind chun fanacht le fotha RSS nó Atom a luchtú; má thógann sé níos faide cuirfear deireadh leis an nuashonrú.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Má chuirtear ar fáil é, déanfar fiosrú ar URL na seirbhíse seo chun na fothaí a thaispeáint sa chuid fothaí iniúchta. Chun brath ar an tseirbhís iniúchta ionsuite, fág an ionchur seo folamh.",
    "Interval in seconds in which the feeds will be updated." : "Eatramh i soicindí ina ndéanfar na fothaí a nuashonrú.",
    "Use next update time for feed updates" : "Úsáid an chéad am nuashonraithe eile le haghaidh nuashonruithe fotha",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Cumasaigh é seo chun an chéad am nuashonraithe eile ríofa a úsáid le haghaidh nuashonruithe fothaí. Díchumasaigh fothaí a nuashonrú bunaithe ar an eatramh nuashonraithe amháin.",
    "Article list" : "Liosta alt",
    "Article details" : "Sonraí alt",
    "No article selected" : "Níor roghnaíodh aon alt",
    "Please select an article from the list." : "Roghnaigh alt ón liosta le do thoil.",
    "Show all articles" : "Taispeáin gach alt",
    "Move feed" : "Bog beatha",
    "Please select the new folder" : "Roghnaigh an fillteán nua le do thoil",
    "Move" : "Bog",
    "User Name" : "Ainm Úsáideora",
    "Share" : "Comhroinn",
    "Share with" : "Roinn le",
    "Share with {num} users" : "Roinn le {num} úsáideoirí",
    "Rename Folder" : "Athainmnigh Fillteán",
    "Are you sure you want to delete?" : "An bhfuil tú cinnte gur mhaith leat a scriosadh?",
    "Unable to save starred open state" : "Ní féidir an staid oscailte réaltaithe a shábháil",
    "Mark read" : "Léigh Mark",
    "All articles" : "Gach alt",
    "Recently viewed" : "Breathnaíodh air le déanaí",
    "Starred" : "Réiltín",
    "Has feeds with errors!" : "Tá fothaí le hearráidí!",
    "Explore" : "Déan iniúchadh",
    "Feed settings" : "Socruithe beatha",
    "News settings" : "Socruithe nuachta",
    "Rename" : "Athainmnigh",
    "Delete" : "Scrios",
    "Rename Feed" : "Athainmnigh Fotha",
    "Open Feed URL" : "Oscail URL Fothaí",
    "Unpin from top" : "Díphionnáil ón mbarr",
    "Pin to top" : "Bioráin go barr",
    "Newest first" : "Is nua ar dtús",
    "Oldest first" : "Is sine ar dtús",
    "Default order" : "Ordú réamhshocraithe",
    "Enable full text" : "Cumasaigh téacs iomlán",
    "Disable full text" : "Díchumasaigh an téacs iomlán",
    "Mark as unread on update" : "Marcáil mar neamhléite ar nuashonrú",
    "Keep read status on update" : "Coinnigh stádas léite ar nuashonrú",
    "Sync disabled" : "Sioncrónú díchumasaithe",
    "Sync enabled" : "Sioncrónú cumasaithe",
    "Show external media" : "Taispeáin meáin sheachtracha",
    "from" : "ó",
    "External media loaded from" : "Meáin sheachtracha luchtaithe ó",
    "Previous Item" : "Mír Roimhe Seo",
    "Next Item" : "An Chéad Mhír Eile",
    "Share within Instance" : "Roinn laistigh de chás",
    "Toggle star article" : "Scoránaigh alt réalta",
    "Mark unread" : "Marcáil neamhléite",
    "Close details" : "Mionsonraí a dhúnadh",
    "shared by" : "roinnte ag",
    "by" : "le",
    "Play audio" : "Seinn fuaime",
    "Download audio" : "Íoslódáil an fhuaim",
    "Download video" : "Íoslódáil físeán",
    "Refresh list" : "Athnuachan an liosta",
    "Open website" : "Oscail láithreán gréasáin",
    "Keep article unread" : "Coinnigh an t-alt gan léamh",
    "Toggle keep current article unread" : "Scoránaigh coinnigh an t-alt reatha gan léamh",
    "Remove keep article unread" : "Bain coinnigh alt neamhléite",
    "Default" : "Réamhshocrú",
    "Compact" : "Dlúth",
    "Screenreader" : "Léitheoir scáileáin",
    "Vertical" : "Ingearach",
    "Horizontal" : "Cothrománach",
    "Off" : "as",
    "Always" : "I gcónaí",
    "Ask" : "Iarr",
    "Never" : "Riamh",
    "Please select a valid OPML file" : "Roghnaigh comhad bailí OPML",
    "File successfully uploaded" : "D'éirigh le huaslódáil an chomhaid",
    "Error uploading the opml file" : "Earráid agus an comhad opml á uaslódáil",
    "Error connecting to the server" : "Earráid agus ceangal leis an bhfreastalaí",
    "Error retrieving the opml file" : "Earráid agus an comhad opml á aisghabháil",
    "Please select a valid json file" : "Roghnaigh comhad json bailí le do thoil",
    "Error uploading the json file" : "Earráid ag uaslódáil an chomhaid json",
    "Error retrieving the json file" : "Earráid ag aisghabháil an chomhaid json",
    "General" : "Ginearálta",
    "Disable mark read through scrolling" : "Díchumasaigh an marc a léitear trí scrollú",
    "Reverse ordering (oldest on top)" : "Ordú droim ar ais (is sine ar an mbarr)",
    "Disable automatic refresh" : "Díchumasaigh athnuachan uathoibríoch",
    "Media" : "Meáin",
    "Show enclosure images" : "Taispeáin íomhánna imfhálúcháin",
    "Show images in the article text" : "Taispeáin íomhánna i dtéacs an ailt",
    "Show iframes in the article text" : "Taispeáin iframes i dtéacs an ailt",
    "Appearance" : "Dealramh",
    "Display mode" : "Mód taispeána",
    "Split mode" : "Modh scoilte",
    "Import" : "Iompórtáil",
    "Export" : "Easpórtáil",
    "Abonnements (OPML)" : "Trócaire (OPML)",
    "Importing feeds" : "Fothaí á n-iompórtáil",
    "Please wait" : "Fán le do thoil",
    "Articles (JSON)" : "Airteagail (JSON)",
    "Keyboard shortcuts" : "Aicearraí méarchláir",
    "Refresh" : "Athnuaigh",
    "Screenreader mode only" : "Mód léitheora scáileáin amháin",
    "Jump to previous article" : "Léim go dtí an t-alt roimhe seo",
    "Jump to next article" : "Léim go dtí an chéad alt eile",
    "Item navigation and control" : "Nascleanúint agus rialú míreanna",
    "Open article in new tab" : "Oscail alt i gcluaisín nua",
    "Show article details in compact view" : "Taispeáin sonraí an ailt i ndlúthmharc",
    "Close article details in compact view" : "Dún sonraí an ailt i bhfianaise dhlúth",
    "Feed/Folder navigation and control" : "Nascleanúint agus rialú beatha/fillteán",
    "Jump to previous feed" : "Léim go dtí an fotha roimhe seo",
    "Jump to next feed" : "Léim go dtí an chéad bheatha eile",
    "Jump to previous folder" : "Léim go dtí an fillteán roimhe seo",
    "Jump to next folder" : "Léim go dtí an chéad fhillteán eile",
    "Mark current articles feed/folder as read" : "Marcáil fotha/fillteán na n-alt reatha mar atá léite",
    "Resources" : "Acmhainní",
    "Last update" : "Nuashonrú is déanaí",
    "Time when the feed was last downloaded" : "An t-am nuair a bhí an fotha íoslódáilte",
    "Next update" : "An chéad nuashonrú eile",
    "Time when the next feed update will be done" : "An t-am nuair a dhéanfar an chéad nuashonrú fotha eile",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Mura gcuirtear i ngníomh é sna socruithe riaracháin amháin, ní úsáidtear an t-eatramh nuashonraithe rialta",
    "Articles per update" : "Ailt in aghaidh an nuashonraithe",
    "Maximum number of articles reached in a feed update" : "Uaslíon alt sroichte i nuashonrú fotha",
    "Error Count" : "Comhaireamh Earráide",
    "Number of errors that have occurred since the last successful feed update" : "Líon na n-earráidí a tharla ón nuashonrú fotha rathúla deiridh",
    "Title" : "Teideal",
    "Folder" : "Fillteán",
    "Not available" : "Níl sé ar fáil",
    "All Articles" : "Gach Airteagal",
    "No feeds found to add" : "Níor aimsíodh fothaí le cur leis",
    "Subscribe to" : "Liostáil le",
    "Unread Articles" : "Airteagail Neamhléite",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Braitheadh ​​mód AJAX nó webcron! Ní dhéanfar d'fhothaí a nuashonrú!",
    "How to set up the operating system cron" : "Conas an córas oibriúcháin cron a shocrú",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Suiteáil agus socraigh nuashonróir comhthreomhar níos tapúla a úsáideann API nuashonraithe an aip Nuachta"
},
"nplurals=5; plural=(n==1 ? 0 : n==2 ? 1 : n<7 ? 2 : n<11 ? 3 : 4);");
