<?php
declare(strict_types=1);
// SPDX-FileCopyrightText: 2022 Carl Schwan <carl@carlschwan.eu>
// SPDX-Licence-Identifier: AGPL-3.0-or-later
\OCP\Util::addScript('news', 'news-admin-settings');
?>

<div id="vue-admin-news"></div>
