OC.L10N.register(
    "news",
    {
    "News" : "Fréttir",
    "%1$s shared \"%2$s\" with you" : "%1$s deildi \"%2$s\" með þér",
    "Unread articles" : "Ólesnar greinar",
    "Shared with me" : "Deilt með mér",
    "An RSS/Atom feed reader" : "RSS/Atom streymislesari",
    "Download" : "Niðurhal",
    "Close" : "Loka",
    "Web address" : "Veffang",
    "No folder" : "Engin mappa",
    "Folder name" : "Nafn möppu",
    "Username" : "Notandanafn",
    "Password" : "Lykilorð",
    "Feed exists already!" : "Streymið er þegar til!",
    "New folder" : "Ný mappa",
    "Folder exists already!" : "Mappan er þegar til!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth auðkenni verða að geymast ódulrituð! Hver sá sem hefur aðgang að þjóninum eða gagnagrunninum mun hafa aðgang að þeim!",
    "Credentials" : "Auðkenni",
    "Subscribe" : "Áskrift",
    "Last job ran {relativeTime}." : "Síðasta verk var keyrt {relativeTime}.",
    "Maximum read count per feed" : "Hámarkfjöldi lestra á hvert streymi",
    "Maximum redirects" : "Hámarks endurbeiningar",
    "Feed fetcher timeout" : "Tímamörk streymissugu",
    "Explore Service URL" : "Skoða slóð á þjónustu (URL)",
    "Update interval" : "Uppfærslutíðni",
    "Use system cron for updates" : "Nota kerfis-cron fyrir uppfærslur",
    "How many redirects the feed fetcher should follow." : "Hversu mörgum endurbeiningum streymissugan á að fylgja.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Hámarksfjöldi sekúndna sem beðið er eftir að RSS eða Atom-streymi hlaðist inn; ef það tekur lengri tíma er hætt við uppfærslu.",
    "Interval in seconds in which the feeds will be updated." : "Tími í sekúndum sem líður milli þess sem streymi eru uppfærð.",
    "Show all articles" : "Birta allar greinar",
    "Move" : "Færa",
    "Share" : "Deila",
    "Share with" : "Deila með",
    "Mark read" : "Merkja sem lesið",
    "All articles" : "Allar greinar",
    "Starred" : "Stjörnumerkt",
    "Explore" : "Skoða",
    "Rename" : "Endurnefna",
    "Delete" : "Eyða",
    "Rename Feed" : "Endurnefna streymi",
    "Unpin from top" : "Aftengja frá topphluta",
    "Pin to top" : "Tengja á topphluta",
    "Newest first" : "Nýjast fyrst",
    "Oldest first" : "Elsta fyrst",
    "Default order" : "Sjálfgefin röðun",
    "Enable full text" : "Virkja allan texta",
    "Disable full text" : "Afvirkja allan texta",
    "from" : "frá",
    "Toggle star article" : "Víxla stjörnumerkingu af/á grein",
    "Mark unread" : "Merkja sem ólesið",
    "Close details" : "Loka nánari upplýsingum",
    "by" : "eftir",
    "Play audio" : "Spila hljóð",
    "Download audio" : "Sækja hljóð",
    "Download video" : "Sækja myndskeið",
    "Open website" : "Opna vefsvæði",
    "Keep article unread" : "Halda greininni sem ólesinni",
    "Toggle keep current article unread" : "Víxla af/á að halda greininni sem ólesinni",
    "Remove keep article unread" : "Fjarlægja að halda greininni sem ólesinni",
    "Default" : "Sjálfgefið",
    "Vertical" : "Lóðrétt",
    "Horizontal" : "Lárétt",
    "Never" : "Aldrei",
    "General" : "Almennt",
    "Disable mark read through scrolling" : "Gera óvirkt að merkja sem lesið við skrun",
    "Reverse ordering (oldest on top)" : "Öfug röðun (elsta efst)",
    "Media" : "Myndefni",
    "Appearance" : "Útlit",
    "Import" : "Flytja inn",
    "Export" : "Flytja út",
    "Please wait" : "Bíddu aðeins",
    "Keyboard shortcuts" : "Flýtilyklar",
    "Refresh" : "Endurlesa",
    "Jump to previous article" : "Hoppa á fyrri grein",
    "Jump to next article" : "Hoppa á næstu grein",
    "Open article in new tab" : "Opna grein í nýjum flipa",
    "Resources" : "Tilföng",
    "Folder" : "Mappa",
    "Subscribe to" : "Gerast áskrifandi að",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax eða webcron fannst! Fréttastraumar þínir verða ekki uppfærðir!",
    "How to set up the operating system cron" : "Hvernig á að setja upp cron-þjónustu stýrikerfis",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Setja upp og stilla hraðvirkari samhliða uppfærslueiningu sem notar API-forritsviðmót fréttaforritsins"
},
"nplurals=2; plural=(n % 10 != 1 || n % 100 == 11);");
