OC.L10N.register(
    "news",
    {
    "Download" : "ಪ್ರತಿಯನ್ನು ಸ್ಥಳೀಯವಾಗಿ ಉಳಿಸಿಕೊಳ್ಳಿ",
    "Close" : "ಮುಚ್ಚು",
    "Username" : "﻿ಬಳಕೆಯ ಹೆಸರು",
    "Password" : "ಗುಪ್ತಪದ",
    "New folder" : "﻿ಹೊಸ ಕೋಶ",
    "Credentials" : "﻿ರುಜುವಾತುಗಳು",
    "Move" : "Move",
    "Share" : "﻿ಹಂಚಿಕೊಳ್ಳಿ",
    "Rename" : "﻿ಮರುಹೆಸರಿಸು",
    "Delete" : "﻿ಅಳಿಸಿ",
    "Import" : "ಆಮದು",
    "Export" : "ರಫ್ತು",
    "Folder" : "ಕೋಶ"
},
"nplurals=2; plural=(n > 1);");
