OC.L10N.register(
    "news",
    {
    "News" : "ニュース",
    "Someone" : "誰か",
    "%1$s shared \"%2$s\" with you" : "%1$s は \"%2$s\" をあなたと共有しました",
    "News feeds" : "ニューズフィード",
    "Unread articles" : "未読の記事",
    "News folders" : "ニューズフォルダー",
    "News articles" : "ニュース記事",
    "Shared with me" : "私と共有",
    "An RSS/Atom feed reader" : "RSS/Atom フィードリーダー",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 NextcloudのためのRSS/Atomフィードリーダーアプリ\n\n- 📲 お持ちのモバイル端末またはデスクトップ間でフィードを同期 [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 ニュースフィードの自動更新\n- 🆓AGPLv3下の無料・オープンソースにより、広告や有料のプレミアム機能はありません\n\n**このアプリの動作にはシステムのCron機能が必要です**\n\nシステム要件は [here](https://nextcloud.github.io/news/install/#dependencies)\n\n変更履歴は [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\n[bug report]から不具合報告(https://github.com/nextcloud/news/issues/new/choose)\n\n[feature request]から機能をリクエスト(https://github.com/nextcloud/news/discussions/new)\n\n[feed issue]からフィードの問題を報告(https://github.com/nextcloud/news/discussions/new)",
    "Download" : "ダウンロード",
    "Close" : "閉じる",
    "Internal server error!" : "サーバー内部のエラー!",
    "Unknown error!" : "不明なエラー",
    "Web address" : "WEBアドレス",
    "No folder" : "フォルダーはありません",
    "Folder name" : "フォルダー名",
    "Username" : "ユーザー名",
    "Password" : "パスワード",
    "Feed exists already!" : "フィードはすでに存在します！",
    "New folder" : "新しいフォルダー",
    "Folder exists already!" : "フォルダーはすでに存在します！",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP ベーシック認証の認証情報は暗号化せずに保管する必要があります。その為、サーバーやデータベースにアクセスできる人はすべてこの情報を見ることができます。",
    "Credentials" : "資格情報",
    "Auto discover Feed" : "自動探索フィード",
    "Subscribe" : "購読",
    "Successfully updated news configuration" : "ニュース設定の更新に成功",
    "Unable to update news config" : "ニュース設定の更新ができません",
    "Last job ran {relativeTime}." : "最終ジョブ実行は {relativeTime} です。",
    "Maximum read count per feed" : "フィード当たりの最大閲覧数",
    "Maximum redirects" : "最大リダイレクト数",
    "Feed fetcher timeout" : "フィードフェッチャーのタイムアウト",
    "Explore Service URL" : "サービスURLの探索",
    "Update interval" : "アップデート周期",
    "Use system cron for updates" : "更新のためにOSのcronを使用",
    "Disable this if you use a custom updater." : "カスタムアップデーターをご利用中の場合はこちらを無効にしてください。",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "クリーンアップジョブによって削除されないフィードごとに読み取ることができる記事の最大量を定義します。古い記事が読み込まれた後に再び表示される場合は、この値を増やします。-1などの負の値を指定すると、この機能はオフになります。",
    "Delete unread articles automatically" : "未読記事を自動的に削除する",
    "Enable this if you also want to delete unread articles." : "未読記事も削除する場合は、これを有効にします。",
    "How many redirects the feed fetcher should follow." : "フィードフェッチャーに許可するリダイレクト数です。",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "RSS / Atom フィードの読み込み待機秒数の制限;設定時間より長くかかる場合はアップデートが中止されます。",
    "Interval in seconds in which the feeds will be updated." : "フィードを更新するまでの間隔を秒数で指定してください。",
    "No article selected" : "記事が選択されていません",
    "Show all articles" : "すべての記事を表示",
    "Please select the new folder" : "新しいフォルダを選択してください",
    "Move" : "移動",
    "User Name" : "ユーザーネーム",
    "Share" : "共有",
    "Share with" : "共有対象",
    "Share with {num} users" : "{num}ユーザーと共有する",
    "Rename Folder" : "フォルダ名を変更する",
    "Are you sure you want to delete?" : "本当に削除してよろしいですか?",
    "Mark read" : "既読にする",
    "All articles" : "すべての記事",
    "Starred" : "共有",
    "Explore" : "探索",
    "Rename" : "名前の変更",
    "Delete" : "削除",
    "Rename Feed" : "フィードの名前を変更",
    "Open Feed URL" : "フィードURLを開く",
    "Unpin from top" : "トップからピンを外す",
    "Pin to top" : "トップにピン",
    "Newest first" : "新しい順",
    "Oldest first" : "古い順",
    "Default order" : "デフォルト順",
    "Enable full text" : "全文検索を有効",
    "Disable full text" : "全文検索を無効",
    "Sync disabled" : "同期が無効",
    "Sync enabled" : "同期が有効",
    "from" : "差出人",
    "Previous Item" : "前のアイテム",
    "Next Item" : "次のアイテム",
    "Share within Instance" : "インスタンス内で共有する",
    "Toggle star article" : "スター付きの記事を切り替え",
    "Mark unread" : "未読にする",
    "Close details" : "詳細を閉じる",
    "shared by" : "共有:",
    "by" : "by",
    "Play audio" : "音楽を再生",
    "Download audio" : "音楽をダウンロード",
    "Download video" : "動画をダウンロード",
    "Open website" : "ウェブサイトを開く",
    "Keep article unread" : "記事を未読のままにする",
    "Toggle keep current article unread" : "現在の記事の未読を切り替え",
    "Remove keep article unread" : "記事の未読保持を解除",
    "Default" : "デフォルト",
    "Vertical" : "垂直",
    "Horizontal" : "水平",
    "Always" : "常に",
    "Never" : "なし",
    "General" : "一般",
    "Disable mark read through scrolling" : "スクロール時の既読マークを無効化",
    "Reverse ordering (oldest on top)" : "逆順",
    "Media" : "メディア",
    "Appearance" : "表示",
    "Import" : "インポート",
    "Export" : "エクスポート",
    "Please wait" : "お待ちください",
    "Keyboard shortcuts" : "キーボードショートカット",
    "Refresh" : "同期",
    "Jump to previous article" : "前の記事へジャンプ",
    "Jump to next article" : "次の記事へジャンプ",
    "Open article in new tab" : "新しいタブで記事を開く",
    "Resources" : "リソース",
    "Last update" : "最終更新",
    "Next update" : "次回の更新",
    "Title" : "タイトル",
    "Folder" : "フォルダー",
    "All Articles" : "全ての記事",
    "No feeds found to add" : "追加するフィードが見つかりません",
    "Subscribe to" : "次を購読:",
    "Unread Articles" : "未読の記事",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax か Web cron モードになっています。フィードは自動的に更新されません。",
    "How to set up the operating system cron" : "OSのcronのやり方",
    "Install and set up a faster parallel updater that uses the News app's update API" : "ニュースアプリのアップデートAPIを使用する、高速な並列アップデーターをインストールして、設定します。"
},
"nplurals=1; plural=0;");
