OC.L10N.register(
    "news",
    {
    "%1$s shared \"%2$s\" with you" : "%1$s koplietots \"%2$s\" ar tevi",
    "Unread articles" : "Nelasītie raksti",
    "Shared with me" : "Koplietots ar mani",
    "Download" : "Lejupielādēt",
    "Close" : "Aizvērt",
    "Web address" : "Tīmekļa adrese",
    "No folder" : "Nav mapes",
    "Folder name" : "Mapes nosaukums",
    "Username" : "Lietotājvārds",
    "Password" : "Parole",
    "Feed exists already!" : "Plūsma jau pastāv.",
    "New folder" : "Jauna mape",
    "Folder exists already!" : "Mape jau pastāv.",
    "Credentials" : "Akreditācijas dati",
    "Subscribe" : "Abonēt",
    "Maximum redirects" : "Lielākais pieļaujamais pārvirzījumu skaits",
    "Use system cron for updates" : "Izmantot sistēmas cron atjauninājumiem",
    "Show all articles" : "Rādīt visus rakstus",
    "Move" : "Pārvietot",
    "Share" : "Koplietot",
    "Rename Folder" : "Pārdēvēt mapi",
    "All articles" : "Visi raksti",
    "Starred" : "Svarīgs",
    "Explore" : "Izpētīt",
    "Rename" : "Pārdēvēt",
    "Delete" : "Izdzēst",
    "Rename Feed" : "Pārdēvēt barotni",
    "Open Feed URL" : "Atvērt barotnes URL",
    "Newest first" : "Jaunākie pirms",
    "Oldest first" : "Vecākie pirms",
    "from" : "no",
    "by" : "līdz",
    "Play audio" : "Atskaņot audio",
    "Download audio" : "Lejupielādēt audio",
    "Download video" : "Lejupielādēt video",
    "Open website" : "Atvērt tīmekļvietni",
    "Never" : "Nekad",
    "General" : "Vispārīgi",
    "Media" : "Informācijas nesēji",
    "Appearance" : "Izskats",
    "Import" : "Ievietot",
    "Export" : "Izgūt",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Refresh" : "Atsvaidzināt",
    "Open article in new tab" : "Atvērt rakstu jaunā cilnē",
    "Resources" : "Resursi",
    "Title" : "Virsraksts",
    "Folder" : "Mape",
    "Not available" : "Nav pieejams",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Noteikts AJAX vai tīmekļa cron. Tavas barotnes netiks atjauninātas."
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
