OC.L10N.register(
    "news",
    {
    "%1$s shared \"%2$s\" with you" : "%1$s deli „%2$s“ sa vama",
    "Download" : "Preuzmi",
    "Close" : "Zatvori",
    "Folder name" : "Naziv fascikle",
    "Username" : "Username",
    "Password" : "Password",
    "New folder" : "Nova fascikla",
    "Credentials" : "Credentials",
    "Move" : "Premesti",
    "Share" : "Podeli",
    "Starred" : "Ozvezdano",
    "Rename" : "Rename",
    "Delete" : "Delete",
    "Rename Feed" : "Preimenuj dovod",
    "Newest first" : "Prvo novije",
    "Oldest first" : "prvo starije",
    "Always" : "Uvek",
    "Never" : "Nikad",
    "Appearance" : "Izgled",
    "Refresh" : "Osveži"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
