OC.L10N.register(
    "news",
    {
    "News" : "News",
    "an article" : "Ein Artikel",
    "Someone" : "Jemand",
    "%1$s shared \"%2$s\" with you" : "%1$s hat \"%2$s\" mit Ihnen geteilt",
    "{user} shared \"{article}\" with you" : "{user} hat \"{article}\" mit Ihnen geteilt",
    "News feeds" : "Nachrichten-Feeds",
    "Unread articles" : "Ungelesene Artikel",
    "News folders" : "Nachrichtenordner",
    "News articles" : "Nachrichtenartikel",
    "Shared with me" : "Mit mir geteilt",
    "Untitled article" : "Artikel ohne Titel",
    "An RSS/Atom feed reader" : "Ein RSS/Atom-Feed-Reader",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Eine RSS/Atom Feed Reader App für Nextcloud\n\n- 📲 Synchronisieren Sie Ihre Feeds mit mehreren mobilen oder Desktop [Clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatische Aktualisierung Ihrer Newsfeeds\n- 🆓 Kostenlos und quelloffen unter AGPLv3, keine Werbung oder Premiumfunktionen\n\n**System Cron wird derzeit benötigt, damit diese App funktioniert**\n\nDie Anforderungen finden Sie [hier](https://nextcloud.github.io/news/install/#dependencies)\n\nDie Liste der Änderungen (Changelog) finden Sie [hier](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nErstellen Sie einen [Fehlerbericht](https://github.com/nextcloud/news/issues/new/choose)\n\nErstellen Sie eine [Funktionsanforderung](https://github.com/nextcloud/news/discussions/new)\n\nMelden Sie ein [Feed-Problem](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Herunterladen",
    "Close" : "Schließen",
    "Internal server error!" : "Interner Serverfehler!",
    "Unknown error!" : "Unbekannter Fehler!",
    "Web address" : "Internetadresse",
    "Please check your data/nextcloud.log file for additional information!" : "Bitte für weitere Informationen data/nextcloud.log kontrollieren!",
    "No folder" : "Kein Ordner",
    "Folder name" : "Ordnername",
    "Username" : "Benutzername",
    "Password" : "Passwort",
    "Feed exists already!" : "Feed existiert bereits!",
    "New folder" : "Neuer Ordner",
    "Folder exists already!" : "Der Ordner existiert bereits!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "Die Anmeldeinformationen der HTTP-Standardauthentifizierung müssen unverschlüsselt gespeichert werden! Jeder mit Serverzugriff ist in der Lage diese Daten zu lesen.",
    "Credentials" : "Zugangsdaten",
    "Auto discover Feed" : "Feed automatisch erkennen",
    "Subscribe" : "Abonnieren",
    "Successfully updated news configuration" : "Die News-Einstellungen wurden aktualisiert",
    "Unable to update news config" : "Die News-Einstellungen konnten nicht aktualisiert werden",
    "Logo purge has never been run." : "Die Logo-Bereinigung wurde noch nie ausgeführt.",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "Die letzte Logo-Bereinigung lief {relativeLastLogoPurge}. Etwas scheint falsch zu sein.",
    "Last logo purge job ran {relativeLastLogoPurge}." : "Die letzte Logo-Bereinigung lief {relativeLastLogoPurge}.",
    "No job execution data available. The cron job may not be running properly." : "Keine Daten zur Auftragsausführung verfügbar. Der Cron-Job läuft möglicherweise nicht richtig.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Die letzte Aufgaben-Ausführung lief {relativeTime}. Etwas scheint falsch zu sein.",
    "Last job ran {relativeTime}." : "Die letzte Aufgabe lief {relativeTime}.",
    "Maximum read count per feed" : "Maximale Anzahl an gelesenen Artikeln pro Feed",
    "Maximum redirects" : "Maximale Anzahl Weiterleitungen",
    "Feed fetcher timeout" : "Zeitüberschreitung Feed-Sammler",
    "Explore Service URL" : "Service-URL finden",
    "Update interval" : "Aktualisierungsintervall",
    "Use system cron for updates" : "Verwende System-Cron für Aktualisierungen",
    "Disable this if you use a custom updater." : "Deaktivieren Sie diese Option, wenn Sie einen eigenen Updater verwenden.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Definiert die maximale Anzahl an Artikeln, die pro Feed gelesen und bei einem Säuberungsauftrag nicht aus der Datenbank gelöscht werden; wenn ältere Artikel nach dem Lesen erhalten bleiben sollen, erhöhe diesen Wert; negative Werte wie -1 deaktivieren diese Funktion komplett",
    "Delete unread articles automatically" : "Ungelesene Artikel automatisch löschen",
    "Enable this if you also want to delete unread articles." : "Dies aktivieren, wenn auch ungelesene Artikel gelöscht werden sollen.",
    "How many redirects the feed fetcher should follow." : "Anzahl Weiterleitungen die der Feed-Sammler folgen soll.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Maximale Anzahl an Sekunden zum Laden eines RSS- oder Atom-Feeds. Wenn dies länger dauert, wird die Aktualisierung abgebrochen.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Falls angegeben, wird die URL dieses Dienstes abgefragt, um die Feeds im Bereich Feeds erkunden anzuzeigen. Um die integrierten Feedvorschläge anzuzeigen, dieses Feld leer lassen.",
    "Interval in seconds in which the feeds will be updated." : "Intervall in Sekunden, in dem die Feeds aktualisiert werden.",
    "Use next update time for feed updates" : "Nächsten Aktualisierungszeitpunkt für Feed-Updates verwenden",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Diese Option aktivieren, um die berechnete nächste Aktualisierungszeit für Feed-Updates zu verwenden. Deaktivieren, um Feeds ausschließlich im eingestellten Aktualisierungsintervall zu aktualisieren.",
    "Article list" : "Artikelliste",
    "Article details" : "Artikeldetails",
    "No article selected" : "Kein Artikel ausgewählt",
    "Please select an article from the list." : "Bitte einen Artikel aus der Liste wählen.",
    "Show all articles" : "Alle Artikel anzeigen",
    "Move feed" : "Feed verschieben",
    "Please select the new folder" : "Bitte den neuen Ordner auswählen",
    "Move" : "Verschieben",
    "User Name" : "Benutzername",
    "Share" : "Teilen",
    "Share with" : "Teilen mit",
    "Share with {num} users" : "Mit {num} Benutzern teilen",
    "Rename Folder" : "Ordner umbenennen",
    "Are you sure you want to delete?" : "Möchten Sie wirklich löschen?",
    "Unable to save starred open state" : "Der markierte offene Zustand konnte nicht gespeichert werden",
    "Mark read" : "Als gelesen markieren",
    "All articles" : "Alle Artikel",
    "Recently viewed" : "Zuletzt angesehen",
    "Starred" : "Markiert",
    "Has feeds with errors!" : "Hat Feeds mit Fehlern!",
    "Explore" : "Entdecken",
    "Feed settings" : "Feed-Einstellungen",
    "News settings" : "News-Einstellungen",
    "Rename" : "Umbenennen",
    "Delete" : "Löschen",
    "Rename Feed" : "Feed umbenennen",
    "Open Feed URL" : "Feed-URL öffnen",
    "Unpin from top" : "Fixierung aufheben",
    "Pin to top" : "Oben fixieren",
    "Newest first" : "Neue zuerst",
    "Oldest first" : "Älteste zuerst",
    "Default order" : "Standard-Sortierung",
    "Enable full text" : "Volltext aktivieren",
    "Disable full text" : "Volltext deaktivieren",
    "Mark as unread on update" : "Bei Aktualisierung als ungelesen markieren",
    "Keep read status on update" : "Lesestatus bei Aktualisierung behalten",
    "Sync disabled" : "Synchronisierung ist deaktiviert",
    "Sync enabled" : "Synchronisierung ist aktiviert",
    "Show external media" : "Externe Medien anzeigen",
    "from" : "von",
    "External media loaded from" : "Externe Medien geladen von",
    "Previous Item" : "Vorheriges Element",
    "Next Item" : "Nächstes Element",
    "Share within Instance" : "Innerhalb der Instanz teilen",
    "Toggle star article" : "Markierung des Artikels umschalten",
    "Mark unread" : "Als ungelesen markieren",
    "Close details" : "Details schließen",
    "shared by" : "Geteilt von",
    "by" : "von",
    "Play audio" : "Audio wiedergeben",
    "Download audio" : "Audio herunterladen",
    "Download video" : "Video herunterladen",
    "Refresh list" : "Liste aktualisieren",
    "Open website" : "Webseite öffnen",
    "Keep article unread" : "Artikel ungelesenen lassen",
    "Toggle keep current article unread" : "Umschalten lässt den Artikel ungelesen",
    "Remove keep article unread" : "\"Artikel ungelesenen lassen\" entfernen",
    "Default" : "Standard",
    "Compact" : "Kompakt",
    "Screenreader" : "Screenreader",
    "Vertical" : "Vertikal",
    "Horizontal" : "Horizontal",
    "Off" : "Aus",
    "Always" : "Immer",
    "Ask" : "Fragen",
    "Never" : "Niemals",
    "Please select a valid OPML file" : "Bitte eine gültige OPML-Datei wählen",
    "File successfully uploaded" : "Datei hochgeladen",
    "Error uploading the opml file" : "Fehler beim Hochladen der OPML-Datei",
    "Error connecting to the server" : "Fehler bei der Verbindung zum Server",
    "Error retrieving the opml file" : "Fehler beim Abruf der OPML-Datei",
    "Please select a valid json file" : "Bitte eine gültige JSON-Datei auswählen",
    "Error uploading the json file" : "Fehler beim Hochladen der JSON-Datei",
    "Error retrieving the json file" : "Fehler beim Abruf der JSON-Datei",
    "General" : "Allgemein",
    "Disable mark read through scrolling" : "Keine Artikel während des Bildlaufs als gelesen markieren",
    "Reverse ordering (oldest on top)" : "Sortierung umkehren (älteste zuerst)",
    "Disable automatic refresh" : "Automatische Aktualisierung deaktivieren",
    "Media" : "Medien",
    "Show embedded thumbnails" : "Titelbildvorschau anzeigen",
    "Show enclosure images" : "Titelbilder anzeigen",
    "Show images in the article text" : "Bilder im Artikeltext anzeigen",
    "Show iframes in the article text" : "IFrames im Artikeltext anzeigen",
    "Appearance" : "Aussehen",
    "Display mode" : "Anzeigemodus",
    "Split mode" : "Split-Modus",
    "Import" : "Importieren",
    "Export" : "Exportieren",
    "Abonnements (OPML)" : "Abonnements (OPML)",
    "Importing feeds" : "Importiere Feeds",
    "Please wait" : "Bitte warten",
    "Articles (JSON)" : "Artikel (JSON)",
    "Keyboard shortcuts" : "Tastaturkürzel",
    "Refresh" : "Aktualisieren",
    "Screenreader mode only" : "Nur Screenreader-Modus",
    "Jump to previous article" : "Zum vorherigen Artikel springen",
    "Jump to next article" : "Zum nächsten Artikel springen",
    "Item navigation and control" : "Artikelnavigation und Kontrolle",
    "Open article in new tab" : "Artikel in neuen Tab öffnen",
    "Show article details in compact view" : "Artikeldetails in kompakter Ansicht anzeigen",
    "Close article details in compact view" : "Artikeldetails in der Kompaktansicht schließen",
    "Feed/Folder navigation and control" : "Feed/Ordner-Navigation und Kontrolle",
    "Jump to previous feed" : "Zum vorherigen Feed springen",
    "Jump to next feed" : "Zum nächsten Feed springen",
    "Jump to previous folder" : "Zum vorherigen Ordner springen",
    "Jump to next folder" : "Zum nächsten Ordner springen",
    "Mark current articles feed/folder as read" : "Feed/Ordner dieses Artikels als gelesen markieren",
    "Resources" : "Ressourcen",
    "Last update" : "Letzte Aktualisierung",
    "Time when the feed was last downloaded" : "Zeitpunkt des letzten Downloads des Feeds",
    "Next update" : "Nächste Aktualisierung",
    "Time when the next feed update will be done" : "Zeitpunkt der nächsten Feedaktualisierung",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Nur wenn in den Administrationseinstellungen aktiviert, ansonsten wird das standardmäßige Aktualisierungsintervall verwendet",
    "Articles per update" : "Artikel pro Update",
    "Maximum number of articles reached in a feed update" : "Maximale Anzahl von Artikeln in einer Feedaktualisierung-erreicht",
    "Error Count" : "Fehleranzahl",
    "Number of errors that have occurred since the last successful feed update" : "Anzahl der Fehler, die seit der letzten erfolgreichen Feedaktualisierung aufgetreten sind",
    "Title" : "Titel",
    "Folder" : "Ordner",
    "Not available" : "Nicht verfügbar",
    "All Articles" : "Alle Artikel",
    "No feeds found to add" : "Keine Feeds zum Hinzufügen gefunden",
    "Subscribe to" : "Abonnieren von",
    "Unread Articles" : "Ungelesene Artikel",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax oder ein webbasierter Cron-Modus gefunden! Ihre Feeds werden nicht aktualisiert!",
    "How to set up the operating system cron" : "Wie der Cron des Betriebssystems eingerichtet wird",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Installieren und richten Sie einen schnellen, parallelen Updater ein, der die Update-API der News-App nutzt"
},
"nplurals=2; plural=(n != 1);");
