OC.L10N.register(
    "news",
    {
    "News" : "新闻",
    "Someone" : "某人",
    "%1$s shared \"%2$s\" with you" : "%1$s 已和你共享了“%2$s”",
    "News feeds" : "新闻源",
    "Unread articles" : "未读文章",
    "News folders" : "新闻文件夹",
    "News articles" : "新闻文章",
    "Shared with me" : "与我分享",
    "An RSS/Atom feed reader" : "一个RSS/Atom订阅源阅读器",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Nextcloud 的 RSS/Atom 订阅源阅读器应用\n\n- 📲 将您的订阅源与多个移动或桌面[客户端](https://nextcloud.github.io/news/clients/)同步\n- 🔄 自动更新您的消息订阅源\n- 🆓 遵循 AGPLv3 的自由开源软件，无广告或付费功能\n\n**此应用当前需要系统 Cron 才能工作**\n\n要求依赖可在[此处](https://nextcloud.github.io/news/install/#dependencies)找到\n\n更新日志可在[此处](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)获取\n\n创建[错误报告](https://github.com/nextcloud/news/issues/new/choose)\n\n创建[功能请求](https://github.com/nextcloud/news/discussions/new)\n\n报告[订阅源问题](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "下载",
    "Close" : "关闭",
    "Internal server error!" : "内部服务器错误！",
    "Unknown error!" : "未知错误！",
    "Web address" : "网络地址",
    "Please check your data/nextcloud.log file for additional information!" : "请检查您的 data/nextcloud.log 文件以获取更多信息！",
    "No folder" : "无文件夹",
    "Folder name" : "文件夹名称",
    "Username" : "用户名",
    "Password" : "密码",
    "Feed exists already!" : "订阅源已存在！",
    "New folder" : "新建文件夹",
    "Folder exists already!" : "文件夹已经存在！",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth 认证只能被未加密保存！所有可以访问这个服务器的数据库的人都可以访问他们！",
    "Credentials" : "凭证",
    "Auto discover Feed" : "自动发现订阅源",
    "Subscribe" : "订阅",
    "Successfully updated news configuration" : "成功更新新闻设置",
    "Unable to update news config" : "无法更新新闻设置",
    "Logo purge has never been run." : "徽标清除从未运行过。",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "上次徽标清除运行于 {relativeLastLogoPurge}。出了点问题。",
    "Last logo purge job ran {relativeLastLogoPurge}." : "上次徽标清除作业运行于 {relativeLastLogoPurge} 。",
    "No job execution data available. The cron job may not be running properly." : "没有可用的作业执行数据。cron 作业可能未正常运行。",
    "Last job execution ran {relativeTime}. Something is wrong." : "上次作业执行运行于 {relativeTime}。出了点问题。",
    "Last job ran {relativeTime}." : "上次作业运行于 {relativeTime}。",
    "Maximum read count per feed" : "每个订阅源的最大阅读次数",
    "Maximum redirects" : "最大重定向次数",
    "Feed fetcher timeout" : "订阅源获取器超时",
    "Explore Service URL" : "探索服务 URL",
    "Update interval" : "更新间隔",
    "Use system cron for updates" : "使用系统cron计划任务执行更新",
    "Disable this if you use a custom updater." : "如果你使用自定义更新器则禁用它",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "定义每个订阅源可以读取、清理作业不会删除的最大文章数；如果旧文章在阅读后又重新出现，请增大此值。类似 -1 这样的负值将会将此功能关闭。",
    "Delete unread articles automatically" : "自动删除未读文章",
    "Enable this if you also want to delete unread articles." : "如果您还想删除未读文章，请启用此功能。",
    "How many redirects the feed fetcher should follow." : "订阅源获取器最多应跟随多少次重定向。",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "最长的等待RSS或Atom订阅源加载的秒数；如果比这个时间更长更新将会中止。",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "如果提供，将查询此服务的 URL，以在探索订阅源部分显示订阅源。要回退至内置探索服务，请将此处留空。",
    "Interval in seconds in which the feeds will be updated." : "订阅源更新的时间间隔（以秒为单位）。",
    "Use next update time for feed updates" : "使用下次更新时间进行订阅源更新",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "启用此选项可用于计算出的下次更新时间进行订阅源更新。禁用仅根据更新间隔更新订阅源。",
    "Article list" : "文章列表",
    "Article details" : "文章详情",
    "No article selected" : "未选择文章",
    "Please select an article from the list." : "请从列表中选择文章。",
    "Show all articles" : "显示全部文章",
    "Move feed" : "移动订阅源",
    "Please select the new folder" : "请选择新文件夹",
    "Move" : "移动",
    "User Name" : "用户名称",
    "Share" : "分享",
    "Share with" : "共享给",
    "Share with {num} users" : "与 {num} 个用户共享",
    "Rename Folder" : "重命名文件夹",
    "Are you sure you want to delete?" : "您确定要删除吗？",
    "Unable to save starred open state" : "无法保存已加星标项目的打开状态",
    "Mark read" : "标记为已读",
    "All articles" : "全部文章",
    "Recently viewed" : "最近查看",
    "Starred" : "已加星标",
    "Has feeds with errors!" : "有错误的订阅源！",
    "Explore" : "探索",
    "Feed settings" : "订阅源设置",
    "News settings" : "新闻设置",
    "Rename" : "重命名",
    "Delete" : "删除",
    "Rename Feed" : "重命名订阅源",
    "Open Feed URL" : "打开订阅源 URL",
    "Unpin from top" : "取消置顶",
    "Pin to top" : "置顶",
    "Newest first" : "从新到旧",
    "Oldest first" : "从旧到新",
    "Default order" : "默认排序",
    "Enable full text" : "启用全文模式",
    "Disable full text" : "禁用全文模式",
    "Mark as unread on update" : "更新时标记为未读",
    "Keep read status on update" : "更新时保持阅读状态",
    "Sync disabled" : "同步已禁用",
    "Sync enabled" : "同步已启用",
    "from" : "发件人",
    "Previous Item" : "上一个项目",
    "Next Item" : "下一个项目",
    "Share within Instance" : "在实例内共享",
    "Toggle star article" : "切换文章星标状态",
    "Mark unread" : "标记为未读",
    "Close details" : "关闭细节",
    "shared by" : "分享者",
    "by" : "发布者：",
    "Play audio" : "播放音频",
    "Download audio" : "下载音频",
    "Download video" : "下载视频",
    "Refresh list" : "刷新列表",
    "Open website" : "打开网站",
    "Keep article unread" : "保持文章未读",
    "Toggle keep current article unread" : "切换保持文章未读状态设置",
    "Remove keep article unread" : "取消保持文章未读",
    "Default" : "默认",
    "Compact" : "紧凑",
    "Screenreader" : "屏幕阅读器",
    "Vertical" : "垂直",
    "Horizontal" : "水平",
    "Off" : "关",
    "Always" : "始终",
    "Never" : "永不",
    "Please select a valid OPML file" : "请选择有效的 OPML 文件",
    "File successfully uploaded" : "文件上传成功",
    "Error uploading the opml file" : "上传 OPML 文件时出错",
    "Error connecting to the server" : "连接到服务器时出错",
    "Error retrieving the opml file" : "检索 OPML 文件时出错",
    "Please select a valid json file" : "请选择一个有效的 JSON 文件",
    "Error uploading the json file" : "上传 JSON 文件时出错",
    "Error retrieving the json file" : "检索 JSON 文件时出错",
    "General" : "常规",
    "Disable mark read through scrolling" : "禁用在滚动时标记文章为已读",
    "Reverse ordering (oldest on top)" : "反向排序（旧文章在上）",
    "Disable automatic refresh" : "禁用自动刷新",
    "Media" : "媒体文件",
    "Appearance" : "外观",
    "Display mode" : "显示模式",
    "Split mode" : "分离模式",
    "Import" : "导入",
    "Export" : "导出",
    "Abonnements (OPML)" : "订阅（OPML）",
    "Importing feeds" : "正在导入订阅源",
    "Please wait" : "请等待",
    "Articles (JSON)" : "文章（JSON）",
    "Keyboard shortcuts" : "快捷键",
    "Refresh" : "刷新",
    "Screenreader mode only" : "仅屏幕阅读器模式",
    "Jump to previous article" : "跳到上一个文章",
    "Jump to next article" : "跳到下一个文章",
    "Item navigation and control" : "项目导航和控制",
    "Open article in new tab" : "在新标签页中打开文章",
    "Show article details in compact view" : "在紧凑视图中显示文章详情",
    "Close article details in compact view" : "在紧凑视图中关闭文章详情",
    "Feed/Folder navigation and control" : "订阅源/文件夹导航和控制",
    "Jump to previous feed" : "跳到上一个订阅源",
    "Jump to next feed" : "跳到下一个订阅源",
    "Jump to previous folder" : "跳到上一个文件夹",
    "Jump to next folder" : "跳到下一个文件夹",
    "Mark current articles feed/folder as read" : "将当前文章订阅源/文件夹标记为已读",
    "Resources" : "资源",
    "Last update" : "上次更新",
    "Time when the feed was last downloaded" : "上次下载订阅源的时间",
    "Next update" : "下次更新",
    "Time when the next feed update will be done" : "下次订阅源更新完成的时间",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "仅当在管理员设置中激活时，否则使用常规更新间隔",
    "Articles per update" : "每次更新的文章数",
    "Maximum number of articles reached in a feed update" : "订阅源更新中达到的最大文章数",
    "Error Count" : "错误数",
    "Number of errors that have occurred since the last successful feed update" : "自上次成功更新订阅源以来发生的错误数",
    "Title" : "头衔",
    "Folder" : "文件夹",
    "Not available" : "不可用",
    "All Articles" : "全部文章",
    "No feeds found to add" : "未找到要添加的订阅源",
    "Subscribe to" : "订阅",
    "Unread Articles" : "未读文章",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "检测到Ajax或Webcron 模式！您的订阅源将无法被更新！",
    "How to set up the operating system cron" : "如何设置操作系统定时任务",
    "Install and set up a faster parallel updater that uses the News app's update API" : "安装并设置一个更快速的更新程序，它使用新闻应用程序更新API"
},
"nplurals=1; plural=0;");
