OC.L10N.register(
    "news",
    {
    "News" : "Вести",
    "Someone" : "Неко",
    "%1$s shared \"%2$s\" with you" : "%1$s дели „%2$s“ са вама",
    "News feeds" : "Наслови вести",
    "Unread articles" : "Непрочитани чланци",
    "News folders" : "Фолдери вести",
    "News articles" : "Чланци вести",
    "Shared with me" : "Дељено са мном",
    "An RSS/Atom feed reader" : "RSS/Atom читач довода",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Апликација RSS/Atom Feed читача за Некстклауд\n\n- 📲 Синхронизујте своје наслове са више мобилних или десктоп  [клијената](https://nextcloud.github.io/news/clients/)\n- 🔄 Аутоматско ажурирње ваших налсова вести\n- 🆓 Слободно и отвореног кода под AGPLv3, без реклама или премијум функција\n\n**Тренутно је неопходан системски Cron да би апликација радила**\n\nЗахтеви могу да се пронађу [овде](https://nextcloud.github.io/news/install/#dependencies)\n\nДневник измена се налази [овде](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nКреирајте [извештај о багу](https://github.com/nextcloud/news/issues/new/choose)\n\nКреирајте [захтев за функционалност](https://github.com/nextcloud/news/discussions/new)\n\nПријавите [проблем са насловом](https://github.com/nextcloud/news/discussions/new)",
    "Download" : "Преузми",
    "Close" : "Затвори",
    "Internal server error!" : "Интерна грешка на серверу!",
    "Unknown error!" : "Непозната грешка!",
    "Web address" : "Веб адреса",
    "Please check your data/nextcloud.log file for additional information!" : "Погледајте data/nextcloud.log фајл за додатне информације!",
    "No folder" : "Нема фасцикле",
    "Folder name" : "Назив фасцикле",
    "Username" : "Корисничко име",
    "Password" : "Лозинка",
    "Feed exists already!" : "Довод већ постоји!",
    "New folder" : "Нова фасцикла",
    "Folder exists already!" : "Фасцикла већ постоји!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Basic Auth акредитиви морају бити сачувани нешифровани! Свак са приступом серверу или бази ће моћи да им приступи!",
    "Credentials" : "Акредитиви",
    "Auto discover Feed" : "Аутоматско откривање Наслова",
    "Subscribe" : "Претплати се",
    "Successfully updated news configuration" : "Конфигурација вести је успешно ажурирана",
    "Unable to update news config" : "Кофигурација вести не може да се ажурира",
    "No job execution data available. The cron job may not be running properly." : "Нема података о извршавању задатка. Можда се cron задатак не извршава како треба.",
    "Last job execution ran {relativeTime}. Something is wrong." : "Извршавање последњег посла је трајало {relativeTime}. Нешто није у реду.",
    "Last job ran {relativeTime}." : "Последњи посао се извршавао {relativeTime}.",
    "Maximum read count per feed" : "Максимални број читања по доводу",
    "Maximum redirects" : "Највише преусмеравања",
    "Feed fetcher timeout" : "Рок добављања довода",
    "Explore Service URL" : "Истражите сервисну адресу",
    "Update interval" : "Време ажурирања",
    "Use system cron for updates" : "Користи системски крон за ажурирања",
    "Disable this if you use a custom updater." : "Искључите ово ако користите прилагођени програм за ажурирање.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Дефинише максимални број чланака који могу да се прочитају по једном наслову и које посао за чишћење неће обрисати; ако се стари чланци поново појаве након што се прочитају, повећајте ову вредност; негативне вредности као што је -1 ће искључити ову могућност.",
    "Delete unread articles automatically" : "Аутоматски обриши непрочитане чланке",
    "Enable this if you also want to delete unread articles." : "Укључите ово ако желите да се бришу и непрочитани чланци.",
    "How many redirects the feed fetcher should follow." : "Колико ће се преусмеравања следити.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "Време у секундама које ће се чекати да се довод учита. Ако траје дуже, ажурирање ће се прекинути.",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "Ако је наведена, URL адреса овог сервиса ће се упитати за приказ довода у одељку истраживања довода. За повратак на коришћење уграђеног сервиса за истраживање, оставите ово празно.",
    "Interval in seconds in which the feeds will be updated." : "Интервал у секундама у којем се ће доводи да се ажурирају.",
    "Use next update time for feed updates" : "Користи наредно време ажурирања за ажурирања дотока",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "Укључите ово да се користи израчунато време наредног ажурирања за ажурирања довода вести засновано само на интервалу ажурирања.",
    "Article list" : "Листа чланака",
    "Article details" : "Детаљи чланка",
    "No article selected" : "Није изабран ниједан чланак",
    "Please select an article from the list." : "Изаберите чланак са листе.",
    "Show all articles" : "Прикажи све чланке",
    "Move feed" : "Премести довод",
    "Please select the new folder" : "Молимо вас да изаберете нови фолдер",
    "Move" : "Помери",
    "User Name" : "Име корисника",
    "Share" : "Подели",
    "Share with" : "Подели са",
    "Share with {num} users" : "Подели са {num} корисника",
    "Rename Folder" : "Промени назив фолдера",
    "Are you sure you want to delete?" : "Да ли сте сигурни да желите да обришете?",
    "Mark read" : "Означи као прочитано",
    "All articles" : "Сви чланци",
    "Recently viewed" : "Погледано недавно",
    "Starred" : "Означено звездицом",
    "Has feeds with errors!" : "Постоје дотоци са грешкама!",
    "Explore" : "Истражи",
    "Rename" : "Преименуј",
    "Delete" : "Обриши",
    "Rename Feed" : "Преименуј довод",
    "Open Feed URL" : "Отвори URL адресу наслова",
    "Unpin from top" : "Откачи са врха",
    "Pin to top" : "Закачи на врх",
    "Newest first" : "Прво новије",
    "Oldest first" : "Прво старије",
    "Default order" : "Подразумевани редослед",
    "Enable full text" : "Укључи цео текст",
    "Disable full text" : "Искључи цео текст",
    "Mark as unread on update" : "Означи као непрочитано приликом ажурирања",
    "Keep read status on update" : "Задржи статус читања приликом ажурирања",
    "Sync disabled" : "Синхронизација је искључена",
    "Sync enabled" : "Синхронизација је укључена",
    "from" : "од",
    "Previous Item" : "Претходна ставка",
    "Next Item" : "Наредна ставка",
    "Share within Instance" : "Дели унутар инстанце",
    "Toggle star article" : "Мења озвезданост чланка",
    "Mark unread" : "Означи као непрочитано",
    "Close details" : "Затвори детаље",
    "shared by" : "поделио",
    "by" : "од",
    "Play audio" : "Пусти аудио",
    "Download audio" : "Преузми аудио",
    "Download video" : "Преузми видео",
    "Refresh list" : "Освежи листу",
    "Open website" : "Отвори веб сајт",
    "Keep article unread" : "Остави чланак непрочитаним",
    "Toggle keep current article unread" : "Мења „остави тренутни чланак непрочитаним“",
    "Remove keep article unread" : "Уклони да остане непрочитан",
    "Default" : "Подразумевано",
    "Compact" : "Збијено",
    "Screenreader" : "Читач екрана",
    "Vertical" : "Вертикална",
    "Horizontal" : "Хоризонтална",
    "Off" : "Искључено",
    "Always" : "Увек",
    "Never" : "Никад",
    "Please select a valid OPML file" : "Молимо вас да изаберете исправан OPML фајл",
    "File successfully uploaded" : "Фајл је успешно отпремљен",
    "Error uploading the opml file" : "Грешка приликом отпремања opml фајла",
    "Error connecting to the server" : "Грешка приликом повезивања са сервером",
    "Error retrieving the opml file" : "Грешка при добављању opml фајла",
    "General" : "Опште",
    "Disable mark read through scrolling" : "Искључи „означи прочитаним при клизању“",
    "Reverse ordering (oldest on top)" : "Обрнуто ређање (најстарији на врху)",
    "Disable automatic refresh" : "Искључи аутоматско освежавање",
    "Media" : "Медији",
    "Appearance" : "Изглед",
    "Display mode" : "Режим приказа",
    "Split mode" : "Подељени режим",
    "Import" : "Увоз",
    "Export" : "Извези",
    "Abonnements (OPML)" : "Абонмани (OPML)",
    "Importing feeds" : "Увозе се новости",
    "Please wait" : "Сачекајте",
    "Keyboard shortcuts" : "Пречице тастатуре",
    "Refresh" : "Освежи",
    "Jump to previous article" : "Пређи на претходни чланак",
    "Jump to next article" : "Пређи на следећи чланак",
    "Open article in new tab" : "Отвори чланак у новом језичку",
    "Show article details in compact view" : "Прикажи чланак у компактном приказу",
    "Close article details in compact view" : "Затвори детаље чланка у компактном приказу",
    "Mark current articles feed/folder as read" : "Означи довод/фасциклу тренутног чланка као прочитан",
    "Resources" : "Ресурси",
    "Last update" : "Последње ажурирање",
    "Time when the feed was last downloaded" : "Време последњег преузимања дотока",
    "Next update" : "Наредно ажурирање",
    "Time when the next feed update will be done" : "Време када ће се извршити наредно ажурирање",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "Само ако је активирано у административним подешавањима, у супротном се користи уобичајен интервал ажурирања",
    "Articles per update" : "Чланака по ажурирању",
    "Maximum number of articles reached in a feed update" : "Максимални број чланака достигнут у ажурирању довода",
    "Error Count" : "Број грешака",
    "Number of errors that have occurred since the last successful feed update" : "Број грешака који се догодио након последњег успешног ажурирања довода",
    "Title" : "Наслов",
    "Folder" : "Фасцикла",
    "Not available" : "Није доступно",
    "All Articles" : "Сви чланци",
    "No feeds found to add" : "Није пронађен ниједан наслов који може да се дода",
    "Subscribe to" : "Претплати се на",
    "Unread Articles" : "Непрочитани чланци",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Детектован Ajax или webcron начин рада! Доводи неће бити ажурирани!",
    "How to set up the operating system cron" : "Како подестити крон оперативног система",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Инсталирајте и подесите брже паралелно ажурирање које користи API за ажурирање од ове апликације"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
