OC.L10N.register(
    "news",
    {
    "News" : "Berriak",
    "Someone" : "Norbait",
    "%1$s shared \"%2$s\" with you" : "%1$s(e)k \"%2$s\" partekatu du zurekin",
    "News feeds" : "Albiste jarioak",
    "Unread articles" : "Irakurri gabeko artikuluak",
    "News folders" : "Albiste karpetak",
    "News articles" : "Artikulu berriak",
    "Shared with me" : "Nirekin partekatuta",
    "An RSS/Atom feed reader" : "RSS/Atom jarioen irakurle bat",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 RSS/Atom Feed irakurgailu aplikazioa Nextcloud-entzat\n\n- 📲Sinkronizatu jarioak mugikorreko edo mahaigaineko [bezero](https://nextcloud.github.io/news/clients/) anitzekin \n- 🔄 Zure albisteen jarioen eguneratze automatikoak\n- 🆓 Kode irekia eta doakoa AGPLv3-pean, iragarkirik edo premium funtziorik gabe\n\n** Une honetan Cron beharrezkoa da aplikazio honek funtziona dezan **\n\nBaldintzak [hemen](https://nextcloud.github.io/news/install/#dependencies) aurki daitezke\n\nAldaketa-erregistroa eskuragarri dago [hemen](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nSortu [akatsen txostena](https://github.com/nextcloud/news/issues/new/choose)\n\nSortu [ezaugarri eskaera](https://github.com/nextcloud/news/discussions/new)\n\nEman [jarioaren arazo](https://github.com/nextcloud/news/discussions/new)-en berri",
    "Download" : "Deskargatu",
    "Close" : "Itxi",
    "Web address" : "Web helbidea",
    "No folder" : "Karpetarik ez",
    "Folder name" : "Karpetaren izena",
    "Username" : "Erabiltzaile-izena",
    "Password" : "Pasahitza",
    "Feed exists already!" : "Jarioa dagoeneko existitzen da!",
    "New folder" : "Karpeta berria",
    "Folder exists already!" : "Karpeta dagoeneko existitzen da!",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP Oinarrizko Autorizazio kredentzialak enkriptatu gabe gorde behar dira! Zerbitzarira edo datu-basera sarbidea duen edonork ikusi ahal izango ditu!",
    "Credentials" : "Kredentzialak",
    "Auto discover Feed" : "Aurkitu automatikoki jarioa",
    "Subscribe" : "Harpidetu",
    "Successfully updated news configuration" : "Berrien konfigurazioa ondo eguneratu da",
    "Unable to update news config" : "Ezin izan da berrien konfigurazioa eguneratu.",
    "Last job ran {relativeTime}." : "Azken lana {relativeTime}-n egin zen.",
    "Maximum read count per feed" : "Gehienezko irakurketa kopurua jarioko",
    "Maximum redirects" : "Gehienezko birbideratzeak",
    "Feed fetcher timeout" : "Jarioak hartzeko denbora-muga",
    "Explore Service URL" : "Arakatu zerbitzuaren URLa",
    "Update interval" : "Eguneraketa tartea",
    "Use system cron for updates" : "Erabili sistemaren cron-a eguneraketak egiteko",
    "Disable this if you use a custom updater." : "Desgaitu hau eguneratze pertsonalizatua erabiltzen baduzu.",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "Garbiketa lanak jario bakoitzean ezabatuko ez dituen artikuluen gehienezko kopurua zehazten du; artikulu zaharrak irakurri ondoren berriz agertzen hasten badira, handitu balio hau; -1 bezalako balio negatiboek ezaugarri hau desgaitzen dute.",
    "Delete unread articles automatically" : "Ezabatu irakurri gabeko artikuluak automatikoki",
    "Enable this if you also want to delete unread articles." : "Gaitu irakurri gabeko artikuluak ere ezabatu nahi badituzu.",
    "How many redirects the feed fetcher should follow." : "Jarioak eskuratzean zenbat birbideratze jarraituko diren.",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "RSS edo Atom jario bat kargatzeko gehienez itxarongo den segundo kopurua; gehiago luzatzen bada eguneraketa bertan behera utziko da.",
    "Interval in seconds in which the feeds will be updated." : "Jarioak zenbat segundoko tartean eguneratuko diren.",
    "Article list" : "Artikuluen zerrenda",
    "Article details" : "Artikuluaren xehetasunak",
    "No article selected" : "Ez da artikulurik hautatu",
    "Show all articles" : "Erakutsi artikulu guztiak",
    "Move" : "Mugitu",
    "User Name" : "Erabiltzaile izena",
    "Share" : "Partekatu",
    "Share with" : "Partekatu honekin",
    "Share with {num} users" : "Partekatu {num} erabiltzaileekin",
    "Rename Folder" : "Berrizendatu karpeta",
    "Are you sure you want to delete?" : "Ziur zaude ezabatu nahi duzula?",
    "Mark read" : "Markatu irakurrita",
    "All articles" : "Artikulu guztiak",
    "Starred" : "Izardunak",
    "Has feeds with errors!" : "Erroreak dituzten jarioak ditu!",
    "Explore" : "Arakatu",
    "Rename" : "Berrizendatu",
    "Delete" : "Ezabatu",
    "Rename Feed" : "Aldatu izena jarioari",
    "Open Feed URL" : "Ireki jarioaren URLa",
    "Unpin from top" : "Kendu aingura goitik",
    "Pin to top" : "Ainguratu goian",
    "Newest first" : "Berrienak lehenik",
    "Oldest first" : "Zaharrenak lehenik",
    "Default order" : "Lehenetsitako ordena",
    "Enable full text" : "Gaitu testu osoa",
    "Disable full text" : "Desgaitu testu osoa",
    "from" : "Jatorria:",
    "Share within Instance" : "Partekatu instantzian",
    "Toggle star article" : "Txandakatu artikuluaren izarra",
    "Mark unread" : "Markatu irakurri gabe bezala",
    "Close details" : "Itxi xehetasunak",
    "shared by" : "honek partekatua",
    "by" : " Egilea:",
    "Play audio" : "Erreproduzitu audioa",
    "Download audio" : "Deskargatu audioa",
    "Download video" : "Deskargatu bideoa",
    "Open website" : "Ireki webgunea",
    "Keep article unread" : "Mantendu artikulua irakurri gabea",
    "Toggle keep current article unread" : "Txandakatu mantendu uneko artikulua irakurri gabea",
    "Remove keep article unread" : "Ezabatu mantendu artikulua irakurri gabea",
    "Default" : "Lehenetsia",
    "Compact" : "Trinkotu",
    "Screenreader" : "Gidoilaria",
    "Vertical" : "Bertikala",
    "Horizontal" : "Horizontala",
    "Off" : "Off",
    "Always" : "Beti",
    "Never" : "Inoiz ez",
    "Please select a valid OPML file" : "Mesedez hautatu baliozko OPML fitxategi bat",
    "File successfully uploaded" : "Fitxategia ondo igo da",
    "Error uploading the opml file" : "Errorea opml fitxategia igotzen",
    "Error connecting to the server" : "Errorea zerbitzarira konektatzean",
    "Error retrieving the opml file" : "Errorea opml fitxategia lortzean",
    "General" : "Orokorra",
    "Disable mark read through scrolling" : "Desgaitu korritzean irakurrita markatzea",
    "Reverse ordering (oldest on top)" : "Alderantzizko ordena (zaharrenak goian)",
    "Disable automatic refresh" : "Desgaitu freskatze automatikoa",
    "Media" : "Media",
    "Appearance" : "Itxura",
    "Display mode" : "Erakuste-modua",
    "Split mode" : "Modu banatua",
    "Import" : "Inportatu",
    "Export" : "Esportatu",
    "Abonnements (OPML)" : "Abonamenduak (OPML)",
    "Please wait" : "Itxaron mesedez",
    "Keyboard shortcuts" : "Teklatuaren lasterbideak",
    "Refresh" : "Freskatu",
    "Jump to previous article" : "Joan aurreko artikulura",
    "Jump to next article" : "Joan hurrengo artikulura",
    "Open article in new tab" : "Ireki artikulua fitxa berri batean",
    "Show article details in compact view" : "Erakutsi artikuluaren xehetasunak ikuspegi trinkoan",
    "Close article details in compact view" : "Itxi artikuluaren xehetasunak ikuspegi trinkoan",
    "Mark current articles feed/folder as read" : "Markatu uneko artikuluen jarioa/karpeta irakurrita",
    "Resources" : "Baliabideak",
    "Last update" : "Azken eguneraketa",
    "Title" : "Izenburua",
    "Folder" : "Karpeta",
    "All Articles" : "Artikulu guztiak",
    "No feeds found to add" : "Ez da aurkitu jariorik gehitzeko",
    "Subscribe to" : "Harpidetu",
    "Unread Articles" : "Irakurri gabeko artikuluak",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "Ajax edo webcron modua detektatu da! Zure jarioak ez dira eguneratuko!",
    "How to set up the operating system cron" : "Nola konfiguratu sistema eragilearen cron-a",
    "Install and set up a faster parallel updater that uses the News app's update API" : "Instalatu eta konfiguratu Berriak aplikazioaren eguneraketa APIa erabiltzen duen eguneratzaile paralelo azkarrago bat"
},
"nplurals=2; plural=(n != 1);");
