OC.L10N.register(
    "news",
    {
    "News" : "新聞",
    "an article" : "一篇文章",
    "Someone" : "某人",
    "%1$s shared \"%2$s\" with you" : "%1$s 分享了 \"%2$s\" 給您",
    "{user} shared \"{article}\" with you" : "{user} 與您分享了「{article}」",
    "News feeds" : "新聞提要",
    "Unread articles" : "未讀文章",
    "News folders" : "新聞資料夾",
    "News articles" : "新聞文章",
    "Shared with me" : "與我分享",
    "Untitled article" : "未命名文章",
    "An RSS/Atom feed reader" : "RSS/Atom feed 閱讀程式",
    "📰 A RSS/Atom Feed reader App for Nextcloud\n\n- 📲 Synchronize your feeds with multiple mobile or desktop [clients](https://nextcloud.github.io/news/clients/)\n- 🔄 Automatic updates of your news feeds\n- 🆓 Free and open source under AGPLv3, no ads or premium functions\n\n**System Cron is currently required for this app to work**\n\nRequirements can be found [here](https://nextcloud.github.io/news/install/#dependencies)\n\nThe Changelog is available [here](https://github.com/nextcloud/news/blob/master/CHANGELOG.md)\n\nCreate a [bug report](https://github.com/nextcloud/news/issues/new/choose)\n\nCreate a [feature request](https://github.com/nextcloud/news/discussions/new)\n\nReport a [feed issue](https://github.com/nextcloud/news/discussions/new)" : "📰 Nextcloud 的 RSS/Atom Feed 閱讀器應用程式\n\n- 📲 讓您的 feed 在多個行動裝置與桌面[客戶端](https://nextcloud.github.io/news/clients/)間同步\n- 🔄 自動更新您的新聞 feed\n- 🆓 以 AGPLv3 授權的自由且開放原始碼軟體，無廣告或付費功能\n\n**此應用程式需要系統 Cron 才能正常運作**\n\n需求可以在［此處］找到（https://nextcloud.github.io/news/install/#dependencies）\n\nChangelog可在［此處］獲得（https://github.com/nextcloud/news/blob/master/CHANGELOG.md）\n\n創建一個［錯誤報告］（https://github.com/nextcloud/news/issues/new/choose）\n\n創建一個［功能請求］（https://github.com/nextcloud/news/discussions/new）\n\n報告［feed 問題］（https://github.com/nextcloud/news/discussions/new）",
    "Download" : "下載",
    "Close" : " 關閉",
    "Internal server error!" : "內部伺服器錯誤！",
    "Unknown error!" : "錯誤不詳！",
    "Web address" : "網址",
    "Please check your data/nextcloud.log file for additional information!" : "請檢查您的 data/nextcloud.log 檔案以取得額外資訊！",
    "No folder" : "無資料夾",
    "Folder name" : "資料夾名稱",
    "Username" : "用戶名稱",
    "Password" : "密碼",
    "Feed exists already!" : "Feed 已存在！",
    "New folder" : "新資料夾",
    "Folder exists already!" : "資料夾已經存在！",
    "HTTP Basic Auth credentials must be stored unencrypted! Everyone with access to the server or database will be able to access them!" : "HTTP 基本身分驗證必須未加密儲存！每個可以存取伺服緝獲數據庫的人都將可以存取它們！",
    "Credentials" : "身分驗證",
    "Auto discover Feed" : "自動發現摘要",
    "Subscribe" : "訂閱",
    "Successfully updated news configuration" : "成功更新新聞設定",
    "Unable to update news config" : "無法更新新聞設定",
    "Logo purge has never been run." : "標誌清除從未執行。",
    "Last logo purge ran {relativeLastLogoPurge}. Something is wrong." : "上次標誌清除執行於 {relativeLastLogoPurge}。似乎有點問題。",
    "Last logo purge job ran {relativeLastLogoPurge}." : "上次標誌清除作業執行於 {relativeLastLogoPurge}。",
    "No job execution data available. The cron job may not be running properly." : "沒有可用的作業執行數據。cron 作業可能並未正確執行。",
    "Last job execution ran {relativeTime}. Something is wrong." : "上次執行作業的時間是 {relativeTime}。似乎有些不對勁。",
    "Last job ran {relativeTime}." : "上次執行作業的時間是 {relativeTime}。",
    "Maximum read count per feed" : "每個 feed 的最大閱讀次數",
    "Maximum redirects" : "最大重新導向",
    "Feed fetcher timeout" : "Feed 擷取程式逾時",
    "Explore Service URL" : "探索服務 URL",
    "Update interval" : "更新間距",
    "Use system cron for updates" : "使用系統 cron 來更新",
    "Disable this if you use a custom updater." : "如果使用自訂更新程序，請停用此功能。",
    "Defines the maximum amount of articles that can be read per feed which will not be deleted by the cleanup job; if old articles reappear after being read, increase this value; negative values such as -1 will turn this feature off." : "定義每個 feed 可以讀取的最大文章數，清理作業不會刪除這些文章；如果舊文章在閱讀後又重新出現，請增加此值；負值（如 -1） 將會關閉此功能。",
    "Delete unread articles automatically" : "自動刪除未讀文章",
    "Enable this if you also want to delete unread articles." : "如果您還想刪除未讀的文章，請啟用此功能。",
    "How many redirects the feed fetcher should follow." : "Feed 擷取程式應遵循多少重新導向。",
    "Maximum number of seconds to wait for an RSS or Atom feed to load; if it takes longer the update will be aborted." : "等待 RSS 或 Atom feed 載入的最大秒數；如果花了更長的時間，更新將會被中止。",
    "If provided, the URL of this service will be queried to display the feeds in the explore feed section. To fall back to the built in explore service, leave this input empty." : "若提供，將查詢此服務的 URL 以在探索餵送部分顯示內容。若要使用內建的探索服務，請將此輸入留空。",
    "Interval in seconds in which the feeds will be updated." : "Feed 更新的時間間隔（以秒為單位）。",
    "Use next update time for feed updates" : "使用下次更新時間更新 feed",
    "Enable this to use the calculated next update time for feed updates. Disable to update feeds based solely on the update interval." : "啟用此項可使用計算出的下次更新時間更新 feed。停用則僅根據更新間隔更新 feed。",
    "Article list" : "文章清單",
    "Article details" : "文章細節",
    "No article selected" : "未選取文章",
    "Please select an article from the list." : "請從清單中選取文章。",
    "Show all articles" : "顯示全部文章",
    "Move feed" : "移動摘要",
    "Please select the new folder" : "請選取新資料夾",
    "Move" : "移動",
    "User Name" : "用戶名稱",
    "Share" : "分享",
    "Share with" : "分享與",
    "Share with {num} users" : "與 {num} 個用戶分享",
    "Rename Folder" : "重新命名資料夾",
    "Are you sure you want to delete?" : "您確定要刪除嗎？",
    "Unable to save starred open state" : "無法儲存已加星標項目的展開狀態",
    "Mark read" : "標為已讀",
    "All articles" : "所有文章",
    "Recently viewed" : "最近檢視",
    "Starred" : "星號",
    "Has feeds with errors!" : "新聞源有錯誤!",
    "Explore" : "探索",
    "Feed settings" : "訂閱來源設定",
    "News settings" : "新聞設定",
    "Rename" : "重新命名",
    "Delete" : "刪除",
    "Rename Feed" : "重新命名 Feed",
    "Open Feed URL" : "開啟 feed URL",
    "Unpin from top" : "取消置頂",
    "Pin to top" : "置頂",
    "Newest first" : "最新的放最前面",
    "Oldest first" : "最舊的放最前面",
    "Default order" : "默認排序",
    "Enable full text" : "啟用全文",
    "Disable full text" : "停用全文",
    "Mark as unread on update" : "更新時標記為未讀",
    "Keep read status on update" : "更新時維持已讀狀態",
    "Sync disabled" : "同步已停用",
    "Sync enabled" : "同步已啟用",
    "Show external media" : "顯示外部媒體",
    "from" : "由",
    "External media loaded from" : "外部媒體已從此處載入",
    "Previous Item" : "上一個項目",
    "Next Item" : "下一個項目",
    "Share within Instance" : "在實例內分享",
    "Toggle star article" : "切換文章星號",
    "Mark unread" : "標記為未讀",
    "Close details" : "關閉細節",
    "shared by" : "分享自",
    "by" : "由",
    "Play audio" : "播放音訊",
    "Download audio" : "下載音訊",
    "Download video" : "下載影片",
    "Refresh list" : "刷新清單",
    "Open website" : "開啟網站",
    "Keep article unread" : "維持未讀狀態",
    "Toggle keep current article unread" : "切換維持目前文章未讀",
    "Remove keep article unread" : "停止維持未讀狀態",
    "Default" : "默認",
    "Compact" : "簡潔",
    "Screenreader" : "螢幕閱讀程式",
    "Vertical" : "垂直",
    "Horizontal" : "水平",
    "Off" : "關閉",
    "Always" : "一律",
    "Ask" : "問",
    "Never" : "從不",
    "Please select a valid OPML file" : "請選取有效的 OPML 檔案",
    "File successfully uploaded" : "檔案已成功上傳",
    "Error uploading the opml file" : "上傳 opml 檔案時發生錯誤",
    "Error connecting to the server" : "連線至伺服器時發生錯誤",
    "Error retrieving the opml file" : "擷取 opml 檔案時發生錯誤",
    "Please select a valid json file" : "請選取有效的 JSON 檔案",
    "Error uploading the json file" : "上傳 JSON 檔案時發生錯誤",
    "Error retrieving the json file" : "擷取 JSON 檔案時發生錯誤",
    "General" : "一般",
    "Disable mark read through scrolling" : "停用捲動時標記已讀",
    "Reverse ordering (oldest on top)" : "反向排序（最舊的文章排在最上面）",
    "Disable automatic refresh" : "停用自動刷新",
    "Media" : "媒體",
    "Show enclosure images" : "顯示附件圖像",
    "Show images in the article text" : "於文章內顯示圖像",
    "Show iframes in the article text" : "於文章內顯示 iframes",
    "Appearance" : "外觀",
    "Display mode" : "顯示模式",
    "Split mode" : "分割模式",
    "Import" : "導入",
    "Export" : "導出",
    "Abonnements (OPML)" : "訂閱 (OPML)",
    "Importing feeds" : "正在導入 feeds",
    "Please wait" : "請稍候",
    "Articles (JSON)" : "文章 (JSON)",
    "Keyboard shortcuts" : "鍵盤快捷鍵",
    "Refresh" : "重新整理",
    "Screenreader mode only" : "僅限螢幕閱讀器模式",
    "Jump to previous article" : "跳到上篇文章",
    "Jump to next article" : "跳到下篇文章",
    "Item navigation and control" : "項目導覽及控制",
    "Open article in new tab" : "在新分頁開啟文章",
    "Show article details in compact view" : "在精簡模式中顯示文章細節",
    "Close article details in compact view" : "在精簡模式中關閉文章細節",
    "Feed/Folder navigation and control" : "訂閱來源／資料夾導覽及控制",
    "Jump to previous feed" : "跳至上一個訂閱來源",
    "Jump to next feed" : "跳至下一個訂閱來源",
    "Jump to previous folder" : "跳至上一個資料夾",
    "Jump to next folder" : "跳至下一個資料夾",
    "Mark current articles feed/folder as read" : "將目前文章的 feed 或資料夾標示為已讀",
    "Resources" : "資源",
    "Last update" : "上次更新",
    "Time when the feed was last downloaded" : "最後一次下載 feed 的時間",
    "Next update" : "下次更新",
    "Time when the next feed update will be done" : "下次更新 feed 的時間",
    "Only if activated in the admin settings, otherwise the regular update interval is used" : "僅當在管理員設定中啟用時運作，否則會使用一般更新間距",
    "Articles per update" : "每次更新的文章數",
    "Maximum number of articles reached in a feed update" : "在 feed 更新中已達到最大文章數量。",
    "Error Count" : "錯誤數",
    "Number of errors that have occurred since the last successful feed update" : "自上次 feed 成功更新後發生的錯誤次數",
    "Title" : "標題",
    "Folder" : "資料夾",
    "Not available" : "不可用",
    "All Articles" : "所有文章",
    "No feeds found to add" : "找不到要新增的 feed",
    "Subscribe to" : "訂閱",
    "Unread Articles" : "未讀文章",
    "Ajax or webcron mode detected! Your feeds will not be updated!" : "偵測到 Ajax 或 webcron！您的 feed 將無法更新！",
    "How to set up the operating system cron" : "如何設定作業系統 cron",
    "Install and set up a faster parallel updater that uses the News app's update API" : "安裝並設定新聞應用程式的更新 API 的較快平行更新程式"
},
"nplurals=1; plural=0;");
