OC.L10N.register(
    "news",
    {
    "Download" : "பதிவிறக்குக",
    "Close" : "மூடுக",
    "Web address" : "வலைய முகவரி",
    "Folder name" : "கோப்புறை பெயர்",
    "Username" : "பயனாளர் பெயர்",
    "Password" : "கடவுச்சொல்",
    "Credentials" : "சான்று ஆவணங்கள்",
    "Move" : "Move",
    "Share" : "பகிர்வு",
    "Rename" : "பெயர்மாற்றம்",
    "Delete" : "நீக்குக",
    "from" : "இலிருந்து",
    "by" : "மூலம்",
    "General" : "பொதுவான",
    "Import" : "இறக்குமதி",
    "Export" : "ஏற்றுமதி",
    "Keyboard shortcuts" : "விசைப்பலகை குறுக்குவழிகள்",
    "Refresh" : "மீள் ஏற்றுக",
    "Title" : "தலைப்பு",
    "Folder" : "கோப்புறை"
},
"nplurals=2; plural=(n != 1);");
